@@ -29,6 +29,7 @@ import threading
 import urllib2
 import pprint
 from random import randint
+import re
 from ambari_commons import subprocess32
 import functools
 
@@ -44,7 +45,8 @@ from ambari_agent.FileCache import FileCache
 from ambari_agent.NetUtil import NetUtil
 from ambari_agent.LiveStatus import LiveStatus
 from ambari_agent.AlertSchedulerHandler import AlertSchedulerHandler
-from ambari_agent.ClusterConfiguration import  ClusterConfiguration
+from ambari_agent.ClusterConfigurationCache import  ClusterConfigurationCache
+from ambari_agent.ClusterTopologyCache import ClusterTopologyCache
 from ambari_agent.RecoveryManager import  RecoveryManager
 from ambari_agent.HeartbeatHandlers import HeartbeatStopHandlers, bind_signal_handlers
 from ambari_agent.ExitHelper import ExitHelper
@@ -61,6 +63,9 @@ AGENT_RAM_OVERUSE_MESSAGE = "Ambari-agent RAM usage {used_ram} MB went above {co
 
 class Controller(threading.Thread):
 
+  EXECUTION_COMMANDS = 'executionCommands'
+  ALERT_DEFINITION_COMMANDS = 'alertDefinitionCommands'
+
   def __init__(self, config, server_hostname, heartbeat_stop_callback = None):
     threading.Thread.__init__(self)
     logger.debug('Initializing Controller RPC thread.')
@@ -107,7 +112,7 @@ class Controller(threading.Thread):
     extensions_cache_dir = os.path.join(cache_dir, FileCache.EXTENSIONS_CACHE_DIRECTORY)
     host_scripts_cache_dir = os.path.join(cache_dir, FileCache.HOST_SCRIPTS_CACHE_DIRECTORY)
     alerts_cache_dir = os.path.join(cache_dir, FileCache.ALERTS_CACHE_DIRECTORY)
-    cluster_config_cache_dir = os.path.join(cache_dir, FileCache.CLUSTER_CONFIGURATION_CACHE_DIRECTORY)
+    cluster_cache_dir = os.path.join(cache_dir, FileCache.CLUSTER_CACHE_DIRECTORY)
     recovery_cache_dir = os.path.join(cache_dir, FileCache.RECOVERY_CACHE_DIRECTORY)
 
     self.heartbeat_idle_interval_min = int(self.config.get('heartbeat', 'idle_interval_min')) if self.config.get('heartbeat', 'idle_interval_min') else self.netutil.HEARTBEAT_IDLE_INTERVAL_DEFAULT_MIN_SEC
@@ -123,7 +128,8 @@ class Controller(threading.Thread):
 
     self.recovery_manager = RecoveryManager(recovery_cache_dir)
 
-    self.cluster_configuration = ClusterConfiguration(cluster_config_cache_dir)
+    self.cluster_configuration_cache = ClusterConfigurationCache(cluster_cache_dir)
+    self.cluster_topology_cache = ClusterTopologyCache(cluster_cache_dir)
 
     self.move_data_dir_mount_file()
 
@@ -132,7 +138,7 @@ class Controller(threading.Thread):
 
     self.alert_scheduler_handler = AlertSchedulerHandler(alerts_cache_dir,
       stacks_cache_dir, common_services_cache_dir, extensions_cache_dir,
-      host_scripts_cache_dir, self.cluster_configuration, config,
+      host_scripts_cache_dir, self.cluster_configuration_cache, config,
       self.recovery_manager)
 
     self.alert_scheduler_handler.start()
@@ -163,18 +169,17 @@ class Controller(threading.Thread):
     while not self.isRegistered:
       try:
         data = json.dumps(self.register.build(self.version))
-        prettyData = pprint.pformat(data)
-
         try:
           server_ip = socket.gethostbyname(self.hostname)
-          logger.info("Registering with %s (%s) (agent=%s)", self.hostname, server_ip, prettyData)
+          logger.info("Registering with %s (%s) (agent=%s)", self.hostname, server_ip, data)
         except socket.error:
           logger.warn("Unable to determine the IP address of '%s', agent registration may fail (agent=%s)",
-                      self.hostname, prettyData)
+                      self.hostname, data)
 
         ret = self.sendRequest(self.registerUrl, data)
-        prettyData = pprint.pformat(ret)
-        logger.debug("Registration response is %s", prettyData)
+
+        if logger.isEnabledFor(logging.DEBUG):
+          logger.debug("Registration response is %s", pprint.pformat(ret))
 
         # exitstatus is a code of error which was raised on server side.
         # exitstatus = 0 (OK - Default)
@@ -199,10 +204,10 @@ class Controller(threading.Thread):
 
         # always update cached cluster configurations on registration
         # must be prior to any other operation
-        self.cluster_configuration.update_configurations_from_heartbeat(ret)
+        self.update_caches_from_heartbeat(ret)
         self.recovery_manager.update_configuration_from_registration(ret)
         self.config.update_configuration_from_registration(ret)
-        logger.debug("Updated config:" + str(self.config))
+        logger.debug("Updated config: %s", self.config)
 
         # Start StatusCommandExecutor child process or restart it if already running
         # in order to receive up to date agent config.
@@ -230,6 +235,35 @@ class Controller(threading.Thread):
 
     return ret
 
+  def update_caches_from_heartbeat(self, heartbeat):
+    heartbeat_keys = heartbeat.keys()
+
+    if self.EXECUTION_COMMANDS in heartbeat_keys:
+      execution_commands = heartbeat[self.EXECUTION_COMMANDS]
+      for command in execution_commands:
+        if 'clusterName' in command and 'configurations' in command:
+          cluster_name = command['clusterName']
+          configurations = command['configurations']
+          topology = command['clusterHostInfo']
+          self.cluster_configuration_cache.update_cluster_cache(cluster_name, configurations)
+          self.cluster_topology_cache.update_cluster_cache(cluster_name, topology)
+
+          # TODO: use this once server part is ready.
+          self.cluster_topology_cache.get_md5_hashsum(cluster_name)
+          self.cluster_configuration_cache.get_md5_hashsum(cluster_name)
+
+
+    if self.ALERT_DEFINITION_COMMANDS in heartbeat_keys:
+      alert_definition_commands = heartbeat[self.ALERT_DEFINITION_COMMANDS]
+      for command in alert_definition_commands:
+        if 'clusterName' in command and 'configurations' in command:
+          cluster_name = command['clusterName']
+          configurations = command['configurations']
+          self.cluster_configuration_cache.update_cluster_cache(cluster_name, configurations)
+
+          # TODO: use this once server part is ready.
+          self.cluster_configuration_cache.get_md5_hashsum(cluster_name)
+
   def cancelCommandInQueue(self, commands):
     """ Remove from the queue commands, kill the process if it's in progress """
     if commands:
@@ -378,7 +412,7 @@ class Controller(threading.Thread):
         # if the response contains configurations, update the in-memory and
         # disk-based configuration cache (execution and alert commands have this)
         logger.log(logging_level, "Updating configurations from heartbeat")
-        self.cluster_configuration.update_configurations_from_heartbeat(response)
+        self.update_caches_from_heartbeat(response)
 
         response_keys = response.keys()
 
@@ -418,7 +452,7 @@ class Controller(threading.Thread):
           logger.log(logging_level, "Executing alert commands")
           self.alert_scheduler_handler.execute_alert(response['alertExecutionCommands'])
 
-        if "true" == response['restartAgent']:
+        if response['restartAgent']:
           logger.error("Received the restartAgent command")
           self.restartAgent()
         else:
@@ -492,10 +526,10 @@ class Controller(threading.Thread):
       self.actionQueue.start()
       self.register = Register(self.config)
       self.heartbeat = Heartbeat(self.actionQueue, self.config, self.alert_scheduler_handler.collector())
- 
+
       opener = urllib2.build_opener()
       urllib2.install_opener(opener)
- 
+
       while True:
         self.repeatRegistration = False
         self.registerAndHeartbeat()
@@ -556,11 +590,11 @@ class Controller(threading.Thread):
     if LiveStatus.SERVICES:
       return
 
-    logger.debug("Updating components map of cluster " + cluster_name)
+    logger.debug("Updating components map of cluster %s", cluster_name)
 
     # May throw IOError on server connection error
     response = self.sendRequest(self.componentsUrl + cluster_name, None)
-    logger.debug("Response from %s was %s", self.serverHostname, str(response))
+    logger.debug("Response from %s was %s", self.serverHostname, response)
 
     services, client_components, server_components = [], [], []
     for service, components in response['components'].items():
@@ -577,9 +611,9 @@ class Controller(threading.Thread):
     LiveStatus.COMPONENTS = server_components
 
     logger.debug("Components map updated")
-    logger.debug("LiveStatus.SERVICES" + str(LiveStatus.SERVICES))
-    logger.debug("LiveStatus.CLIENT_COMPONENTS" + str(LiveStatus.CLIENT_COMPONENTS))
-    logger.debug("LiveStatus.COMPONENTS" + str(LiveStatus.COMPONENTS))
+    logger.debug("LiveStatus.SERVICES %s", LiveStatus.SERVICES)
+    logger.debug("LiveStatus.CLIENT_COMPONENTS %s", LiveStatus.CLIENT_COMPONENTS)
+    logger.debug("LiveStatus.COMPONENTS %s", LiveStatus.COMPONENTS)
 
   def get_status_commands_executor(self):
     return self.statusCommandsExecutor
@@ -591,7 +625,9 @@ class Controller(threading.Thread):
     Stack Upgrade.
     """
     try:
-      if compare_versions(self.version, "2.1.2") >= 0:
+      version = self.get_version()
+      logger.debug("Ambari Agent version {0}".format(version))
+      if compare_versions(version, "2.1.2") >= 0:
         source_file = "/etc/hadoop/conf/dfs_data_dir_mount.hist"
         destination_file = "/var/lib/ambari-agent/data/datanode/dfs_data_dir_mount.hist"
         if os.path.exists(source_file) and not os.path.exists(destination_file):
@@ -605,9 +641,16 @@ class Controller(threading.Thread):
           return_code = subprocess32.call(command, shell=True)
           logger.info("Return code: %d" % return_code)
     except Exception, e:
-      logger.info("Exception in move_data_dir_mount_file(). Error: {0}".format(str(e)))
-
+      logger.error("Exception in move_data_dir_mount_file(). Error: {0}".format(str(e)))
 
+  def get_version(self):
+    version = self.version
+    matches = re.findall(r"[\d+.]+",version)
+    if not matches:
+      logger.warning("No version match result, use original version {0}".format(version))
+      return version
+    else:
+      return matches[0]
 
 def main(argv=None):
   # Allow Ctrl-C
