@@ -25,13 +25,16 @@ _all__ = ["Repository"]
 from resource_management.core.base import Resource, ForcedListArgument, ResourceArgument, BooleanArgument
 
 class Repository(Resource):
-  action = ForcedListArgument(default="create")
+  action = ForcedListArgument(default="prepare")
   repo_id = ResourceArgument(default=lambda obj: obj.name)
   base_url = ResourceArgument()
   mirror_list = ResourceArgument()
   repo_file_name = ResourceArgument()
   repo_template = ResourceArgument()
-  append_to_file = ResourceArgument(default=False)
   components = ForcedListArgument(default=[]) # ubuntu specific
 
-  actions = Resource.actions + ["create","remove"]
\ No newline at end of file
+  """
+  'prepare' action only adds repositories information into memory.
+  'create' action writes prepared repositories into file (possibly multiple repos into single file)
+  """
+  actions = Resource.actions + ["prepare", "create","remove"]
\ No newline at end of file
