@@ -19,6 +19,8 @@ package org.apache.hadoop.metrics2.sink.timeline;
 
 import com.google.common.base.Supplier;
 import com.google.common.base.Suppliers;
+import com.google.common.cache.Cache;
+import com.google.common.cache.CacheBuilder;
 import com.google.common.reflect.TypeToken;
 import com.google.gson.Gson;
 import com.google.gson.JsonSyntaxException;
@@ -58,6 +60,7 @@ import java.util.List;
 import java.util.Random;
 import java.util.Set;
 import java.util.SortedSet;
+import java.util.TreeMap;
 import java.util.TreeSet;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
@@ -79,6 +82,9 @@ public abstract class AbstractTimelineMetricsSink {
   public static final String SSL_KEYSTORE_PATH_PROPERTY = "truststore.path";
   public static final String SSL_KEYSTORE_TYPE_PROPERTY = "truststore.type";
   public static final String SSL_KEYSTORE_PASSWORD_PROPERTY = "truststore.password";
+  public static final String HOST_IN_MEMORY_AGGREGATION_ENABLED_PROPERTY = "host_in_memory_aggregation";
+  public static final String HOST_IN_MEMORY_AGGREGATION_PORT_PROPERTY = "host_in_memory_aggregation_port";
+  public static final String HOST_IN_MEMORY_AGGREGATION_PROTOCOL_PROPERTY = "host_in_memory_aggregation_protocol";
   public static final String COLLECTOR_LIVE_NODES_PATH = "/ws/v1/timeline/metrics/livenodes";
   public static final String INSTANCE_ID_PROPERTY = "instanceId";
   public static final String SET_INSTANCE_ID_PROPERTY = "set.instanceId";
@@ -86,7 +92,7 @@ public abstract class AbstractTimelineMetricsSink {
   private static final String WWW_AUTHENTICATE = "WWW-Authenticate";
   private static final String NEGOTIATE = "Negotiate";
 
-  protected static final AtomicInteger failedCollectorConnectionsCounter = new AtomicInteger(0);
+  protected final AtomicInteger failedCollectorConnectionsCounter = new AtomicInteger(0);
   public static int NUMBER_OF_SKIPPED_COLLECTOR_EXCEPTIONS = 100;
   protected static final AtomicInteger nullCollectorCounter = new AtomicInteger(0);
   public static int NUMBER_OF_NULL_COLLECTOR_EXCEPTIONS = 20;
@@ -113,12 +119,14 @@ public abstract class AbstractTimelineMetricsSink {
   // well as timed refresh
   protected Supplier<String> targetCollectorHostSupplier;
 
+  private final CollectorShardSupplier collectorShardSupplier = new CollectorShardSupplier();
+
   protected final SortedSet<String> allKnownLiveCollectors = new TreeSet<>();
 
   private volatile boolean isInitializedForHA = false;
 
   @SuppressWarnings("all")
-  private final int RETRY_COUNT_BEFORE_COLLECTOR_FAILOVER = 5;
+  private final int RETRY_COUNT_BEFORE_COLLECTOR_FAILOVER = 3;
 
   private final Gson gson = new Gson();
 
@@ -127,6 +135,13 @@ public abstract class AbstractTimelineMetricsSink {
   private static final int COLLECTOR_HOST_CACHE_MAX_EXPIRATION_MINUTES = 75;
   private static final int COLLECTOR_HOST_CACHE_MIN_EXPIRATION_MINUTES = 60;
 
+  //10 seconds
+  protected int collectionPeriodMillis = 10000;
+
+  private int cacheExpireTimeMinutesDefault = 10;
+
+  private volatile Cache<String, TimelineMetric> metricsPostCache = CacheBuilder.newBuilder().expireAfterAccess(cacheExpireTimeMinutesDefault, TimeUnit.MINUTES).build();
+
   static {
     mapper = new ObjectMapper();
     AnnotationIntrospector introspector = new JaxbAnnotationIntrospector();
@@ -135,6 +150,20 @@ public abstract class AbstractTimelineMetricsSink {
       .withSerializationInclusion(JsonSerialize.Inclusion.NON_NULL);
   }
 
+  private final class CollectorShardSupplier implements Supplier<String> {
+    @Override
+    public String get() {
+      //shardExpired flag is used to determine if the Supplier.get() is invoked through the
+      // findPreferredCollectHost method (No need to refresh collector hosts)
+      // OR
+      // through Expiry (Refresh needed to pick up dead collectors that might have not become alive).
+      if (shardExpired) {
+        refreshCollectorsFromConfigured(getConfiguredCollectorHosts());
+      }
+      return metricSinkWriteShardStrategy.findCollectorShard(new ArrayList<>(allKnownLiveCollectors));
+    }
+  }
+
   public AbstractTimelineMetricsSink() {
     LOG = LogFactory.getLog(this.getClass());
   }
@@ -259,18 +288,22 @@ public abstract class AbstractTimelineMetricsSink {
 
   protected String getCurrentCollectorHost() {
     String collectorHost;
-    // Get cached target
-    if (targetCollectorHostSupplier != null) {
-      collectorHost = targetCollectorHostSupplier.get();
-      // Last X attempts have failed - force refresh
-      if (failedCollectorConnectionsCounter.get() > RETRY_COUNT_BEFORE_COLLECTOR_FAILOVER) {
-        LOG.debug("Removing collector " + collectorHost + " from allKnownLiveCollectors.");
-        allKnownLiveCollectors.remove(collectorHost);
-        targetCollectorHostSupplier = null;
+    /* Using collectorShardSupplier as sync_object since the Supplier.get() is using the same
+       object under the hood to provide thread safety. */
+    synchronized (collectorShardSupplier) {
+      // Get cached target
+      if (targetCollectorHostSupplier != null) {
+        collectorHost = targetCollectorHostSupplier.get();
+        // Last X attempts have failed - force refresh
+        if (failedCollectorConnectionsCounter.get() > RETRY_COUNT_BEFORE_COLLECTOR_FAILOVER) {
+          LOG.debug("Removing collector " + collectorHost + " from allKnownLiveCollectors.");
+          allKnownLiveCollectors.remove(collectorHost);
+          targetCollectorHostSupplier = null;
+          collectorHost = findPreferredCollectHost();
+        }
+      } else {
         collectorHost = findPreferredCollectHost();
       }
-    } else {
-      collectorHost = findPreferredCollectHost();
     }
 
     if (collectorHost == null) {
@@ -286,14 +319,52 @@ public abstract class AbstractTimelineMetricsSink {
     return collectorHost;
   }
 
+  /**
+   * @param metrics metrics to post, metric values will be aligned by minute mark,
+   *                last uncompleted minute will be cached to post in future iteration
+   */
   protected boolean emitMetrics(TimelineMetrics metrics) {
-    String collectorHost = getCurrentCollectorHost();
-    if (collectorHost != null) {
-      String connectUrl = getCollectorUri(collectorHost);
+    return emitMetrics(metrics, false);
+  }
+
+  /**
+   * @param metrics metrics to post, if postAllCachedMetrics is false metric values will be aligned by minute mark,
+   *                last uncompleted minute will be cached to post in future iteration
+   * @param postAllCachedMetrics if set to true all cached metrics will be posted, ignoring the minute aligning
+   * @return
+   */
+  protected boolean emitMetrics(TimelineMetrics metrics, boolean postAllCachedMetrics) {
+    String connectUrl;
+    boolean validCollectorHost = true;
+
+    if (isHostInMemoryAggregationEnabled()) {
+      String hostname = "localhost";
+      if (getHostInMemoryAggregationProtocol().equalsIgnoreCase("https")) {
+        hostname = getHostname();
+      }
+      connectUrl = constructTimelineMetricUri(getHostInMemoryAggregationProtocol(), hostname, String.valueOf(getHostInMemoryAggregationPort()));
+    } else {
+      String collectorHost  = getCurrentCollectorHost();
+      if (collectorHost == null) {
+        validCollectorHost = false;
+      }
+      connectUrl = getCollectorUri(collectorHost);
+    }
+
+    TimelineMetrics metricsToEmit = alignMetricsByMinuteMark(metrics);
+
+    if (postAllCachedMetrics) {
+      for (TimelineMetric timelineMetric : metricsPostCache.asMap().values()) {
+        metricsToEmit.addOrMergeTimelineMetric(timelineMetric);
+      }
+      metricsPostCache.invalidateAll();
+    }
+
+    if (validCollectorHost) {
       String jsonData = null;
       LOG.debug("EmitMetrics connectUrl = "  + connectUrl);
       try {
-        jsonData = mapper.writeValueAsString(metrics);
+        jsonData = mapper.writeValueAsString(metricsToEmit);
       } catch (IOException e) {
         LOG.error("Unable to parse metrics", e);
       }
@@ -309,11 +380,70 @@ public abstract class AbstractTimelineMetricsSink {
    *
    * @return the app cookie manager
    */
-  public synchronized AppCookieManager getAppCookieManager() {
-    if (appCookieManager == null) {
-      appCookieManager = new AppCookieManager();
+  public AppCookieManager getAppCookieManager() {
+    /* Using collectorShardSupplier as sync_object since the Supplier.get() is using the same
+       object under the hood to provide thread safety. */
+    synchronized (collectorShardSupplier) {
+      if (appCookieManager == null) {
+        appCookieManager = new AppCookieManager();
+      }
+      return appCookieManager;
     }
-    return appCookieManager;
+  }
+
+  /**
+   * Align metrics by the minutes so that only complete minutes are send.
+   * Not completed minutes data points will be cached and posted when the minute will be completed.
+   * Cached metrics are merged with currently posting metrics
+   * e.g:
+   * first iteration if metrics from 00m15s to 01m15s are processed,
+   *               then metrics from 00m15s to 00m59s will be posted
+   *                        and from 01m00s to 01m15s will be cached
+   * second iteration   metrics from 01m25s to 02m55s are processed,
+   *     cached metrics from previous call will be merged with current,
+   *                    metrics from 01m00s to 02m55s will be posted, cache will be empty
+   * @param metrics
+   * @return
+   */
+  protected TimelineMetrics alignMetricsByMinuteMark(TimelineMetrics metrics) {
+    TimelineMetrics allMetricsToPost = new TimelineMetrics();
+
+    for (TimelineMetric metric : metrics.getMetrics()) {
+      TimelineMetric cachedMetric = metricsPostCache.getIfPresent(metric.getMetricName());
+      if (cachedMetric != null) {
+        metric.addMetricValues(cachedMetric.getMetricValues());
+        metricsPostCache.invalidate(metric.getMetricName());
+      }
+    }
+
+    for (TimelineMetric metric : metrics.getMetrics()) {
+      TreeMap<Long, Double> valuesToCache = new TreeMap<>();
+      TreeMap<Long, Double> valuesToPost = metric.getMetricValues();
+
+      // in case there can't be any more datapoints in last minute just post the metrics,
+      // otherwise need to cut off and cache the last uncompleted minute
+      if (!(valuesToPost.lastKey() % 60000 > 60000 - collectionPeriodMillis)) {
+        Long lastMinute = valuesToPost.lastKey() / 60000;
+        while (!valuesToPost.isEmpty() && valuesToPost.lastKey() / 60000 == lastMinute) {
+          valuesToCache.put(valuesToPost.lastKey(), valuesToPost.get(valuesToPost.lastKey()));
+          valuesToPost.remove(valuesToPost.lastKey());
+        }
+      }
+
+      if (!valuesToCache.isEmpty()) {
+        TimelineMetric metricToCache = new TimelineMetric(metric);
+        metricToCache.setMetricValues(valuesToCache);
+        metricsPostCache.put(metricToCache.getMetricName(), metricToCache);
+      }
+
+      if (!valuesToPost.isEmpty()) {
+        TimelineMetric metricToPost = new TimelineMetric(metric);
+        metricToPost.setMetricValues(valuesToPost);
+        allMetricsToPost.addOrMergeTimelineMetric(metricToPost);
+      }
+    }
+
+    return allMetricsToPost;
   }
 
   /**
@@ -407,72 +537,59 @@ public abstract class AbstractTimelineMetricsSink {
    *
    * @return String Collector hostname
    */
-  protected synchronized String findPreferredCollectHost() {
-    if (!isInitializedForHA) {
-      init();
-    }
-
-    shardExpired = false;
-    // Auto expire and re-calculate after 1 hour
-    if (targetCollectorHostSupplier != null) {
-      String targetCollector = targetCollectorHostSupplier.get();
-      if (targetCollector != null) {
-        return targetCollector;
+  protected String findPreferredCollectHost() {
+    /* Using collectorShardSupplier as sync_object since the Supplier.get() is using the same
+       object under the hood to provide thread safety. */
+    synchronized (collectorShardSupplier) {
+      if (!isInitializedForHA) {
+        init();
       }
-    }
 
-    // Reach out to all configured collectors before Zookeeper
-    Collection<String> collectorHosts = getConfiguredCollectorHosts();
-    refreshCollectorsFromConfigured(collectorHosts);
-
-    // Lookup Zookeeper for live hosts - max 10 seconds wait time
-    long currentTime = System.currentTimeMillis();
-    if (allKnownLiveCollectors.size() == 0 && getZookeeperQuorum() != null
-      && (currentTime - lastFailedZkRequestTime) > zookeeperBackoffTimeMillis) {
-
-      LOG.debug("No live collectors from configuration. Requesting zookeeper...");
-      allKnownLiveCollectors.addAll(collectorHAHelper.findLiveCollectorHostsFromZNode());
-      boolean noNewCollectorFromZk = true;
-      for (String collectorHostFromZk : allKnownLiveCollectors) {
-        if (!collectorHosts.contains(collectorHostFromZk)) {
-          noNewCollectorFromZk = false;
-          break;
+      shardExpired = false;
+      // Auto expire and re-calculate after 1 hour
+      if (targetCollectorHostSupplier != null) {
+        String targetCollector = targetCollectorHostSupplier.get();
+        if (targetCollector != null) {
+          return targetCollector;
         }
       }
-      if (noNewCollectorFromZk) {
-        LOG.debug("No new collector was found from Zookeeper. Will not request zookeeper for " + zookeeperBackoffTimeMillis + " millis");
-        lastFailedZkRequestTime = System.currentTimeMillis();
-      }
-    }
 
-    if (allKnownLiveCollectors.size() != 0) {
-      targetCollectorHostSupplier = Suppliers.memoizeWithExpiration(
-        new Supplier<String>() {
-          @Override
-          public String get() {
-            //shardExpired flag is used to determine if the Supplier.get() is invoked through the
-            // findPreferredCollectHost method (No need to refresh collector hosts
-            // OR
-            // through Expiry (Refresh needed to pick up dead collectors that might have not become alive).
-            if (shardExpired) {
-              refreshCollectorsFromConfigured(getConfiguredCollectorHosts());
-            }
-            return metricSinkWriteShardStrategy.findCollectorShard(new ArrayList<>(allKnownLiveCollectors));
+      // Reach out to all configured collectors before Zookeeper
+      Collection<String> collectorHosts = getConfiguredCollectorHosts();
+      refreshCollectorsFromConfigured(collectorHosts);
+
+      // Lookup Zookeeper for live hosts - max 10 seconds wait time
+      long currentTime = System.currentTimeMillis();
+      if (allKnownLiveCollectors.size() == 0 && getZookeeperQuorum() != null
+              && (currentTime - lastFailedZkRequestTime) > zookeeperBackoffTimeMillis) {
+
+        LOG.debug("No live collectors from configuration. Requesting zookeeper...");
+        allKnownLiveCollectors.addAll(collectorHAHelper.findLiveCollectorHostsFromZNode());
+        boolean noNewCollectorFromZk = true;
+        for (String collectorHostFromZk : allKnownLiveCollectors) {
+          if (!collectorHosts.contains(collectorHostFromZk)) {
+            noNewCollectorFromZk = false;
+            break;
           }
-        },  // random.nextInt(max - min + 1) + min # (60 to 75 minutes)
-        rand.nextInt(COLLECTOR_HOST_CACHE_MAX_EXPIRATION_MINUTES
-          - COLLECTOR_HOST_CACHE_MIN_EXPIRATION_MINUTES + 1)
-          + COLLECTOR_HOST_CACHE_MIN_EXPIRATION_MINUTES,
-        TimeUnit.MINUTES
-      );
+        }
+        if (noNewCollectorFromZk) {
+          LOG.debug("No new collector was found from Zookeeper. Will not request zookeeper for " + zookeeperBackoffTimeMillis + " millis");
+          lastFailedZkRequestTime = System.currentTimeMillis();
+        }
+      }
 
-      String collectorHost = targetCollectorHostSupplier.get();
+      if (allKnownLiveCollectors.size() != 0) {
+        SupplierExpiry expiry = getSupplierExpiry();
+        targetCollectorHostSupplier = Suppliers.memoizeWithExpiration(collectorShardSupplier, expiry.duration, expiry.timeUnit);
+
+        String collectorHost = targetCollectorHostSupplier.get();
+        shardExpired = true;
+        return collectorHost;
+      }
+      LOG.debug("Couldn't find any live collectors. Returning null");
       shardExpired = true;
-      return collectorHost;
+      return null;
     }
-    LOG.debug("Couldn't find any live collectors. Returning null");
-    shardExpired = true;
-    return null;
   }
 
   private void refreshCollectorsFromConfigured(Collection<String> collectorHosts) {
@@ -485,14 +602,12 @@ public abstract class AbstractTimelineMetricsSink {
           try {
             Collection<String> liveHosts = findLiveCollectorHostsFromKnownCollector(hostStr, getCollectorPort());
             // Update live Hosts - current host will already be a part of this
-            for (String host : liveHosts) {
-              allKnownLiveCollectors.add(host);
-            }
+            allKnownLiveCollectors.addAll(liveHosts);
             break; // Found at least 1 live collector
           } catch (MetricCollectorUnavailableException e) {
             LOG.debug("Collector " + hostStr + " is not longer live. Removing " +
               "it from list of know live collector hosts : " + allKnownLiveCollectors);
-            allKnownLiveCollectors.remove(hostStr);
+            boolean res = allKnownLiveCollectors.remove(hostStr);
           }
         }
       }
@@ -520,18 +635,27 @@ public abstract class AbstractTimelineMetricsSink {
       connection.setReadTimeout(2000);
 
       int responseCode = connection.getResponseCode();
-      if (responseCode == 200) {
-        try (InputStream in = connection.getInputStream()) {
-          StringWriter writer = new StringWriter();
-          IOUtils.copy(in, writer);
-          try {
-            collectors = gson.fromJson(writer.toString(), new TypeToken<List<String>>(){}.getType());
-          } catch (JsonSyntaxException jse) {
-            // Swallow this at the behest of still trying to POST
-            LOG.debug("Exception deserializing the json data on live " +
-              "collector nodes.", jse);
+
+      switch (responseCode) {
+        case 200 :
+          try (InputStream in = connection.getInputStream()) {
+            StringWriter writer = new StringWriter();
+            IOUtils.copy(in, writer);
+            try {
+              collectors = gson.fromJson(writer.toString(), new TypeToken<List<String>>(){}.getType());
+            } catch (JsonSyntaxException jse) {
+              // Swallow this at the behest of still trying to POST
+              LOG.debug("Exception deserializing the json data on live " +
+                      "collector nodes.", jse);
+            }
           }
-        }
+          break;
+        case 500 :
+          String warnMsg = "Unable to connect to collector to find live nodes, Internal server error";
+          throw new MetricCollectorUnavailableException(warnMsg);
+        default :
+          String msg = String.format("Unhandled response code (%d) at requesting live collector nodes!", responseCode);
+          LOG.warn(msg);
       }
 
     } catch (IOException ioe) {
@@ -591,6 +715,28 @@ public abstract class AbstractTimelineMetricsSink {
       rand.nextInt(zookeeperMaxBackoffTimeMins - zookeeperMinBackoffTimeMins + 1)) * 60*1000l;
   }
 
+  //for now it's used only for testing
+  protected Cache<String, TimelineMetric> getMetricsPostCache() {
+    return metricsPostCache;
+  }
+
+  class SupplierExpiry {
+    final long duration;
+    final TimeUnit timeUnit;
+
+    public SupplierExpiry(long duration, TimeUnit timeUnit) {
+      this.duration = duration;
+      this.timeUnit = timeUnit;
+    }
+  }
+  protected SupplierExpiry getSupplierExpiry() {
+    // random.nextInt(max - min + 1) + min # (60 to 75 minutes)
+    long duration = rand.nextInt(COLLECTOR_HOST_CACHE_MAX_EXPIRATION_MINUTES
+            - COLLECTOR_HOST_CACHE_MIN_EXPIRATION_MINUTES + 1)
+            + COLLECTOR_HOST_CACHE_MIN_EXPIRATION_MINUTES;
+    return new SupplierExpiry(duration, TimeUnit.MINUTES);
+  }
+
   /**
    * Get a pre-formatted URI for the collector
    */
@@ -622,4 +768,22 @@ public abstract class AbstractTimelineMetricsSink {
    * @return String "host1"
    */
   abstract protected String getHostname();
+
+  /**
+   * Check if host in-memory aggregation is enabled
+   * @return
+   */
+  abstract protected boolean isHostInMemoryAggregationEnabled();
+
+  /**
+   * In memory aggregation port
+   * @return
+   */
+  abstract protected int getHostInMemoryAggregationPort();
+
+  /**
+   * In memory aggregation protocol
+   * @return
+   */
+  abstract protected String getHostInMemoryAggregationProtocol();
 }
