@@ -422,6 +422,27 @@ public class TimelineMetricMetadataManager {
     }
   }
 
+  /**
+   * Add uuid to metrics metadata mapping.
+   *
+   * @param uuid        metrics uuid
+   * @param metadataKey metrics metadata key
+   */
+  public void addMetricsInUuidMap(byte[] uuid, TimelineMetricMetadataKey metadataKey) {
+    uuidKeyMap.put(new TimelineMetricUuid(uuid), metadataKey);
+  }
+
+  /**
+   * Add host with uuid into uuidHostMap
+   *
+   * @param hostName       host name
+   * @param tmHostMetadata TimelineMetricHostMetadata
+   */
+  public void addHostInUuidHostMap(String hostName, TimelineMetricHostMetadata tmHostMetadata) {
+    TimelineMetricUuid timelineMetricUuid = new TimelineMetricUuid(tmHostMetadata.getUuid());
+    uuidHostMap.put(timelineMetricUuid, hostName);
+  }
+
   /**
    * Returns the UUID gen strategy.
    * @param configuration the config
