@@ -28,12 +28,15 @@ import org.apache.ambari.annotations.Experimental;
 import org.apache.ambari.annotations.ExperimentalFeature;
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.RoleCommand;
+import org.apache.ambari.server.actionmanager.ExecutionCommandWrapper;
 import org.apache.ambari.server.state.Cluster;
 import org.apache.ambari.server.state.UpgradeContext.UpgradeSummary;
 import org.apache.ambari.server.utils.StageUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.fasterxml.jackson.annotation.JsonIgnore;
+import com.fasterxml.jackson.annotation.JsonInclude;
 import com.google.gson.annotations.SerializedName;
 
 
@@ -41,6 +44,7 @@ import com.google.gson.annotations.SerializedName;
  * Execution commands are scheduled by action manager, and these are
  * persisted in the database for recovery.
  */
+@JsonInclude(JsonInclude.Include.NON_EMPTY)
 public class ExecutionCommand extends AgentCommand {
 
   private static final Logger LOG = LoggerFactory.getLogger(ExecutionCommand.class);
@@ -49,74 +53,103 @@ public class ExecutionCommand extends AgentCommand {
     super(AgentCommandType.EXECUTION_COMMAND);
   }
 
+  @com.fasterxml.jackson.annotation.JsonProperty("clusterId")
+  private String clusterId;
+
   @SerializedName("clusterName")
+  @com.fasterxml.jackson.annotation.JsonProperty("clusterName")
   private String clusterName;
 
   @SerializedName("requestId")
+  @com.fasterxml.jackson.annotation.JsonProperty("requestId")
   private long requestId;
 
   @SerializedName("stageId")
+  @JsonIgnore
   private long stageId;
 
   @SerializedName("taskId")
+  @com.fasterxml.jackson.annotation.JsonProperty("taskId")
   private long taskId;
 
   @SerializedName("commandId")
+  @com.fasterxml.jackson.annotation.JsonProperty("commandId")
   private String commandId;
 
   @SerializedName("hostname")
+  @JsonIgnore
   private String hostname;
 
   @SerializedName("role")
+  @com.fasterxml.jackson.annotation.JsonProperty("role")
   private String role;
 
   @SerializedName("hostLevelParams")
+  @JsonIgnore
   private Map<String, String> hostLevelParams = new HashMap<>();
 
   @SerializedName("roleParams")
+  @com.fasterxml.jackson.annotation.JsonProperty("roleParams")
   private Map<String, String> roleParams = null;
 
   @SerializedName("roleCommand")
+  @com.fasterxml.jackson.annotation.JsonProperty("roleCommand")
   private RoleCommand roleCommand;
 
   @SerializedName("clusterHostInfo")
-  private Map<String, Set<String>> clusterHostInfo = new HashMap<>();
+  private Map<String, Set<String>> clusterHostInfo =
+    new HashMap<>();
 
   @SerializedName("configurations")
+  @JsonIgnore
   private Map<String, Map<String, String>> configurations;
 
-  @SerializedName("configuration_attributes")
+  @SerializedName("configurationAttributes")
+  @JsonIgnore
   private Map<String, Map<String, Map<String, String>>> configurationAttributes;
 
   @SerializedName("configurationTags")
+  @JsonIgnore
   private Map<String, Map<String, String>> configurationTags;
 
   @SerializedName("forceRefreshConfigTagsBeforeExecution")
+  @JsonIgnore
   private boolean forceRefreshConfigTagsBeforeExecution = false;
 
   @SerializedName("commandParams")
+  @com.fasterxml.jackson.annotation.JsonProperty("commandParams")
   private Map<String, String> commandParams = new HashMap<>();
 
   @SerializedName("serviceName")
+  @com.fasterxml.jackson.annotation.JsonProperty("serviceName")
   private String serviceName;
 
   @SerializedName("serviceType")
+  @JsonIgnore
   private String serviceType;
 
   @SerializedName("componentName")
+  @JsonIgnore
   private String componentName;
 
   @SerializedName("kerberosCommandParams")
+  @com.fasterxml.jackson.annotation.JsonProperty("kerberosCommandParams")
   private List<Map<String, String>> kerberosCommandParams = new ArrayList<>();
 
   @SerializedName("localComponents")
+  @JsonIgnore
   private Set<String> localComponents = new HashSet<>();
 
+  @SerializedName("availableServices")
+  @JsonIgnore
+  private Map<String, String> availableServices = new HashMap<>();
+
   /**
    * "true" or "false" indicating whether this
    * service is enabled for credential store use.
    */
   @SerializedName("credentialStoreEnabled")
+  @JsonIgnore
   private String credentialStoreEnabled;
 
   /**
@@ -142,12 +175,12 @@ public class ExecutionCommand extends AgentCommand {
    *   </pre>
    */
   @SerializedName("configuration_credentials")
+  @JsonIgnore
   private Map<String, Map<String, String>> configurationCredentials;
 
 
   /**
-   * Provides information regarding the content of repositories.  This structure replaces
-   * the deprecated use of {@link KeyNames#REPO_INFO}
+   * Provides information regarding the content of repositories.
    */
   @SerializedName("repositoryFile")
   private CommandRepository commandRepository;
@@ -161,6 +194,9 @@ public class ExecutionCommand extends AgentCommand {
   @SerializedName("roleParameters")
   private Map<String, Object> roleParameters;
 
+  @SerializedName("useLatestConfigs")
+  private Boolean useLatestConfigs = null;
+
   public void setConfigurationCredentials(Map<String, Map<String, String>> configurationCredentials) {
     this.configurationCredentials = configurationCredentials;
   }
@@ -403,15 +439,42 @@ public class ExecutionCommand extends AgentCommand {
     kerberosCommandParams =  params;
   }
 
+  public String getClusterId() {
+    return clusterId;
+  }
+
+  public void setClusterId(String clusterId) {
+    this.clusterId = clusterId;
+  }
+
   /**
+   * Gets the repository file which was set on this command. The repository can
+   * be set either by the creator of the command or by the
+   * {@link ExecutionCommandWrapper} when it is about to execute the command.
+   *
    * @return the repository file that is to be written.
+   * @see #setRepositoryFile(CommandRepository)
    */
   public CommandRepository getRepositoryFile() {
     return commandRepository;
   }
 
   /**
-   * @param repository  the command repository instance.
+   * Sets the {@link CommandRepository} which will be sent down to the agent
+   * instructing it on which repository file to create on the host. In most
+   * cases, it is not necessary to set this file since the
+   * {@link ExecutionCommandWrapper} will set it in the event that it is
+   * missing. In fact, it is only appropriate to set this file in the following
+   * cases:
+   * <ul>
+   * <li>When distributing a repository to hosts in preparation for upgrade.
+   * This is because the service/component desired stack is not pointing to the
+   * new repository yet</li>
+   * <li>If the command does not contain a host or service/component></li>
+   * </ul>
+   *
+   * @param repository
+   *          the command repository instance.
    */
   public void setRepositoryFile(CommandRepository repository) {
     commandRepository = repository;
@@ -434,6 +497,15 @@ public class ExecutionCommand extends AgentCommand {
     roleParameters = params;
   }
 
+
+  public Boolean getUseLatestConfigs() {
+    return useLatestConfigs;
+  }
+
+  public void setUseLatestConfigs(Boolean useLatestConfigs) {
+    this.useLatestConfigs = useLatestConfigs;
+  }
+
   /**
    * Contains key name strings. These strings are used inside maps
    * incapsulated inside command.
@@ -448,12 +520,17 @@ public class ExecutionCommand extends AgentCommand {
     String STACK_NAME = "stack_name";
     String SERVICE_TYPE = "service_type";
     String STACK_VERSION = "stack_version";
+    @Deprecated
+    @Experimental(feature=ExperimentalFeature.PATCH_UPGRADES)
     String SERVICE_REPO_INFO = "service_repo_info";
     String PACKAGE_LIST = "package_list";
-    String IGNORE_PACKAGE_DEPENDENCIES = "ignore_package_dependencies";
     String JDK_LOCATION = "jdk_location";
     String JAVA_HOME = "java_home";
     String GPL_LICENSE_ACCEPTED = "gpl_license_accepted";
+    String AMBARI_JAVA_HOME = "ambari_java_home";
+    String AMBARI_JDK_NAME = "ambari_jdk_name";
+    String AMBARI_JCE_NAME = "ambari_jce_name";
+    String AMBARI_JAVA_VERSION = "ambari_java_version";
     String JAVA_VERSION = "java_version";
     String JDK_NAME = "jdk_name";
     String JCE_NAME = "jce_name";
@@ -462,12 +539,6 @@ public class ExecutionCommand extends AgentCommand {
     String ORACLE_JDBC_URL = "oracle_jdbc_url";
     String DB_DRIVER_FILENAME = "db_driver_filename";
     String CLIENTS_TO_UPDATE_CONFIGS = "clientsToUpdateConfigs";
-    /**
-     * Keep for backward compatibility.
-     */
-    @Deprecated
-    @Experimental(feature=ExperimentalFeature.PATCH_UPGRADES)
-    String REPO_INFO = "repo_info";
 
     String DB_NAME = "db_name";
     String GLOBAL = "global";
@@ -479,6 +550,7 @@ public class ExecutionCommand extends AgentCommand {
     String USER_LIST = "user_list";
     String GROUP_LIST = "group_list";
     String USER_GROUPS = "user_groups";
+    String BLUEPRINT_PROVISIONING_STATE = "blueprint_provisioning_state";
     String NOT_MANAGED_HDFS_PATH_LIST = "not_managed_hdfs_path_list";
     String REFRESH_TOPOLOGY = "refresh_topology";
     String HOST_SYS_PREPPED = "host_sys_prepped";
@@ -487,6 +559,7 @@ public class ExecutionCommand extends AgentCommand {
     String AGENT_STACK_RETRY_ON_UNAVAILABILITY = "agent_stack_retry_on_unavailability";
     String AGENT_STACK_RETRY_COUNT = "agent_stack_retry_count";
     String LOG_OUTPUT = "log_output";
+    String DFS_TYPE = "dfs_type";
 
     /**
      * A boolean indicating whether configuration tags should be refreshed
@@ -519,6 +592,7 @@ public class ExecutionCommand extends AgentCommand {
     @Deprecated
     @Experimental(feature=ExperimentalFeature.PATCH_UPGRADES)
     String REPO_VERSION_ID = "repository_version_id";
+    String CLUSTER_NAME = "cluster_name";
 
     /**
      * The version of the component to send down with the command. Normally,
@@ -526,20 +600,10 @@ public class ExecutionCommand extends AgentCommand {
      * upgrades, this value may change depending on the progress of the upgrade
      * and the type/direction.
      */
-    String VERSION = "version";
-
-    /**
-     * Previously used to represent the version of a cluster, this singular
-     * value is no longer valid. However, to maintain backward compatibility
-     * with Python code inside of management packs and extension services it
-     * will be still be provided. It should be set to the repository version of
-     * the command, if th repository has been resolved.
-     */
-    @Deprecated
     @Experimental(
         feature = ExperimentalFeature.PATCH_UPGRADES,
-        comment = "This value is still around purely for backward compatibility with mpacks")
-    String CURRENT_VERSION = "current_version";
+        comment = "Change this to reflect the component version")
+    String VERSION = "version";
 
 
     /**
