@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -29,5 +29,5 @@ public interface ResultPostProcessor {
    *
    * @param result the result to process.
    */
-  public void process(Result result);
+  void process(Result result);
 }
