@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -89,22 +89,21 @@ public abstract class AbstractProviderModule implements ProviderModule,
   private static final String GANGLIA_SERVER                            = "GANGLIA_SERVER";
   private static final String METRIC_SERVER                             = "METRICS_COLLECTOR";
   private static final String PROPERTIES_CATEGORY = "properties";
-  private static final Map<String, String> serviceConfigVersions = new ConcurrentHashMap<String, String>();
-  private static final Map<Service.Type, String> serviceConfigTypes = new EnumMap<Service.Type, String>(Service.Type.class);
-  private static final Map<Service.Type, Map<String, String[]>> serviceDesiredProperties = new EnumMap<Service.Type, Map<String, String[]>>(Service.Type.class);
-  private static final Map<String, Service.Type> componentServiceMap = new HashMap<String, Service.Type>();
+  private static final Map<String, String> serviceConfigVersions = new ConcurrentHashMap<>();
+  private static final Map<Service.Type, String> serviceConfigTypes = new EnumMap<>(Service.Type.class);
+  private static final Map<Service.Type, Map<String, String[]>> serviceDesiredProperties = new EnumMap<>(Service.Type.class);
+  private static final Map<String, Service.Type> componentServiceMap = new HashMap<>();
 
   private static final Map<String, List<HttpPropertyProvider.HttpPropertyRequest>> HTTP_PROPERTY_REQUESTS = new HashMap<>();
 
   private static final String PROPERTY_HDFS_HTTP_POLICY_VALUE_HTTPS_ONLY = "HTTPS_ONLY";
 
   private static final String COLLECTOR_DEFAULT_PORT = "6188";
-  private static boolean vipHostConfigPresent = false;
 
-  private static final Map<String, Map<String, String[]>> jmxDesiredProperties = new HashMap<String, Map<String, String[]>>();
+  private static final Map<String, Map<String, String[]>> jmxDesiredProperties = new HashMap<>();
   private static final Map<String, Map<String, String[]>> jmxDesiredRpcSuffixProperties = new ConcurrentHashMap<>();
-  private volatile Map<String, Map<String, Map<String, String>>> jmxDesiredRpcSuffixes = new HashMap<String, Map<String, Map<String,String>>>();
-  private volatile Map<String, String> clusterHdfsSiteConfigVersionMap = new HashMap<String, String>();
+  private volatile Map<String, Map<String, Map<String, String>>> jmxDesiredRpcSuffixes = new HashMap<>();
+  private volatile Map<String, String> clusterHdfsSiteConfigVersionMap = new HashMap<>();
   private volatile Map<String, String> clusterJmxProtocolMap = new ConcurrentHashMap<>();
   private volatile String clusterMetricServerPort = null;
   private volatile String clusterMetricServerVipPort = null;
@@ -126,7 +125,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
     componentServiceMap.put("NODEMANAGER", Service.Type.YARN);
     componentServiceMap.put("HISTORYSERVER", Service.Type.MAPREDUCE2);
 
-    Map<String, String[]> initPropMap = new HashMap<String, String[]>();
+    Map<String, String[]> initPropMap = new HashMap<>();
     initPropMap.put("NAMENODE", new String[]{"dfs.http.address", "dfs.namenode.http-address"});
     initPropMap.put("NAMENODE-HTTPS", new String[]{"dfs.namenode.https-address", "dfs.https.port"});
     initPropMap.put("NAMENODE-HA", new String[]{"dfs.namenode.http-address.%s.%s"});
@@ -138,84 +137,85 @@ public abstract class AbstractProviderModule implements ProviderModule,
     serviceDesiredProperties.put(Service.Type.HDFS, initPropMap);
 
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("HBASE_MASTER", new String[]{"hbase.master.info.port"});
     initPropMap.put("HBASE_REGIONSERVER", new String[]{"hbase.regionserver.info.port"});
     initPropMap.put("HBASE_MASTER-HTTPS", new String[]{"hbase.master.info.port"});
     initPropMap.put("HBASE_REGIONSERVER-HTTPS", new String[]{"hbase.regionserver.info.port"});
     serviceDesiredProperties.put(Service.Type.HBASE, initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("RESOURCEMANAGER", new String[]{"yarn.resourcemanager.webapp.address"});
     initPropMap.put("RESOURCEMANAGER-HTTPS", new String[]{"yarn.resourcemanager.webapp.https.address"});
     initPropMap.put("NODEMANAGER", new String[]{"yarn.nodemanager.webapp.address"});
     initPropMap.put("NODEMANAGER-HTTPS", new String[]{"yarn.nodemanager.webapp.https.address"});
     serviceDesiredProperties.put(Service.Type.YARN, initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("HISTORYSERVER", new String[]{"mapreduce.jobhistory.webapp.address"});
     initPropMap.put("HISTORYSERVER-HTTPS", new String[]{"mapreduce.jobhistory.webapp.https.address"});
     serviceDesiredProperties.put(Service.Type.MAPREDUCE2, initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("NAMENODE", new String[]{"dfs.http.policy"});
     jmxDesiredProperties.put("NAMENODE", initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("DATANODE", new String[]{"dfs.http.policy"});
     jmxDesiredProperties.put("DATANODE", initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("JOURNALNODE", new String[]{"dfs.http.policy"});
     jmxDesiredProperties.put("JOURNALNODE", initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("RESOURCEMANAGER", new String[]{"yarn.http.policy"});
     jmxDesiredProperties.put("RESOURCEMANAGER", initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("HBASE_MASTER", new String[]{"hbase.ssl.enabled"});
     jmxDesiredProperties.put("HBASE_MASTER", initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("HBASE_REGIONSERVER", new String[]{"hbase.ssl.enabled"});
     jmxDesiredProperties.put("HBASE_REGIONSERVER", initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("NODEMANAGER", new String[]{"yarn.http.policy"});
     jmxDesiredProperties.put("NODEMANAGER", initPropMap);
-    initPropMap = new HashMap<String, String[]>();
+
+    initPropMap = new HashMap<>();
     initPropMap.put("HISTORYSERVER", new String[]{"mapreduce.jobhistory.http.policy"});
     jmxDesiredProperties.put("HISTORYSERVER", initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("client", new String[]{"dfs.namenode.rpc-address"});
     initPropMap.put("datanode", new String[]{"dfs.namenode.servicerpc-address"});
     initPropMap.put("healthcheck", new String[]{"dfs.namenode.lifeline.rpc-address"});
     jmxDesiredRpcSuffixProperties.put("NAMENODE", initPropMap);
 
-    initPropMap = new HashMap<String, String[]>();
+    initPropMap = new HashMap<>();
     initPropMap.put("client", new String[]{"dfs.namenode.rpc-address.%s.%s"});
     initPropMap.put("datanode", new String[]{"dfs.namenode.servicerpc-address.%s.%s"});
     initPropMap.put("healthcheck", new String[]{"dfs.namenode.lifeline.rpc-address.%s.%s"});
     jmxDesiredRpcSuffixProperties.put("NAMENODE-HA", initPropMap);
 
     HTTP_PROPERTY_REQUESTS.put("RESOURCEMANAGER",
-        Collections.<HttpPropertyProvider.HttpPropertyRequest>singletonList(new ResourceManagerHttpPropertyRequest()));
+        Collections.singletonList(new ResourceManagerHttpPropertyRequest()));
 
     HTTP_PROPERTY_REQUESTS.put("ATLAS_SERVER",
-        Collections.<HttpPropertyProvider.HttpPropertyRequest>singletonList(new AtlasServerHttpPropertyRequest()));
+        Collections.singletonList(new AtlasServerHttpPropertyRequest()));
   }
 
   /**
    * The map of resource providers.
    */
-  private final Map<Resource.Type, ResourceProvider> resourceProviders = new HashMap<Resource.Type, ResourceProvider>();
+  private final Map<Resource.Type, ResourceProvider> resourceProviders = new HashMap<>();
 
   /**
    * The map of lists of property providers.
    */
-  private final Map<Resource.Type, List<PropertyProvider>> propertyProviders = new HashMap<Resource.Type, List<PropertyProvider>>();
+  private final Map<Resource.Type, List<PropertyProvider>> propertyProviders = new HashMap<>();
 
   /*
    * TODO: Instantiation for the concrete impl of this class is not done through
@@ -223,7 +223,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
    * are going to work unless refactoring is complete.
    */
   @Inject
-  AmbariManagementController managementController;
+  protected AmbariManagementController managementController;
 
   @Inject
   TimelineMetricCacheProvider metricCacheProvider;
@@ -266,7 +266,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
 
   private volatile boolean initialized = false;
 
-  protected final static Logger LOG =
+  private static final Logger LOG =
       LoggerFactory.getLogger(AbstractProviderModule.class);
 
 
@@ -373,26 +373,27 @@ public abstract class AbstractProviderModule implements ProviderModule,
     return null;
   }
 
-  private String getMetricsCollectorHostName(String clusterName)
-    throws SystemException {
+
+  private void checkAndAddExternalCollectorHosts(String clusterName) throws SystemException {
     try {
       // try to get vip properties from cluster-env
       String configType = "cluster-env";
       String currentConfigVersion = getDesiredConfigVersion(clusterName, configType);
       String oldConfigVersion = serviceConfigVersions.get(configType);
       if (!currentConfigVersion.equals(oldConfigVersion)) {
-        vipHostConfigPresent = false;
         serviceConfigVersions.put(configType, currentConfigVersion);
         Map<String, String> configProperties = getDesiredConfigMap
           (clusterName, currentConfigVersion, configType,
             Collections.singletonMap("METRICS_COLLECTOR",
-              new String[]{"metrics_collector_vip_host"}));
+              new String[]{"metrics_collector_external_hosts"}));
 
         if (!configProperties.isEmpty()) {
           clusterMetricserverVipHost = configProperties.get("METRICS_COLLECTOR");
-          if (clusterMetricserverVipHost != null) {
-            LOG.info("Setting Metrics Collector Vip Host : " + clusterMetricserverVipHost);
-            vipHostConfigPresent = true;
+          if (StringUtils.isNotEmpty(clusterMetricserverVipHost)) {
+            for (String collectorHost : StringUtils.split(clusterMetricserverVipHost, ",")) {
+              metricsCollectorHAManager.addExternalMetricsCollectorHost(clusterName, collectorHost);
+            }
+            LOG.info("Setting Metrics Collector External Host : " + clusterMetricserverVipHost);
           }
         }
         // updating the port value, because both vip properties are stored in
@@ -400,26 +401,30 @@ public abstract class AbstractProviderModule implements ProviderModule,
         configProperties = getDesiredConfigMap
           (clusterName, currentConfigVersion, configType,
             Collections.singletonMap("METRICS_COLLECTOR",
-              new String[]{"metrics_collector_vip_port"}));
+              new String[]{"metrics_collector_external_port"}));
 
         if (!configProperties.isEmpty()) {
-          clusterMetricServerVipPort = configProperties.get("METRICS_COLLECTOR");
+          clusterMetricServerVipPort = configProperties.getOrDefault("METRICS_COLLECTOR", "6188");
         }
       }
     } catch (NoSuchParentResourceException | UnsupportedPropertyException e) {
       LOG.warn("Failed to retrieve collector hostname.", e);
     }
+  }
 
-    //If vip config not present
-    //  If current collector host is null or if the host or the host component not live
-    //    Update clusterMetricCollectorMap with a live metric collector host.
-    String currentCollectorHost = null;
-    if (!vipHostConfigPresent) {
-      currentCollectorHost = metricsCollectorHAManager.getCollectorHost(clusterName);
-      }
+  private String getMetricsCollectorHostName(String clusterName)
+    throws SystemException {
+
+    checkAndAddExternalCollectorHosts(clusterName);
+    String currentCollectorHost = metricsCollectorHAManager.getCollectorHost(clusterName);
     LOG.debug("Cluster Metrics Vip Host : " + clusterMetricserverVipHost);
 
-    return (clusterMetricserverVipHost != null) ? clusterMetricserverVipHost : currentCollectorHost;
+    return currentCollectorHost;
+  }
+
+  @Override
+  public boolean isCollectorHostExternal(String clusterName) {
+    return metricsCollectorHAManager.isExternalCollector();
   }
 
   @Override
@@ -485,8 +490,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
     return hosts;
   }
 
-  @Override
-  public Host getHost(String clusterName, String hostName) {
+  private Host getHost(String clusterName, String hostName) {
     Host host = null;
     try {
       Cluster cluster = managementController.getClusters().getCluster(clusterName);
@@ -517,12 +521,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
   // ----- JMXHostProvider ---------------------------------------------------
 
   @Override
-  public String getPort(String clusterName, String componentName, String hostName) throws SystemException {
-    return getPort(clusterName, componentName, hostName, false);
-  }
-
-  @Override
-  public String getPort(String clusterName, String componentName, String hostName, boolean httpsEnabled) throws SystemException {
+  public String getPort(String clusterName, String componentName, String hostName, boolean httpsEnabled) {
     ConcurrentMap<String, ConcurrentMap<String, String>> clusterJmxPorts;
     // Still need double check to ensure single init
     if (!jmxPortMap.containsKey(clusterName)) {
@@ -533,9 +532,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
         }
       }
     }
-
     clusterJmxPorts = jmxPortMap.get(clusterName);
-
     Service.Type service = componentServiceMap.get(componentName);
 
     if (service != null) {
@@ -581,7 +578,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
             // this will trigger using the default port for the component
             String portString = getPortString(entry.getValue());
             if (null != portString) {
-              clusterJmxPorts.putIfAbsent(hostName, new ConcurrentHashMap<String, String>());
+              clusterJmxPorts.putIfAbsent(hostName, new ConcurrentHashMap<>());
               clusterJmxPorts.get(hostName).put(entry.getKey(), portString);
             }
           }
@@ -593,7 +590,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
       }
     }
 
-    LOG.debug("jmxPortMap -> " + jmxPortMap);
+    LOG.debug("jmxPortMap -> {}", jmxPortMap);
 
     ConcurrentMap<String, String> hostJmxPorts = clusterJmxPorts.get(hostName);
     if (hostJmxPorts == null) {
@@ -665,14 +662,14 @@ public abstract class AbstractProviderModule implements ProviderModule,
   private String postProcessPropertyValue(String key, String value, Map<String, String> properties, Set<String> prevProps) {
     if (value != null && key != null && value.contains("${")) {
       if (prevProps == null) {
-        prevProps = new HashSet<String>();
+        prevProps = new HashSet<>();
       }
       if (prevProps.contains(key)) {
         return value;
       }
       prevProps.add(key);
       String refValueString = value;
-      Map<String, String> refMap = new HashMap<String, String>();
+      Map<String, String> refMap = new HashMap<>();
       while (refValueString.contains("${")) {
         int startValueRef = refValueString.indexOf("${") + 2;
         int endValueRef = refValueString.indexOf('}');
@@ -716,7 +713,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
 
   protected void createPropertyProviders(Resource.Type type) {
 
-    List<PropertyProvider> providers = new LinkedList<PropertyProvider>();
+    List<PropertyProvider> providers = new LinkedList<>();
 
     ComponentSSLConfiguration configuration = ComponentSSLConfiguration.instance();
     URLStreamProvider streamProvider = new URLStreamProvider(
@@ -785,8 +782,8 @@ public abstract class AbstractProviderModule implements ProviderModule,
               PropertyHelper.getPropertyId("ServiceComponentInfo", "state"),
               jpp,
               gpp));
+          break;
         }
-        break;
         case HostComponent: {
           // TODO as we fill out stack metric definitions, these can be phased out
           PropertyProvider jpp = createJMXPropertyProvider(
@@ -834,8 +831,8 @@ public abstract class AbstractProviderModule implements ProviderModule,
           // this follows the current pattern of relying on the management controller
           // to instantiate this PropertyProvider
           providers.add(managementController.getLoggingSearchPropertyProvider());
+          break;
         }
-        break;
         case RootServiceComponent:
           providers.add(new RootServiceComponentPropertyProvider());
           break;
@@ -861,8 +858,6 @@ public abstract class AbstractProviderModule implements ProviderModule,
     if (initialized) {
       synchronized (this) {
         if (initialized) {
-          LOG.info("Resetting property provider maps to reflect changes in " +
-            "cluster state");
           initialized = false;
         }
       }
@@ -872,9 +867,11 @@ public abstract class AbstractProviderModule implements ProviderModule,
   // TODO: Fix for multi-service feature support (trunk)
   // Called from a synchornized block !
   private void initProviderMaps() throws SystemException {
+
     jmxPortMap.clear();
     clusterHostComponentMap = new HashMap<>();
     clusterGangliaCollectorMap = new HashMap<>();
+    boolean hasMetricCollector = false;
 
     Map<String, Cluster> clusterMap = clusters.getClusters();
     if (MapUtils.isEmpty(clusterMap)) {
@@ -882,6 +879,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
     }
 
     for (Cluster cluster : clusterMap.values()) {
+      hasMetricCollector = false;
       String clusterName = cluster.getClusterName();
       Map<String, String> hostComponentMap = clusterHostComponentMap.get(clusterName);
 
@@ -906,9 +904,13 @@ public abstract class AbstractProviderModule implements ProviderModule,
             //  If current collector host is null or if the host or the host component not live
             //  Update clusterMetricCollectorMap.
             metricsCollectorHAManager.addCollectorHost(clusterName, hostName);
+            hasMetricCollector = true;
           }
         }
       }
+      if (!hasMetricCollector) {
+        checkAndAddExternalCollectorHosts(clusterName);
+      }
     }
   }
 
@@ -924,7 +926,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
    * @param clusterName
    *          the cluster name
    * @param configType
-   *          the configuration type (for example {@value hdfs-site}).
+   *          the configuration type (for example <code>hdfs-site</code>).
    * @return
    */
   private String getDesiredConfigVersion(String clusterName,
@@ -956,15 +958,15 @@ public abstract class AbstractProviderModule implements ProviderModule,
     // Get desired configs based on the tag
     ResourceProvider configResourceProvider = getResourceProvider(Resource.Type.Configuration);
     Predicate configPredicate = new PredicateBuilder().property
-        (ConfigurationResourceProvider.CONFIGURATION_CLUSTER_NAME_PROPERTY_ID).equals(clusterName).and()
-        .property(ConfigurationResourceProvider.CONFIGURATION_CONFIG_TYPE_PROPERTY_ID).equals(configType).and()
-        .property(ConfigurationResourceProvider.CONFIGURATION_CONFIG_TAG_PROPERTY_ID).equals(versionTag).toPredicate();
+        (ConfigurationResourceProvider.CLUSTER_NAME).equals(clusterName).and()
+        .property(ConfigurationResourceProvider.TYPE).equals(configType).and()
+        .property(ConfigurationResourceProvider.TAG).equals(versionTag).toPredicate();
     Set<Resource> configResources;
     try {
       configResources = configResourceProvider.getResources
-          (PropertyHelper.getReadRequest(ConfigurationResourceProvider.CONFIGURATION_CLUSTER_NAME_PROPERTY_ID,
-              ConfigurationResourceProvider.CONFIGURATION_CONFIG_TYPE_PROPERTY_ID,
-              ConfigurationResourceProvider.CONFIGURATION_CONFIG_TAG_PROPERTY_ID), configPredicate);
+          (PropertyHelper.getReadRequest(ConfigurationResourceProvider.CLUSTER_NAME,
+              ConfigurationResourceProvider.TYPE,
+              ConfigurationResourceProvider.TAG), configPredicate);
     } catch (NoSuchResourceException e) {
       LOG.info("Resource for the desired config not found. " + e);
       return Collections.emptyMap();
@@ -989,7 +991,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
     if(configProperties == null) {
       configProperties = getConfigProperties(clusterName, versionTag, configType);
     }
-    Map<String, String> mConfigs = new HashMap<String, String>();
+    Map<String, String> mConfigs = new HashMap<>();
     if (!configProperties.isEmpty()) {
       Map<String, String> evaluatedProperties = null;
       for (Entry<String, String[]> entry : keys.entrySet()) {
@@ -1013,7 +1015,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
 
         if (value != null && value.contains("${")) {
           if (evaluatedProperties == null) {
-            evaluatedProperties = new HashMap<String, String>();
+            evaluatedProperties = new HashMap<>();
             for (Map.Entry<String, Object> subentry : configProperties.entrySet()) {
               String keyString = subentry.getKey();
               Object object = subentry.getValue();
@@ -1027,7 +1029,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
           }
         }
         value = postProcessPropertyValue(propName, value, evaluatedProperties, null);
-        LOG.debug("PROPERTY -> key: " + propName + ", " + "value: " + value);
+        LOG.debug("PROPERTY -> key: {}, value: {}", propName, value);
 
         mConfigs.put(entry.getKey(), value);
 
@@ -1161,15 +1163,12 @@ public abstract class AbstractProviderModule implements ProviderModule,
       jmxProtocolString = "http";
     }
     if (jmxProtocolString == null) {
-      LOG.debug("Detected JMX protocol is null for clusterName = " + clusterName +
-          ", componentName = " + componentName);
-      LOG.debug("Defaulting JMX to HTTP protocol for  for clusterName = " + clusterName +
-          ", componentName = " + componentName);
+      LOG.debug("Detected JMX protocol is null for clusterName = {}, componentName = {}", clusterName, componentName);
+      LOG.debug("Defaulting JMX to HTTP protocol for  for clusterName = {}, componentName = {}", clusterName, componentName);
       jmxProtocolString = "http";
     }
     if (LOG.isDebugEnabled()) {
-      LOG.debug("JMXProtocol = " + jmxProtocolString + ", for clusterName=" + clusterName +
-          ", componentName = " + componentName);
+      LOG.debug("JMXProtocol = {}, for clusterName={}, componentName = {}", jmxProtocolString, clusterName, componentName);
     }
     clusterJmxProtocolMap.put(mapKey, jmxProtocolString);
     return jmxProtocolString;
@@ -1201,7 +1200,7 @@ public abstract class AbstractProviderModule implements ProviderModule,
         componentToPortsMap = jmxDesiredRpcSuffixes.get(clusterName);
       } else {
         componentToPortsMap = new HashMap<>();
-        componentToPortsMap.put(componentName, new HashMap<String, String>());
+        componentToPortsMap.put(componentName, new HashMap<>());
         jmxDesiredRpcSuffixes.put(clusterName, componentToPortsMap);
       }
 
