@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -19,6 +19,17 @@
 
 package org.apache.ambari.server.controller.internal;
 
+import java.net.InetAddress;
+import java.net.UnknownHostException;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.api.util.TreeNode;
 import org.apache.ambari.server.controller.AmbariManagementController;
@@ -39,17 +50,6 @@ import org.apache.ambari.server.topology.TopologyRequest;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.net.InetAddress;
-import java.net.UnknownHostException;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-
 /**
  * Request to export a blueprint from an existing cluster.
  */
@@ -63,7 +63,7 @@ public class ExportBlueprintRequest implements TopologyRequest {
   private Blueprint blueprint;
   private Configuration configuration;
   //todo: Should this map be represented by a new class?
-  private Map<String, HostGroupInfo> hostGroupInfo = new HashMap<String, HostGroupInfo>();
+  private Map<String, HostGroupInfo> hostGroupInfo = new HashMap<>();
 
 
   public ExportBlueprintRequest(TreeNode<Resource> clusterNode) throws InvalidTopologyTemplateException {
@@ -123,11 +123,11 @@ public class ExportBlueprintRequest implements TopologyRequest {
   private void createBlueprint(Collection<ExportedHostGroup> exportedHostGroups, Stack stack) {
     String bpName = "exported-blueprint";
 
-    Collection<HostGroup> hostGroups = new ArrayList<HostGroup>();
+    Collection<HostGroup> hostGroups = new ArrayList<>();
     for (ExportedHostGroup exportedHostGroup : exportedHostGroups) {
 
       // create Component using component name
-      List<Component> componentList = new ArrayList<Component>();
+      List<Component> componentList = new ArrayList<>();
       for (String component : exportedHostGroup.getComponents()) {
         componentList.add(new Component(component));
       }
@@ -169,8 +169,8 @@ public class ExportBlueprintRequest implements TopologyRequest {
    */
   private void createConfiguration(TreeNode<Resource> clusterNode) {
 
-    Map<String, Map<String, String>> properties = new HashMap<String, Map<String, String>>();
-    Map<String, Map<String, Map<String, String>>> attributes = new HashMap<String, Map<String, Map<String, String>>>();
+    Map<String, Map<String, String>> properties = new HashMap<>();
+    Map<String, Map<String, Map<String, String>>> attributes = new HashMap<>();
 
     Map<String, Object> desiredConfigMap = clusterNode.getObject().getPropertiesMap().get("Clusters/desired_configs");
     TreeNode<Resource> configNode = clusterNode.getChild("configurations");
@@ -186,8 +186,8 @@ public class ExportBlueprintRequest implements TopologyRequest {
     configuration = new Configuration(properties, attributes);
     // empty parent configuration when exporting as all properties are included in this configuration
     configuration.setParentConfiguration(new Configuration(
-        Collections.<String, Map<String, String>>emptyMap(),
-        Collections.<String, Map<String, Map<String, String>>>emptyMap()));
+        Collections.emptyMap(),
+        Collections.emptyMap()));
   }
 
   /**
@@ -198,7 +198,7 @@ public class ExportBlueprintRequest implements TopologyRequest {
    * @return collection of host groups
    */
   private Collection<ExportedHostGroup> processHostGroups(TreeNode<Resource> hostNode) {
-    Map<ExportedHostGroup, ExportedHostGroup> mapHostGroups = new HashMap<ExportedHostGroup, ExportedHostGroup>();
+    Map<ExportedHostGroup, ExportedHostGroup> mapHostGroups = new HashMap<>();
     int count = 1;
     for (TreeNode<Resource> host : hostNode.getChildren()) {
       ExportedHostGroup group = new ExportedHostGroup(host);
@@ -229,9 +229,9 @@ public class ExportBlueprintRequest implements TopologyRequest {
    * @return list of component names for the host
    */
   private List<Map<String, String>> processHostGroupComponents(ExportedHostGroup group) {
-    List<Map<String, String>> listHostGroupComponents = new ArrayList<Map<String, String>>();
+    List<Map<String, String>> listHostGroupComponents = new ArrayList<>();
     for (String component : group.getComponents()) {
-      Map<String, String> mapComponentProperties = new HashMap<String, String>();
+      Map<String, String> mapComponentProperties = new HashMap<>();
       listHostGroupComponents.add(mapComponentProperties);
       mapComponentProperties.put("name", component);
     }
@@ -255,12 +255,12 @@ public class ExportBlueprintRequest implements TopologyRequest {
     /**
      * Associated components.
      */
-    private Set<String> components = new HashSet<String>();
+    private Set<String> components = new HashSet<>();
 
     /**
      * Host group scoped configurations.
      */
-    private Collection<ExportedConfiguration> configurations = new HashSet<ExportedConfiguration>();
+    private Collection<ExportedConfiguration> configurations = new HashSet<>();
 
     /**
      * Number of instances.
@@ -270,7 +270,7 @@ public class ExportBlueprintRequest implements TopologyRequest {
     /**
      * Collection of associated hosts.
      */
-    private Collection<String> hosts = new HashSet<String>();
+    private Collection<String> hosts = new HashSet<>();
 
     /**
      * Constructor.
@@ -290,8 +290,8 @@ public class ExportBlueprintRequest implements TopologyRequest {
     }
 
     public Configuration getConfiguration() {
-      Map<String, Map<String, String>> configProperties = new HashMap<String, Map<String, String>>();
-      Map<String, Map<String, Map<String, String>>> configAttributes = new HashMap<String, Map<String, Map<String, String>>>();
+      Map<String, Map<String, String>> configProperties = new HashMap<>();
+      Map<String, Map<String, Map<String, String>>> configAttributes = new HashMap<>();
 
       for (ExportedConfiguration config : configurations) {
         configProperties.put(config.getType(), config.getProperties());
@@ -444,12 +444,12 @@ public class ExportBlueprintRequest implements TopologyRequest {
     /**
      * Properties of the configuration.
      */
-    private Map<String, String> properties = new HashMap<String, String>();
+    private Map<String, String> properties = new HashMap<>();
 
     /**
      * Attributes for the properties in the cluster configuration.
      */
-    private Map<String, Map<String, String>> propertyAttributes = new HashMap<String, Map<String, String>>();
+    private Map<String, Map<String, String>> propertyAttributes = new HashMap<>();
 
     /**
      * Constructor.
