@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -17,31 +17,11 @@
  */
 package org.apache.ambari.server.controller.metrics.timeline;
 
-import com.google.common.collect.Sets;
-import com.google.inject.Inject;
-import org.apache.ambari.server.api.services.AmbariMetaInfo;
-import org.apache.ambari.server.configuration.ComponentSSLConfiguration;
-import org.apache.ambari.server.controller.AmbariManagementController;
-import org.apache.ambari.server.controller.AmbariServer;
-import org.apache.ambari.server.controller.internal.PropertyInfo;
-import org.apache.ambari.server.controller.internal.URLStreamProvider;
-import org.apache.ambari.server.controller.metrics.MetricHostProvider;
-import org.apache.ambari.server.controller.metrics.MetricsPropertyProvider;
-import org.apache.ambari.server.controller.metrics.timeline.cache.TimelineAppMetricCacheKey;
-import org.apache.ambari.server.controller.metrics.timeline.cache.TimelineMetricCache;
-import org.apache.ambari.server.controller.metrics.timeline.cache.TimelineMetricCacheProvider;
-import org.apache.ambari.server.controller.spi.Request;
-import org.apache.ambari.server.controller.spi.Resource;
-import org.apache.ambari.server.controller.spi.SystemException;
-import org.apache.ambari.server.controller.spi.TemporalInfo;
-import org.apache.ambari.server.controller.utilities.PropertyHelper;
-import org.apache.ambari.server.events.MetricsCollectorHostDownEvent;
-import org.apache.ambari.server.events.publishers.AmbariEventPublisher;
-import org.apache.ambari.server.state.StackId;
-import org.apache.commons.lang.StringUtils;
-import org.apache.hadoop.metrics2.sink.timeline.TimelineMetric;
-import org.apache.hadoop.metrics2.sink.timeline.TimelineMetrics;
-import org.apache.http.client.utils.URIBuilder;
+import static org.apache.ambari.server.Role.HBASE_MASTER;
+import static org.apache.ambari.server.Role.HBASE_REGIONSERVER;
+import static org.apache.ambari.server.Role.METRICS_COLLECTOR;
+import static org.apache.ambari.server.controller.metrics.MetricsPaddingMethod.ZERO_PADDING_PARAM;
+import static org.apache.ambari.server.controller.metrics.MetricsServiceProvider.MetricsService.TIMELINE_METRICS;
 
 import java.io.IOException;
 import java.net.ConnectException;
@@ -61,13 +41,38 @@ import java.util.concurrent.atomic.AtomicInteger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import static org.apache.ambari.server.Role.HBASE_MASTER;
-import static org.apache.ambari.server.Role.HBASE_REGIONSERVER;
-import static org.apache.ambari.server.Role.METRICS_COLLECTOR;
-import static org.apache.ambari.server.controller.metrics.MetricsPaddingMethod.ZERO_PADDING_PARAM;
-import static org.apache.ambari.server.controller.metrics.MetricsServiceProvider.MetricsService.TIMELINE_METRICS;
+import org.apache.ambari.server.api.services.AmbariMetaInfo;
+import org.apache.ambari.server.configuration.ComponentSSLConfiguration;
+import org.apache.ambari.server.controller.AmbariManagementController;
+import org.apache.ambari.server.controller.AmbariServer;
+import org.apache.ambari.server.controller.internal.PropertyInfo;
+import org.apache.ambari.server.controller.internal.URLStreamProvider;
+import org.apache.ambari.server.controller.metrics.MetricHostProvider;
+import org.apache.ambari.server.controller.metrics.MetricsPropertyProvider;
+import org.apache.ambari.server.controller.metrics.timeline.cache.TimelineAppMetricCacheKey;
+import org.apache.ambari.server.controller.metrics.timeline.cache.TimelineMetricCache;
+import org.apache.ambari.server.controller.metrics.timeline.cache.TimelineMetricCacheProvider;
+import org.apache.ambari.server.controller.spi.Request;
+import org.apache.ambari.server.controller.spi.Resource;
+import org.apache.ambari.server.controller.spi.SystemException;
+import org.apache.ambari.server.controller.spi.TemporalInfo;
+import org.apache.ambari.server.controller.utilities.PropertyHelper;
+import org.apache.ambari.server.events.MetricsCollectorHostDownEvent;
+import org.apache.ambari.server.events.publishers.AmbariEventPublisher;
+import org.apache.ambari.server.state.Cluster;
+import org.apache.ambari.server.state.Service;
+import org.apache.ambari.server.state.StackId;
+import org.apache.commons.lang.StringUtils;
+import org.apache.hadoop.metrics2.sink.timeline.TimelineMetric;
+import org.apache.hadoop.metrics2.sink.timeline.TimelineMetrics;
+import org.apache.http.client.utils.URIBuilder;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import com.google.common.collect.Sets;
 
 public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
+  private static final Logger LOG = LoggerFactory.getLogger(AMSPropertyProvider.class);
   private static final String METRIC_REGEXP_PATTERN = "\\([^)]*\\)";
   private static final int COLLECTOR_DEFAULT_PORT = 6188;
   private final TimelineMetricCache metricCache;
@@ -119,7 +124,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
    */
   @Override
   public Set<String> checkPropertyIds(Set<String> propertyIds) {
-    Set<String> supportedIds = new HashSet<String>();
+    Set<String> supportedIds = new HashSet<>();
     for (String propertyId : propertyIds) {
       if (propertyId.startsWith(ZERO_PADDING_PARAM)
           || PropertyHelper.hasAggregateFunctionSuffix(propertyId)) {
@@ -135,15 +140,15 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
    */
   class MetricsRequest {
     private final TemporalInfo temporalInfo;
-    private final Map<String, Set<Resource>> resources = new HashMap<String, Set<Resource>>();
-    private final Map<String, Set<String>> metrics = new HashMap<String, Set<String>>();
+    private final Map<String, Set<Resource>> resources = new HashMap<>();
+    private final Map<String, Set<String>> metrics = new HashMap<>();
     private final URIBuilder uriBuilder;
     Set<String> resolvedMetricsParams;
     MetricsRequestHelper requestHelper = new MetricsRequestHelper(streamProvider);
 
     // Metrics with amsHostMetric = true
     // Basically a host metric to be returned for a hostcomponent
-    private final Set<String> hostComponentHostMetrics = new HashSet<String>();
+    private final Set<String> hostComponentHostMetrics = new HashSet<>();
     private String clusterName;
     private Map<String, Set<String>> componentMetricMap = new HashMap<>();
 
@@ -161,7 +166,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
     public void putResource(String componentName, Resource resource) {
       Set<Resource> resourceSet = resources.get(componentName);
       if (resourceSet == null) {
-        resourceSet = new HashSet<Resource>();
+        resourceSet = new HashSet<>();
         resources.put(componentName, resourceSet);
       }
       resourceSet.add(resource);
@@ -171,7 +176,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
       Set<String> propertyIds = metrics.get(metric);
 
       if (propertyIds == null) {
-        propertyIds = new HashSet<String>();
+        propertyIds = new HashSet<>();
         metrics.put(metric, propertyIds);
       }
       propertyIds.add(id);
@@ -277,7 +282,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
                       && checkMetricName(patterns, metric.getMetricName())) {
                 String hostnameTmp = metric.getHostName();
                 if (!metricsMap.containsKey(hostnameTmp)) {
-                  metricsMap.put(hostnameTmp, new HashSet<TimelineMetric>());
+                  metricsMap.put(hostnameTmp, new HashSet<>());
                 }
                 metricsMap.get(hostnameTmp).add(metric);
               }
@@ -308,12 +313,15 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
         StackId stackId;
         try {
           AmbariManagementController managementController = AmbariServer.getController();
-          stackId = managementController.getClusters().getCluster(clusterName).getCurrentStackVersion();
+          Cluster cluster = managementController.getClusters().getCluster(clusterName);
+          Service service = cluster.getServiceByComponentName(componentName);
+          stackId = service.getDesiredStackId();
+
           if (stackId != null) {
             String stackName = stackId.getStackName();
             String version = stackId.getStackVersion();
             AmbariMetaInfo ambariMetaInfo = managementController.getAmbariMetaInfo();
-            String serviceName = ambariMetaInfo.getComponentToService(stackName, version, componentName);
+            String serviceName = service.getName();
             String timeLineAppId = ambariMetaInfo.getComponent(stackName, version, serviceName, componentName).getTimelineAppid();
             if (timeLineAppId != null){
               timelineAppIdCache.put(componentName, timeLineAppId);
@@ -352,6 +360,10 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
         uriBuilder.setParameter("appId", componentName);
       }
 
+      if (clusterName != null && hostProvider.isCollectorHostExternal(clusterName)) {
+        uriBuilder.setParameter("instanceId", clusterName);
+      }
+
       if (temporalInfo != null) {
         long startTime = temporalInfo.getStartTime();
         if (startTime != -1) {
@@ -367,7 +379,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
 
     private Set<String> createPatterns(Set<String> rawNames) {
       Pattern pattern = Pattern.compile(METRIC_REGEXP_PATTERN);
-      Set<String> result = new HashSet<String>();
+      Set<String> result = new HashSet<>();
       for (String rawName : rawNames) {
         Matcher matcher = pattern.matcher(rawName);
         StringBuilder sb = new StringBuilder();
@@ -393,7 +405,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
     }
 
     private Set<String> processRegexps(Set<String> metricNames) {
-      Set<String> result = new HashSet<String>();
+      Set<String> result = new HashSet<>();
       for (String name : metricNames) {
         result.add(name.replaceAll(METRIC_REGEXP_PATTERN, Matcher.quoteReplacement("%")));
       }
@@ -404,7 +416,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
                                   TemporalInfo temporalInfo) {
       String metric_name = metric.getMetricName();
       Set<String> propertyIdSet = metrics.get(metric_name);
-      List<String> parameterList  = new LinkedList<String>();
+      List<String> parameterList  = new LinkedList<>();
 
       if (propertyIdSet == null) {
         for (Map.Entry<String, Set<String>> entry : metrics.entrySet()) {
@@ -441,6 +453,14 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
                   } else {
                     propertyId = substituteArgument(propertyId, "$1", metric.getInstanceId());
                   }
+                }else {
+                  if(metric.getInstanceId() != null){
+                    //instanceId "CHANNEL.ch1"
+                    String instanceId = metric.getInstanceId();
+                    instanceId = instanceId.matches("^\\w+\\..+$") ? instanceId.split("\\.")[1]:"";
+                    //propertyId "metrics/flume/flume/CHANNEL/ch1/[ChannelCapacity]"
+                    if(!propertyId.contains(instanceId)) continue;
+                  }
                 }
                 Object value = getValue(metric, temporalInfo);
                 if (value != null && !containsArguments(propertyId)) {
@@ -553,7 +573,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
     } else {
       metricPropertyIds = PropertyHelper.getMetricPropertyIds(Resource.Type.Component);
     }
-    Map<String, PropertyInfo> amsMetrics = new HashMap<String, PropertyInfo>();
+    Map<String, PropertyInfo> amsMetrics = new HashMap<>();
     if (metricPropertyIds.containsKey(HBASE_MASTER.name())) {
       amsMetrics.putAll(metricPropertyIds.get(HBASE_MASTER.name()));
     }
@@ -579,7 +599,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
               Set<Resource> resources, Request request, Set<String> ids) throws SystemException {
 
     Map<String, Map<TemporalInfo, MetricsRequest>> requestMap =
-      new HashMap<String, Map<TemporalInfo, MetricsRequest>>();
+      new HashMap<>();
 
     String collectorPort = null;
     Map<String, Boolean> clusterCollectorComponentLiveMap = new HashMap<>();
@@ -637,7 +657,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
 
       Map<TemporalInfo, MetricsRequest> requests = requestMap.get(clusterName);
       if (requests == null) {
-        requests = new HashMap<TemporalInfo, MetricsRequest>();
+        requests = new HashMap<>();
         requestMap.put(clusterName, requests);
       }
 
@@ -648,7 +668,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
       }
 
       for (String id : ids) {
-        Map<String, PropertyInfo> propertyInfoMap = new HashMap<String, PropertyInfo>();
+        Map<String, PropertyInfo> propertyInfoMap = new HashMap<>();
 
         String componentName = getOverridenComponentName(resource);
 
@@ -703,7 +723,7 @@ public abstract class AMSPropertyProvider extends MetricsPropertyProvider {
   private String preprocessPropertyId(String propertyId, String componentName) {
     if (propertyId.startsWith("jvm") && JVM_PROCESS_NAMES.keySet().contains(componentName)) {
       String newPropertyId = propertyId.replace("jvm.", "jvm." + JVM_PROCESS_NAMES.get(componentName));
-      LOG.debug("Pre-process: " + propertyId + ", to: " + newPropertyId);
+      LOG.debug("Pre-process: {}, to: {}", propertyId, newPropertyId);
       return newPropertyId;
     }
 
