@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,14 +18,14 @@
 
 package org.apache.ambari.server.controller.predicate;
 
-import org.apache.ambari.server.controller.spi.Predicate;
-
 import java.util.Set;
 
+import org.apache.ambari.server.controller.spi.Predicate;
+
 /**
  * An extended predicate interface which allows for the retrieval of any
  * associated property ids.
  */
 public interface BasePredicate extends Predicate, PredicateVisitorAcceptor {
-  public Set<String> getPropertyIds();
+  Set<String> getPropertyIds();
 }
