@@ -21,7 +21,6 @@ package org.apache.ambari.server.orm.dao;
 import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.Date;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -46,7 +45,10 @@ import org.apache.ambari.server.orm.entities.StageEntity;
 import org.apache.ambari.server.orm.entities.TopologyHostRequestEntity;
 import org.apache.ambari.server.orm.entities.TopologyHostTaskEntity;
 import org.apache.ambari.server.orm.entities.TopologyLogicalTaskEntity;
+import org.apache.ambari.server.orm.helpers.SQLConstants;
+import org.apache.ambari.server.orm.helpers.SQLOperations;
 import org.apache.ambari.server.state.Clusters;
+import org.apache.commons.collections.CollectionUtils;
 import org.eclipse.persistence.config.HintValues;
 import org.eclipse.persistence.config.QueryHints;
 import org.slf4j.Logger;
@@ -64,9 +66,6 @@ public class RequestDAO implements Cleanable {
 
   private static final Logger LOG = LoggerFactory.getLogger(RequestDAO.class);
 
-
-  private static final int BATCH_SIZE = 999;
-
   /**
    * SQL template to retrieve all request IDs, sorted by the ID.
    */
@@ -83,8 +82,6 @@ public class RequestDAO implements Cleanable {
   private final static String REQUESTS_WITH_NO_CLUSTER_SQL =
       "SELECT request.requestId FROM RequestEntity request WHERE request.clusterId = -1 OR request.clusterId IS NULL ORDER BY request.requestId %s";
 
-
-
   @Inject
   Provider<EntityManager> entityManagerProvider;
 
@@ -97,9 +94,6 @@ public class RequestDAO implements Cleanable {
   @Inject
   private HostRoleCommandDAO hostRoleCommandDAO;
 
-  @Inject
-  private StageDAO stageDAO;
-
   @Inject
   private TopologyLogicalTaskDAO topologyLogicalTaskDAO;
 
@@ -130,10 +124,6 @@ public class RequestDAO implements Cleanable {
    */
   @RequiresSession
   public List<RequestEntity> findByPks(Collection<Long> requestIds, boolean refreshHint) {
-    if (null == requestIds || 0 == requestIds.size()) {
-      return Collections.emptyList();
-    }
-
     TypedQuery<RequestEntity> query = entityManagerProvider.get().createQuery("SELECT request FROM RequestEntity request " +
         "WHERE request.requestId IN ?1", RequestEntity.class);
 
@@ -143,7 +133,13 @@ public class RequestDAO implements Cleanable {
       query.setHint(QueryHints.REFRESH, HintValues.TRUE);
     }
 
-    return daoUtils.selectList(query, requestIds);
+    List<RequestEntity> result = new ArrayList<>();
+    SQLOperations.batch(requestIds, SQLConstants.IN_ARGUMENT_MAX_SIZE, (chunk, currentBatch, totalBatches, totalSize) -> {
+      result.addAll(daoUtils.selectList(query, chunk));
+      return 0;
+    });
+
+    return Lists.newArrayList(result);
   }
 
   @RequiresSession
@@ -191,6 +187,14 @@ public class RequestDAO implements Cleanable {
     return daoUtils.selectSingle(query, requestId);
   }
 
+  @Transactional
+  public RequestEntity updateStatus(long requestId, HostRoleStatus status, HostRoleStatus displayStatus) {
+    RequestEntity requestEntity = findByPK(requestId);
+    requestEntity.setStatus(status);
+    requestEntity.setDisplayStatus(displayStatus);
+    return merge(requestEntity);
+  }
+
   @Transactional
   public void create(RequestEntity requestEntity) {
     entityManagerProvider.get().persist(requestEntity);
@@ -215,8 +219,8 @@ public class RequestDAO implements Cleanable {
    * Retrieves from the database for a cluster, or specifically for non-cluster requests.
    * This method should be considered temporary until Request/Stage/Task cleanup is achieved.
    *
-   * @param limit  the max number to return
-   * @param sortAscending    {@code true} to sort by requestId ascending, {@code false} for descending
+   * @param limit the max number to return
+   * @param sortAscending {@code true} to sort by requestId ascending, {@code false} for descending
    * @param clusterId   the cluster to find, or {@code null} to search for requests without cluster
    */
   @RequiresSession
@@ -307,23 +311,21 @@ public class RequestDAO implements Cleanable {
   @Transactional
   protected <T> int cleanTableByIds(Set<Long> ids, String paramName, String entityName, Long beforeDateMillis,
                                   String entityQuery, Class<T> type) {
-    LOG.info(String.format("Deleting %s entities before date %s", entityName, new Date(beforeDateMillis)));
-    EntityManager entityManager = entityManagerProvider.get();
-    int affectedRows = 0;
-    // Batch delete
-    TypedQuery<T> query = entityManager.createNamedQuery(entityQuery, type);
-    if (ids != null && !ids.isEmpty()) {
-      for (int i = 0; i < ids.size(); i += BATCH_SIZE) {
-        int endRow = (i + BATCH_SIZE) > ids.size() ? ids.size() : (i + BATCH_SIZE);
-        List<Long> idsSubList = new ArrayList<>(ids).subList(i, endRow);
-        LOG.info("Deleting " + entityName + " entity batch with task ids: " +
-                idsSubList.get(0) + " - " + idsSubList.get(idsSubList.size() - 1));
-        query.setParameter(paramName, idsSubList);
-        affectedRows += query.executeUpdate();
-      }
+    LOG.info(String.format("Purging %s entity records before date %s", entityName, new Date(beforeDateMillis)));
+
+    if (CollectionUtils.isEmpty(ids)) {
+      return 0;
     }
 
-    return affectedRows;
+    final EntityManager entityManager = entityManagerProvider.get();
+    final TypedQuery<T> query = entityManager.createNamedQuery(entityQuery, type);
+
+    // Batch delete
+    return SQLOperations.batch(ids, SQLConstants.IN_ARGUMENT_MAX_SIZE, (chunk, currentBatch, totalBatches, totalSize) -> {
+      LOG.info(String.format("Purging %s entity, batch %s/%s.", entityName, currentBatch, totalBatches));
+      query.setParameter(paramName, chunk);
+      return query.executeUpdate();
+    });
   }
 
   /**
@@ -342,35 +344,34 @@ public class RequestDAO implements Cleanable {
   @Transactional
   protected <T> int cleanTableByStageEntityPK(List<StageEntityPK> ids, LinkedList<String> paramNames, String entityName, Long beforeDateMillis,
                                   String entityQuery, Class<T> type) {
-    LOG.info(String.format("Deleting %s entities before date %s", entityName, new Date(beforeDateMillis)));
-    EntityManager entityManager = entityManagerProvider.get();
-    int affectedRows = 0;
-    // Batch delete
-    TypedQuery<T> query = entityManager.createNamedQuery(entityQuery, type);
-    if (ids != null && !ids.isEmpty()) {
-      for (int i = 0; i < ids.size(); i += BATCH_SIZE) {
-        int endRow = (i + BATCH_SIZE) > ids.size() ? ids.size() : (i + BATCH_SIZE);
-        List<StageEntityPK> idsSubList = new ArrayList<>(ids).subList(i, endRow);
-        LOG.info("Deleting " + entityName + " entity batch with task ids: " +
-                idsSubList.get(0) + " - " + idsSubList.get(idsSubList.size() - 1));
-        for (StageEntityPK requestIds : idsSubList) {
-          query.setParameter(paramNames.get(0), requestIds.getStageId());
-          query.setParameter(paramNames.get(1), requestIds.getRequestId());
-          affectedRows += query.executeUpdate();
-        }
-      }
+    LOG.info(String.format("Purging %s entity records before date %s", entityName, new Date(beforeDateMillis)));
+
+    if (CollectionUtils.isEmpty(ids)) {
+      return 0;
     }
 
-    return affectedRows;
+    final EntityManager entityManager = entityManagerProvider.get();
+    final TypedQuery<T> query = entityManager.createNamedQuery(entityQuery, type);
+
+    // Batch delete
+    return SQLOperations.batch(ids, SQLConstants.IN_ARGUMENT_MAX_SIZE, (chunk, currentBatch, totalBatches, totalSize) -> {
+      int affectedRows = 0;
+
+      for (StageEntityPK requestIds : chunk) {
+        query.setParameter(paramNames.get(0), requestIds.getStageId());
+        query.setParameter(paramNames.get(1), requestIds.getRequestId());
+        affectedRows += query.executeUpdate();
+      }
+      return affectedRows;
+    });
   }
 
   @Transactional
   @Override
   public long cleanup(TimeBasedCleanupPolicy policy) {
     long affectedRows = 0;
-    Long clusterId = null;
     try {
-      clusterId = m_clusters.get().getCluster(policy.getClusterName()).getClusterId();
+      Long clusterId = m_clusters.get().getCluster(policy.getClusterName()).getClusterId();
       // find request and stage ids that were created before date populated by user.
       List<StageEntityPK> requestStageIds = findRequestAndStageIdsInClusterBeforeDate(clusterId, policy.getToDateInMillis());
 
@@ -378,17 +379,14 @@ public class RequestDAO implements Cleanable {
       // request ids set that we already have. We don't want to make any changes for upgrade
       Set<Long> requestIdsFromUpgrade = findAllRequestIdsFromUpgrade();
       Iterator<StageEntityPK> requestStageIdsIterator =  requestStageIds.iterator();
+      Set<Long> requestIds = new HashSet<>();
       while (requestStageIdsIterator.hasNext()) {
         StageEntityPK nextRequestStageIds = requestStageIdsIterator.next();
         if (requestIdsFromUpgrade.contains(nextRequestStageIds.getRequestId())) {
           requestStageIdsIterator.remove();
+          continue;
         }
-      }
-
-
-      Set<Long> requestIds = new HashSet<>();
-      for (StageEntityPK ids : requestStageIds) {
-        requestIds.add(ids.getRequestId());
+        requestIds.add(nextRequestStageIds.getRequestId());
       }
 
       // find task ids using request stage ids
@@ -398,47 +396,36 @@ public class RequestDAO implements Cleanable {
       params.add("requestId");
 
       // find host task ids, to find related host requests and also to remove needed host tasks
-      Set<Long> hostTaskIds = new HashSet<>();
-      if (taskIds != null && !taskIds.isEmpty()) {
-        hostTaskIds = topologyLogicalTaskDAO.findHostTaskIdsByPhysicalTaskIds(taskIds);
-      }
+      Set<Long> hostTaskIds = topologyLogicalTaskDAO.findHostTaskIdsByPhysicalTaskIds(taskIds);
 
       // find host request ids by host task ids to remove later needed host requests
-      Set<Long> hostRequestIds = new HashSet<>();
-      if (!hostTaskIds.isEmpty()) {
-        hostRequestIds = topologyHostTaskDAO.findHostRequestIdsByHostTaskIds(hostTaskIds);
-      }
-
-      Set<Long> topologyRequestIds = new HashSet<>();
-      if (!hostRequestIds.isEmpty()) {
-        topologyRequestIds = topologyLogicalRequestDAO.findRequestIdsByIds(hostRequestIds);
-      }
-
+      Set<Long> hostRequestIds = topologyHostTaskDAO.findHostRequestIdsByHostTaskIds(hostTaskIds);
+      Set<Long> topologyRequestIds = topologyLogicalRequestDAO.findRequestIdsByIds(hostRequestIds);
 
       //removing all entities one by one according to their relations using stage, task and request ids
       affectedRows += cleanTableByIds(taskIds, "taskIds", "ExecutionCommand", policy.getToDateInMillis(),
-              "ExecutionCommandEntity.removeByTaskIds", ExecutionCommandEntity.class);
+        "ExecutionCommandEntity.removeByTaskIds", ExecutionCommandEntity.class);
       affectedRows += cleanTableByIds(taskIds, "taskIds", "TopologyLogicalTask", policy.getToDateInMillis(),
-              "TopologyLogicalTaskEntity.removeByPhysicalTaskIds", TopologyLogicalTaskEntity.class);
+        "TopologyLogicalTaskEntity.removeByPhysicalTaskIds", TopologyLogicalTaskEntity.class);
       affectedRows += cleanTableByIds(hostTaskIds, "hostTaskIds", "TopologyHostTask", policy.getToDateInMillis(),
-              "TopologyHostTaskEntity.removeByTaskIds", TopologyHostTaskEntity.class);
+        "TopologyHostTaskEntity.removeByTaskIds", TopologyHostTaskEntity.class);
       affectedRows += cleanTableByIds(hostRequestIds, "hostRequestIds", "TopologyHostRequest", policy.getToDateInMillis(),
-              "TopologyHostRequestEntity.removeByIds", TopologyHostRequestEntity.class);
+        "TopologyHostRequestEntity.removeByIds", TopologyHostRequestEntity.class);
       for (Long topologyRequestId : topologyRequestIds) {
         topologyRequestDAO.removeByPK(topologyRequestId);
       }
       affectedRows += cleanTableByIds(taskIds, "taskIds", "HostRoleCommand", policy.getToDateInMillis(),
-              "HostRoleCommandEntity.removeByTaskIds", HostRoleCommandEntity.class);
+        "HostRoleCommandEntity.removeByTaskIds", HostRoleCommandEntity.class);
       affectedRows += cleanTableByStageEntityPK(requestStageIds, params, "RoleSuccessCriteria", policy.getToDateInMillis(),
-              "RoleSuccessCriteriaEntity.removeByRequestStageIds", RoleSuccessCriteriaEntity.class);
+        "RoleSuccessCriteriaEntity.removeByRequestStageIds", RoleSuccessCriteriaEntity.class);
       affectedRows += cleanTableByStageEntityPK(requestStageIds, params, "Stage", policy.getToDateInMillis(),
-              "StageEntity.removeByRequestStageIds", StageEntity.class);
+        "StageEntity.removeByRequestStageIds", StageEntity.class);
       affectedRows += cleanTableByIds(requestIds, "requestIds", "RequestResourceFilter", policy.getToDateInMillis(),
-              "RequestResourceFilterEntity.removeByRequestIds", RequestResourceFilterEntity.class);
+        "RequestResourceFilterEntity.removeByRequestIds", RequestResourceFilterEntity.class);
       affectedRows += cleanTableByIds(requestIds, "requestIds", "RequestOperationLevel", policy.getToDateInMillis(),
-              "RequestOperationLevelEntity.removeByRequestIds", RequestOperationLevelEntity.class);
+        "RequestOperationLevelEntity.removeByRequestIds", RequestOperationLevelEntity.class);
       affectedRows += cleanTableByIds(requestIds, "requestIds", "Request", policy.getToDateInMillis(),
-              "RequestEntity.removeByRequestIds", RequestEntity.class);
+        "RequestEntity.removeByRequestIds", RequestEntity.class);
 
     } catch (AmbariException e) {
       LOG.error("Error while looking up cluster with name: {}", policy.getClusterName(), e);
