@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -45,24 +45,30 @@ import javax.persistence.TableGenerator;
 import javax.persistence.Transient;
 import javax.persistence.UniqueConstraint;
 
-import com.google.inject.AbstractModule;
-import com.google.inject.Guice;
-import com.google.inject.Injector;
 import org.apache.ambari.server.controller.spi.Resource;
 import org.apache.ambari.server.security.SecurityHelper;
 import org.apache.ambari.server.security.SecurityHelperImpl;
 import org.apache.ambari.server.security.authorization.AmbariAuthorizationFilter;
+import org.apache.ambari.server.security.authorization.AuthorizationHelper;
 import org.apache.ambari.server.view.ViewContextImpl;
 import org.apache.ambari.server.view.ViewRegistry;
 import org.apache.ambari.server.view.configuration.InstanceConfig;
 import org.apache.ambari.server.view.validation.InstanceValidationResultImpl;
 import org.apache.ambari.server.view.validation.ValidationException;
 import org.apache.ambari.server.view.validation.ValidationResultImpl;
-import org.apache.ambari.view.*;
+import org.apache.ambari.view.ClusterType;
+import org.apache.ambari.view.ResourceProvider;
+import org.apache.ambari.view.ViewContext;
+import org.apache.ambari.view.ViewDefinition;
+import org.apache.ambari.view.ViewInstanceDefinition;
 import org.apache.ambari.view.migration.ViewDataMigrationContext;
 import org.apache.ambari.view.migration.ViewDataMigrator;
-import org.apache.ambari.view.validation.Validator;
 import org.apache.ambari.view.validation.ValidationResult;
+import org.apache.ambari.view.validation.Validator;
+
+import com.google.inject.AbstractModule;
+import com.google.inject.Guice;
+import com.google.inject.Injector;
 
 /**
  * Represents an instance of a View.
@@ -180,19 +186,19 @@ public class ViewInstanceEntity implements ViewInstanceDefinition {
    * The instance properties.
    */
   @OneToMany(cascade = CascadeType.ALL, mappedBy = "viewInstance")
-  private Collection<ViewInstancePropertyEntity> properties = new HashSet<ViewInstancePropertyEntity>();
+  private Collection<ViewInstancePropertyEntity> properties = new HashSet<>();
 
   /**
    * The instance data.
    */
   @OneToMany(cascade = CascadeType.ALL, mappedBy = "viewInstance")
-  private Collection<ViewInstanceDataEntity> data = new HashSet<ViewInstanceDataEntity>();
+  private Collection<ViewInstanceDataEntity> data = new HashSet<>();
 
   /**
    * The list of view entities.
    */
   @OneToMany(cascade = CascadeType.ALL, mappedBy = "viewInstance")
-  private Collection<ViewEntityEntity> entities = new HashSet<ViewEntityEntity>();
+  private Collection<ViewEntityEntity> entities = new HashSet<>();
 
   @ManyToOne
   @JoinColumn(name = "view_name", referencedColumnName = "view_name", nullable = false)
@@ -219,14 +225,14 @@ public class ViewInstanceEntity implements ViewInstanceDefinition {
    * instance is added.
    */
   @Transient
-  private final Map<Resource.Type, ResourceProvider> resourceProviders = new HashMap<Resource.Type, ResourceProvider>();
+  private final Map<Resource.Type, ResourceProvider> resourceProviders = new HashMap<>();
 
   /**
    * The mapping of the resource plural name to service.  Calculated when the
    * instance is added.
    */
   @Transient
-  private final Map<String, Object> services = new HashMap<String, Object>();
+  private final Map<String, Object> services = new HashMap<>();
 
   /**
    * Helper class.
@@ -319,7 +325,7 @@ public class ViewInstanceEntity implements ViewInstanceDefinition {
 
   @Override
   public Map<String, String> getPropertyMap() {
-    Map<String, String> propertyMap = new HashMap<String, String>();
+    Map<String, String> propertyMap = new HashMap<>();
 
     for (ViewInstancePropertyEntity viewInstancePropertyEntity : getProperties()) {
       propertyMap.put(viewInstancePropertyEntity.getName(), viewInstancePropertyEntity.getValue());
@@ -335,7 +341,7 @@ public class ViewInstanceEntity implements ViewInstanceDefinition {
 
   @Override
   public Map<String, String> getInstanceDataMap() {
-    Map<String, String> applicationData = new HashMap<String, String>();
+    Map<String, String> applicationData = new HashMap<>();
 
     String user = getCurrentUserName();
 
@@ -806,7 +812,7 @@ public class ViewInstanceEntity implements ViewInstanceDefinition {
    * @return the current user name; empty String if user is not known
    */
   public String getUsername() {
-    return securityHelper.getCurrentUserName();
+    return AuthorizationHelper.resolveLoginAliasToUserName(securityHelper.getCurrentUserName());
   }
 
   /**
@@ -889,14 +895,14 @@ public class ViewInstanceEntity implements ViewInstanceDefinition {
   public InstanceValidationResultImpl getValidationResult(ViewEntity viewEntity, Validator.ValidationContext context)
       throws IllegalStateException {
 
-    Map<String, ValidationResult> propertyResults = new HashMap<String, ValidationResult>();
+    Map<String, ValidationResult> propertyResults = new HashMap<>();
 
     if (context.equals(Validator.ValidationContext.PRE_CREATE) ||
         context.equals(Validator.ValidationContext.PRE_UPDATE)) {
 
       // make sure that there is an instance property value defined
       // for each required view parameter
-      Set<String> requiredParameterNames = new HashSet<String>();
+      Set<String> requiredParameterNames = new HashSet<>();
       for (ViewParameterEntity parameter : viewEntity.getParameters()) {
         if (parameter.isRequired()) {
           // Don't enforce 'required' validation for cluster config parameters since
