@@ -20,7 +20,7 @@ package org.apache.ambari.server.serveraction.kerberos;
 
 import java.io.File;
 import java.io.IOException;
-import java.lang.reflect.Type;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
@@ -32,18 +32,27 @@ import java.util.Set;
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.agent.CommandReport;
 import org.apache.ambari.server.controller.KerberosHelper;
+import org.apache.ambari.server.controller.RootComponent;
+import org.apache.ambari.server.controller.RootService;
+import org.apache.ambari.server.controller.UpdateConfigurationPolicy;
+import org.apache.ambari.server.orm.dao.KerberosKeytabPrincipalDAO;
+import org.apache.ambari.server.orm.entities.KerberosKeytabPrincipalEntity;
+import org.apache.ambari.server.serveraction.kerberos.stageutils.ResolvedKerberosKeytab;
+import org.apache.ambari.server.serveraction.kerberos.stageutils.ResolvedKerberosPrincipal;
 import org.apache.ambari.server.state.Cluster;
+import org.apache.ambari.server.state.ConfigHelper;
 import org.apache.ambari.server.state.ServiceComponentHost;
+import org.apache.ambari.server.state.kerberos.AbstractKerberosDescriptorContainer;
 import org.apache.ambari.server.state.kerberos.KerberosComponentDescriptor;
 import org.apache.ambari.server.state.kerberos.KerberosDescriptor;
 import org.apache.ambari.server.state.kerberos.KerberosIdentityDescriptor;
 import org.apache.ambari.server.state.kerberos.KerberosServiceDescriptor;
 import org.apache.ambari.server.utils.StageUtils;
+import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.reflect.TypeToken;
 import com.google.inject.Inject;
 
 public abstract class AbstractPrepareKerberosServerAction extends KerberosServerAction {
@@ -61,23 +70,42 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
   @Inject
   private KerberosConfigDataFileWriterFactory kerberosConfigDataFileWriterFactory;
 
+  @Inject
+  private ConfigHelper configHelper;
+
+  @Inject
+  private KerberosKeytabPrincipalDAO kerberosKeytabPrincipalDAO;
+
   @Override
-  protected CommandReport processIdentity(Map<String, String> identityRecord, String evaluatedPrincipal, KerberosOperationHandler operationHandler, Map<String, String> kerberosConfiguration, Map<String, Object> requestSharedDataContext) throws AmbariException {
+  protected CommandReport processIdentity(ResolvedKerberosPrincipal resolvedPrincipal, KerberosOperationHandler operationHandler, Map<String, String> kerberosConfiguration, boolean includedInFilter, Map<String, Object> requestSharedDataContext) throws AmbariException {
     throw new UnsupportedOperationException();
   }
 
-  KerberosHelper getKerberosHelper() {
+  protected KerberosHelper getKerberosHelper() {
     return kerberosHelper;
   }
 
-  void processServiceComponentHosts(Cluster cluster, KerberosDescriptor kerberosDescriptor,
-                                    List<ServiceComponentHost> schToProcess,
-                                    Collection<String> identityFilter, String dataDirectory,
-                                    Map<String, Map<String, String>> currentConfigurations,
-                                    Map<String, Map<String, String>> kerberosConfigurations,
-                                    boolean includeAmbariIdentity,
-                                    Map<String, Set<String>> propertiesToBeIgnored,
-                                    boolean excludeHeadless) throws AmbariException {
+  public void processServiceComponentHosts(Cluster cluster, KerberosDescriptor kerberosDescriptor,
+                                           List<ServiceComponentHost> schToProcess,
+                                           Collection<String> identityFilter, String dataDirectory,
+                                           Map<String, Map<String, String>> currentConfigurations,
+                                           Map<String, Map<String, String>> kerberosConfigurations,
+                                           boolean includeAmbariIdentity,
+                                           Map<String, Set<String>> propertiesToBeIgnored) throws AmbariException {
+    List<Component> components = new ArrayList<>();
+    for (ServiceComponentHost each : schToProcess) {
+      components.add(Component.fromServiceComponentHost(each));
+    }
+    processServiceComponents(cluster, kerberosDescriptor, components, identityFilter, dataDirectory, currentConfigurations, kerberosConfigurations, includeAmbariIdentity, propertiesToBeIgnored);
+  }
+
+  protected void processServiceComponents(Cluster cluster, KerberosDescriptor kerberosDescriptor,
+                                          List<Component> schToProcess,
+                                          Collection<String> identityFilter, String dataDirectory,
+                                          Map<String, Map<String, String>> currentConfigurations,
+                                          Map<String, Map<String, String>> kerberosConfigurations,
+                                          boolean includeAmbariIdentity,
+                                          Map<String, Set<String>> propertiesToBeIgnored) throws AmbariException {
 
     actionLog.writeStdOut("Processing Kerberos identities and configurations");
 
@@ -94,7 +122,7 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
       KerberosIdentityDataFileWriter kerberosIdentityDataFileWriter;
 
       // Create the context to use for filtering Kerberos Identities based on the state of the cluster
-      Map<String, Object> filterContext = new HashMap<String, Object>();
+      Map<String, Object> filterContext = new HashMap<>();
       filterContext.put("configurations", currentConfigurations);
       filterContext.put("services", cluster.getServices().keySet());
 
@@ -109,15 +137,17 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
         throw new AmbariException(message, e);
       }
 
+      HashMap<String, ResolvedKerberosKeytab> resolvedKeytabs = new HashMap<>();
+      String realm = getDefaultRealm(getCommandParameters());
+
       try {
         Map<String, Set<String>> propertiesToIgnore = null;
-
         // Iterate over the components installed on the current host to get the service and
         // component-level Kerberos descriptors in order to determine which principals,
         // keytab files, and configurations need to be created or updated.
-        for (ServiceComponentHost sch : schToProcess) {
+        for (Component sch : schToProcess) {
           String hostName = sch.getHostName();
-
+          Long hostId = sch.getHostId();
           String serviceName = sch.getServiceName();
           String componentName = sch.getServiceComponentName();
 
@@ -128,11 +158,7 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
 
             if (!StringUtils.isEmpty(hostName)) {
               // Update the configurations with the relevant hostname
-              Map<String, String> generalProperties = currentConfigurations.get("");
-              if (generalProperties == null) {
-                generalProperties = new HashMap<>();
-                currentConfigurations.put("", generalProperties);
-              }
+              Map<String, String> generalProperties = currentConfigurations.computeIfAbsent("", k -> new HashMap<>());
 
               // Add the current hostname under "host" and "hostname"
               generalProperties.put("host", hostName);
@@ -141,7 +167,8 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
 
             // Add service-level principals (and keytabs)
             kerberosHelper.addIdentities(kerberosIdentityDataFileWriter, serviceIdentities,
-                identityFilter, hostName, serviceName, componentName, kerberosConfigurations, currentConfigurations, excludeHeadless);
+                identityFilter, hostName, hostId, serviceName, componentName, kerberosConfigurations, currentConfigurations,
+                resolvedKeytabs, realm);
             propertiesToIgnore = gatherPropertiesToIgnore(serviceIdentities, propertiesToIgnore);
 
             KerberosComponentDescriptor componentDescriptor = serviceDescriptor.getComponent(componentName);
@@ -156,7 +183,8 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
 
               // Add component-level principals (and keytabs)
               kerberosHelper.addIdentities(kerberosIdentityDataFileWriter, componentIdentities,
-                  identityFilter, hostName, serviceName, componentName, kerberosConfigurations, currentConfigurations, excludeHeadless);
+                  identityFilter, hostName, hostId, serviceName, componentName, kerberosConfigurations, currentConfigurations,
+                  resolvedKeytabs, realm);
               propertiesToIgnore = gatherPropertiesToIgnore(componentIdentities, propertiesToIgnore);
             }
           }
@@ -173,11 +201,12 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
               // component.
               String componentName = KerberosHelper.AMBARI_SERVER_KERBEROS_IDENTITY_NAME.equals(identity.getName())
                   ? "AMBARI_SERVER_SELF"
-                  : "AMBARI_SERVER";
+                  : RootComponent.AMBARI_SERVER.name();
 
               List<KerberosIdentityDescriptor> componentIdentities = Collections.singletonList(identity);
               kerberosHelper.addIdentities(kerberosIdentityDataFileWriter, componentIdentities,
-                  identityFilter, KerberosHelper.AMBARI_SERVER_HOST_NAME, "AMBARI", componentName, kerberosConfigurations, currentConfigurations, excludeHeadless);
+                  identityFilter, StageUtils.getHostName(), ambariServerHostID(), RootService.AMBARI.name(), componentName, kerberosConfigurations, currentConfigurations,
+                  resolvedKeytabs, realm);
               propertiesToIgnore = gatherPropertiesToIgnore(componentIdentities, propertiesToIgnore);
             }
           }
@@ -186,6 +215,10 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
         if ((propertiesToBeIgnored != null) && (propertiesToIgnore != null)) {
           propertiesToBeIgnored.putAll(propertiesToIgnore);
         }
+
+        // create database records for keytab that must be presented on cluster
+        List<KerberosKeytabPrincipalEntity> keytabList = kerberosKeytabPrincipalDAO.findAll();
+        resolvedKeytabs.values().forEach(keytab -> kerberosHelper.createResolvedKeytab(keytab, keytabList));
       } catch (IOException e) {
         String message = String.format("Failed to write index file - %s", identityDataFile.getAbsolutePath());
         LOG.error(message, e);
@@ -208,45 +241,12 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
     }
   }
 
-  protected Map<String, ? extends Collection<String>> getServiceComponentFilter() {
-    String serializedValue = getCommandParameterValue(SERVICE_COMPONENT_FILTER);
-
-    if(serializedValue != null) {
-      Type type = new TypeToken<Map<String, ? extends Collection<String>>>() {}.getType();
-      return StageUtils.getGson().fromJson(serializedValue, type);
-    } else {
-      return null;
-    }
-  }
-
-  protected Set<String> getHostFilter() {
-    String serializedValue = getCommandParameterValue(HOST_FILTER);
-
-    if(serializedValue != null) {
-      Type type = new TypeToken<Set<String>>() {}.getType();
-      return StageUtils.getGson().fromJson(serializedValue, type);
-    } else {
-      return null;
-    }
-  }
-
-  protected Collection<String> getIdentityFilter() {
-    String serializedValue = getCommandParameterValue(IDENTITY_FILTER);
-
-    if(serializedValue != null) {
-      Type type = new TypeToken<Collection<String>>() {}.getType();
-      return StageUtils.getGson().fromJson(serializedValue, type);
-    } else {
-      return null;
-    }
-  }
-
   private Map<String, Set<String>> gatherPropertiesToIgnore(List<KerberosIdentityDescriptor> identities,
                                                             Map<String, Set<String>> propertiesToIgnore) {
     Map<String, Map<String, String>> identityConfigurations = kerberosHelper.getIdentityConfigurations(identities);
     if ((identityConfigurations != null) && !identityConfigurations.isEmpty()) {
       if (propertiesToIgnore == null) {
-        propertiesToIgnore = new HashMap<String, Set<String>>();
+        propertiesToIgnore = new HashMap<>();
       }
 
       for (Map.Entry<String, Map<String, String>> entry : identityConfigurations.entrySet()) {
@@ -256,7 +256,7 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
         if ((properties != null) && !properties.isEmpty()) {
           Set<String> propertyNames = propertiesToIgnore.get(configType);
           if (propertyNames == null) {
-            propertyNames = new HashSet<String>();
+            propertyNames = new HashSet<>();
             propertiesToIgnore.put(configType, propertyNames);
           }
           propertyNames.addAll(properties.keySet());
@@ -273,15 +273,19 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
    * If work is to be done, a data file containing the details is created so it they changes may be
    * processed in the appropriate stage.
    *
-   * @param dataDirectory          the directory in which to write the configuration changes data file
-   * @param kerberosConfigurations the Kerberos-specific configuration map
-   * @param propertiesToBeRemoved  a map of properties to be removed from the current configuration,
-   *                               grouped by configuration type.
+   * @param dataDirectory             the directory in which to write the configuration changes data file
+   * @param kerberosConfigurations    the Kerberos-specific configuration map
+   * @param propertiesToBeRemoved     a map of properties to be removed from the current configuration,
+   *                                  grouped by configuration type.
+   * @param kerberosDescriptor        the Kerberos descriptor
+   * @param updateConfigurationPolicy the policy used to determine which configurations to update
    * @throws AmbariException
    */
   protected void processConfigurationChanges(String dataDirectory,
                                              Map<String, Map<String, String>> kerberosConfigurations,
-                                             Map<String, Set<String>> propertiesToBeRemoved)
+                                             Map<String, Set<String>> propertiesToBeRemoved,
+                                             KerberosDescriptor kerberosDescriptor,
+                                             UpdateConfigurationPolicy updateConfigurationPolicy)
       throws AmbariException {
     actionLog.writeStdOut("Determining configuration changes");
 
@@ -294,6 +298,12 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
         throw new AmbariException(message);
       }
 
+      // Determine what the relevant Kerberos identity-related properties are...
+      Map<String, Set<String>> kerberosIdentityProperties = getIdentityProperties(kerberosDescriptor, null);
+
+      // Determine what the existing properties are...
+      Map<String, Map<String, String>> existingProperties = configHelper.getEffectiveConfigProperties(getClusterName(), null);
+
       File configFile = new File(dataDirectory, KerberosConfigDataFileWriter.DATA_FILE_NAME);
       KerberosConfigDataFileWriter kerberosConfDataFileWriter = null;
 
@@ -307,10 +317,15 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
 
           if (properties != null) {
             for (Map.Entry<String, String> configTypeEntry : properties.entrySet()) {
-              kerberosConfDataFileWriter.addRecord(type,
-                  configTypeEntry.getKey(),
-                  configTypeEntry.getValue(),
-                  KerberosConfigDataFileWriter.OPERATION_TYPE_SET);
+
+              // Determine if this configuration should be written or not...
+              String propertyName = configTypeEntry.getKey();
+              if (includeConfiguration(type, propertyName, updateConfigurationPolicy, existingProperties, kerberosIdentityProperties)) {
+                kerberosConfDataFileWriter.addRecord(type,
+                    propertyName,
+                    configTypeEntry.getValue(),
+                    KerberosConfigDataFileWriter.OPERATION_TYPE_SET);
+              }
             }
           }
         }
@@ -350,4 +365,120 @@ public abstract class AbstractPrepareKerberosServerAction extends KerberosServer
       }
     }
   }
+
+  /**
+   * Determine of the configuration should be included in the set of configurations to update.
+   *
+   * @param configType
+   * @param propertyName
+   * @param updateConfigurationPolicy
+   * @param existingProperties
+   * @param kerberosIdentityProperties
+   * @return
+   */
+  private boolean includeConfiguration(String configType, String propertyName,
+                                       UpdateConfigurationPolicy updateConfigurationPolicy,
+                                       Map<String, Map<String, String>> existingProperties,
+                                       Map<String, Set<String>> kerberosIdentityProperties) {
+
+    // Determine if the property represents a Kerberos identity-related property
+    boolean isIdentity;
+    if (kerberosIdentityProperties == null) {
+      isIdentity = false;
+    } else {
+      Set<String> propertyNames = kerberosIdentityProperties.get(configType);
+      isIdentity = !CollectionUtils.isEmpty(propertyNames) && propertyNames.contains(propertyName);
+    }
+
+    if (isIdentity) {
+      return updateConfigurationPolicy.applyIdentityChanges();
+    }
+
+    // Determine if the property is a new property
+    boolean isNew;
+    if (existingProperties == null) {
+      isNew = true;
+    } else {
+      Map<String, String> propertyNames = existingProperties.get(configType);
+      isNew = (propertyNames == null) || !propertyNames.containsKey(propertyName);
+    }
+
+    if (isNew) {
+      return updateConfigurationPolicy.applyAdditions();
+    }
+
+    // All other properties...
+    return updateConfigurationPolicy.applyOtherChanges();
+  }
+
+  /**
+   * Recursively processes a Kerberos descriptor container and it children to find the
+   * Kerberos identity-related properties.
+   * <p>
+   * Kerberos identity-related properties are those that contain the following information:
+   * <ul>
+   * <li>principal names</li>
+   * <li>keytab file paths</li>
+   * <li>auth-to-local rules</li>
+   * </ul>
+   *
+   * @param container          the AbstractKerberosDescriptorContainer to process
+   * @param identityProperties a map of config-types to sets of property names to append data
+   * @return a map of config-types to sets of property names
+   */
+  private Map<String, Set<String>> getIdentityProperties(AbstractKerberosDescriptorContainer container, Map<String, Set<String>> identityProperties) {
+    if (container != null) {
+      if (identityProperties == null) {
+        identityProperties = new HashMap<>();
+      }
+
+      // Process the Kerberos identities - principal and keytab file properties.
+      List<KerberosIdentityDescriptor> identityDescriptors;
+      try {
+        // There is no need to resolve references since we just need to get the set of configurations that can be changed.
+        identityDescriptors = container.getIdentities(false, null);
+      } catch (AmbariException e) {
+        LOG.error("An exception occurred getting the Kerberos identity descriptors.  No configurations will be identified.", e);
+        identityDescriptors = null;
+      }
+
+      if (identityDescriptors != null) {
+        Map<String, Map<String, String>> identityConfigurations = kerberosHelper.getIdentityConfigurations(identityDescriptors);
+
+        if (identityConfigurations != null) {
+          for (Map.Entry<String, Map<String, String>> entry : identityConfigurations.entrySet()) {
+            Map<String, String> properties = entry.getValue();
+            if (properties != null) {
+              Set<String> configProperties = identityProperties.computeIfAbsent(entry.getKey(), k -> new HashSet<>());
+              configProperties.addAll(properties.keySet());
+            }
+          }
+        }
+      }
+
+      // Process any auth-to-local rule properties
+      Map<String, Set<String>> authToLocalProperties = kerberosHelper.translateConfigurationSpecifications(container.getAuthToLocalProperties());
+      if (authToLocalProperties != null) {
+        for (Map.Entry<String, Set<String>> entry : authToLocalProperties.entrySet()) {
+          String configType = entry.getKey();
+          Set<String> propertyNames = entry.getValue();
+
+          if (propertyNames != null) {
+            Set<String> configProperties = identityProperties.computeIfAbsent(configType, k -> new HashSet<>());
+            configProperties.addAll(propertyNames);
+          }
+        }
+      }
+
+      // Process the children...
+      Collection<? extends AbstractKerberosDescriptorContainer> childContainers = container.getChildContainers();
+      if (childContainers != null) {
+        for (AbstractKerberosDescriptorContainer childContainer : childContainers) {
+          getIdentityProperties(childContainer, identityProperties);
+        }
+      }
+    }
+
+    return identityProperties;
+  }
 }
