@@ -26,18 +26,21 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentMap;
+import java.util.stream.Collectors;
 
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.actionmanager.HostRoleStatus;
 import org.apache.ambari.server.agent.CommandReport;
+import org.apache.ambari.server.agent.stomp.AgentConfigsHolder;
+import org.apache.ambari.server.agent.stomp.MetadataHolder;
 import org.apache.ambari.server.api.services.AmbariMetaInfo;
 import org.apache.ambari.server.configuration.Configuration;
 import org.apache.ambari.server.controller.AmbariManagementController;
+import org.apache.ambari.server.controller.AmbariManagementControllerImpl;
 import org.apache.ambari.server.controller.ConfigurationRequest;
 import org.apache.ambari.server.orm.entities.RepositoryVersionEntity;
 import org.apache.ambari.server.serveraction.ServerAction;
 import org.apache.ambari.server.state.Cluster;
-import org.apache.ambari.server.state.Clusters;
 import org.apache.ambari.server.state.Config;
 import org.apache.ambari.server.state.ConfigHelper;
 import org.apache.ambari.server.state.ConfigMergeHelper;
@@ -46,7 +49,9 @@ import org.apache.ambari.server.state.DesiredConfig;
 import org.apache.ambari.server.state.PropertyInfo;
 import org.apache.ambari.server.state.StackId;
 import org.apache.ambari.server.state.UpgradeContext;
+import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.ConditionalField;
 import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.ConfigurationKeyValue;
+import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.IfValueMatchType;
 import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.Insert;
 import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.Masked;
 import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.Replace;
@@ -87,12 +92,7 @@ import com.google.inject.Provider;
 public class ConfigureAction extends AbstractUpgradeServerAction {
 
   private static final Logger LOG = LoggerFactory.getLogger(ConfigureAction.class);
-
-  /**
-   * Used to lookup the cluster.
-   */
-  @Inject
-  private Clusters m_clusters;
+  private static final String ALL_SYMBOL = "*";
 
   /**
    * Used to update the configuration properties.
@@ -129,6 +129,15 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
   @Inject
   private Gson m_gson;
 
+  @Inject
+  private Provider<AmbariManagementControllerImpl> m_ambariManagementController;
+
+  @Inject
+  private Provider<MetadataHolder> m_metadataHolder;
+
+  @Inject
+  private Provider<AgentConfigsHolder> m_agentConfigsHolder;
+
   /**
    * Aside from the normal execution, this method performs the following logic, with
    * the stack values set in the table below:
@@ -183,7 +192,7 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
     }
 
     String clusterName = commandParameters.get("clusterName");
-    Cluster cluster = m_clusters.getCluster(clusterName);
+    Cluster cluster = getClusters().getCluster(clusterName);
     UpgradeContext upgradeContext = getUpgradeContext(cluster);
 
     // such as hdfs-site or hbase-env
@@ -213,8 +222,7 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
     List<Transfer> transfers = Collections.emptyList();
     String transferJson = commandParameters.get(ConfigureTask.PARAMETER_TRANSFERS);
     if (null != transferJson) {
-      transfers = m_gson.fromJson(
-        transferJson, new TypeToken<List<Transfer>>(){}.getType());
+      transfers = m_gson.fromJson(transferJson, new TypeToken<List<Transfer>>(){}.getType());
       transfers = getAllowedTransfers(cluster, configType, transfers);
     }
 
@@ -222,8 +230,7 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
     List<Replace> replacements = Collections.emptyList();
     String replaceJson = commandParameters.get(ConfigureTask.PARAMETER_REPLACEMENTS);
     if (null != replaceJson) {
-      replacements = m_gson.fromJson(
-          replaceJson, new TypeToken<List<Replace>>(){}.getType());
+      replacements = m_gson.fromJson(replaceJson, new TypeToken<List<Replace>>(){}.getType());
       replacements = getAllowedReplacements(cluster, configType, replacements);
     }
 
@@ -231,8 +238,8 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
     List<Insert> insertions = Collections.emptyList();
     String insertJson = commandParameters.get(ConfigureTask.PARAMETER_INSERTIONS);
     if (null != insertJson) {
-      insertions = m_gson.fromJson(
-          insertJson, new TypeToken<List<Insert>>(){}.getType());
+      insertions = m_gson.fromJson(insertJson, new TypeToken<List<Insert>>(){}.getType());
+      insertions = getAllowedInsertions(cluster, configType, insertions);
     }
 
     // if there is nothing to do, then skip the task
@@ -361,7 +368,7 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
 
           break;
         case DELETE:
-          if ("*".equals(transfer.deleteKey)) {
+          if (ALL_SYMBOL.equals(transfer.deleteKey)) {
             newValues.clear();
 
             // append standard output
@@ -466,9 +473,15 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
 
           newValues.put(replacement.key, replaced);
 
-          updateBufferWithMessage(outputBuffer,
-              MessageFormat.format("Replaced {0}/{1} containing \"{2}\" with \"{3}\"", configType,
-                  replacement.key, replacement.find, replacement.replaceWith));
+          // customize the replacement message if the new value is empty
+          if (StringUtils.isEmpty(replacement.replaceWith)) {
+            updateBufferWithMessage(outputBuffer, MessageFormat.format(
+                "Removed \"{0}\" from {1}/{2}", replacement.find, configType, replacement.key));
+          } else {
+            updateBufferWithMessage(outputBuffer,
+                MessageFormat.format("Replaced {0}/{1} containing \"{2}\" with \"{3}\"", configType,
+                    replacement.key, replacement.find, replacement.replaceWith));
+          }
         }
       } else {
         updateBufferWithMessage(outputBuffer, MessageFormat.format(
@@ -521,7 +534,7 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
         newValues.put(insert.key, valueToInsertInto);
 
         updateBufferWithMessage(outputBuffer, MessageFormat.format(
-            "Updated {0}/{1} by inserting {2}", configType, insert.key, insert.value));
+            "Updated {0}/{1} by inserting \"{2}\"", configType, insert.key, insert.value));
       } else {
         updateBufferWithMessage(outputBuffer, MessageFormat.format(
             "Skipping insertion for {0}/{1} because it does not exist or is empty.", configType,
@@ -536,6 +549,9 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
       config.setProperties(newValues);
       config.save();
 
+      m_metadataHolder.get().updateData(m_ambariManagementController.get().getClusterMetadataOnConfigsUpdate(cluster));
+      m_agentConfigsHolder.get().updateData(cluster.getClusterId(), null);
+
       return createCommandReport(0, HostRoleStatus.COMPLETED, "{}", outputBuffer.toString(), "");
     }
 
@@ -596,7 +612,7 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
 
 
     String configType = config.getType();
-    Cluster cluster = m_clusters.getCluster(clusterName);
+    Cluster cluster = getClusters().getCluster(clusterName);
     StackId oldStack = cluster.getCurrentStackVersion();
 
     // iterate over all properties for every cluster service; if the property
@@ -652,8 +668,7 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
     List<Replace> allowedReplacements= new ArrayList<>();
 
     for(Replace replacement: replacements){
-      if(isOperationAllowed(cluster, configType, replacement.key,
-          replacement.ifKey, replacement.ifType, replacement.ifValue, replacement.ifKeyState)) {
+      if(isOperationAllowed(cluster, configType, replacement.key, replacement)) {
         allowedReplacements.add(replacement);
       }
     }
@@ -665,8 +680,7 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
     List<ConfigurationKeyValue> allowedSets = new ArrayList<>();
 
     for(ConfigurationKeyValue configurationKeyValue: sets){
-      if(isOperationAllowed(cluster, configType, configurationKeyValue.key,
-          configurationKeyValue.ifKey, configurationKeyValue.ifType, configurationKeyValue.ifValue, configurationKeyValue.ifKeyState)) {
+      if(isOperationAllowed(cluster, configType, configurationKeyValue.key, configurationKeyValue)) {
         allowedSets.add(configurationKeyValue);
       }
     }
@@ -677,15 +691,14 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
   private List<Transfer> getAllowedTransfers(Cluster cluster, String configType, List<Transfer> transfers){
     List<Transfer> allowedTransfers = new ArrayList<>();
     for (Transfer transfer : transfers) {
-      String key = "";
+      String key;
       if(transfer.operation == TransferOperation.DELETE) {
         key = transfer.deleteKey;
       } else {
         key = transfer.fromKey;
       }
 
-      if(isOperationAllowed(cluster, configType, key,
-          transfer.ifKey, transfer.ifType, transfer.ifValue, transfer.ifKeyState)) {
+      if(isOperationAllowed(cluster, configType, key, transfer)) {
         allowedTransfers.add(transfer);
       }
     }
@@ -693,6 +706,14 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
     return allowedTransfers;
   }
 
+
+  private List<Insert> getAllowedInsertions(Cluster cluster, String configType, List<Insert> insertions){
+    return insertions.stream()
+      .filter(insertion -> isOperationAllowed(cluster, configType, insertion.key, insertion))
+      .collect(Collectors.toList());
+  }
+
+
   /**
    * Gets whether the {@code set} directive is valid based on the optional
    * attributes specified.
@@ -703,66 +724,63 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
    *          the configuration type for the change (not {@code null}).
    * @param targetPropertyKey
    *          the property to set (not {@code null}).
-   * @param ifKey
-   *          the property name to check in order to satisfy a condition, or
-   *          {@code null} if there is no condition.
-   * @param ifType
-   *          the property type to check in order to satisfy a condition, or
-   *          {@code null} if there is no condition.
-   * @param ifValue
-   *          the property value to compare for equality in order to satisfy a
-   *          condition, or {@code null} if there is no condition.
-   * @param ifKeyState
-   *          the state of the if-property. If the property is
-   *          {@link PropertyKeyState#ABSENT}, then execute the set directory
-   *          only if the if-key is absent.
+   * @param operationItem
+   *           operation field compatible with {@link ConditionalField}
    * @return {@code true} if the set operation should be executed by the
    *         upgrade, {@code false} otherwise.
    */
-  private boolean isOperationAllowed(Cluster cluster, String configType, String targetPropertyKey,
-      String ifKey, String ifType, String ifValue, PropertyKeyState ifKeyState){
+  private boolean isOperationAllowed(Cluster cluster, String configType, String targetPropertyKey, ConditionalField operationItem)
+  {
     boolean isAllowed = true;
 
-    boolean ifKeyIsNotBlank = StringUtils.isNotBlank(ifKey);
-    boolean ifTypeIsNotBlank = StringUtils.isNotBlank(ifType);
-    boolean ifValueIsBlank = StringUtils.isBlank(ifValue);
+    boolean ifKeyIsNotBlank = StringUtils.isNotBlank(operationItem.ifKey);
+    boolean ifTypeIsNotBlank = StringUtils.isNotBlank(operationItem.ifType);
+    boolean ifValueIsBlank = StringUtils.isBlank(operationItem.ifValue);
 
     // if-key/if-type and no value - set only if absent
-    if (ifKeyIsNotBlank && ifTypeIsNotBlank && ifValueIsBlank && ifKeyState == PropertyKeyState.ABSENT) {
-      boolean keyPresent = getDesiredConfigurationKeyPresence(cluster, ifType, ifKey);
+    if (ifKeyIsNotBlank && ifTypeIsNotBlank && ifValueIsBlank && operationItem.ifKeyState == PropertyKeyState.ABSENT) {
+      boolean keyPresent = getDesiredConfigurationKeyPresence(cluster, operationItem.ifType, operationItem.ifKey);
       if (keyPresent) {
         LOG.info("Skipping property operation for {}/{} as the key {} for {} is present",
-          configType, targetPropertyKey, ifKey, ifType);
+          configType, targetPropertyKey, operationItem.ifKey, operationItem.ifType);
         isAllowed = false;
       }
       // if-key/if-type and no value - set only is present
-    } else if (ifKeyIsNotBlank && ifTypeIsNotBlank && ifValueIsBlank && ifKeyState == PropertyKeyState.PRESENT) {
-      boolean keyPresent = getDesiredConfigurationKeyPresence(cluster, ifType, ifKey);
+    } else if (ifKeyIsNotBlank && ifTypeIsNotBlank && ifValueIsBlank
+      && operationItem.ifKeyState == PropertyKeyState.PRESENT) {
+
+      boolean keyPresent = getDesiredConfigurationKeyPresence(cluster, operationItem.ifType, operationItem.ifKey);
       if (!keyPresent) {
         LOG.info("Skipping property operation for {}/{} as the key {} for {} is not present",
-          configType, targetPropertyKey, ifKey, ifType);
+          configType, targetPropertyKey, operationItem.ifKey, operationItem.ifType);
         isAllowed = false;
       }
       // if-key/if-type and a value to check - set only if values match
     } else if (ifKeyIsNotBlank && ifTypeIsNotBlank && !ifValueIsBlank) {
-      String ifConfigType = ifType;
-      String checkValue = getDesiredConfigurationValue(cluster, ifConfigType, ifKey);
+      String checkValue = getDesiredConfigurationValue(cluster, operationItem.ifType, operationItem.ifKey);
 
       // the check value is blank and there is an if-key-state of ABSENT - in
       // this case, it means set the value if it matches or if it's absent
-      if (ifKeyState == PropertyKeyState.ABSENT) {
-        boolean keyPresent = getDesiredConfigurationKeyPresence(cluster, ifType, ifKey);
+      if (operationItem.ifKeyState == PropertyKeyState.ABSENT) {
+        boolean keyPresent = getDesiredConfigurationKeyPresence(cluster, operationItem.ifType, operationItem.ifKey);
         if (!keyPresent) {
           return true;
         }
       }
 
       // the if-key was found, so we need to do a comparison
-      if (!StringUtils.equalsIgnoreCase(ifValue, checkValue)) {
-        // skip adding
-        LOG.info("Skipping property operation for {}/{} as the value {} for {}/{} is not equal to {}",
-                 configType, targetPropertyKey, checkValue, ifConfigType, ifKey, ifValue);
-        isAllowed = false;
+      if (operationItem.ifValueMatchType == IfValueMatchType.PARTIAL) {
+        if (!StringUtils.containsIgnoreCase(checkValue, operationItem.ifValue) ^ operationItem.ifValueNotMatched) {
+          LOG.info("Skipping property operation for {}/{} as the value {} for {}/{} is not found in {}",
+            configType, targetPropertyKey, operationItem.ifValue, operationItem.ifType, operationItem.ifKey, checkValue);
+          isAllowed = false;
+        }
+      } else {
+        if (!StringUtils.equalsIgnoreCase(operationItem.ifValue, checkValue) ^ operationItem.ifValueNotMatched) {
+          LOG.info("Skipping property operation for {}/{} as the value {} for {}/{} is not equal to {}",
+            configType, targetPropertyKey, checkValue, operationItem.ifType, operationItem.ifKey, operationItem.ifValue);
+          isAllowed = false;
+        }
       }
     }
 
@@ -832,4 +850,4 @@ public class ConfigureAction extends AbstractUpgradeServerAction {
   private void updateBufferWithMessage(StringBuilder buffer, String message) {
     buffer.append(message).append(System.lineSeparator());
   }
-}
\ No newline at end of file
+}
