@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -20,11 +20,15 @@ package org.apache.ambari.server.state;
 
 import org.apache.ambari.server.orm.entities.HostComponentDesiredStateEntity;
 import org.apache.ambari.server.orm.entities.HostComponentStateEntity;
+import org.apache.ambari.server.orm.entities.ServiceComponentDesiredStateEntity;
 
 public interface ServiceComponentHostFactory {
 
   ServiceComponentHost createNew(ServiceComponent serviceComponent, String hostName);
 
+  ServiceComponentHost createNew(ServiceComponent serviceComponent, String hostName,
+                                 ServiceComponentDesiredStateEntity serviceComponentDesiredStateEntity);
+
   ServiceComponentHost createExisting(ServiceComponent serviceComponent,
                                       HostComponentStateEntity stateEntity,
                                       HostComponentDesiredStateEntity desiredStateEntity);
