@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -22,22 +22,26 @@ import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
+import java.util.stream.Collectors;
 
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.HostNotFoundException;
-import org.apache.ambari.server.StackAccessException;
 import org.apache.ambari.server.agent.AgentEnv;
 import org.apache.ambari.server.agent.DiskInfo;
 import org.apache.ambari.server.agent.HostInfo;
 import org.apache.ambari.server.agent.RecoveryReport;
 import org.apache.ambari.server.api.services.AmbariMetaInfo;
 import org.apache.ambari.server.controller.HostResponse;
+import org.apache.ambari.server.controller.MaintenanceStateHelper;
+import org.apache.ambari.server.events.HostStateUpdateEvent;
+import org.apache.ambari.server.events.HostStatusUpdateEvent;
 import org.apache.ambari.server.events.MaintenanceModeEvent;
 import org.apache.ambari.server.events.publishers.AmbariEventPublisher;
 import org.apache.ambari.server.orm.cache.HostConfigMapping;
@@ -68,6 +72,7 @@ import org.apache.ambari.server.state.HostHealthStatus;
 import org.apache.ambari.server.state.HostHealthStatus.HealthStatus;
 import org.apache.ambari.server.state.HostState;
 import org.apache.ambari.server.state.MaintenanceState;
+import org.apache.ambari.server.state.ServiceComponentHost;
 import org.apache.ambari.server.state.StackId;
 import org.apache.ambari.server.state.UpgradeState;
 import org.apache.ambari.server.state.configgroup.ConfigGroup;
@@ -80,6 +85,7 @@ import org.apache.commons.lang.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.annotations.VisibleForTesting;
 import com.google.gson.Gson;
 import com.google.gson.reflect.TypeToken;
 import com.google.inject.Inject;
@@ -140,6 +146,12 @@ public class HostImpl implements Host {
   @Inject
   private AmbariMetaInfo ambariMetaInfo;
 
+  @Inject
+  private AmbariEventPublisher ambariEventPublisher;
+
+  @Inject
+  private MaintenanceStateHelper maintenanceStateHelper;
+
   /**
    * The ID of the host which is to retrieve it from JPA.
    */
@@ -152,6 +164,12 @@ public class HostImpl implements Host {
   private final String hostName;
 
   private long lastHeartbeatTime = 0L;
+
+  /**
+   * An agent can re-register several times without restarting.
+   * We should save the agent start time to timeout execution commands only on restart, not re-register.
+   */
+  private long lastAgentStartTime = 0L;
   private AgentEnv lastAgentEnv = null;
   private List<DiskInfo> disksInfo = new CopyOnWriteArrayList<>();
   private RecoveryReport recoveryReport = new RecoveryReport();
@@ -303,6 +321,12 @@ public class HostImpl implements Host {
     maintMap = ensureMaintMap(hostEntity.getHostStateEntity());
   }
 
+  @VisibleForTesting
+  HostImpl(HostEntity hostEntity, Gson gson, HostDAO hostDAO, HostStateDAO hostStateDAO, AmbariEventPublisher publisher) {
+    this(hostEntity, gson, hostDAO, hostStateDAO);
+    this.ambariEventPublisher = publisher;
+  }
+
   @Override
   public int compareTo(Object o) {
     if ((o != null ) && (o instanceof Host)) {
@@ -318,21 +342,14 @@ public class HostImpl implements Host {
     @Override
     public void transition(HostImpl host, HostEvent event) {
       HostRegistrationRequestEvent e = (HostRegistrationRequestEvent) event;
-      host.importHostInfo(e.hostInfo);
-      host.setLastRegistrationTime(e.registrationTime);
-      //Initialize heartbeat time and timeInState with registration time.
-      host.setLastHeartbeatTime(e.registrationTime);
-      host.setLastAgentEnv(e.agentEnv);
-      host.setTimeInState(e.registrationTime);
-      host.setAgentVersion(e.agentVersion);
-      host.setPublicHostName(e.publicHostName);
+      host.updateHost(e);
 
       String agentVersion = null;
       if (e.agentVersion != null) {
         agentVersion = e.agentVersion.getVersion();
       }
       LOG.info("Received host registration, host="
-        + e.hostInfo.toString()
+        + e.hostInfo
         + ", registrationTime=" + e.registrationTime
         + ", agentVersion=" + agentVersion);
 
@@ -350,6 +367,11 @@ public class HostImpl implements Host {
       }
 
       host.topologyManager.onHostRegistered(host, associatedWithCluster);
+
+      host.setHealthStatus(new HostHealthStatus(HealthStatus.HEALTHY,
+          host.getHealthStatus().getHealthReport()));
+      // initialize agent times in the last time to prevent setting registering/heartbeat times for failed registration.
+      host.updateHostTimestamps(e);
     }
   }
 
@@ -360,9 +382,7 @@ public class HostImpl implements Host {
     public void transition(HostImpl host, HostEvent event) {
       HostStatusUpdatesReceivedEvent e = (HostStatusUpdatesReceivedEvent)event;
       // TODO Audit logs
-      LOG.debug("Host transition to host status updates received state"
-          + ", host=" + e.getHostName()
-          + ", heartbeatTime=" + e.getTimestamp());
+      LOG.debug("Host transition to host status updates received state, host={}, heartbeatTime={}", e.getHostName(), e.getTimestamp());
       host.setHealthStatus(new HostHealthStatus(HealthStatus.HEALTHY,
         host.getHealthStatus().getHealthReport()));
     }
@@ -409,9 +429,7 @@ public class HostImpl implements Host {
       HostHealthyHeartbeatEvent e = (HostHealthyHeartbeatEvent) event;
       host.setLastHeartbeatTime(e.getHeartbeatTime());
       // TODO Audit logs
-      LOG.debug("Host transitioned to a healthy state"
-              + ", host=" + e.getHostName()
-              + ", heartbeatTime=" + e.getHeartbeatTime());
+      LOG.debug("Host transitioned to a healthy state, host={}, heartbeatTime={}", e.getHostName(), e.getHeartbeatTime());
       host.setHealthStatus(new HostHealthStatus(HealthStatus.HEALTHY, host.getHealthStatus().getHealthReport()));
     }
   }
@@ -424,10 +442,8 @@ public class HostImpl implements Host {
       HostUnhealthyHeartbeatEvent e = (HostUnhealthyHeartbeatEvent) event;
       host.setLastHeartbeatTime(e.getHeartbeatTime());
       // TODO Audit logs
-      LOG.debug("Host transitioned to an unhealthy state"
-          + ", host=" + e.getHostName()
-          + ", heartbeatTime=" + e.getHeartbeatTime()
-          + ", healthStatus=" + e.getHealthStatus());
+      LOG.debug("Host transitioned to an unhealthy state, host={}, heartbeatTime={}, healthStatus={}",
+        e.getHostName(), e.getHeartbeatTime(), e.getHealthStatus());
       host.setHealthStatus(e.getHealthStatus());
     }
   }
@@ -439,11 +455,9 @@ public class HostImpl implements Host {
     public void transition(HostImpl host, HostEvent event) {
       HostHeartbeatLostEvent e = (HostHeartbeatLostEvent) event;
       // TODO Audit logs
-      LOG.debug("Host transitioned to heartbeat lost state"
-          + ", host=" + e.getHostName()
-          + ", lastHeartbeatTime=" + host.getLastHeartbeatTime());
+      LOG.debug("Host transitioned to heartbeat lost state, host={}, lastHeartbeatTime={}", e.getHostName(), host.getLastHeartbeatTime());
       host.setHealthStatus(new HostHealthStatus(HealthStatus.UNKNOWN, host.getHealthStatus().getHealthReport()));
-
+      host.setLastAgentStartTime(0);
       host.topologyManager.onHostHeartBeatLost(host);
     }
   }
@@ -561,6 +575,7 @@ public class HostImpl implements Host {
   public void setState(HostState state) {
     stateMachine.setCurrentState(state);
     HostStateEntity hostStateEntity = getHostStateEntity();
+    ambariEventPublisher.publish(new HostStateUpdateEvent(getHostName(), state));
 
     if (hostStateEntity != null) {
       hostStateEntity.setCurrentState(state);
@@ -569,12 +584,17 @@ public class HostImpl implements Host {
     }
   }
 
+  @Override
+  public void setStateMachineState(HostState state) {
+    stateMachine.setCurrentState(state);
+    ambariEventPublisher.publish(new HostStateUpdateEvent(getHostName(), state));
+  }
+
   @Override
   public void handleEvent(HostEvent event)
       throws InvalidStateTransitionException {
     if (LOG.isDebugEnabled()) {
-      LOG.debug("Handling Host event, eventType=" + event.getType().name()
-          + ", event=" + event.toString());
+      LOG.debug("Handling Host event, eventType={}, event={}", event.getType().name(), event);
     }
     HostState oldState = getState();
     try {
@@ -594,13 +614,10 @@ public class HostImpl implements Host {
       writeLock.unlock();
     }
     if (oldState != getState()) {
+      ambariEventPublisher.publish(new HostStateUpdateEvent(getHostName(), getState()));
       if (LOG.isDebugEnabled()) {
-        LOG.debug("Host transitioned to a new state"
-            + ", host=" + getHostName()
-            + ", oldState=" + oldState
-            + ", currentState=" + getState()
-            + ", eventType=" + event.getType().name()
-            + ", event=" + event);
+        LOG.debug("Host transitioned to a new state, host={}, oldState={}, currentState={}, eventType={}, event={}",
+          getHostName(), oldState, getState(), event.getType().name(), event);
       }
     }
   }
@@ -755,6 +772,11 @@ public class HostImpl implements Host {
 	  return getOSFamilyFromHostAttributes(hostAttributes);
   }
 
+  @Override
+  public String getOsFamily(Map<String, String> hostAttributes) {
+	  return getOSFamilyFromHostAttributes(hostAttributes);
+  }
+
   @Override
   public String getOSFamilyFromHostAttributes(Map<String, String> hostAttributes) {
     try {
@@ -796,6 +818,15 @@ public class HostImpl implements Host {
     return null;
   }
 
+  @Override
+  public HostHealthStatus getHealthStatus(HostStateEntity hostStateEntity) {
+    if (hostStateEntity != null) {
+      return gson.fromJson(hostStateEntity.getHealthStatus(), HostHealthStatus.class);
+    }
+
+    return null;
+  }
+
   @Override
   public void setHealthStatus(HostHealthStatus healthStatus) {
     HostStateEntity hostStateEntity = getHostStateEntity();
@@ -827,6 +858,11 @@ public class HostImpl implements Host {
     return gson.fromJson(getHostEntity().getHostAttributes(), hostAttributesType);
   }
 
+  @Override
+  public Map<String, String> getHostAttributes(HostEntity hostEntity) {
+    return gson.fromJson(hostEntity.getHostAttributes(), hostAttributesType);
+  }
+
   @Override
   public void setHostAttributes(Map<String, String> hostAttributes) {
     HostEntity hostEntity = getHostEntity();
@@ -875,6 +911,16 @@ public class HostImpl implements Host {
     this.lastHeartbeatTime = lastHeartbeatTime;
   }
 
+  @Override
+  public long getLastAgentStartTime() {
+    return lastAgentStartTime;
+  }
+
+  @Override
+  public void setLastAgentStartTime(long lastAgentStartTime) {
+    this.lastAgentStartTime = lastAgentStartTime;
+  }
+
   @Override
   public AgentVersion getAgentVersion() {
     HostStateEntity hostStateEntity = getHostStateEntity();
@@ -885,6 +931,15 @@ public class HostImpl implements Host {
     return null;
   }
 
+  @Override
+  public AgentVersion getAgentVersion(HostStateEntity hostStateEntity) {
+    if (hostStateEntity != null) {
+      return gson.fromJson(hostStateEntity.getAgentVersion(), AgentVersion.class);
+    }
+
+    return null;
+  }
+
   @Override
   public void setAgentVersion(AgentVersion agentVersion) {
     HostStateEntity hostStateEntity = getHostStateEntity();
@@ -909,15 +964,27 @@ public class HostImpl implements Host {
     }
   }
 
-
   @Override
   public String getStatus() {
     return status;
   }
 
+  /**
+   * Sets the Host's status.
+   *
+   * @param status Host Status string representation of the Host's status
+   * @throws IllegalArgumentException if <code>status</code> is <code>null</code> or {@link HealthStatus} enum has no such constant name.
+   */
   @Override
   public void setStatus(String status) {
-    this.status = status;
+    if (status == null) {
+      throw new IllegalArgumentException("Host status cannot be null");
+    }
+    String newStatus = HealthStatus.valueOf(status).name();
+    if (!newStatus.equals(this.status)) {
+      ambariEventPublisher.publish(new HostStatusUpdateEvent(getHostName(), newStatus));
+      this.status = newStatus;
+    }
   }
 
   @Override
@@ -943,26 +1010,33 @@ public class HostImpl implements Host {
   public HostResponse convertToResponse() {
     HostResponse r = new HostResponse(getHostName());
 
-    r.setAgentVersion(getAgentVersion());
-    r.setPhCpuCount(getPhCpuCount());
-    r.setCpuCount(getCpuCount());
+    HostEntity hostEntity = getHostEntity();
+    HostStateEntity hostStateEntity = getHostStateEntity();
+
+    Map<String, String> hostAttributes = getHostAttributes(hostEntity);
+    r.setHostAttributes(hostAttributes);
+    r.setOsFamily(getOsFamily(hostAttributes));
+
+    r.setAgentVersion(getAgentVersion(hostStateEntity));
+    r.setHealthStatus(getHealthStatus(hostStateEntity));
+
+    r.setPhCpuCount(hostEntity.getPhCpuCount());
+    r.setCpuCount(hostEntity.getCpuCount());
+    r.setIpv4(hostEntity.getIpv4());
+    r.setOsArch(hostEntity.getOsArch());
+    r.setOsType(hostEntity.getOsType());
+    r.setTotalMemBytes(hostEntity.getTotalMem());
+    r.setLastRegistrationTime(hostEntity.getLastRegistrationTime());
+    r.setPublicHostName(hostEntity.getPublicHostName());
+    r.setRackInfo(hostEntity.getRackInfo());
+
     r.setDisksInfo(getDisksInfo());
-    r.setHealthStatus(getHealthStatus());
-    r.setHostAttributes(getHostAttributes());
-    r.setIpv4(getIPv4());
+    r.setStatus(getStatus());
     r.setLastHeartbeatTime(getLastHeartbeatTime());
     r.setLastAgentEnv(lastAgentEnv);
-    r.setLastRegistrationTime(getLastRegistrationTime());
-    r.setOsArch(getOsArch());
-    r.setOsType(getOsType());
-    r.setOsFamily(getOsFamily());
-    r.setRackInfo(getRackInfo());
-    r.setTotalMemBytes(getTotalMemBytes());
-    r.setPublicHostName(getPublicHostName());
-    r.setHostState(getState());
-    r.setStatus(getStatus());
     r.setRecoveryReport(getRecoveryReport());
     r.setRecoverySummary(getRecoveryReport().getSummary());
+    r.setHostState(getState());
     return r;
   }
 
@@ -1035,7 +1109,6 @@ public class HostImpl implements Host {
       DesiredConfig dc = new DesiredConfig();
       dc.setTag(e.getVersion());
       dc.setServiceName(e.getServiceName());
-      dc.setUser(e.getUser());
       map.put(e.getType(), dc);
 
     }
@@ -1048,9 +1121,8 @@ public class HostImpl implements Host {
   @Override
   public Map<String, HostConfig> getDesiredHostConfigs(Cluster cluster,
       Map<String, DesiredConfig> clusterDesiredConfigs) throws AmbariException {
-    Map<String, HostConfig> hostConfigMap = new HashMap<>();
 
-    if( null == cluster ){
+    if(null == cluster){
       clusterDesiredConfigs = new HashMap<>();
     }
 
@@ -1059,39 +1131,36 @@ public class HostImpl implements Host {
       clusterDesiredConfigs = cluster.getDesiredConfigs();
     }
 
-    if (clusterDesiredConfigs != null) {
-      for (Map.Entry<String, DesiredConfig> desiredConfigEntry
-          : clusterDesiredConfigs.entrySet()) {
+    Map<String, HostConfig> hostConfigMap = clusterDesiredConfigs.entrySet().stream().collect(Collectors.toMap(
+      Map.Entry::getKey,
+      desiredConfigEntry -> {
         HostConfig hostConfig = new HostConfig();
         hostConfig.setDefaultVersionTag(desiredConfigEntry.getValue().getTag());
-        hostConfigMap.put(desiredConfigEntry.getKey(), hostConfig);
+        return hostConfig;
       }
+    ));
+
+    Map<Long, ConfigGroup> configGroups = (cluster == null) ? new HashMap<>() : cluster.getConfigGroupsByHostname(getHostName());
+    if (configGroups == null || configGroups.isEmpty()) {
+      return hostConfigMap;
     }
 
-    Map<Long, ConfigGroup> configGroups = (cluster == null) ? new HashMap<Long, ConfigGroup>() : cluster.getConfigGroupsByHostname(getHostName());
-
-    if (configGroups != null && !configGroups.isEmpty()) {
-      for (ConfigGroup configGroup : configGroups.values()) {
-        for (Map.Entry<String, Config> configEntry : configGroup
-            .getConfigurations().entrySet()) {
-
-          String configType = configEntry.getKey();
-          // HostConfig config holds configType -> versionTag, per config group
-          HostConfig hostConfig = hostConfigMap.get(configType);
-          if (hostConfig == null) {
-            hostConfig = new HostConfig();
-            hostConfigMap.put(configType, hostConfig);
-            if (cluster != null) {
-              Config conf = cluster.getDesiredConfigByType(configType);
-              if (conf != null) {
-                hostConfig.setDefaultVersionTag(conf.getTag());
-              }
-            }
+    for (ConfigGroup configGroup : configGroups.values()) {
+      for (Map.Entry<String, Config> configEntry : configGroup.getConfigurations().entrySet()) {
+        String configType = configEntry.getKey();
+        // HostConfig config holds configType -> versionTag, per config group
+        HostConfig hostConfig = hostConfigMap.get(configType);
+        if (hostConfig == null) {
+          hostConfig = new HostConfig();
+          hostConfigMap.put(configType, hostConfig);
+          Config conf = cluster.getDesiredConfigByType(configType);
+          if(conf == null) {
+            LOG.error("Config inconsistency exists: unknown configType=" + configType);
+          } else {
+            hostConfig.setDefaultVersionTag(conf.getTag());
           }
-          Config config = configEntry.getValue();
-          hostConfig.getConfigGroupOverrides().put(configGroup.getId(),
-              config.getTag());
         }
+        hostConfig.getConfigGroupOverrides().put(configGroup.getId(), configEntry.getValue().getTag());
       }
     }
     return hostConfigMap;
@@ -1173,24 +1242,91 @@ public class HostImpl implements Host {
     HostEntity hostEntity = getHostEntity();
 
     for (HostComponentStateEntity componentState : hostEntity.getHostComponentStateEntities()) {
-      try {
-        ComponentInfo component = ambariMetaInfo.getComponent(stackId.getStackName(),
-            stackId.getStackVersion(), componentState.getServiceName(),
-            componentState.getComponentName());
+      ComponentInfo component = ambariMetaInfo.getComponent(stackId.getStackName(),
+          stackId.getStackVersion(), componentState.getServiceName(),
+          componentState.getComponentName());
 
-        if (component.isVersionAdvertised()) {
-          return true;
-        }
-      } catch( StackAccessException stackAccessException ){
-        LOG.info("{}/{} does not exist in {} and will not advertise its version for that stack.",
-            componentState.getServiceName(), componentState.getComponentName(),
-            stackId.getStackId());
+      if (component.isVersionAdvertised()) {
+        return true;
       }
     }
 
     return false;
   }
 
+  @Override
+  public void calculateHostStatus(Long clusterId) throws AmbariException {
+    //Use actual component status to compute the host status
+    int masterCount = 0;
+    int mastersRunning = 0;
+    int slaveCount = 0;
+    int slavesRunning = 0;
+
+    StackId stackId;
+    Cluster cluster = clusters.getCluster(clusterId);
+    stackId = cluster.getDesiredStackVersion();
+
+
+    List<ServiceComponentHost> scHosts = cluster.getServiceComponentHosts(hostName);
+    for (ServiceComponentHost scHost : scHosts) {
+      ComponentInfo componentInfo =
+          ambariMetaInfo.getComponent(stackId.getStackName(),
+              stackId.getStackVersion(), scHost.getServiceName(),
+              scHost.getServiceComponentName());
+
+      String status = scHost.getState().name();
+
+      String category = componentInfo.getCategory();
+      if (category == null) {
+        LOG.warn("In stack {}-{} service {} component {} category is null!",
+                stackId.getStackName(), stackId.getStackVersion(), scHost.getServiceName(), scHost.getServiceComponentName());
+        continue;
+      }
+
+      if (MaintenanceState.OFF == maintenanceStateHelper.getEffectiveState(scHost, this)) {
+        if (Objects.equals("MASTER", category)) {
+          ++masterCount;
+          if (Objects.equals("STARTED", status)) {
+            ++mastersRunning;
+          }
+        } else if (Objects.equals("SLAVE", category)) {
+          ++slaveCount;
+          if (Objects.equals("STARTED", status)) {
+            ++slavesRunning;
+          }
+        }
+      }
+    }
+
+    HostHealthStatus.HealthStatus healthStatus;
+    if (masterCount == mastersRunning && slaveCount == slavesRunning) {
+      healthStatus = HostHealthStatus.HealthStatus.HEALTHY;
+    } else if (masterCount > 0 && mastersRunning < masterCount) {
+      healthStatus = HostHealthStatus.HealthStatus.UNHEALTHY;
+    } else {
+      healthStatus = HostHealthStatus.HealthStatus.ALERT;
+    }
+
+    setStatus(healthStatus.name());
+  }
+
+  @Transactional
+  public void updateHost(HostRegistrationRequestEvent e) {
+    importHostInfo(e.hostInfo);
+    setLastAgentEnv(e.agentEnv);
+    setAgentVersion(e.agentVersion);
+    setPublicHostName(e.publicHostName);
+    setState(HostState.INIT);
+  }
+
+  @Transactional
+  public void updateHostTimestamps(HostRegistrationRequestEvent e) {
+    setLastHeartbeatTime(e.registrationTime);
+    setLastRegistrationTime(e.registrationTime);
+    setLastAgentStartTime(e.agentStartTime);
+    setTimeInState(e.registrationTime);
+  }
+
   /**
    * {@inheritDoc}
    */
@@ -1203,8 +1339,8 @@ public class HostImpl implements Host {
     // for every host component, if it matches the desired repo and has reported
     // the correct version then we're good
     for (HostComponentStateEntity hostComponentState : hostComponentStates) {
-      ServiceComponentDesiredStateEntity desiredComponmentState = hostComponentState.getServiceComponentDesiredStateEntity();
-      RepositoryVersionEntity desiredRepositoryVersion = desiredComponmentState.getDesiredRepositoryVersion();
+      ServiceComponentDesiredStateEntity desiredComponentState = hostComponentState.getServiceComponentDesiredStateEntity();
+      RepositoryVersionEntity desiredRepositoryVersion = desiredComponentState.getDesiredRepositoryVersion();
 
       ComponentInfo componentInfo = ambariMetaInfo.getComponent(
           desiredRepositoryVersion.getStackName(), desiredRepositoryVersion.getStackVersion(),
