@@ -22,27 +22,21 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.TreeSet;
 
 import org.apache.ambari.server.AmbariException;
-import org.apache.ambari.server.controller.AmbariManagementController;
 import org.apache.ambari.server.orm.DBAccessor.DBColumnInfo;
 import org.apache.ambari.server.orm.dao.ArtifactDAO;
-import org.apache.ambari.server.orm.dao.ClusterDAO;
 import org.apache.ambari.server.orm.entities.ArtifactEntity;
-import org.apache.ambari.server.orm.entities.ClusterConfigEntity;
-import org.apache.ambari.server.orm.entities.ClusterEntity;
 import org.apache.ambari.server.serveraction.kerberos.DeconstructedPrincipal;
 import org.apache.ambari.server.state.Cluster;
 import org.apache.ambari.server.state.Clusters;
 import org.apache.ambari.server.state.Config;
 import org.apache.ambari.server.state.ConfigHelper;
 import org.apache.ambari.server.state.PropertyInfo;
-import org.apache.ambari.server.state.StackId;
 import org.apache.ambari.server.state.kerberos.AbstractKerberosDescriptorContainer;
 import org.apache.ambari.server.state.kerberos.KerberosComponentDescriptor;
 import org.apache.ambari.server.state.kerberos.KerberosConfigurationDescriptor;
@@ -137,8 +131,6 @@ public class UpgradeCatalog252 extends AbstractUpgradeCatalog {
   protected void executeDMLUpdates() throws AmbariException, SQLException {
     addNewConfigurationsFromXml();
     resetStackToolsAndFeatures();
-    ensureConfigTypesHaveAtLeastOneVersionSelected();
-    updateMariaDBRedHatSupportHive();
     updateKerberosDescriptorArtifacts();
     fixLivySuperusers();
   }
@@ -239,113 +231,6 @@ public class UpgradeCatalog252 extends AbstractUpgradeCatalog {
     }
   }
 
-  /**
-   * When doing a cross-stack upgrade, we found that one config type (spark2-javaopts-properties)
-   * did not have any mappings that were selected, so it caused Ambari Server start to fail on the DB Consistency Checker.
-   * To fix this, iterate over all config types and ensure that at least one is selected.
-   * If none are selected, then pick the one with the greatest time stamp; this should be safe since we are only adding
-   * more data to use as opposed to removing.
-   */
-  private void ensureConfigTypesHaveAtLeastOneVersionSelected() {
-    ClusterDAO clusterDAO = injector.getInstance(ClusterDAO.class);
-    List<ClusterEntity> clusters = clusterDAO.findAll();
-
-    if (null == clusters) {
-      return;
-    }
-
-    for (ClusterEntity clusterEntity : clusters) {
-      LOG.info("Ensuring all config types have at least one selected config for cluster {}", clusterEntity.getClusterName());
-
-      boolean atLeastOneChanged = false;
-      Collection<ClusterConfigEntity> configEntities = clusterEntity.getClusterConfigEntities();
-
-      if (configEntities != null) {
-        Set<String> configTypesNotSelected = new HashSet<>();
-        Set<String> configTypesWithAtLeastOneSelected = new HashSet<>();
-
-        for (ClusterConfigEntity clusterConfigEntity : configEntities) {
-          String typeName = clusterConfigEntity.getType();
-
-          if (clusterConfigEntity.isSelected()) {
-            configTypesWithAtLeastOneSelected.add(typeName);
-          } else {
-            configTypesNotSelected.add(typeName);
-          }
-        }
-
-        // Due to the ordering, eliminate any configs with at least one selected.
-        configTypesNotSelected.removeAll(configTypesWithAtLeastOneSelected);
-        if (!configTypesNotSelected.isEmpty()) {
-          LOG.info("The following config types have entries which are not enabled: {}", StringUtils.join(configTypesNotSelected, ", "));
-
-          LOG.info("Filtering only config types these config types: {}", StringUtils.join(configTypesToEnsureSelected, ", "));
-          // Get the intersection with a subset of configs that are allowed to be selected during the migration.
-          configTypesNotSelected.retainAll(configTypesToEnsureSelected);
-        }
-
-        if (!configTypesNotSelected.isEmpty()) {
-          LOG.info("The following config types have entries which don't have at least one as selected. {}", StringUtils.join(configTypesNotSelected, ", "));
-
-          for (String typeName : configTypesNotSelected) {
-            ClusterConfigEntity clusterConfigMappingWithGreatestTimeStamp = null;
-
-            for (ClusterConfigEntity clusterConfigEntity : configEntities) {
-              if (typeName.equals(clusterConfigEntity.getType())) {
-
-                if (null == clusterConfigMappingWithGreatestTimeStamp) {
-                  clusterConfigMappingWithGreatestTimeStamp = clusterConfigEntity;
-                } else {
-                  if (clusterConfigEntity.getTimestamp() >= clusterConfigMappingWithGreatestTimeStamp.getTimestamp()) {
-                    clusterConfigMappingWithGreatestTimeStamp = clusterConfigEntity;
-                  }
-                }
-              }
-            }
-
-            if (null != clusterConfigMappingWithGreatestTimeStamp) {
-              LOG.info("Saving. Config type {} has a mapping with tag {} and greatest timestamp {} that is not selected, so will mark it selected.",
-                  typeName, clusterConfigMappingWithGreatestTimeStamp.getTag(), clusterConfigMappingWithGreatestTimeStamp.getTimestamp());
-              atLeastOneChanged = true;
-              clusterConfigMappingWithGreatestTimeStamp.setSelected(true);
-            }
-          }
-        } else {
-          LOG.info("All config types have at least one mapping that is selected. Nothing to do.");
-        }
-      }
-
-      if (atLeastOneChanged) {
-        clusterDAO.merge(clusterEntity);
-      }
-    }
-  }
-
-  /**
-   * Insert mariadb_redhat_support to hive-env if the current stack is BigInsights 4.2.5
-   * @throws AmbariException
-   * */
-  private void updateMariaDBRedHatSupportHive() throws AmbariException {
-    AmbariManagementController ambariManagementController = injector.getInstance(AmbariManagementController.class);
-    Clusters clusters = ambariManagementController.getClusters();
-    if (clusters != null) {
-      Map<String, Cluster> clusterMap = getCheckedClusterMap(clusters);
-      if (clusterMap != null && !clusterMap.isEmpty()) {
-        for (final Cluster cluster : clusterMap.values()) {
-          Set<String> installedServices = cluster.getServices().keySet();
-          if (installedServices.contains("HIVE")) {
-            StackId currentStack = cluster.getCurrentStackVersion();
-            if (currentStack.getStackName().equals("BigInsights") && currentStack.getStackVersion().equals("4.2.5")) {
-              Map<String, String> newProperties = new HashMap<>();
-              newProperties.put(MARIADB_REDHAT_SUPPORT, "true");
-              updateConfigurationPropertiesForCluster(cluster, HIVE_ENV, newProperties, true, false);
-            }
-          }
-        }
-      }
-    }
-  }
-
   /**
    * {@inheritDoc}
    */
@@ -540,7 +425,7 @@ public class UpgradeCatalog252 extends AbstractUpgradeCatalog {
                 updated = true;
 
                 // If there are no more properties in the configurationDescriptor, remove it from the container.
-                if(properties.isEmpty()) {
+                if (properties.isEmpty()) {
                   configurationDescriptors.remove(configType);
                   kerberosDescriptorContainer.setConfigurations(configurationDescriptors);
                 }
