@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,6 +18,29 @@
 
 package org.apache.ambari.server.view.persistence;
 
+import java.beans.IntrospectionException;
+import java.beans.Introspector;
+import java.beans.PropertyDescriptor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
+import java.lang.reflect.ParameterizedType;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.LinkedHashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.StringTokenizer;
+
+import javax.inject.Inject;
+import javax.persistence.EntityManager;
+import javax.persistence.EntityManagerFactory;
+import javax.persistence.EntityTransaction;
+import javax.persistence.Query;
+
 import org.apache.ambari.server.orm.entities.ViewEntityEntity;
 import org.apache.ambari.server.orm.entities.ViewInstanceEntity;
 import org.apache.ambari.view.DataStore;
@@ -36,20 +59,6 @@ import org.eclipse.persistence.sessions.Session;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import javax.inject.Inject;
-import javax.persistence.EntityManager;
-import javax.persistence.EntityManagerFactory;
-import javax.persistence.EntityTransaction;
-import javax.persistence.Query;
-import java.beans.IntrospectionException;
-import java.beans.Introspector;
-import java.beans.PropertyDescriptor;
-import java.lang.reflect.Field;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
-import java.lang.reflect.ParameterizedType;
-import java.util.*;
-
 
 /**
  * A data store implementation that uses dynamic JPA entities to
@@ -90,17 +99,17 @@ public class DataStoreImpl implements DataStore {
   /**
    * Map of dynamic entity names keyed by view entity class.
    */
-  private final Map<Class, String> entityClassMap = new LinkedHashMap<Class, String>();
+  private final Map<Class, String> entityClassMap = new LinkedHashMap<>();
 
   /**
    * Map of entity primary key fields keyed by dynamic entity name.
    */
-  private final Map<String, ViewEntityEntity> entityMap = new LinkedHashMap<String, ViewEntityEntity>();
+  private final Map<String, ViewEntityEntity> entityMap = new LinkedHashMap<>();
 
   /**
    * Map of dynamic entity type builders keyed by dynamic entity name.
    */
-  private final Map<String, JPADynamicTypeBuilder> typeBuilderMap = new LinkedHashMap<String, JPADynamicTypeBuilder>();
+  private final Map<String, JPADynamicTypeBuilder> typeBuilderMap = new LinkedHashMap<>();
 
   /**
    * Indicates whether or not the data store has been initialized.
@@ -110,7 +119,7 @@ public class DataStoreImpl implements DataStore {
   /**
    * The logger.
    */
-  protected final static Logger LOG = LoggerFactory.getLogger(DataStoreImpl.class);
+  private static final Logger LOG = LoggerFactory.getLogger(DataStoreImpl.class);
 
   /**
    * Max length of entity string field.
@@ -138,10 +147,10 @@ public class DataStoreImpl implements DataStore {
     try {
       em.getTransaction().begin();
       try {
-        DynamicEntity dynamicEntity = persistEntity(entity, em, new HashSet<DynamicEntity>());
+        DynamicEntity dynamicEntity = persistEntity(entity, em, new HashSet<>());
         em.getTransaction().commit();
         Map<String, Object> props = getEntityProperties(entity);
-        List<String> keys = new ArrayList<String>(props.keySet());
+        List<String> keys = new ArrayList<>(props.keySet());
         for( String key : keys){
           String attribute = getAttributeName(key);
           try {
@@ -224,7 +233,7 @@ public class DataStoreImpl implements DataStore {
 
     EntityManager em = getEntityManager();
     try {
-      Collection<T> resources = new HashSet<T>();
+      Collection<T> resources = new HashSet<>();
       DynamicType   type      = getDynamicEntityType(clazz);
 
       if (type != null) {
@@ -476,7 +485,7 @@ public class DataStoreImpl implements DataStore {
       IllegalAccessException, InstantiationException, NoSuchFieldException {
     T resource = clazz.newInstance();
 
-    Map<String, Object> properties = new HashMap<String, Object>();
+    Map<String, Object> properties = new HashMap<>();
 
     for (String attributeName : type.getPropertiesNames()) {
       String fieldName = getFieldName(attributeName);
@@ -519,7 +528,7 @@ public class DataStoreImpl implements DataStore {
   // get a map of properties from the given view entity
   private Map<String, Object> getEntityProperties(Object entity)
       throws IntrospectionException, InvocationTargetException, IllegalAccessException {
-    Map<String, Object> properties = new HashMap<String, Object>();
+    Map<String, Object> properties = new HashMap<>();
 
     for (PropertyDescriptor pd : Introspector.getBeanInfo(entity.getClass()).getPropertyDescriptors()) {
       String name       = pd.getName();
@@ -546,7 +555,7 @@ public class DataStoreImpl implements DataStore {
           Object value = properties.get(name);
 
           if (value instanceof Collection) {
-            Set<Object> newCollection = new HashSet<Object>();
+            Set<Object> newCollection = new HashSet<>();
 
             for (Object collectionValue: (Collection)value) {
 
@@ -604,7 +613,7 @@ public class DataStoreImpl implements DataStore {
 
   // get a descriptor map for the given bean class
   private static Map<String, PropertyDescriptor> getDescriptorMap(Class<?> clazz) throws IntrospectionException {
-    Map<String, PropertyDescriptor> descriptorMap = new HashMap<String, PropertyDescriptor>();
+    Map<String, PropertyDescriptor> descriptorMap = new HashMap<>();
 
     for (PropertyDescriptor pd : Introspector.getBeanInfo(clazz).getPropertyDescriptors()) {
       String name = pd.getName();
@@ -617,7 +626,7 @@ public class DataStoreImpl implements DataStore {
 
   // get the property names for the given view entity class
   private static Set<String> getPropertyNames(Class clazz) throws IntrospectionException {
-    Set<String> propertyNames = new HashSet<String>();
+    Set<String> propertyNames = new HashSet<>();
     for (PropertyDescriptor pd : Introspector.getBeanInfo(clazz).getPropertyDescriptors()) {
       propertyNames.add(pd.getName());
     }
