@@ -18,7 +18,12 @@ limitations under the License.
 
 """
 
-from resource_management import *
+from resource_management.core.resources.system import Directory, Execute, File
+from resource_management.libraries.resources.xml_config import XmlConfig
+from resource_management.libraries.resources.template_config import TemplateConfig
+from resource_management.core.resources.service import ServiceConfig
+from resource_management.core.source import InlineTemplate, Template
+from resource_management.libraries.functions.format import format
 from ambari_commons import OSConst
 from ambari_commons.os_family_impl import OsFamilyFuncImpl, OsFamilyImpl
 from ambari_commons.str_utils import compress_backslashes
@@ -45,7 +50,7 @@ def ams(name=None):
     XmlConfig("ams-site.xml",
               conf_dir=params.ams_collector_conf_dir,
               configurations=params.config['configurations']['ams-site'],
-              configuration_attributes=params.config['configuration_attributes']['ams-site'],
+              configuration_attributes=params.config['configurationAttributes']['ams-site'],
               owner=params.ams_user,
     )
 
@@ -57,7 +62,7 @@ def ams(name=None):
     XmlConfig( "hbase-site.xml",
                conf_dir = params.ams_collector_conf_dir,
                configurations = merged_ams_hbase_site,
-               configuration_attributes=params.config['configuration_attributes']['ams-hbase-site'],
+               configuration_attributes=params.config['configurationAttributes']['ams-hbase-site'],
                owner = params.ams_user,
     )
 
@@ -82,7 +87,7 @@ def ams(name=None):
       XmlConfig("hdfs-site.xml",
             conf_dir=params.ams_collector_conf_dir,
             configurations=params.config['configurations']['hdfs-site'],
-            configuration_attributes=params.config['configuration_attributes']['hdfs-site'],
+            configuration_attributes=params.config['configurationAttributes']['hdfs-site'],
             owner=params.ams_user,
             group=params.user_group,
             mode=0644
@@ -91,7 +96,7 @@ def ams(name=None):
       XmlConfig("hdfs-site.xml",
             conf_dir=params.hbase_conf_dir,
             configurations=params.config['configurations']['hdfs-site'],
-            configuration_attributes=params.config['configuration_attributes']['hdfs-site'],
+            configuration_attributes=params.config['configurationAttributes']['hdfs-site'],
             owner=params.ams_user,
             group=params.user_group,
             mode=0644
@@ -100,7 +105,7 @@ def ams(name=None):
       XmlConfig("core-site.xml",
                 conf_dir=params.ams_collector_conf_dir,
                 configurations=params.config['configurations']['core-site'],
-                configuration_attributes=params.config['configuration_attributes']['core-site'],
+                configuration_attributes=params.config['configurationAttributes']['core-site'],
                 owner=params.ams_user,
                 group=params.user_group,
                 mode=0644
@@ -109,7 +114,7 @@ def ams(name=None):
       XmlConfig("core-site.xml",
                 conf_dir=params.hbase_conf_dir,
                 configurations=params.config['configurations']['core-site'],
-                configuration_attributes=params.config['configuration_attributes']['core-site'],
+                configuration_attributes=params.config['configurationAttributes']['core-site'],
                 owner=params.ams_user,
                 group=params.user_group,
                 mode=0644
@@ -158,6 +163,31 @@ def ams(name=None):
               create_parents = True
     )
 
+    if params.host_in_memory_aggregation:
+      if params.log4j_props is not None:
+        File(os.path.join(params.ams_monitor_conf_dir, "log4j.properties"),
+             owner=params.ams_user,
+             content=params.log4j_props
+             )
+        pass
+
+      XmlConfig("ams-site.xml",
+              conf_dir=params.ams_monitor_conf_dir,
+              configurations=params.config['configurations']['ams-site'],
+              configuration_attributes=params.config['configurationAttributes']['ams-site'],
+              owner=params.ams_user,
+              group=params.user_group
+              )
+
+      XmlConfig("ssl-server.xml",
+              conf_dir=params.ams_monitor_conf_dir,
+              configurations=params.config['configurations']['ams-ssl-server'],
+              configuration_attributes=params.config['configurationAttributes']['ams-ssl-server'],
+              owner=params.ams_user,
+              group=params.user_group
+              )
+      pass
+
     TemplateConfig(
       os.path.join(params.ams_monitor_conf_dir, "metric_monitor.ini"),
       owner=params.ams_user,
@@ -196,10 +226,40 @@ def ams(name=None, action=None):
               recursive_ownership = True
     )
 
+    new_ams_site = {}
+    new_ams_site.update(params.config['configurations']['ams-site'])
+    if params.clusterHostInfoDict:
+      master_components = []
+      slave_components = []
+      components = dict(params.clusterHostInfoDict).keys()
+      known_slave_components = ["nodemanager", "metrics_monitor", "datanode", "hbase_regionserver"]
+      for component in components:
+        if component and component.endswith("_hosts"):
+          component_name = component[:-6]
+        elif component and component.endswith("_host"):
+          component_name = component[:-5]
+        else:
+          continue
+        if component_name in known_slave_components:
+          slave_components.append(component_name)
+        else:
+          master_components.append(component_name)
+
+      if slave_components:
+        new_ams_site['timeline.metrics.initial.configured.slave.components'] = ",".join(slave_components)
+      if master_components:
+        if 'ambari_server' not in master_components:
+          master_components.append('ambari_server')
+        new_ams_site['timeline.metrics.initial.configured.master.components'] = ",".join(master_components)
+
+    hbase_total_heapsize_with_trailing_m = params.hbase_heapsize
+    hbase_total_heapsize = int(hbase_total_heapsize_with_trailing_m[:-1]) * 1024 * 1024
+    new_ams_site['hbase_total_heapsize'] = hbase_total_heapsize
+
     XmlConfig("ams-site.xml",
               conf_dir=params.ams_collector_conf_dir,
-              configurations=params.config['configurations']['ams-site'],
-              configuration_attributes=params.config['configuration_attributes']['ams-site'],
+              configurations=new_ams_site,
+              configuration_attributes=params.config['configurationAttributes']['ams-site'],
               owner=params.ams_user,
               group=params.user_group
     )
@@ -207,7 +267,7 @@ def ams(name=None, action=None):
     XmlConfig("ssl-server.xml",
               conf_dir=params.ams_collector_conf_dir,
               configurations=params.config['configurations']['ams-ssl-server'],
-              configuration_attributes=params.config['configuration_attributes']['ams-ssl-server'],
+              configuration_attributes=params.config['configurationAttributes']['ams-ssl-server'],
               owner=params.ams_user,
               group=params.user_group
     )
@@ -224,7 +284,7 @@ def ams(name=None, action=None):
     XmlConfig( "hbase-site.xml",
                conf_dir = params.ams_collector_conf_dir,
                configurations = merged_ams_hbase_site,
-               configuration_attributes=params.config['configuration_attributes']['ams-hbase-site'],
+               configuration_attributes=params.config['configurationAttributes']['ams-hbase-site'],
                owner = params.ams_user,
                group = params.user_group
     )
@@ -300,7 +360,7 @@ def ams(name=None, action=None):
       XmlConfig("hdfs-site.xml",
             conf_dir=params.ams_collector_conf_dir,
             configurations=params.config['configurations']['hdfs-site'],
-            configuration_attributes=params.config['configuration_attributes']['hdfs-site'],
+            configuration_attributes=params.config['configurationAttributes']['hdfs-site'],
             owner=params.ams_user,
             group=params.user_group,
             mode=0644
@@ -309,25 +369,23 @@ def ams(name=None, action=None):
       XmlConfig("hdfs-site.xml",
             conf_dir=params.hbase_conf_dir,
             configurations=params.config['configurations']['hdfs-site'],
-            configuration_attributes=params.config['configuration_attributes']['hdfs-site'],
+            configuration_attributes=params.config['configurationAttributes']['hdfs-site'],
             owner=params.ams_user,
             group=params.user_group,
             mode=0644
       )
 
-      # Remove spnego configs from core-site, since AMS does not support spnego (AMBARI-14384)
+      # Remove spnego configs from core-site if platform does not have python-kerberos library
       truncated_core_site = {}
       truncated_core_site.update(params.config['configurations']['core-site'])
-      if 'core-site' in params.config['configurations']:
-        if 'hadoop.http.authentication.type' in params.config['configurations']['core-site']:
-          truncated_core_site.pop('hadoop.http.authentication.type')
-        if 'hadoop.http.filter.initializers' in params.config['configurations']['core-site']:
-          truncated_core_site.pop('hadoop.http.filter.initializers')
+      if is_spnego_enabled(params):
+        truncated_core_site.pop('hadoop.http.authentication.type')
+        truncated_core_site.pop('hadoop.http.filter.initializers')
 
       XmlConfig("core-site.xml",
                 conf_dir=params.ams_collector_conf_dir,
                 configurations=truncated_core_site,
-                configuration_attributes=params.config['configuration_attributes']['core-site'],
+                configuration_attributes=params.config['configurationAttributes']['core-site'],
                 owner=params.ams_user,
                 group=params.user_group,
                 mode=0644
@@ -336,7 +394,7 @@ def ams(name=None, action=None):
       XmlConfig("core-site.xml",
                 conf_dir=params.hbase_conf_dir,
                 configurations=truncated_core_site,
-                configuration_attributes=params.config['configuration_attributes']['core-site'],
+                configuration_attributes=params.config['configurationAttributes']['core-site'],
                 owner=params.ams_user,
                 group=params.user_group,
                 mode=0644
@@ -348,6 +406,14 @@ def ams(name=None, action=None):
     pass
 
   elif name == 'monitor':
+
+    # TODO Uncomment when SPNEGO support has been added to AMS service check and Grafana.
+    if is_spnego_enabled(params) and is_redhat_centos_6_plus():
+      try:
+        import kerberos
+      except ImportError:
+        raise ImportError("python-kerberos package need to be installed to run AMS in SPNEGO mode")
+
     Directory(params.ams_monitor_conf_dir,
               owner=params.ams_user,
               group=params.user_group,
@@ -361,6 +427,30 @@ def ams(name=None, action=None):
               create_parents = True
     )
 
+    if params.host_in_memory_aggregation and params.log4j_props is not None:
+      File(format("{params.ams_monitor_conf_dir}/log4j.properties"),
+           mode=0644,
+           group=params.user_group,
+           owner=params.ams_user,
+           content=InlineTemplate(params.log4j_props)
+           )
+
+      XmlConfig("ams-site.xml",
+              conf_dir=params.ams_monitor_conf_dir,
+              configurations=params.config['configurations']['ams-site'],
+              configuration_attributes=params.config['configurationAttributes']['ams-site'],
+              owner=params.ams_user,
+              group=params.user_group
+              )
+      XmlConfig("ssl-server.xml",
+              conf_dir=params.ams_monitor_conf_dir,
+              configurations=params.config['configurations']['ams-ssl-server'],
+              configuration_attributes=params.config['configurationAttributes']['ams-ssl-server'],
+              owner=params.ams_user,
+              group=params.user_group
+              )
+      pass
+
     Execute(format("{sudo} chown -R {ams_user}:{user_group} {ams_monitor_log_dir}")
             )
 
@@ -400,7 +490,7 @@ def ams(name=None, action=None):
          content=InlineTemplate(params.ams_env_sh_template)
     )
 
-    if params.metric_collector_https_enabled:
+    if params.metric_collector_https_enabled or params.is_aggregation_https_enabled:
       export_ca_certs(params.ams_monitor_conf_dir)
 
     pass
@@ -446,6 +536,22 @@ def ams(name=None, action=None):
 
     pass
 
+def is_spnego_enabled(params):
+  if 'core-site' in params.config['configurations'] \
+      and 'hadoop.http.authentication.type' in params.config['configurations']['core-site'] \
+      and params.config['configurations']['core-site']['hadoop.http.authentication.type'] == "kerberos" \
+      and 'hadoop.http.filter.initializers' in params.config['configurations']['core-site'] \
+      and "org.apache.hadoop.security.AuthenticationFilterInitializer" in params.config['configurations']['core-site']['hadoop.http.filter.initializers']:
+    return True
+  return False
+
+def is_redhat_centos_6_plus():
+  import platform
+
+  if platform.dist()[0] in ['redhat', 'centos'] and platform.dist()[1] > '6.0':
+    return True
+  return False
+
 def export_ca_certs(dir_path):
   # export ca certificates on every restart to handle changed truststore content
 
