@@ -15,7 +15,8 @@
 # specific language governing permissions and limitations
 # under the License.
 #
-from resource_management import *
+from resource_management.core.resources.system import Execute, File
+from resource_management.libraries.functions.format import format
 from ambari_commons.os_check import OSCheck
 
 
