@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -17,8 +17,8 @@
  */
 package org.apache.ambari.server.controller.internal;
 
-import static org.apache.ambari.server.configuration.Configuration.JDBC_IN_MEMORY_URL;
 import static org.apache.ambari.server.configuration.Configuration.JDBC_IN_MEMORY_DRIVER;
+import static org.apache.ambari.server.configuration.Configuration.JDBC_IN_MEMORY_URL;
 import static org.easymock.EasyMock.capture;
 import static org.easymock.EasyMock.createMock;
 import static org.easymock.EasyMock.expect;
@@ -566,7 +566,7 @@ public class AlertResourceProviderTest {
 
     SecurityContextHolder.getContext().setAuthentication(TestAuthenticationFactory.createAdministrator());
 
-    Set<String> requestProperties = new HashSet<String>();
+    Set<String> requestProperties = new HashSet<>();
     requestProperties.add(AlertResourceProvider.ALERT_ID);
     requestProperties.add(AlertResourceProvider.ALERT_DEFINITION_NAME);
 
@@ -653,7 +653,7 @@ public class AlertResourceProviderTest {
     int unknown = 3;
     int total = ok + warning + critical + unknown;
 
-    List<AlertCurrentEntity> currents = new ArrayList<AlertCurrentEntity>(total);
+    List<AlertCurrentEntity> currents = new ArrayList<>(total);
 
     for (int i = 0; i < total; i++) {
       AlertState state = AlertState.OK;
