@@ -37,14 +37,8 @@ import org.apache.ambari.server.controller.MaintenanceStateHelper;
 import org.apache.ambari.server.controller.ServiceComponentHostRequest;
 import org.apache.ambari.server.controller.ServiceComponentRequest;
 import org.apache.ambari.server.controller.ServiceRequest;
-import org.apache.ambari.server.controller.spi.NoSuchParentResourceException;
-import org.apache.ambari.server.controller.spi.NoSuchResourceException;
 import org.apache.ambari.server.controller.spi.Resource;
-import org.apache.ambari.server.controller.spi.ResourceAlreadyExistsException;
 import org.apache.ambari.server.controller.spi.ResourceProvider;
-import org.apache.ambari.server.controller.spi.SystemException;
-import org.apache.ambari.server.controller.spi.UnsupportedPropertyException;
-import org.apache.ambari.server.controller.utilities.PropertyHelper;
 import org.apache.ambari.server.orm.GuiceJpaInitializer;
 import org.apache.ambari.server.orm.InMemoryDefaultTestModule;
 import org.apache.ambari.server.orm.OrmTestHelper;
@@ -117,7 +111,7 @@ public class JMXHostProviderTest {
   }
 
   private void createService(String clusterName, String serviceName, State desiredState)
-      throws AmbariException, AuthorizationException {
+      throws AmbariException, AuthorizationException, NoSuchFieldException, IllegalAccessException {
     String dStateStr = null;
 
     if (desiredState != null) {
@@ -163,7 +157,7 @@ public class JMXHostProviderTest {
     controller.createHostComponents(requests);
   }
 
-  private void createHDFSServiceConfigs(boolean version1) throws AmbariException, AuthorizationException {
+  private void createHDFSServiceConfigs(boolean version1) throws AmbariException, AuthorizationException, NoSuchFieldException, IllegalAccessException {
     String clusterName = "c1";
     ClusterRequest r = new ClusterRequest(null, clusterName, "HDP-0.1", null);
     controller.createCluster(r);
@@ -196,6 +190,8 @@ public class JMXHostProviderTest {
     clusters.getHost("h2").setHostAttributes(hostAttributes);
     clusters.mapHostToCluster(host1, clusterName);
     clusters.mapHostToCluster(host2, clusterName);
+    clusters.updateHostMappings(clusters.getHost(host1));
+    clusters.updateHostMappings(clusters.getHost(host2));
 
     createServiceComponentHost(clusterName, null, componentName1,
       host1, null);
@@ -219,7 +215,7 @@ public class JMXHostProviderTest {
         "hdfs-site", "version1", configs, null);
       ClusterRequest crequest = new ClusterRequest(cluster.getClusterId(), clusterName, null, null);
       crequest.setDesiredConfig(Collections.singletonList(cr));
-      controller.updateClusters(Collections.singleton(crequest), new HashMap<String,String>());
+      controller.updateClusters(Collections.singleton(crequest), new HashMap<>());
 
     } else {
       Map<String, String> configs = new HashMap<>();
@@ -231,11 +227,11 @@ public class JMXHostProviderTest {
 
       ClusterRequest crequest = new ClusterRequest(cluster.getClusterId(), clusterName, null, null);
       crequest.setDesiredConfig(Collections.singletonList(cr));
-      controller.updateClusters(Collections.singleton(crequest), new HashMap<String,String>());
+      controller.updateClusters(Collections.singleton(crequest), new HashMap<>());
     }
   }
 
-  private void createConfigs() throws AmbariException, AuthorizationException {
+  private void createConfigs() throws AmbariException, AuthorizationException, NoSuchFieldException, IllegalAccessException {
     String clusterName = "c1";
     ClusterRequest r = new ClusterRequest(null, clusterName, "HDP-2.0.6", null);
     controller.createCluster(r);
@@ -294,6 +290,8 @@ public class JMXHostProviderTest {
     clusters.getHost("h2").setHostAttributes(hostAttributes);
     clusters.mapHostToCluster(host1, clusterName);
     clusters.mapHostToCluster(host2, clusterName);
+    clusters.updateHostMappings(clusters.getHost(host1));
+    clusters.updateHostMappings(clusters.getHost(host2));
 
     createServiceComponentHost(clusterName, null, componentName1,
       host1, null);
@@ -374,7 +372,7 @@ public class JMXHostProviderTest {
       ("hdfs-site").getProperties().get(NAMENODE_PORT_V1));
   }
 
-  private void createConfigsNameNodeHa() throws AmbariException, AuthorizationException {
+  private void createConfigsNameNodeHa() throws AmbariException, AuthorizationException, NoSuchFieldException, IllegalAccessException {
     String clusterName = "nnha";
     ClusterRequest r = new ClusterRequest(null, clusterName, "HDP-2.0.6", null);
     controller.createCluster(r);
@@ -407,6 +405,8 @@ public class JMXHostProviderTest {
     clusters.getHost("h2").setHostAttributes(hostAttributes);
     clusters.mapHostToCluster(host1, clusterName);
     clusters.mapHostToCluster(host2, clusterName);
+    clusters.updateHostMappings(clusters.getHost(host1));
+    clusters.updateHostMappings(clusters.getHost(host2));
 
     createServiceComponentHost(clusterName, serviceName, componentName1,
         host1, null);
@@ -443,10 +443,7 @@ public class JMXHostProviderTest {
 
 
   @Test
-  public void testJMXPortMapInitAtServiceLevelVersion1() throws
-    NoSuchParentResourceException,
-    ResourceAlreadyExistsException, UnsupportedPropertyException,
-    SystemException, AmbariException, NoSuchResourceException {
+  public void testJMXPortMapInitAtServiceLevelVersion1() throws Exception {
 
     createHDFSServiceConfigs(true);
 
@@ -454,19 +451,16 @@ public class JMXHostProviderTest {
     providerModule.registerResourceProvider(Resource.Type.Service);
     providerModule.registerResourceProvider(Resource.Type.Configuration);
     // Non default port addresses
-    Assert.assertEquals("70070", providerModule.getPort("c1", "NAMENODE", "localhost"));
-    Assert.assertEquals("70075", providerModule.getPort("c1", "DATANODE", "localhost"));
+    Assert.assertEquals("70070", providerModule.getPort("c1", "NAMENODE", "localhost", false));
+    Assert.assertEquals("70075", providerModule.getPort("c1", "DATANODE", "localhost", false));
     // Default port addresses
-    Assert.assertEquals(null, providerModule.getPort("c1", "JOBTRACKER", "localhost"));
-    Assert.assertEquals(null, providerModule.getPort("c1", "TASKTRACKER", "localhost"));
-    Assert.assertEquals(null, providerModule.getPort("c1", "HBASE_MASTER", "localhost"));
+    Assert.assertEquals(null, providerModule.getPort("c1", "JOBTRACKER", "localhost", false));
+    Assert.assertEquals(null, providerModule.getPort("c1", "TASKTRACKER", "localhost", false));
+    Assert.assertEquals(null, providerModule.getPort("c1", "HBASE_MASTER", "localhost", false));
   }
 
   @Test
-  public void testJMXPortMapInitAtServiceLevelVersion2() throws
-    NoSuchParentResourceException,
-    ResourceAlreadyExistsException, UnsupportedPropertyException,
-    SystemException, AmbariException, NoSuchResourceException {
+  public void testJMXPortMapInitAtServiceLevelVersion2() throws Exception {
 
     createHDFSServiceConfigs(false);
 
@@ -474,20 +468,16 @@ public class JMXHostProviderTest {
     providerModule.registerResourceProvider(Resource.Type.Service);
     providerModule.registerResourceProvider(Resource.Type.Configuration);
     // Non default port addresses
-    Assert.assertEquals("70071", providerModule.getPort("c1", "NAMENODE", "localhost"));
-    Assert.assertEquals("70075", providerModule.getPort("c1", "DATANODE", "localhost"));
+    Assert.assertEquals("70071", providerModule.getPort("c1", "NAMENODE", "localhost", false));
+    Assert.assertEquals("70075", providerModule.getPort("c1", "DATANODE", "localhost", false));
     // Default port addresses
-    Assert.assertEquals(null, providerModule.getPort("c1", "JOBTRACKER", "localhost"));
-    Assert.assertEquals(null, providerModule.getPort("c1", "TASKTRACKER", "localhost"));
-    Assert.assertEquals(null, providerModule.getPort("c1", "HBASE_MASTER", "localhost"));
+    Assert.assertEquals(null, providerModule.getPort("c1", "JOBTRACKER", "localhost", false));
+    Assert.assertEquals(null, providerModule.getPort("c1", "TASKTRACKER", "localhost", false));
+    Assert.assertEquals(null, providerModule.getPort("c1", "HBASE_MASTER", "localhost", false));
   }
 
   @Test
-  public void testJMXPortMapNameNodeHa() throws
-      NoSuchParentResourceException,
-      ResourceAlreadyExistsException, UnsupportedPropertyException,
-      SystemException, AmbariException, NoSuchResourceException {
-
+  public void testJMXPortMapNameNodeHa() throws Exception {
     createConfigsNameNodeHa();
 
     JMXHostProviderModule providerModule = new JMXHostProviderModule(controller);
@@ -495,28 +485,24 @@ public class JMXHostProviderTest {
     providerModule.registerResourceProvider(Resource.Type.Configuration);
 
 
-    Assert.assertEquals("50071", providerModule.getPort("nnha", "NAMENODE", "h1"));
-    Assert.assertEquals("50072", providerModule.getPort("nnha", "NAMENODE", "h2"));
+    Assert.assertEquals("50071", providerModule.getPort("nnha", "NAMENODE", "h1", false));
+    Assert.assertEquals("50072", providerModule.getPort("nnha", "NAMENODE", "h2", false));
   }
 
   @Test
-  public void testJMXPortMapInitAtClusterLevel() throws
-    NoSuchParentResourceException,
-    ResourceAlreadyExistsException, UnsupportedPropertyException,
-    SystemException, AmbariException, NoSuchResourceException {
-
+  public void testJMXPortMapInitAtClusterLevel() throws Exception {
     createConfigs();
 
     JMXHostProviderModule providerModule = new JMXHostProviderModule(controller);
     providerModule.registerResourceProvider(Resource.Type.Cluster);
     providerModule.registerResourceProvider(Resource.Type.Configuration);
     // Non default port addresses
-    Assert.assertEquals("70070", providerModule.getPort("c1", "NAMENODE", "localhost"));
-    Assert.assertEquals("70075", providerModule.getPort("c1", "DATANODE", "localhost"));
+    Assert.assertEquals("70070", providerModule.getPort("c1", "NAMENODE", "localhost", false));
+    Assert.assertEquals("70075", providerModule.getPort("c1", "DATANODE", "localhost", false));
     // Default port addresses
-    Assert.assertEquals(null, providerModule.getPort("c1", "JOBTRACKER", "localhost"));
-    Assert.assertEquals(null, providerModule.getPort("c1", "TASKTRACKER", "localhost"));
-    Assert.assertEquals(null, providerModule.getPort("c1", "HBASE_MASTER", "localhost"));
+    Assert.assertEquals(null, providerModule.getPort("c1", "JOBTRACKER", "localhost", false));
+    Assert.assertEquals(null, providerModule.getPort("c1", "TASKTRACKER", "localhost", false));
+    Assert.assertEquals(null, providerModule.getPort("c1", "HBASE_MASTER", "localhost", false));
   }
 
   @Test
@@ -547,10 +533,7 @@ public class JMXHostProviderTest {
   }
 
   @Test
-  public void testJMXHttpsPort() throws
-    NoSuchParentResourceException,
-    ResourceAlreadyExistsException, UnsupportedPropertyException,
-    SystemException, AmbariException, NoSuchResourceException {
+  public void testJMXHttpsPort() throws Exception {
     createConfigs();
     JMXHostProviderModule providerModule = new JMXHostProviderModule(controller);
     providerModule.registerResourceProvider(Resource.Type.Cluster);
@@ -562,10 +545,7 @@ public class JMXHostProviderTest {
   }
 
   @Test
-  public void testJMXHistoryServerHttpsPort() throws
-    NoSuchParentResourceException,
-    ResourceAlreadyExistsException, UnsupportedPropertyException,
-    SystemException, AmbariException, NoSuchResourceException {
+  public void testJMXHistoryServerHttpsPort() throws Exception {
     createConfigs();
     JMXHostProviderModule providerModule = new JMXHostProviderModule(controller);
     providerModule.registerResourceProvider(Resource.Type.Cluster);
@@ -576,10 +556,7 @@ public class JMXHostProviderTest {
   }
 
   @Test
-  public void testJMXJournalNodeHttpsPort() throws
-    NoSuchParentResourceException,
-    ResourceAlreadyExistsException, UnsupportedPropertyException,
-    SystemException, AmbariException, NoSuchResourceException {
+  public void testJMXJournalNodeHttpsPort() throws Exception {
     createConfigs();
     JMXHostProviderModule providerModule = new JMXHostProviderModule(controller);
     providerModule.registerResourceProvider(Resource.Type.Cluster);
@@ -589,10 +566,7 @@ public class JMXHostProviderTest {
   }
 
   @Test
-  public void testJMXDataNodeHttpsPort() throws
-    NoSuchParentResourceException,
-    ResourceAlreadyExistsException, UnsupportedPropertyException,
-    SystemException, AmbariException, NoSuchResourceException {
+  public void testJMXDataNodeHttpsPort() throws Exception {
     createConfigs();
     JMXHostProviderModule providerModule = new JMXHostProviderModule(controller);
     providerModule.registerResourceProvider(Resource.Type.Cluster);
@@ -602,10 +576,7 @@ public class JMXHostProviderTest {
   }
 
   @Test
-  public void testJMXHbaseMasterHttps() throws
-          NoSuchParentResourceException,
-          ResourceAlreadyExistsException, UnsupportedPropertyException,
-          SystemException, AmbariException, NoSuchResourceException {
+  public void testJMXHbaseMasterHttps() throws Exception {
     createConfigs();
     JMXHostProviderModule providerModule = new JMXHostProviderModule(controller);
     providerModule.registerResourceProvider(Resource.Type.Cluster);
@@ -615,18 +586,14 @@ public class JMXHostProviderTest {
   }
 
   @Test
-  public void testJMXPortMapUpdate() throws
-    NoSuchParentResourceException,
-    ResourceAlreadyExistsException, UnsupportedPropertyException,
-    SystemException, AmbariException, NoSuchResourceException {
-
+  public void testJMXPortMapUpdate() throws Exception {
     createConfigs();
 
     JMXHostProviderModule providerModule = new JMXHostProviderModule(controller);
     providerModule.registerResourceProvider(Resource.Type.Cluster);
     providerModule.registerResourceProvider(Resource.Type.Configuration);
     // Non default port addresses
-    Assert.assertEquals("8088", providerModule.getPort("c1", "RESOURCEMANAGER", "localhost"));
+    Assert.assertEquals("8088", providerModule.getPort("c1", "RESOURCEMANAGER", "localhost", false));
 
     Map<String, String> yarnConfigs = new HashMap<>();
     yarnConfigs.put(RESOURCEMANAGER_PORT, "localhost:50030");
@@ -637,15 +604,15 @@ public class JMXHostProviderTest {
     ClusterRequest crReq = new ClusterRequest(1L, "c1", null, null);
     crReq.setDesiredConfig(Collections.singletonList(cr2));
     controller.updateClusters(Collections.singleton(crReq), null);
-    Assert.assertEquals("50030", providerModule.getPort("c1", "RESOURCEMANAGER", "localhost"));
-    Assert.assertEquals("11111", providerModule.getPort("c1", "NODEMANAGER", "localhost"));
+    Assert.assertEquals("50030", providerModule.getPort("c1", "RESOURCEMANAGER", "localhost", false));
+    Assert.assertEquals("11111", providerModule.getPort("c1", "NODEMANAGER", "localhost", false));
 
     //Unrelated ports
-    Assert.assertEquals("70070", providerModule.getPort("c1", "NAMENODE", "localhost"));
-    Assert.assertEquals(null, providerModule.getPort("c1", "JOBTRACKER", "localhost"));
+    Assert.assertEquals("70070", providerModule.getPort("c1", "NAMENODE", "localhost", false));
+    Assert.assertEquals(null, providerModule.getPort("c1", "JOBTRACKER", "localhost", false));
 
     //test another host and component without property
-    Assert.assertNull(providerModule.getPort("c1", "HBASE_REGIONSERVER", "remotehost1"));
+    Assert.assertNull(providerModule.getPort("c1", "HBASE_REGIONSERVER", "remotehost1", false));
   }
 
   private static class JMXHostProviderModule extends AbstractProviderModule {
@@ -667,9 +634,7 @@ public class JMXHostProviderTest {
         maintenanceStateHelper, repositoryVersionDAO);
 
     ResourceProvider hostCompResourceProvider = new
-      HostComponentResourceProvider(PropertyHelper.getPropertyIds(Resource
-      .Type.HostComponent), PropertyHelper.getKeyPropertyIds(Resource.Type
-      .HostComponent), controller, injector);
+      HostComponentResourceProvider(controller, injector);
 
     ResourceProvider configResourceProvider = new ConfigurationResourceProvider(
         controller);
@@ -695,4 +660,4 @@ public class JMXHostProviderTest {
     }
 
   }
-}
\ No newline at end of file
+}
