@@ -19,6 +19,7 @@
 package org.apache.ambari.server.controller.internal;
 
 import java.sql.SQLException;
+import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
@@ -41,8 +42,8 @@ import org.apache.ambari.server.orm.GuiceJpaInitializer;
 import org.apache.ambari.server.orm.InMemoryDefaultTestModule;
 import org.apache.ambari.server.orm.dao.RepositoryVersionDAO;
 import org.apache.ambari.server.orm.dao.StackDAO;
-import org.apache.ambari.server.orm.entities.OperatingSystemEntity;
-import org.apache.ambari.server.orm.entities.RepositoryEntity;
+import org.apache.ambari.server.orm.entities.RepoDefinitionEntity;
+import org.apache.ambari.server.orm.entities.RepoOsEntity;
 import org.apache.ambari.server.orm.entities.RepositoryVersionEntity;
 import org.apache.ambari.server.orm.entities.StackEntity;
 import org.apache.ambari.server.security.TestAuthenticationFactory;
@@ -76,8 +77,16 @@ public class RepositoryVersionResourceProviderTest {
 
   private static Injector injector;
 
-  private static String jsonStringRedhat6 = "[{\"OperatingSystems\":{\"os_type\":\"redhat6\"},\"repositories\":[]}]";
-  private static String jsonStringRedhat7 = "[{\"OperatingSystems\":{\"os_type\":\"redhat7\"},\"repositories\":[]}]";
+  public static final List<RepoOsEntity> osRedhat6 = new ArrayList<>();
+
+  static {
+    RepoOsEntity repoOsEntity = new RepoOsEntity();
+    repoOsEntity.setFamily("redhat6");
+    repoOsEntity.setAmbariManaged(true);
+    osRedhat6.add(repoOsEntity);
+  }
+
+  public static final List<RepoOsEntity> osRedhat7 = new ArrayList<>();
 
   @Before
   public void before() throws Exception {
@@ -250,7 +259,7 @@ public class RepositoryVersionResourceProviderTest {
     final RepositoryVersionDAO repositoryVersionDAO = injector.getInstance(RepositoryVersionDAO.class);
     final RepositoryVersionEntity entity = new RepositoryVersionEntity();
     entity.setDisplayName("name");
-    entity.setOperatingSystems(jsonStringRedhat6);
+    entity.addRepoOsEntities(osRedhat6);
     entity.setStack(stackEntity);
     entity.setVersion("1.1.1.1");
 
@@ -276,7 +285,21 @@ public class RepositoryVersionResourceProviderTest {
     entity.setDisplayName("name");
     entity.setStack(stackEntity);
     entity.setVersion("1.1");
-    entity.setOperatingSystems("[{\"OperatingSystems/os_type\":\"redhat6\",\"repositories\":[{\"Repositories/repo_id\":\"1\",\"Repositories/repo_name\":\"1\",\"Repositories/base_url\":\"http://example.com/repo1\",\"Repositories/unique\":\"true\"}]}]");
+
+
+    List<RepoOsEntity> osEntities = new ArrayList<>();
+    RepoDefinitionEntity repoDefinitionEntity1 = new RepoDefinitionEntity();
+    repoDefinitionEntity1.setRepoID("1");
+    repoDefinitionEntity1.setBaseUrl("http://example.com/repo1");
+    repoDefinitionEntity1.setRepoName("1");
+    repoDefinitionEntity1.setUnique(true);
+    RepoOsEntity repoOsEntity = new RepoOsEntity();
+    repoOsEntity.setFamily("redhat6");
+    repoOsEntity.setAmbariManaged(true);
+    repoOsEntity.addRepoDefinition(repoDefinitionEntity1);
+    osEntities.add(repoOsEntity);
+
+    entity.addRepoOsEntities(osEntities);
 
     final RepositoryVersionDAO repositoryVersionDAO = injector.getInstance(RepositoryVersionDAO.class);
     AmbariMetaInfo info = injector.getInstance(AmbariMetaInfo.class);
@@ -293,14 +316,8 @@ public class RepositoryVersionResourceProviderTest {
     RepositoryVersionResourceProvider.validateRepositoryVersion(repositoryVersionDAO, info, entity);
 
     // test invalid usecases
-    entity.setOperatingSystems(jsonStringRedhat7);
-    try {
-      RepositoryVersionResourceProvider.validateRepositoryVersion(repositoryVersionDAO, info, entity);
-      Assert.fail("Should throw exception");
-    } catch (Exception ex) {
-    }
 
-    entity.setOperatingSystems("");
+    entity.addRepoOsEntities(new ArrayList<>());
     try {
       RepositoryVersionResourceProvider.validateRepositoryVersion(repositoryVersionDAO, info, entity);
       Assert.fail("Should throw exception");
@@ -320,7 +337,7 @@ public class RepositoryVersionResourceProviderTest {
     entity.setDisplayName("name");
     entity.setStack(stackEntity);
     entity.setVersion("1.1");
-    entity.setOperatingSystems("[{\"OperatingSystems/os_type\":\"redhat6\",\"repositories\":[{\"Repositories/repo_id\":\"1\",\"Repositories/repo_name\":\"1\",\"Repositories/base_url\":\"http://example.com/repo1\",\"Repositories/unique\":\"true\"}]}]");
+    entity.addRepoOsEntities(osEntities);
     repositoryVersionDAO.create(entity);
 
     final RepositoryVersionEntity entity2 = new RepositoryVersionEntity();
@@ -328,7 +345,7 @@ public class RepositoryVersionResourceProviderTest {
     entity2.setDisplayName("name2");
     entity2.setStack(stackEntity);
     entity2.setVersion("1.2");
-    entity2.setOperatingSystems("[{\"OperatingSystems/os_type\":\"redhat6\",\"repositories\":[{\"Repositories/repo_id\":\"1\",\"Repositories/repo_name\":\"1\",\"Repositories/base_url\":\"http://example.com/repo1\",\"Repositories/unique\":\"true\"}]}]");
+    entity2.addRepoOsEntities(osEntities);
 
     try {
       RepositoryVersionResourceProvider.validateRepositoryVersion(repositoryVersionDAO, info, entity2);
@@ -341,7 +358,7 @@ public class RepositoryVersionResourceProviderTest {
     entity3.setDisplayName("name2");
     entity3.setStack(stackEntity);
     entity3.setVersion("1.1");
-    entity3.setOperatingSystems("[{\"OperatingSystems/ambari_managed_repositories\": true, \"OperatingSystems/os_type\":\"redhat6\",\"repositories\":[{\"Repositories/repo_id\":\"1\",\"Repositories/repo_name\":\"1\",\"Repositories/base_url\":\"http://example.com/repo1\",\"Repositories/unique\":\"true\"}]}]");
+    entity3.addRepoOsEntities(osEntities);
 
     try {
       RepositoryVersionResourceProvider.validateRepositoryVersion(repositoryVersionDAO, info, entity3);
@@ -350,7 +367,8 @@ public class RepositoryVersionResourceProviderTest {
       // expected
     }
 
-    entity3.setOperatingSystems("[{\"OperatingSystems/ambari_managed_repositories\": false, \"OperatingSystems/os_type\":\"redhat6\",\"repositories\":[{\"Repositories/repo_id\":\"1\",\"Repositories/repo_name\":\"1\",\"Repositories/base_url\":\"http://example.com/repo1\",\"Repositories/unique\":\"true\"}]}]");
+    entity3.addRepoOsEntities(osEntities);
+    repoOsEntity.setAmbariManaged(false);
     RepositoryVersionResourceProvider.validateRepositoryVersion(repositoryVersionDAO, info, entity3);
 
   }
@@ -446,12 +464,12 @@ public class RepositoryVersionResourceProviderTest {
     Gson gson = new Gson();
     String operatingSystemsJson = gson.toJson(operatingSystems);
     RepositoryVersionHelper repositoryVersionHelper = new RepositoryVersionHelper();
-    List<OperatingSystemEntity> operatingSystemEntities = repositoryVersionHelper.parseOperatingSystems(operatingSystemsJson);
-    for (OperatingSystemEntity operatingSystemEntity : operatingSystemEntities) {
-      String osType = operatingSystemEntity.getOsType();
-      List<RepositoryEntity> repositories = operatingSystemEntity.getRepositories();
-      for (RepositoryEntity repository : repositories) {
-        RepositoryInfo repo = ambariMetaInfo.getRepository(stackName, stackVersion, osType, repository.getRepositoryId());
+    List<RepoOsEntity> operatingSystemEntities = repositoryVersionHelper.parseOperatingSystems(operatingSystemsJson);
+    for (RepoOsEntity operatingSystemEntity : operatingSystemEntities) {
+      String osType = operatingSystemEntity.getFamily();
+      List<RepoDefinitionEntity> repositories = operatingSystemEntity.getRepoDefinitionEntities();
+      for (RepoDefinitionEntity repository : repositories) {
+        RepositoryInfo repo = ambariMetaInfo.getRepository(stackName, stackVersion, osType, repository.getRepoID());
         if (repo != null) {
           String baseUrlActual = repo.getBaseUrl();
           String baseUrlExpected = repository.getBaseUrl();
@@ -515,13 +533,13 @@ public class RepositoryVersionResourceProviderTest {
     Gson gson = new Gson();
     String operatingSystemsJson = gson.toJson(operatingSystems);
     RepositoryVersionHelper repositoryVersionHelper = new RepositoryVersionHelper();
-    List<OperatingSystemEntity> operatingSystemEntities = repositoryVersionHelper.parseOperatingSystems(operatingSystemsJson);
-    for (OperatingSystemEntity operatingSystemEntity : operatingSystemEntities) {
-      Assert.assertFalse(operatingSystemEntity.isAmbariManagedRepos());
-      String osType = operatingSystemEntity.getOsType();
-      List<RepositoryEntity> repositories = operatingSystemEntity.getRepositories();
-      for (RepositoryEntity repository : repositories) {
-        RepositoryInfo repo = ambariMetaInfo.getRepository(stackName, stackVersion, osType, repository.getRepositoryId());
+    List<RepoOsEntity> operatingSystemEntities = repositoryVersionHelper.parseOperatingSystems(operatingSystemsJson);
+    for (RepoOsEntity operatingSystemEntity : operatingSystemEntities) {
+      Assert.assertFalse(operatingSystemEntity.isAmbariManaged());
+      String osType = operatingSystemEntity.getFamily();
+      List<RepoDefinitionEntity> repositories = operatingSystemEntity.getRepoDefinitionEntities();
+      for (RepoDefinitionEntity repository : repositories) {
+        RepositoryInfo repo = ambariMetaInfo.getRepository(stackName, stackVersion, osType, repository.getRepoID());
         if (repo != null) {
           String baseUrlActual = repo.getBaseUrl();
           String baseUrlExpected = repository.getBaseUrl();
