@@ -18,13 +18,29 @@
 
 package org.apache.ambari.server.controller.internal;
 
-import junit.framework.Assert;
+import static org.easymock.EasyMock.anyObject;
+import static org.easymock.EasyMock.expect;
+
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.LinkedList;
+import java.util.List;
+import java.util.Set;
+
+import javax.persistence.EntityManager;
+
+import org.apache.ambari.server.controller.UserPrivilegeResponse;
 import org.apache.ambari.server.controller.spi.Predicate;
 import org.apache.ambari.server.controller.spi.Request;
 import org.apache.ambari.server.controller.spi.Resource;
 import org.apache.ambari.server.controller.spi.SystemException;
 import org.apache.ambari.server.controller.utilities.PredicateBuilder;
 import org.apache.ambari.server.controller.utilities.PropertyHelper;
+import org.apache.ambari.server.hooks.HookContextFactory;
+import org.apache.ambari.server.hooks.HookService;
+import org.apache.ambari.server.ldap.service.AmbariLdapConfigurationProvider;
+import org.apache.ambari.server.orm.DBAccessor;
 import org.apache.ambari.server.orm.dao.ClusterDAO;
 import org.apache.ambari.server.orm.dao.GroupDAO;
 import org.apache.ambari.server.orm.dao.MemberDAO;
@@ -32,7 +48,6 @@ import org.apache.ambari.server.orm.dao.PrivilegeDAO;
 import org.apache.ambari.server.orm.dao.UserDAO;
 import org.apache.ambari.server.orm.dao.ViewInstanceDAO;
 import org.apache.ambari.server.orm.entities.ClusterEntity;
-import org.apache.ambari.server.orm.entities.MemberEntity;
 import org.apache.ambari.server.orm.entities.PermissionEntity;
 import org.apache.ambari.server.orm.entities.PrincipalEntity;
 import org.apache.ambari.server.orm.entities.PrincipalTypeEntity;
@@ -46,24 +61,23 @@ import org.apache.ambari.server.security.TestAuthenticationFactory;
 import org.apache.ambari.server.security.authorization.AuthorizationException;
 import org.apache.ambari.server.security.authorization.ResourceType;
 import org.apache.ambari.server.security.authorization.Users;
+import org.apache.ambari.server.state.stack.OsFamily;
+import org.easymock.EasyMockSupport;
 import org.junit.Test;
 import org.springframework.security.core.Authentication;
 import org.springframework.security.core.context.SecurityContextHolder;
+import org.springframework.security.crypto.password.PasswordEncoder;
 
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.HashSet;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Set;
+import com.google.inject.AbstractModule;
+import com.google.inject.Guice;
+import com.google.inject.Injector;
 
-import static org.easymock.EasyMock.anyObject;
-import static org.easymock.EasyMock.expect;
+import junit.framework.Assert;
 
 /**
  * UserPrivilegeResourceProvider tests.
  */
-public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResourceProviderTest {
+public class UserPrivilegeResourceProviderTest extends EasyMockSupport {
 
   @Test(expected = SystemException.class)
   public void testCreateResources() throws Exception {
@@ -141,9 +155,10 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
 
     UserPrivilegeResourceProvider.init(userDAO, clusterDAO, groupDAO, viewInstanceDAO, users);
     UserPrivilegeResourceProvider provider = new UserPrivilegeResourceProvider();
-    Resource resource = provider.toResource(privilegeEntity, "jdoe", provider.getPropertyIds());
+    UserPrivilegeResponse response = provider.getResponse(privilegeEntity, "jdoe");
+    Resource resource = provider.toResource(response, provider.getPropertyIds());
 
-    Assert.assertEquals(ResourceType.AMBARI.name(), resource.getPropertyValue(UserPrivilegeResourceProvider.PRIVILEGE_TYPE_PROPERTY_ID));
+    Assert.assertEquals(ResourceType.AMBARI.name(), resource.getPropertyValue(UserPrivilegeResourceProvider.TYPE));
 
     verifyAll();
   }
@@ -194,10 +209,11 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
 
     UserPrivilegeResourceProvider.init(userDAO, clusterDAO, groupDAO, viewInstanceDAO, users);
     UserPrivilegeResourceProvider provider = new UserPrivilegeResourceProvider();
-    Resource resource = provider.toResource(privilegeEntity, "jdoe", provider.getPropertyIds());
+    UserPrivilegeResponse response = provider.getResponse(privilegeEntity, "jdoe");
+    Resource resource = provider.toResource(response, provider.getPropertyIds());
 
-    Assert.assertEquals("TestCluster", resource.getPropertyValue(ClusterPrivilegeResourceProvider.PRIVILEGE_CLUSTER_NAME_PROPERTY_ID));
-    Assert.assertEquals(ResourceType.CLUSTER.name(), resource.getPropertyValue(UserPrivilegeResourceProvider.PRIVILEGE_TYPE_PROPERTY_ID));
+    Assert.assertEquals("TestCluster", resource.getPropertyValue(ClusterPrivilegeResourceProvider.CLUSTER_NAME));
+    Assert.assertEquals(ResourceType.CLUSTER.name(), resource.getPropertyValue(UserPrivilegeResourceProvider.TYPE));
 
     verifyAll();
   }
@@ -253,12 +269,13 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
 
     UserPrivilegeResourceProvider.init(userDAO, clusterDAO, groupDAO, viewInstanceDAO, users);
     UserPrivilegeResourceProvider provider = new UserPrivilegeResourceProvider();
-    Resource resource = provider.toResource(privilegeEntity, "jdoe", provider.getPropertyIds());
+    UserPrivilegeResponse response = provider.getResponse(privilegeEntity, "jdoe");
+    Resource resource = provider.toResource(response, provider.getPropertyIds());
 
-    Assert.assertEquals("Test View", resource.getPropertyValue(ViewPrivilegeResourceProvider.PRIVILEGE_INSTANCE_NAME_PROPERTY_ID));
-    Assert.assertEquals("TestView", resource.getPropertyValue(ViewPrivilegeResourceProvider.PRIVILEGE_VIEW_NAME_PROPERTY_ID));
-    Assert.assertEquals("1.2.3.4", resource.getPropertyValue(ViewPrivilegeResourceProvider.PRIVILEGE_VIEW_VERSION_PROPERTY_ID));
-    Assert.assertEquals(ResourceType.VIEW.name(), resource.getPropertyValue(UserPrivilegeResourceProvider.PRIVILEGE_TYPE_PROPERTY_ID));
+    Assert.assertEquals("Test View", resource.getPropertyValue(ViewPrivilegeResourceProvider.INSTANCE_NAME));
+    Assert.assertEquals("TestView", resource.getPropertyValue(ViewPrivilegeResourceProvider.VIEW_NAME));
+    Assert.assertEquals("1.2.3.4", resource.getPropertyValue(ViewPrivilegeResourceProvider.VERSION));
+    Assert.assertEquals(ResourceType.VIEW.name(), resource.getPropertyValue(UserPrivilegeResourceProvider.TYPE));
 
     verifyAll();
   }
@@ -314,12 +331,13 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
 
     UserPrivilegeResourceProvider.init(userDAO, clusterDAO, groupDAO, viewInstanceDAO, users);
     UserPrivilegeResourceProvider provider = new UserPrivilegeResourceProvider();
-    Resource resource = provider.toResource(privilegeEntity, "jdoe", provider.getPropertyIds());
+    UserPrivilegeResponse response = provider.getResponse(privilegeEntity, "jdoe");
+    Resource resource = provider.toResource(response, provider.getPropertyIds());
 
-    Assert.assertEquals("Test View", resource.getPropertyValue(ViewPrivilegeResourceProvider.PRIVILEGE_INSTANCE_NAME_PROPERTY_ID));
-    Assert.assertEquals("TestView", resource.getPropertyValue(ViewPrivilegeResourceProvider.PRIVILEGE_VIEW_NAME_PROPERTY_ID));
-    Assert.assertEquals("1.2.3.4", resource.getPropertyValue(ViewPrivilegeResourceProvider.PRIVILEGE_VIEW_VERSION_PROPERTY_ID));
-    Assert.assertEquals(ResourceType.VIEW.name(), resource.getPropertyValue(UserPrivilegeResourceProvider.PRIVILEGE_TYPE_PROPERTY_ID));
+    Assert.assertEquals("Test View", resource.getPropertyValue(ViewPrivilegeResourceProvider.INSTANCE_NAME));
+    Assert.assertEquals("TestView", resource.getPropertyValue(ViewPrivilegeResourceProvider.VIEW_NAME));
+    Assert.assertEquals("1.2.3.4", resource.getPropertyValue(ViewPrivilegeResourceProvider.VERSION));
+    Assert.assertEquals(ResourceType.VIEW.name(), resource.getPropertyValue(UserPrivilegeResourceProvider.TYPE));
 
     verifyAll();
   }
@@ -328,45 +346,56 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
   public void testToResource_SpecificVIEW_WithClusterInheritedPermission() throws Exception {
     SecurityContextHolder.getContext().setAuthentication(TestAuthenticationFactory.createClusterAdministrator("jdoe", 2L));
 
-    PrincipalTypeEntity rolePrincipalTypeEntity = createMock(PrincipalTypeEntity.class);
+    Injector injector = createInjector();
+
+    final UserPrivilegeResourceProvider resourceProvider = new UserPrivilegeResourceProvider();
+    final UserDAO userDAO = injector.getInstance(UserDAO.class);
+    final GroupDAO groupDAO = injector.getInstance(GroupDAO.class);
+    final ClusterDAO clusterDAO = injector.getInstance(ClusterDAO.class);
+    final ViewInstanceDAO viewInstanceDAO = injector.getInstance(ViewInstanceDAO.class);
+    final PrivilegeDAO privilegeDAO = injector.getInstance(PrivilegeDAO.class);
+    final MemberDAO memberDAO = injector.getInstance(MemberDAO.class);
+
+
+    final PrincipalTypeEntity rolePrincipalTypeEntity = createMock(PrincipalTypeEntity.class);
     expect(rolePrincipalTypeEntity.getName()).andReturn("ROLE").atLeastOnce();
 
-    PrincipalEntity rolePrincipalEntity = createMock(PrincipalEntity.class);
+    final PrincipalEntity rolePrincipalEntity = createMock(PrincipalEntity.class);
     expect(rolePrincipalEntity.getPrincipalType()).andReturn(rolePrincipalTypeEntity).atLeastOnce();
 
-    PermissionEntity permissionEntity = createMock(PermissionEntity.class);
+    final PermissionEntity permissionEntity = createMock(PermissionEntity.class);
     expect(permissionEntity.getPrincipal()).andReturn(rolePrincipalEntity).atLeastOnce();
     expect(permissionEntity.getPermissionName()).andReturn("CLUSTER.ADMINISTRATOR").atLeastOnce();
     expect(permissionEntity.getPermissionLabel()).andReturn("Cluster Administrator").atLeastOnce();
 
-    PrincipalTypeEntity principalTypeEntity = createMock(PrincipalTypeEntity.class);
+    final PrincipalTypeEntity principalTypeEntity = createMock(PrincipalTypeEntity.class);
     expect(principalTypeEntity.getName()).andReturn("USER").atLeastOnce();
 
-    PrincipalEntity principalEntity = createMock(PrincipalEntity.class);
+    final PrincipalEntity principalEntity = createMock(PrincipalEntity.class);
     expect(principalEntity.getPrincipalType()).andReturn(principalTypeEntity).atLeastOnce();
 
-    ViewEntity viewEntity = createMock(ViewEntity.class);
+    final ViewEntity viewEntity = createMock(ViewEntity.class);
     expect(viewEntity.getCommonName()).andReturn("TestView").atLeastOnce();
     expect(viewEntity.getVersion()).andReturn("1.2.3.4").atLeastOnce();
 
-    ResourceTypeEntity resourceTypeEntity = createMock(ResourceTypeEntity.class);
+    final ResourceTypeEntity resourceTypeEntity = createMock(ResourceTypeEntity.class);
     expect(resourceTypeEntity.getName()).andReturn("TestView{1.2.3.4}").atLeastOnce();
 
-    ResourceEntity resourceEntity = createMock(ResourceEntity.class);
+    final ResourceEntity resourceEntity = createMock(ResourceEntity.class);
     expect(resourceEntity.getId()).andReturn(1L).anyTimes();
     expect(resourceEntity.getResourceType()).andReturn(resourceTypeEntity).anyTimes();
 
-    ViewInstanceEntity viewInstanceEntity = createMock(ViewInstanceEntity.class);
+    final ViewInstanceEntity viewInstanceEntity = createMock(ViewInstanceEntity.class);
     expect(viewInstanceEntity.getViewEntity()).andReturn(viewEntity).atLeastOnce();
     expect(viewInstanceEntity.getName()).andReturn("Test View").atLeastOnce();
 
-    PrivilegeEntity explicitPrivilegeEntity = createMock(PrivilegeEntity.class);
+    final PrivilegeEntity explicitPrivilegeEntity = createMock(PrivilegeEntity.class);
     expect(explicitPrivilegeEntity.getId()).andReturn(1).atLeastOnce();
     expect(explicitPrivilegeEntity.getPermission()).andReturn(permissionEntity).atLeastOnce();
     expect(explicitPrivilegeEntity.getPrincipal()).andReturn(principalEntity).atLeastOnce();
     expect(explicitPrivilegeEntity.getResource()).andReturn(resourceEntity).atLeastOnce();
 
-    PrivilegeEntity implicitPrivilegeEntity = createMock(PrivilegeEntity.class);
+    final PrivilegeEntity implicitPrivilegeEntity = createMock(PrivilegeEntity.class);
     expect(implicitPrivilegeEntity.getId()).andReturn(2).atLeastOnce();
     expect(implicitPrivilegeEntity.getPermission()).andReturn(permissionEntity).atLeastOnce();
     expect(implicitPrivilegeEntity.getPrincipal()).andReturn(rolePrincipalEntity).atLeastOnce();
@@ -376,28 +405,18 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
     expect(userEntity.getUserName()).andReturn("jdoe").atLeastOnce();
     expect(userEntity.getPrincipal()).andReturn(principalEntity).atLeastOnce();
 
-    ClusterDAO clusterDAO = createMock(ClusterDAO.class);
-    GroupDAO groupDAO = createMock(GroupDAO.class);
-
-    ViewInstanceDAO viewInstanceDAO = createMock(ViewInstanceDAO.class);
     expect(viewInstanceDAO.findByResourceId(1L)).andReturn(viewInstanceEntity).atLeastOnce();
 
-    final UserDAO userDAO = createNiceMock(UserDAO.class);
-    expect(userDAO.findLocalUserByName("jdoe")).andReturn(userEntity).anyTimes();
+    expect(userDAO.findUserByName("jdoe")).andReturn(userEntity).anyTimes();
     expect(userDAO.findUserByPrincipal(anyObject(PrincipalEntity.class))).andReturn(userEntity).anyTimes();
-    expect(userDAO.findAll()).andReturn(Collections.<UserEntity>emptyList()).anyTimes();
+    expect(userDAO.findAll()).andReturn(Collections.emptyList()).anyTimes();
 
-    final PrivilegeDAO privilegeDAO = createMock(PrivilegeDAO.class);
-    final MemberDAO memberDAO = createMock(MemberDAO.class);
+    final Users users = injector.getInstance(Users.class);
 
-    final TestUsers users = new TestUsers();
-    users.setPrivilegeDAO(privilegeDAO);
-    users.setMemberDAO(memberDAO);
-
-    List<PrincipalEntity> rolePrincipals = new LinkedList<PrincipalEntity>();
+    List<PrincipalEntity> rolePrincipals = new LinkedList<>();
     rolePrincipals.add(rolePrincipalEntity);
 
-    List<PrincipalEntity> userPrincipals = new LinkedList<PrincipalEntity>();
+    List<PrincipalEntity> userPrincipals = new LinkedList<>();
     userPrincipals.add(principalEntity);
 
     expect(privilegeDAO.findAllByPrincipal(userPrincipals)).
@@ -408,17 +427,17 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
         andReturn(Collections.singletonList(implicitPrivilegeEntity))
         .once();
     expect(memberDAO.findAllMembersByUser(userEntity)).
-        andReturn(Collections.<MemberEntity>emptyList())
+        andReturn(Collections.emptyList())
         .atLeastOnce();
 
     replayAll();
 
-    final Set<String> propertyIds = new HashSet<String>();
-    propertyIds.add(UserPrivilegeResourceProvider.PRIVILEGE_USER_NAME_PROPERTY_ID);
+    final Set<String> propertyIds = new HashSet<>();
+    propertyIds.add(UserPrivilegeResourceProvider.USER_NAME);
     final Predicate predicate = new PredicateBuilder()
-      .property(UserPrivilegeResourceProvider.PRIVILEGE_USER_NAME_PROPERTY_ID)
-      .equals("jdoe")
-      .toPredicate();
+        .property(UserPrivilegeResourceProvider.USER_NAME)
+        .equals("jdoe")
+        .toPredicate();
     TestAuthenticationFactory.createClusterAdministrator("jdoe", 2L);
     Request request = PropertyHelper.getReadRequest(propertyIds);
 
@@ -428,7 +447,7 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
 
     Assert.assertEquals(1, resources.size());
     for (Resource resource : resources) {
-      String userName = (String) resource.getPropertyValue(UserPrivilegeResourceProvider.PRIVILEGE_USER_NAME_PROPERTY_ID);
+      String userName = (String) resource.getPropertyValue(UserPrivilegeResourceProvider.USER_NAME);
       Assert.assertEquals("jdoe", userName);
     }
 
@@ -437,11 +456,16 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
 
   //  @SuppressWarnings("serial")
   private void getResourcesTest(Authentication authentication, String requestedUsername) throws Exception {
+    Injector injector = createInjector();
+
     final UserPrivilegeResourceProvider resourceProvider = new UserPrivilegeResourceProvider();
-    final UserDAO userDAO = createNiceMock(UserDAO.class);
-    final GroupDAO groupDAO = createNiceMock(GroupDAO.class);
-    final ClusterDAO clusterDAO = createNiceMock(ClusterDAO.class);
-    final ViewInstanceDAO viewInstanceDAO = createNiceMock(ViewInstanceDAO.class);
+    final UserDAO userDAO = injector.getInstance(UserDAO.class);
+    final GroupDAO groupDAO = injector.getInstance(GroupDAO.class);
+    final ClusterDAO clusterDAO = injector.getInstance(ClusterDAO.class);
+    final ViewInstanceDAO viewInstanceDAO = injector.getInstance(ViewInstanceDAO.class);
+    final PrivilegeDAO privilegeDAO = injector.getInstance(PrivilegeDAO.class);
+    final MemberDAO memberDAO = injector.getInstance(MemberDAO.class);
+
     final UserEntity userEntity = createNiceMock(UserEntity.class);
     final PrincipalEntity principalEntity = createNiceMock(PrincipalEntity.class);
     final PrivilegeEntity privilegeEntity = createNiceMock(PrivilegeEntity.class);
@@ -449,26 +473,22 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
     final PrincipalTypeEntity principalTypeEntity = createNiceMock(PrincipalTypeEntity.class);
     final ResourceEntity resourceEntity = createNiceMock(ResourceEntity.class);
     final ResourceTypeEntity resourceTypeEntity = createNiceMock(ResourceTypeEntity.class);
-    final PrivilegeDAO privilegeDAO = createMock(PrivilegeDAO.class);
-    final MemberDAO memberDAO = createMock(MemberDAO.class);
 
-    final TestUsers users = new TestUsers();
-    users.setPrivilegeDAO(privilegeDAO);
-    users.setMemberDAO(memberDAO);
+    final Users users = injector.getInstance(Users.class);
 
-    List<PrincipalEntity> userPrincipals = new LinkedList<PrincipalEntity>();
+    List<PrincipalEntity> userPrincipals = new LinkedList<>();
     userPrincipals.add(principalEntity);
 
     expect(privilegeDAO.findAllByPrincipal(userPrincipals)).
         andReturn(Collections.singletonList(privilegeEntity))
         .atLeastOnce();
     expect(memberDAO.findAllMembersByUser(userEntity)).
-        andReturn(Collections.<MemberEntity>emptyList())
+        andReturn(Collections.emptyList())
         .atLeastOnce();
-    expect(userDAO.findLocalUserByName(requestedUsername)).andReturn(userEntity).anyTimes();
-    expect(userDAO.findAll()).andReturn(Collections.<UserEntity>emptyList()).anyTimes();
+    expect(userDAO.findAll()).andReturn(Collections.emptyList()).anyTimes();
+    expect(userDAO.findUserByName(requestedUsername)).andReturn(userEntity).anyTimes();
     expect(userEntity.getPrincipal()).andReturn(principalEntity).anyTimes();
-    expect(userEntity.getMemberEntities()).andReturn(Collections.<MemberEntity>emptySet()).anyTimes();
+    expect(userEntity.getMemberEntities()).andReturn(Collections.emptySet()).anyTimes();
     expect(privilegeEntity.getPermission()).andReturn(permissionEntity).anyTimes();
     expect(privilegeEntity.getPrincipal()).andReturn(principalEntity).anyTimes();
     expect(principalEntity.getPrincipalType()).andReturn(principalTypeEntity).anyTimes();
@@ -483,17 +503,17 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
     expect(privilegeEntity.getResource()).andReturn(resourceEntity).anyTimes();
     expect(resourceEntity.getResourceType()).andReturn(resourceTypeEntity).anyTimes();
     expect(resourceTypeEntity.getName()).andReturn(ResourceType.AMBARI.name());
-    expect(viewInstanceDAO.findAll()).andReturn(new ArrayList<ViewInstanceEntity>()).anyTimes();
+    expect(viewInstanceDAO.findAll()).andReturn(new ArrayList<>()).anyTimes();
 
     replayAll();
 
     UserPrivilegeResourceProvider.init(userDAO, clusterDAO, groupDAO, viewInstanceDAO, users);
 
-    final Set<String> propertyIds = new HashSet<String>();
-    propertyIds.add(UserPrivilegeResourceProvider.PRIVILEGE_USER_NAME_PROPERTY_ID);
+    final Set<String> propertyIds = new HashSet<>();
+    propertyIds.add(UserPrivilegeResourceProvider.USER_NAME);
 
     final Predicate predicate = new PredicateBuilder()
-        .property(UserPrivilegeResourceProvider.PRIVILEGE_USER_NAME_PROPERTY_ID)
+        .property(UserPrivilegeResourceProvider.USER_NAME)
         .equals(requestedUsername)
         .toPredicate();
     Request request = PropertyHelper.getReadRequest(propertyIds);
@@ -505,11 +525,33 @@ public class UserPrivilegeResourceProviderTest extends AbstractPrivilegeResource
 
     Assert.assertEquals(1, resources.size());
     for (Resource resource : resources) {
-      String userName = (String) resource.getPropertyValue(UserPrivilegeResourceProvider.PRIVILEGE_USER_NAME_PROPERTY_ID);
+      String userName = (String) resource.getPropertyValue(UserPrivilegeResourceProvider.USER_NAME);
       Assert.assertEquals(requestedUsername, userName);
     }
 
     verifyAll();
   }
 
+  private Injector createInjector() {
+    return Guice.createInjector(new AbstractModule() {
+      @Override
+      protected void configure() {
+        bind(OsFamily.class).toInstance(createNiceMock(OsFamily.class));
+        bind(EntityManager.class).toInstance(createNiceMock(EntityManager.class));
+        bind(DBAccessor.class).toInstance(createNiceMock(DBAccessor.class));
+        bind(PasswordEncoder.class).toInstance(createNiceMock(PasswordEncoder.class));
+        bind(HookService.class).toInstance(createMock(HookService.class));
+        bind(HookContextFactory.class).toInstance(createMock(HookContextFactory.class));
+
+        bind(UserDAO.class).toInstance(createNiceMock(UserDAO.class));
+        bind(GroupDAO.class).toInstance(createNiceMock(GroupDAO.class));
+        bind(ClusterDAO.class).toInstance(createNiceMock(ClusterDAO.class));
+        bind(ViewInstanceDAO.class).toInstance(createNiceMock(ViewInstanceDAO.class));
+        bind(PrivilegeDAO.class).toInstance(createMock(PrivilegeDAO.class));
+        bind(MemberDAO.class).toInstance(createMock(MemberDAO.class));
+        bind(AmbariLdapConfigurationProvider.class).toInstance(createMock(AmbariLdapConfigurationProvider.class));
+      }
+    });
+  }
+
 }
