@@ -64,6 +64,7 @@ import org.apache.ambari.server.state.ServiceFactory;
 import org.apache.ambari.server.state.StackId;
 import org.apache.ambari.server.state.State;
 import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.ConfigurationKeyValue;
+import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.IfValueMatchType;
 import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.Insert;
 import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.InsertType;
 import org.apache.ambari.server.state.stack.upgrade.ConfigUpgradeChangeDefinition.Replace;
@@ -73,7 +74,7 @@ import org.apache.ambari.server.state.stack.upgrade.PropertyKeyState;
 import org.apache.ambari.server.state.stack.upgrade.TransferCoercionType;
 import org.apache.ambari.server.state.stack.upgrade.TransferOperation;
 import org.apache.ambari.server.state.stack.upgrade.UpgradeType;
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
@@ -167,7 +168,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -217,16 +218,13 @@ public class ConfigureActionTest {
     Cluster c = clusters.getCluster("c1");
     assertEquals(1, c.getConfigsByType("zoo.cfg").size());
 
-    c.setCurrentStackVersion(repoVersion2110.getStackId());
-    c.setDesiredStackVersion(repoVersion2200.getStackId());
-
     Map<String, String> properties = new HashMap<String, String>() {
       {
         put("initLimit", "10");
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2200, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -282,7 +280,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -340,7 +338,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -470,7 +468,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -528,7 +526,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -594,7 +592,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -618,7 +616,7 @@ public class ConfigureActionTest {
     ExecutionCommand executionCommand = new ExecutionCommand();
     executionCommand.setCommandParams(commandParams);
     executionCommand.setClusterName("c1");
-    executionCommand.setRoleParams(new HashMap<String, String>());
+    executionCommand.setRoleParams(new HashMap<>());
     executionCommand.getRoleParams().put(ServerAction.ACTION_USER_NAME, "username");
 
     HostRoleCommand hostRoleCommand = hostRoleCommandFactory.create(null, null, null, null);
@@ -643,16 +641,13 @@ public class ConfigureActionTest {
     Cluster c = clusters.getCluster("c1");
     assertEquals(1, c.getConfigsByType("zoo.cfg").size());
 
-    c.setCurrentStackVersion(repoVersion2110.getStackId());
-    c.setDesiredStackVersion(repoVersion2200.getStackId());
-
     Map<String, String> properties = new HashMap<String, String>() {
       {
         put("fooKey", "barValue");
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2200, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -704,9 +699,6 @@ public class ConfigureActionTest {
     Cluster c = clusters.getCluster("c1");
     assertEquals(1, c.getConfigsByType("zoo.cfg").size());
 
-    c.setCurrentStackVersion(repoVersion2110.getStackId());
-    c.setDesiredStackVersion(repoVersion2200.getStackId());
-
     Map<String, String> properties = new HashMap<String, String>() {
       {
         put("set.key.1", "s1");
@@ -716,7 +708,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2200, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -804,7 +796,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2200, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -869,12 +861,10 @@ public class ConfigureActionTest {
   @Test
   public void testAllowedReplacment() throws Exception {
 
+
     Cluster c = clusters.getCluster("c1");
     assertEquals(1, c.getConfigsByType("zoo.cfg").size());
 
-    c.setCurrentStackVersion(repoVersion2110.getStackId());
-    c.setDesiredStackVersion(repoVersion2200.getStackId());
-
     Map<String, String> properties = new HashMap<String, String>() {
       {
         put("replace.key.1", "r1");
@@ -885,7 +875,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2200, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -972,7 +962,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -1052,7 +1042,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -1161,7 +1151,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -1213,7 +1203,7 @@ public class ConfigureActionTest {
     ExecutionCommand executionCommand = new ExecutionCommand();
     executionCommand.setCommandParams(commandParams);
     executionCommand.setClusterName("c1");
-    executionCommand.setRoleParams(new HashMap<String, String>());
+    executionCommand.setRoleParams(new HashMap<>());
     executionCommand.getRoleParams().put(ServerAction.ACTION_USER_NAME, "username");
 
     HostRoleCommand hostRoleCommand = hostRoleCommandFactory.create(null, null,
@@ -1257,7 +1247,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -1359,7 +1349,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -1456,7 +1446,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -1550,7 +1540,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -1641,7 +1631,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version2", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
     assertEquals(2, c.getConfigsByType("zoo.cfg").size());
@@ -1706,6 +1696,185 @@ public class ConfigureActionTest {
     assertEquals(expectedAppend, config.getProperties().get("key_to_append"));
   }
 
+  /**
+   * Tests using the {@code <insert/>} element in a configuration upgrade pack.
+   *
+   * @throws Exception
+   */
+  @Test
+  public void testInsertWithCondition() throws Exception {
+    Cluster c = clusters.getCluster("c1");
+    assertEquals(1, c.getConfigsByType("zoo.cfg").size());
+
+    final String lineSample = "This is before";
+    Map<String, String> properties = new HashMap<String, String>() {
+      {
+        put("item_not_inserted", lineSample);
+        put("item_inserted", lineSample);
+        put("item_partial_inserted", lineSample);
+        put("item_partial_not_inserted", lineSample);
+        put("item_value_not_inserted", lineSample);
+        put("item_partial_value_not_inserted", lineSample);
+        put("item_value_not_not_inserted", lineSample);
+        put("item_partial_value_not_not_inserted", lineSample);
+      }
+    };
+
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version2", properties);
+
+    c.addDesiredConfig("user", Collections.singleton(config));
+    assertEquals(2, c.getConfigsByType("zoo.cfg").size());
+
+    createUpgrade(c, repoVersion2111);
+
+    Map<String, String> commandParams = new HashMap<>();
+    commandParams.put("clusterName", "c1");
+    commandParams.put(ConfigureTask.PARAMETER_CONFIG_TYPE, "zoo.cfg");
+
+
+    final String appendValue = " this will be after...";
+
+    // insert tasks
+    List<Insert> insertions = new ArrayList<>();
+
+    Insert in1 = new Insert();
+    Insert in2 = new Insert();
+    Insert in3 = new Insert();
+    Insert in4 = new Insert();
+    Insert in5 = new Insert();
+    Insert in6 = new Insert();
+    Insert in7 = new Insert();
+    Insert in8 = new Insert();
+
+    //expect: no changes
+    in1.insertType = InsertType.APPEND;
+    in1.key = "item_not_inserted";
+    in1.value = appendValue;
+    in1.newlineBefore = false;
+    in1.newlineAfter = false;
+    in1.ifType = "zoo.cfg";
+    in1.ifKey = "item_not_inserted";
+    in1.ifValue = "multiline";
+    in1.ifValueMatchType = IfValueMatchType.EXACT;
+
+    //expect: value appended to the property
+    in2.insertType = InsertType.APPEND;
+    in2.key = "item_inserted";
+    in2.value = appendValue;
+    in2.newlineBefore = false;
+    in2.newlineAfter = false;
+    in2.ifType = "zoo.cfg";
+    in2.ifKey = "item_inserted";
+    in2.ifValue = lineSample;
+    in2.ifValueMatchType = IfValueMatchType.EXACT;
+
+    //expect: value appended to the property
+    in3.insertType = InsertType.APPEND;
+    in3.key = "item_partial_inserted";
+    in3.value = appendValue;
+    in3.newlineBefore = false;
+    in3.newlineAfter = false;
+    in3.ifType = "zoo.cfg";
+    in3.ifKey = "item_partial_inserted";
+    in3.ifValue = "before";
+    in3.ifValueMatchType = IfValueMatchType.PARTIAL;
+
+    //expect: no changes
+    in4.insertType = InsertType.APPEND;
+    in4.key = "item_partial_not_inserted";
+    in4.value = appendValue;
+    in4.newlineBefore = false;
+    in4.newlineAfter = false;
+    in4.ifType = "zoo.cfg";
+    in4.ifKey = "item_partial_not_inserted";
+    in4.ifValue = "wrong word";
+    in4.ifValueMatchType = IfValueMatchType.PARTIAL;
+
+    //expect: value appended to the property
+    in5.insertType = InsertType.APPEND;
+    in5.key = "item_value_not_inserted";
+    in5.value = appendValue;
+    in5.newlineBefore = false;
+    in5.newlineAfter = false;
+    in5.ifType = "zoo.cfg";
+    in5.ifKey = "item_value_not_inserted";
+    in5.ifValue = "wrong word";
+    in5.ifValueMatchType = IfValueMatchType.EXACT;
+    in5.ifValueNotMatched = true;
+
+    //expect: value appended to the property
+    in6.insertType = InsertType.APPEND;
+    in6.key = "item_partial_value_not_inserted";
+    in6.value = appendValue;
+    in6.newlineBefore = false;
+    in6.newlineAfter = false;
+    in6.ifType = "zoo.cfg";
+    in6.ifKey = "item_partial_value_not_inserted";
+    in6.ifValue = "wrong word";
+    in6.ifValueMatchType = IfValueMatchType.PARTIAL;
+    in6.ifValueNotMatched = true;
+
+    //expect: no changes
+    in7.insertType = InsertType.APPEND;
+    in7.key = "item_value_not_not_inserted";
+    in7.value = appendValue;
+    in7.newlineBefore = false;
+    in7.newlineAfter = false;
+    in7.ifType = "zoo.cfg";
+    in7.ifKey = "item_value_not_not_inserted";
+    in7.ifValue = lineSample;
+    in7.ifValueMatchType = IfValueMatchType.EXACT;
+    in7.ifValueNotMatched = true;
+
+    //expect: no changes
+    in8.insertType = InsertType.APPEND;
+    in8.key = "item_partial_value_not_not_inserted";
+    in8.value = appendValue;
+    in8.newlineBefore = false;
+    in8.newlineAfter = false;
+    in8.ifType = "zoo.cfg";
+    in8.ifKey = "item_partial_value_not_not_inserted";
+    in8.ifValue = "before";
+    in8.ifValueMatchType = IfValueMatchType.PARTIAL;
+    in8.ifValueNotMatched = true;
+
+    insertions.add(in1);
+    insertions.add(in2);
+    insertions.add(in3);
+    insertions.add(in4);
+    insertions.add(in5);
+    insertions.add(in6);
+    insertions.add(in7);
+    insertions.add(in8);
+
+    commandParams.put(ConfigureTask.PARAMETER_INSERTIONS, new Gson().toJson(insertions));
+
+    ExecutionCommand executionCommand = getExecutionCommand(commandParams);
+    HostRoleCommand hostRoleCommand = hostRoleCommandFactory.create(null, null, null, null);
+    hostRoleCommand.setExecutionCommandWrapper(new ExecutionCommandWrapper(executionCommand));
+    action.setExecutionCommand(executionCommand);
+    action.setHostRoleCommand(hostRoleCommand);
+
+    CommandReport report = action.execute(null);
+    assertNotNull(report);
+
+    config = c.getDesiredConfigByType("zoo.cfg");
+    assertNotNull(config);
+
+    // build the expected values
+    String expectedAppend = lineSample + appendValue;
+
+    assertEquals(expectedAppend, config.getProperties().get("item_inserted"));
+    assertEquals(expectedAppend, config.getProperties().get("item_partial_inserted"));
+    assertEquals(expectedAppend, config.getProperties().get("item_value_not_inserted"));
+    assertEquals(expectedAppend, config.getProperties().get("item_partial_value_not_inserted"));
+
+    assertTrue(lineSample.equalsIgnoreCase(config.getProperties().get("item_not_inserted")));
+    assertTrue(lineSample.equalsIgnoreCase(config.getProperties().get("item_partial_not_inserted")));
+    assertTrue(lineSample.equalsIgnoreCase(config.getProperties().get("item_value_not_not_inserted")));
+    assertTrue(lineSample.equalsIgnoreCase(config.getProperties().get("item_partial_value_not_not_inserted")));
+  }
+
   /**
    * Creates a cluster using {@link #repoVersion2110} with ZooKeeper installed.
    *
@@ -1714,6 +1883,7 @@ public class ConfigureActionTest {
   private void makeUpgradeCluster() throws Exception {
     String clusterName = "c1";
     String hostName = "h1";
+    Long hostId = 1L;
 
     clusters.addCluster(clusterName, repoVersion2110.getStackId());
 
@@ -1728,6 +1898,7 @@ public class ConfigureActionTest {
     host.setHostAttributes(hostAttributes);
 
     clusters.mapHostToCluster(hostName, clusterName);
+    clusters.updateHostMappings(host);
 
     // !!! very important, otherwise the loops that walk the list of installed
     // service properties will not run!
@@ -1743,7 +1914,7 @@ public class ConfigureActionTest {
       }
     };
 
-    Config config = createConfig(c, "zoo.cfg", "version1", properties);
+    Config config = createConfig(c, repoVersion2110, "zoo.cfg", "version1", properties);
 
     c.addDesiredConfig("user", Collections.singleton(config));
 
@@ -1849,15 +2020,15 @@ public class ConfigureActionTest {
     ExecutionCommand executionCommand = new ExecutionCommand();
     executionCommand.setClusterName("c1");
     executionCommand.setCommandParams(commandParams);
-    executionCommand.setRoleParams(new HashMap<String, String>());
+    executionCommand.setRoleParams(new HashMap<>());
     executionCommand.getRoleParams().put(ServerAction.ACTION_USER_NAME, "username");
 
     return executionCommand;
   }
 
-  private Config createConfig(Cluster cluster, String type, String tag,
-      Map<String, String> properties) {
-    return configFactory.createNew(cluster, type, tag, properties,
+  private Config createConfig(Cluster cluster, RepositoryVersionEntity repoVersion, String type,
+      String tag, Map<String, String> properties) {
+    return configFactory.createNew(repoVersion.getStackId(), cluster, type, tag, properties,
         NO_ATTRIBUTES);
   }
-}
\ No newline at end of file
+}
