@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -42,7 +42,6 @@ import java.util.Set;
 import org.apache.ambari.server.AmbariException;
 import org.apache.ambari.server.api.services.stackadvisor.StackAdvisorBlueprintProcessor;
 import org.apache.ambari.server.controller.AmbariManagementController;
-import org.apache.ambari.server.controller.ConfigurationRequest;
 import org.apache.ambari.server.controller.KerberosHelper;
 import org.apache.ambari.server.controller.internal.ConfigurationTopologyException;
 import org.apache.ambari.server.controller.internal.Stack;
@@ -215,13 +214,13 @@ public class ClusterConfigurationRequestTest {
 
     Map<String, Map<String, String>> existingConfig = new HashMap<>();
     Configuration stackDefaultConfig = new Configuration(existingConfig,
-      new HashMap<String, Map<String, Map<String, String>>>());
+      new HashMap<>());
     if (stackPropertyValue != null) {
       stackDefaultConfig.setProperty("testConfigType", "testProperty", stackPropertyValue);
     }
 
     Configuration blueprintConfig = new Configuration(stackDefaultConfig.getFullProperties(),
-      new HashMap<String, Map<String, Map<String, String>>>());
+      new HashMap<>());
     if (blueprintPropertyValue != null) {
       blueprintConfig.setProperty("testConfigType", "testProperty", blueprintPropertyValue);
     }
@@ -239,11 +238,10 @@ public class ClusterConfigurationRequestTest {
     expect(stack.getName()).andReturn(STACK_NAME).anyTimes();
     expect(stack.getVersion()).andReturn(STACK_VERSION).anyTimes();
     expect(stack.getServiceForConfigType("testConfigType")).andReturn("KERBEROS").anyTimes();
-    expect(stack.getAllConfigurationTypes(anyString())).andReturn(Collections.<String>singletonList("testConfigType")
+    expect(stack.getAllConfigurationTypes(anyString())).andReturn(Collections.singletonList("testConfigType")
     ).anyTimes();
-    expect(stack.getExcludedConfigurationTypes(anyString())).andReturn(Collections.<String>emptySet()).anyTimes();
-    expect(stack.getConfigurationPropertiesWithMetadata(anyString(), anyString())).andReturn(Collections.<String,
-      Stack.ConfigProperty>emptyMap()).anyTimes();
+    expect(stack.getExcludedConfigurationTypes(anyString())).andReturn(Collections.emptySet()).anyTimes();
+    expect(stack.getConfigurationPropertiesWithMetadata(anyString(), anyString())).andReturn(Collections.emptyMap()).anyTimes();
 
     Set<String> services = new HashSet<>();
     services.add("HDFS");
@@ -269,15 +267,15 @@ public class ClusterConfigurationRequestTest {
     expect(blueprint.isValidConfigType("testConfigType")).andReturn(true).anyTimes();
 
     expect(topology.getConfiguration()).andReturn(blueprintConfig).anyTimes();
-    expect(topology.getHostGroupInfo()).andReturn(Collections.<String, HostGroupInfo>emptyMap()).anyTimes();
+    expect(topology.getHostGroupInfo()).andReturn(Collections.emptyMap()).anyTimes();
     expect(topology.getClusterId()).andReturn(Long.valueOf(1)).anyTimes();
-    expect(topology.getHostGroupsForComponent(anyString())).andReturn(Collections.<String>emptyList())
+    expect(topology.getHostGroupsForComponent(anyString())).andReturn(Collections.emptyList())
       .anyTimes();
 
     expect(ambariContext.getConfigHelper()).andReturn(configHelper).anyTimes();
     expect(ambariContext.getClusterName(Long.valueOf(1))).andReturn("testCluster").anyTimes();
-    expect(ambariContext.createConfigurationRequests(anyObject(Map.class))).andReturn(Collections
-      .<ConfigurationRequest>emptyList()).anyTimes();
+    expect(ambariContext.createConfigurationRequests(EasyMock.anyObject())).andReturn(Collections
+      .emptyList()).anyTimes();
 
     expect(configHelper.getDefaultStackProperties(
         EasyMock.eq(new StackId(STACK_NAME, STACK_VERSION)))).andReturn(stackProperties).anyTimes();
@@ -288,10 +286,10 @@ public class ClusterConfigurationRequestTest {
       properties.put("testProperty", "KERBEROStestValue");
       kerberosConfig.put("testConfigType", properties);
      }
-    expect(kerberosHelper.ensureHeadlessIdentities(anyObject(Cluster.class), anyObject(Map.class), anyObject
-      (Set.class))).andReturn(true).once();
-    expect(kerberosHelper.getServiceConfigurationUpdates(anyObject(Cluster.class), anyObject(Map.class), anyObject
-      (Map.class), anyObject(Map.class), anyObject(Set.class), anyBoolean(), eq(false))).andReturn(kerberosConfig).once();
+    expect(kerberosHelper.ensureHeadlessIdentities(anyObject(Cluster.class), EasyMock.anyObject(),
+      EasyMock.anyObject())).andReturn(true).once();
+    expect(kerberosHelper.getServiceConfigurationUpdates(anyObject(Cluster.class), EasyMock.anyObject(),
+      EasyMock.anyObject(), EasyMock.anyObject(), EasyMock.anyObject(), anyBoolean(), eq(false))).andReturn(kerberosConfig).once();
 
     Capture<? extends String> captureClusterName = newCapture(CaptureType.ALL);
     Capture<? extends Set<String>> captureUpdatedConfigTypes = newCapture(CaptureType.ALL);
@@ -319,7 +317,7 @@ public class ClusterConfigurationRequestTest {
 
     Map<String, Map<String, String>> existingConfig = new HashMap<>();
     Configuration stackConfig = new Configuration(existingConfig,
-      new HashMap<String, Map<String, Map<String, String>>>());
+      new HashMap<>());
 
     PowerMock.mockStatic(AmbariContext.class);
     AmbariContext.getController();
@@ -331,10 +329,9 @@ public class ClusterConfigurationRequestTest {
     expect(blueprint.getStack()).andReturn(stack).anyTimes();
     expect(stack.getName()).andReturn(STACK_NAME).anyTimes();
     expect(stack.getVersion()).andReturn(STACK_VERSION).anyTimes();
-    expect(stack.getAllConfigurationTypes(anyString())).andReturn(Collections.<String>singletonList("testConfigType")).anyTimes();
-    expect(stack.getExcludedConfigurationTypes(anyString())).andReturn(Collections.<String>emptySet()).anyTimes();
-    expect(stack.getConfigurationPropertiesWithMetadata(anyString(), anyString())).andReturn(Collections.<String,
-      Stack.ConfigProperty>emptyMap()).anyTimes();
+    expect(stack.getAllConfigurationTypes(anyString())).andReturn(Collections.singletonList("testConfigType")).anyTimes();
+    expect(stack.getExcludedConfigurationTypes(anyString())).andReturn(Collections.emptySet()).anyTimes();
+    expect(stack.getConfigurationPropertiesWithMetadata(anyString(), anyString())).andReturn(Collections.emptyMap()).anyTimes();
 
     Set<String> services = new HashSet<>();
     services.add("HDFS");
@@ -357,13 +354,13 @@ public class ClusterConfigurationRequestTest {
     expect(topology.getConfigRecommendationStrategy()).andReturn(ConfigRecommendationStrategy.NEVER_APPLY).anyTimes();
     expect(topology.getBlueprint()).andReturn(blueprint).anyTimes();
     expect(topology.getConfiguration()).andReturn(stackConfig).anyTimes();
-    expect(topology.getHostGroupInfo()).andReturn(Collections.<String, HostGroupInfo>emptyMap()).anyTimes();
+    expect(topology.getHostGroupInfo()).andReturn(Collections.emptyMap()).anyTimes();
     expect(topology.getClusterId()).andReturn(Long.valueOf(1)).anyTimes();
 
     expect(ambariContext.getConfigHelper()).andReturn(configHelper).anyTimes();
     expect(ambariContext.getClusterName(Long.valueOf(1))).andReturn("testCluster").anyTimes();
-    expect(ambariContext.createConfigurationRequests(anyObject(Map.class))).andReturn(Collections
-      .<ConfigurationRequest>emptyList()).anyTimes();
+    expect(ambariContext.createConfigurationRequests(EasyMock.anyObject())).andReturn(Collections
+      .emptyList()).anyTimes();
 
     expect(configHelper.getDefaultStackProperties(
         EasyMock.eq(new StackId(STACK_NAME, STACK_VERSION)))).andReturn(stackProperties).anyTimes();
@@ -427,8 +424,8 @@ public class ClusterConfigurationRequestTest {
   public void testProcessClusterConfigRequestWithOnlyHostGroupConfigRemoveUnusedConfigTypes() throws Exception {
     // Given
     Map<String, Map<String, String>> config = Maps.newHashMap();
-    config.put("cluster-env", new HashMap<String, String>());
-    config.put("global", new HashMap<String, String>());
+    config.put("cluster-env", new HashMap<>());
+    config.put("global", new HashMap<>());
     Map<String, Map<String, Map<String, String>>> attributes = Maps.newHashMap();
 
     Configuration configuration = new Configuration(config, attributes);
@@ -475,18 +472,18 @@ public class ClusterConfigurationRequestTest {
 
   private Configuration createConfigurations() {
     Map<String, Map<String, String>> firstLevelConfig = Maps.newHashMap();
-    firstLevelConfig.put("hdfs-site", new HashMap<String, String>());
-    firstLevelConfig.put("yarn-site", new HashMap<String, String>());
-    firstLevelConfig.put("cluster-env", new HashMap<String, String>());
-    firstLevelConfig.put("global", new HashMap<String, String>());
+    firstLevelConfig.put("hdfs-site", new HashMap<>());
+    firstLevelConfig.put("yarn-site", new HashMap<>());
+    firstLevelConfig.put("cluster-env", new HashMap<>());
+    firstLevelConfig.put("global", new HashMap<>());
 
     Map<String, Map<String, Map<String, String>>> firstLevelAttributes = Maps.newHashMap();
-    firstLevelAttributes.put("hdfs-site", new HashMap<String, Map<String, String>>());
+    firstLevelAttributes.put("hdfs-site", new HashMap<>());
 
     Map<String, Map<String, String>> secondLevelConfig = Maps.newHashMap();
-    secondLevelConfig.put("admin-properties", new HashMap<String, String>());
+    secondLevelConfig.put("admin-properties", new HashMap<>());
     Map<String, Map<String, Map<String, String>>> secondLevelAttributes = Maps.newHashMap();
-    secondLevelAttributes.put("admin-properties", new HashMap<String, Map<String, String>>());
+    secondLevelAttributes.put("admin-properties", new HashMap<>());
 
 
     Configuration secondLevelConf = new Configuration(secondLevelConfig, secondLevelAttributes);
@@ -495,18 +492,18 @@ public class ClusterConfigurationRequestTest {
 
   private Configuration createConfigurationsForHostGroup() {
     Map<String, Map<String, String>> firstLevelConfig = Maps.newHashMap();
-    firstLevelConfig.put("hdfs-site", new HashMap<String, String>());
-    firstLevelConfig.put("spark-env", new HashMap<String, String>());
-    firstLevelConfig.put("cluster-env", new HashMap<String, String>());
-    firstLevelConfig.put("global", new HashMap<String, String>());
+    firstLevelConfig.put("hdfs-site", new HashMap<>());
+    firstLevelConfig.put("spark-env", new HashMap<>());
+    firstLevelConfig.put("cluster-env", new HashMap<>());
+    firstLevelConfig.put("global", new HashMap<>());
 
     Map<String, Map<String, Map<String, String>>> firstLevelAttributes = Maps.newHashMap();
-    firstLevelAttributes.put("hdfs-site", new HashMap<String, Map<String, String>>());
+    firstLevelAttributes.put("hdfs-site", new HashMap<>());
 
     Map<String, Map<String, String>> secondLevelConfig = Maps.newHashMap();
-    secondLevelConfig.put("admin-properties", new HashMap<String, String>());
+    secondLevelConfig.put("admin-properties", new HashMap<>());
     Map<String, Map<String, Map<String, String>>> secondLevelAttributes = Maps.newHashMap();
-    secondLevelAttributes.put("admin-properties", new HashMap<String, Map<String, String>>());
+    secondLevelAttributes.put("admin-properties", new HashMap<>());
 
 
     Configuration secondLevelConf = new Configuration(secondLevelConfig, secondLevelAttributes);
