@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,11 +18,10 @@
 
 package org.apache.ambari.server.view;
 
-import junit.framework.Assert;
-
-import org.apache.ambari.server.view.DefaultMasker;
 import org.junit.Test;
 
+import junit.framework.Assert;
+
 /**
  * DefaultMasker test.
  */
