@@ -24,13 +24,18 @@ from unittest import TestCase
 
 class TestPXF300ServiceAdvisor(TestCase):
 
-  testDirectory = os.path.dirname(os.path.abspath(__file__))
-  stack_advisor_path = os.path.join(testDirectory, '../../../../main/resources/stacks/stack_advisor.py')
+  test_directory = os.path.dirname(os.path.abspath(__file__))
+  resources_path = os.path.join(test_directory, '../../../../main/resources')
+
+  ambari_configuration_path = os.path.abspath(os.path.join(resources_path, 'stacks/ambari_configuration.py'))
+  with open(ambari_configuration_path, 'rb') as fp:
+    imp.load_module('ambari_configuration', fp, ambari_configuration_path, ('.py', 'rb', imp.PY_SOURCE))
+
+  stack_advisor_path = os.path.join(resources_path, 'stacks/stack_advisor.py')
   with open(stack_advisor_path, 'rb') as fp:
     imp.load_module('stack_advisor', fp, stack_advisor_path, ('.py', 'rb', imp.PY_SOURCE))
 
-  serviceAdvisorPath = '../../../../main/resources/common-services/PXF/3.0.0/service_advisor.py'
-  pxf300ServiceAdvisorPath = os.path.join(testDirectory, serviceAdvisorPath)
+  pxf300ServiceAdvisorPath = os.path.join(resources_path, 'common-services/PXF/3.0.0/service_advisor.py')
   with open(pxf300ServiceAdvisorPath, 'rb') as fp:
     service_advisor_impl = imp.load_module('service_advisor_impl', fp, pxf300ServiceAdvisorPath, ('.py', 'rb', imp.PY_SOURCE))
 
@@ -40,7 +45,7 @@ class TestPXF300ServiceAdvisor(TestCase):
     self.PXF_PATH = "export HBASE_CLASSPATH=${HBASE_CLASSPATH}:/usr/lib/pxf/pxf-hbase.jar"
 
   def load_json(self, filename):
-    file = os.path.join(self.testDirectory, "../configs", filename)
+    file = os.path.join(self.test_directory, "../configs", filename)
     with open(file, 'rb') as f:
       data = json.load(f)
     return data
