@@ -29,40 +29,40 @@ from resource_management.libraries.providers.hdfs_resource import WebHDFSUtil
 import tempfile
 
 REPOSITORY_FILE_DICT = {
-        "resolved": True, 
-        "repoVersion": "2.6.4.0-52", 
+        "resolved": True,
+        "repoVersion": "2.6.4.0-52",
         "repositories": [
             {
-                "tags": [], 
-                "ambariManaged": True, 
-                "baseUrl": "http://s3.amazonaws.com/dev.hortonworks.com/HDP/centos6/2.x/BUILDS/2.6.4.0-52", 
-                "repoName": "HDP", 
-                "repoId": "HDP-2.6-repo-1", 
+                "tags": [],
+                "ambariManaged": True,
+                "baseUrl": "http://s3.amazonaws.com/dev.hortonworks.com/HDP/centos6/2.x/BUILDS/2.6.4.0-52",
+                "repoName": "HDP",
+                "repoId": "HDP-2.6-repo-1",
                 "applicableServices": []
-            }, 
+            },
             {
-                "repoName": "HDP-GPL", 
+                "repoName": "HDP-GPL",
                 "tags": [
                     "GPL"
-                ], 
-                "ambariManaged": True, 
-                "baseUrl": "http://s3.amazonaws.com/dev.hortonworks.com/HDP-GPL/centos6/2.x/BUILDS/2.6.4.0-52", 
+                ],
+                "ambariManaged": True,
+                "baseUrl": "http://s3.amazonaws.com/dev.hortonworks.com/HDP-GPL/centos6/2.x/BUILDS/2.6.4.0-52",
                 "repoId": "HDP-2.6-GPL-repo-1"
-            }, 
+            },
             {
-                "repoName": "HDP-UTILS", 
-                "tags": [], 
-                "ambariManaged": True, 
-                "baseUrl": "http://s3.amazonaws.com/dev.hortonworks.com/HDP-UTILS-1.1.0.22/repos/centos6", 
+                "repoName": "HDP-UTILS",
+                "tags": [],
+                "ambariManaged": True,
+                "baseUrl": "http://s3.amazonaws.com/dev.hortonworks.com/HDP-UTILS-1.1.0.22/repos/centos6",
                 "repoId": "HDP-UTILS-1.1.0.22-repo-1"
             }
-        ], 
+        ],
         "feature": {
-            "preInstalled": False, 
+            "preInstalled": False,
             "scoped": True
-        }, 
-        "stackName": "HDP", 
-        "repoVersionId": 1, 
+        },
+        "stackName": "HDP",
+        "repoVersionId": 1,
         "repoFileName": "ambari-hdp-1"
     }
 
@@ -829,7 +829,7 @@ class TestOozieServer(RMFTestCase):
                               mode = 0664,
                               conf_dir = '/etc/oozie/conf',
                               configurations = self.getConfig()['configurations']['oozie-site'],
-                              configuration_attributes = self.getConfig()['configuration_attributes']['oozie-site']
+                              configuration_attributes = self.getConfig()['configurationAttributes']['oozie-site']
                               )
     self.assertResourceCalled('File', '/etc/oozie/conf/oozie-env.sh',
                               owner = 'oozie',
@@ -1028,7 +1028,7 @@ class TestOozieServer(RMFTestCase):
                               mode = 0664,
                               conf_dir = '/etc/oozie/conf',
                               configurations = expected_oozie_site,
-                              configuration_attributes = self.getConfig()['configuration_attributes']['oozie-site']
+                              configuration_attributes = self.getConfig()['configurationAttributes']['oozie-site']
                               )
     self.assertResourceCalled('File', '/etc/oozie/conf/oozie-env.sh',
                               owner = 'oozie',
@@ -1200,7 +1200,7 @@ class TestOozieServer(RMFTestCase):
     with open(config_file, "r") as f:
       default_json = json.load(f)
 
-    default_json['hostLevelParams']['stack_version']= '2.2'
+    default_json['clusterLevelParams']['stack_version']= '2.2'
     self.executeScript(self.COMMON_SERVICES_PACKAGE_DIR + "/scripts/oozie_server.py",
                      classname = "OozieServer",
                      command = "configure",
@@ -1257,34 +1257,34 @@ class TestOozieServer(RMFTestCase):
       sudo = True )
 
     self.assertResourceCalled('Directory', '/usr/hdp/current/oozie-server/libext', mode = 0777)
-    
+
     self.assertResourceCalled('Repository', 'HDP-2.6-repo-1',
-        append_to_file = False,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP/centos6/2.x/BUILDS/2.6.4.0-52',
-        action = ['create'],
+        action = ['prepare'],
         components = [u'HDP', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
     self.assertResourceCalled('Repository', 'HDP-2.6-GPL-repo-1',
-        append_to_file = True,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP-GPL/centos6/2.x/BUILDS/2.6.4.0-52',
-        action = ['create'],
+        action = ['prepare'],
         components = [u'HDP-GPL', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
     self.assertResourceCalled('Repository', 'HDP-UTILS-1.1.0.22-repo-1',
-        append_to_file = True,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP-UTILS-1.1.0.22/repos/centos6',
-        action = ['create'],
+        action = ['prepare'],
         components = [u'HDP-UTILS', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
+    self.assertResourceCalled('Repository', None,
+        action = ['create'],
+    )
     self.assertResourceCalled('Package', ('lzo'), retry_count=5, retry_on_repo_unavailability= False)
     self.assertResourceCalled('Package', ('hadooplzo_1_2_3_4'), retry_count = 5, retry_on_repo_unavailability = False)
     self.assertResourceCalled('Package', ('hadooplzo_1_2_3_4-native'), retry_count = 5, retry_on_repo_unavailability = False)
@@ -1325,7 +1325,7 @@ class TestOozieServer(RMFTestCase):
 
     version = '2.3.0.0-1234'
     json_content['commandParams']['version'] = version
-    json_content['hostLevelParams']['stack_version'] = "2.3"
+    json_content['clusterLevelParams']['stack_version'] = "2.3"
     json_content['repositoryFile'] = REPOSITORY_FILE_DICT
 
     mocks_dict = {}
@@ -1351,32 +1351,32 @@ class TestOozieServer(RMFTestCase):
     self.assertResourceCalled('Directory', '/usr/hdp/current/oozie-server/libext', mode = 0777)
 
     self.assertResourceCalled('Repository', 'HDP-2.6-repo-1',
-        append_to_file = False,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP/centos6/2.x/BUILDS/2.6.4.0-52',
-        action = ['create'],
+        action = ['prepare'],
         components = ['HDP', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
     self.assertResourceCalled('Repository', 'HDP-2.6-GPL-repo-1',
-        append_to_file = True,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP-GPL/centos6/2.x/BUILDS/2.6.4.0-52',
-        action = ['create'],
+        action = ['prepare'],
         components = ['HDP-GPL', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
     self.assertResourceCalled('Repository', 'HDP-UTILS-1.1.0.22-repo-1',
-        append_to_file = True,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP-UTILS-1.1.0.22/repos/centos6',
-        action = ['create'],
+        action = ['prepare'],
         components = ['HDP-UTILS', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
+    self.assertResourceCalled('Repository', None,
+        action = ['create'],
+    )    
     self.assertResourceCalled('Package', ('lzo'), retry_count=5, retry_on_repo_unavailability= False)
     self.assertResourceCalled('Package', ('hadooplzo_1_2_3_4'), retry_count = 5, retry_on_repo_unavailability = False)
     self.assertResourceCalled('Package', ('hadooplzo_1_2_3_4-native'), retry_count = 5, retry_on_repo_unavailability = False)
@@ -1418,7 +1418,7 @@ class TestOozieServer(RMFTestCase):
 
     version = '2.3.0.0-1234'
     json_content['commandParams']['version'] = version
-    json_content['hostLevelParams']['stack_version'] = "2.3"
+    json_content['clusterLevelParams']['stack_version'] = "2.3"
     json_content['upgradeSummary'] = {
       'services': { 'OOZIE': { 'sourceStackId': 'HDP-2.3' }},
       'direction': 'UPGRADE',
@@ -1451,32 +1451,32 @@ class TestOozieServer(RMFTestCase):
     self.assertResourceCalled('Directory', '/usr/hdp/current/oozie-server/libext', mode = 0777)
 
     self.assertResourceCalled('Repository', 'HDP-2.6-repo-1',
-        append_to_file = False,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP/centos6/2.x/BUILDS/2.6.4.0-52',
-        action = ['create'],
+        action = ['prepare'],
         components = ['HDP', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
     self.assertResourceCalled('Repository', 'HDP-2.6-GPL-repo-1',
-        append_to_file = True,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP-GPL/centos6/2.x/BUILDS/2.6.4.0-52',
-        action = ['create'],
+        action = ['prepare'],
         components = ['HDP-GPL', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
     self.assertResourceCalled('Repository', 'HDP-UTILS-1.1.0.22-repo-1',
-        append_to_file = True,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP-UTILS-1.1.0.22/repos/centos6',
-        action = ['create'],
+        action = ['prepare'],
         components = ['HDP-UTILS', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
+    self.assertResourceCalled('Repository', None,
+        action = ['create'],
+    )
     self.assertResourceCalled('Package', ('lzo'), retry_count=5, retry_on_repo_unavailability= False)
     self.assertResourceCalled('Package', ('hadooplzo_1_2_3_4'), retry_count = 5, retry_on_repo_unavailability = False)
     self.assertResourceCalled('Package', ('hadooplzo_1_2_3_4-native'), retry_count = 5, retry_on_repo_unavailability = False)
@@ -1539,7 +1539,7 @@ class TestOozieServer(RMFTestCase):
     version = '2.3.0.0-1234'
     json_content['commandParams']['version'] = version
     json_content['hostLevelParams']['stack_name'] = "HDP"
-    json_content['hostLevelParams']['stack_version'] = "2.3"
+    json_content['clusterLevelParams']['stack_version'] = "2.3"
 
     self.executeScript(self.COMMON_SERVICES_PACKAGE_DIR + "/scripts/oozie_server_upgrade.py",
       classname = "OozieUpgrade", command = "upgrade_oozie_database_and_sharelib",
@@ -1601,8 +1601,8 @@ class TestOozieServer(RMFTestCase):
 
     version = '2.3.0.0-1234'
     json_content['commandParams']['version'] = version
-    json_content['hostLevelParams']['stack_name'] = "HDP"
-    json_content['hostLevelParams']['stack_version'] = "2.3"
+    json_content['clusterLevelParams']['stack_name'] = "HDP"
+    json_content['clusterLevelParams']['stack_version'] = "2.3"
 
     # use mysql external database
     json_content['configurations']['oozie-site']['oozie.service.JPAService.jdbc.driver'] = "com.mysql.jdbc.Driver"
@@ -1696,7 +1696,7 @@ class TestOozieServer(RMFTestCase):
     json_content['commandParams']['version'] = version
     json_content['clusterHostInfo']['falcon_server_hosts'] = ['c6401.ambari.apache.org']
     json_content['repositoryFile'] = REPOSITORY_FILE_DICT
-    
+
     mocks_dict = {}
     self.executeScript(self.COMMON_SERVICES_PACKAGE_DIR + "/scripts/oozie_server.py",
      classname = "OozieServer", command = "pre_upgrade_restart", config_dict = json_content,
@@ -1719,32 +1719,32 @@ class TestOozieServer(RMFTestCase):
     self.assertResourceCalled('Directory', '/usr/hdp/current/oozie-server/libext', mode = 0777)
 
     self.assertResourceCalled('Repository', 'HDP-2.6-repo-1',
-        append_to_file = False,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP/centos6/2.x/BUILDS/2.6.4.0-52',
-        action = ['create'],
+        action = ['prepare'],
         components = ['HDP', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
     self.assertResourceCalled('Repository', 'HDP-2.6-GPL-repo-1',
-        append_to_file = True,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP-GPL/centos6/2.x/BUILDS/2.6.4.0-52',
-        action = ['create'],
+        action = ['prepare'],
         components = ['HDP-GPL', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
     self.assertResourceCalled('Repository', 'HDP-UTILS-1.1.0.22-repo-1',
-        append_to_file = True,
         base_url = 'http://s3.amazonaws.com/dev.hortonworks.com/HDP-UTILS-1.1.0.22/repos/centos6',
-        action = ['create'],
+        action = ['prepare'],
         components = ['HDP-UTILS', 'main'],
         repo_template = UnknownConfigurationMock(),
         repo_file_name = 'ambari-hdp-1',
         mirror_list = None,
     )
+    self.assertResourceCalled('Repository', None,
+        action = ['create'],
+    )
     self.assertResourceCalled('Package', ('lzo'), retry_count=5, retry_on_repo_unavailability= False)
     self.assertResourceCalled('Package', ('hadooplzo_1_2_3_4'), retry_count = 5, retry_on_repo_unavailability = False)
     self.assertResourceCalled('Package', ('hadooplzo_1_2_3_4-native'), retry_count = 5, retry_on_repo_unavailability = False)
