@@ -99,53 +99,6 @@ class TestAts(RMFTestCase):
                               create_parents = True,
                               cd_access = 'a',
                               )
-    self.assertResourceCalled('XmlConfig', 'core-site.xml',
-                              group = 'hadoop',
-                              conf_dir = '/etc/hadoop/conf',
-                              mode = 0644,
-                              configuration_attributes = {u'final': {u'hadoop.proxyuser.hive.groups': u'true',
-                                                                     u'hadoop.proxyuser.oozie.hosts': u'true',
-                                                                     u'webinterface.private.actions': u'true'}},
-                              owner = 'hdfs',
-                              configurations = self.getConfig()['configurations']['core-site'],
-                              )
-    self.assertResourceCalled('XmlConfig', 'hdfs-site.xml',
-                              group = 'hadoop',
-                              conf_dir = '/etc/hadoop/conf',
-                              mode = 0644,
-                              configuration_attributes = {u'final': {u'dfs.cluster.administrators': u'true',
-                                                                     u'dfs.support.append': u'true',
-                                                                     u'dfs.web.ugi': u'true'}},
-                              owner = 'hdfs',
-                              configurations = self.getConfig()['configurations']['hdfs-site'],
-                              )
-    self.assertResourceCalled('XmlConfig', 'mapred-site.xml',
-                              group = 'hadoop',
-                              conf_dir = '/etc/hadoop/conf',
-                              mode = 0644,
-                              configuration_attributes = {u'final': {u'mapred.healthChecker.script.path': u'true',
-                                                                     u'mapreduce.jobtracker.staging.root.dir': u'true'}},
-                              owner = 'yarn',
-                              configurations = self.getConfig()['configurations']['mapred-site'],
-                              )
-    self.assertResourceCalled('XmlConfig', 'yarn-site.xml',
-                              group = 'hadoop',
-                              conf_dir = '/etc/hadoop/conf',
-                              mode = 0644,
-                              configuration_attributes = {u'final': {u'yarn.nodemanager.container-executor.class': u'true',
-                                                                     u'yarn.nodemanager.disk-health-checker.min-healthy-disks': u'true',
-                                                                     u'yarn.nodemanager.local-dirs': u'true'}},
-                              owner = 'yarn',
-                              configurations = self.getConfig()['configurations']['yarn-site'],
-                              )
-    self.assertResourceCalled('XmlConfig', 'capacity-scheduler.xml',
-                              group = 'hadoop',
-                              conf_dir = '/etc/hadoop/conf',
-                              mode = 0644,
-                              configuration_attributes = {u'final': {u'yarn.scheduler.capacity.node-locality-delay': u'true'}},
-                              owner = 'yarn',
-                              configurations = self.getConfig()['configurations']['capacity-scheduler'],
-                              )
     self.assertResourceCalled('Directory', '/var/log/hadoop-yarn/timeline',
                               owner = 'yarn',
                               group = 'hadoop',
@@ -240,6 +193,53 @@ class TestAts(RMFTestCase):
                               action = ['execute'], hdfs_resource_ignore_file='/var/lib/ambari-agent/data/.hdfs_resource_ignore',
                               hadoop_conf_dir = '/etc/hadoop/conf',
                               )
+    self.assertResourceCalled('XmlConfig', 'core-site.xml',
+                              group = 'hadoop',
+                              conf_dir = '/etc/hadoop/conf',
+                              mode = 0644,
+                              configuration_attributes = {u'final': {u'hadoop.proxyuser.hive.groups': u'true',
+                                                                     u'hadoop.proxyuser.oozie.hosts': u'true',
+                                                                     u'webinterface.private.actions': u'true'}},
+                              owner = 'hdfs',
+                              configurations = self.getConfig()['configurations']['core-site'],
+                              )
+    self.assertResourceCalled('XmlConfig', 'hdfs-site.xml',
+                              group = 'hadoop',
+                              conf_dir = '/etc/hadoop/conf',
+                              mode = 0644,
+                              configuration_attributes = {u'final': {u'dfs.cluster.administrators': u'true',
+                                                                     u'dfs.support.append': u'true',
+                                                                     u'dfs.web.ugi': u'true'}},
+                              owner = 'hdfs',
+                              configurations = self.getConfig()['configurations']['hdfs-site'],
+                              )
+    self.assertResourceCalled('XmlConfig', 'mapred-site.xml',
+                              group = 'hadoop',
+                              conf_dir = '/etc/hadoop/conf',
+                              mode = 0644,
+                              configuration_attributes = {u'final': {u'mapred.healthChecker.script.path': u'true',
+                                                                     u'mapreduce.jobtracker.staging.root.dir': u'true'}},
+                              owner = 'yarn',
+                              configurations = self.getConfig()['configurations']['mapred-site'],
+                              )
+    self.assertResourceCalled('XmlConfig', 'yarn-site.xml',
+                              group = 'hadoop',
+                              conf_dir = '/etc/hadoop/conf',
+                              mode = 0644,
+                              configuration_attributes = {u'final': {u'yarn.nodemanager.container-executor.class': u'true',
+                                                                     u'yarn.nodemanager.disk-health-checker.min-healthy-disks': u'true',
+                                                                     u'yarn.nodemanager.local-dirs': u'true'}},
+                              owner = 'yarn',
+                              configurations = self.getConfig()['configurations']['yarn-site'],
+                              )
+    self.assertResourceCalled('XmlConfig', 'capacity-scheduler.xml',
+                              group = 'hadoop',
+                              conf_dir = '/etc/hadoop/conf',
+                              mode = 0644,
+                              configuration_attributes = {u'final': {u'yarn.scheduler.capacity.node-locality-delay': u'true'}},
+                              owner = 'yarn',
+                              configurations = self.getConfig()['configurations']['capacity-scheduler'],
+                              )
     self.assertResourceCalled('File', '/etc/security/limits.d/yarn.conf',
                               content = Template('yarn.conf.j2'),
                               mode = 0644,
@@ -259,7 +259,7 @@ class TestAts(RMFTestCase):
                               mode = 02050,
                               )
     self.assertResourceCalled('File', '/etc/hadoop/conf/container-executor.cfg',
-                              content = Template('container-executor.cfg.j2'),
+                              content = InlineTemplate(self.getConfig()['configurations']['container-executor']['content']),
                               group = 'hadoop',
                               mode = 0644,
                               )
