@@ -44,6 +44,7 @@ PATH_TO_STACKS = "main/resources/stacks/HDP"
 PATH_TO_STACK_TESTS = "test/python/stacks/"
 
 PATH_TO_COMMON_SERVICES = "main/resources/common-services"
+PATH_TO_STACK_HOOKS = "main/resources/stack-hooks"
 
 PATH_TO_CUSTOM_ACTIONS = "main/resources/custom_actions"
 PATH_TO_CUSTOM_ACTION_TESTS = "test/python/custom_actions"
@@ -63,6 +64,9 @@ class RMFTestCase(TestCase):
   # build all paths to test common services scripts
   TARGET_COMMON_SERVICES = 'TARGET_COMMON_SERVICES'
 
+  # build all paths to test common services scripts
+  TARGET_STACK_HOOKS = 'TARGET_STACK_HOOKS'
+
   def executeScript(self, path, classname=None, command=None, config_file=None,
                     config_dict=None,
                     # common mocks for all the scripts
@@ -148,17 +152,18 @@ class RMFTestCase(TestCase):
         with patch('resource_management.core.shell.call', side_effect=call_mocks) as mocks_dict['call']:
           with patch.object(Script, 'get_config', return_value=self.config_dict) as mocks_dict['get_config']:
             with patch.object(Script, 'get_tmp_dir', return_value="/tmp") as mocks_dict['get_tmp_dir']:
-              with patch('resource_management.libraries.functions.get_kinit_path', return_value=kinit_path_local) as mocks_dict['get_kinit_path']:
-                with patch.object(platform, 'linux_distribution', return_value=os_type) as mocks_dict['linux_distribution']:
-                  with patch('resource_management.libraries.functions.stack_select.is_package_supported', return_value=True):
-                    with patch('resource_management.libraries.functions.stack_select.get_supported_packages', return_value=MagicMock()):
-                      with patch.object(os, "environ", new=os_env) as mocks_dict['environ']:
-                        with patch('resource_management.libraries.functions.stack_select.unsafe_get_stack_versions', return_value = (("",0,[]))):
-                          if not try_install:
-                            with patch.object(Script, 'install_packages') as install_mock_value:
+              with patch.object(Script, 'post_start') as mocks_dict['post_start']:
+                with patch('resource_management.libraries.functions.get_kinit_path', return_value=kinit_path_local) as mocks_dict['get_kinit_path']:
+                  with patch.object(platform, 'linux_distribution', return_value=os_type) as mocks_dict['linux_distribution']:
+                    with patch('resource_management.libraries.functions.stack_select.is_package_supported', return_value=True):
+                      with patch('resource_management.libraries.functions.stack_select.get_supported_packages', return_value=MagicMock()):
+                        with patch.object(os, "environ", new=os_env) as mocks_dict['environ']:
+                          with patch('resource_management.libraries.functions.stack_select.unsafe_get_stack_versions', return_value = (("",0,[]))):
+                            if not try_install:
+                              with patch.object(Script, 'install_packages') as install_mock_value:
+                                method(RMFTestCase.env, *command_args)
+                            else:
                               method(RMFTestCase.env, *command_args)
-                          else:
-                            method(RMFTestCase.env, *command_args)
 
     sys.path.remove(scriptsdir)
 
@@ -199,6 +204,10 @@ class RMFTestCase(TestCase):
       base_path = os.path.join(src_dir, PATH_TO_COMMON_SERVICES)
       configs_path = os.path.join(src_dir, PATH_TO_STACK_TESTS, stack_version, "configs")
       return base_path, configs_path
+    elif target == self.TARGET_STACK_HOOKS:
+      base_path = os.path.join(src_dir, PATH_TO_STACK_HOOKS)
+      configs_path = os.path.join(src_dir, PATH_TO_STACK_TESTS, stack_version, "configs")
+      return base_path, configs_path
     else:
       raise RuntimeError("Wrong target value %s", target)
 
@@ -435,5 +444,15 @@ class CallFunctionMock():
       result = other(*self.args, **self.kwargs)
       return self.call_result == result
     return False
-      
+
+def experimental_mock(*args, **kwargs):
+  """
+  Used to disable experimental mocks...
+  :return: 
+  """
+  def decorator(function):
+    def wrapper(*args, **kwargs):
+      return function(*args, **kwargs)
+    return wrapper
+  return decorator
 
