@@ -38,10 +38,7 @@ var files = [
   'test/init_computed_aliases',
   'test/init_model_test',
   'test/app_test',
-  'test/data/HDP2/site_properties_test',
-  'test/data/HDP2/secure_mapping_test',
-  'test/data/HDP2.2/site_properties_test',
-  'test/data/HDP2.3/site_properties_test',
+  'test/data/configs/site_properties_test',
   'test/controllers/global/background_operations_test',
   'test/controllers/global/cluster_controller_test',
   'test/controllers/global/update_controller_test',
@@ -68,21 +65,51 @@ var files = [
   'test/controllers/main/admin/kerberos/step6_controller_test',
   'test/controllers/main/admin/kerberos/step7_controller_test',
   'test/controllers/main/admin/kerberos/step8_controller_test',
-
+  'test/controllers/main/admin/service_auto_start_test',
   'test/controllers/main/admin/stack_and_upgrade_controller_test',
   'test/controllers/main/admin/stack_upgrade_history_controller_test',
   'test/controllers/main/admin/serviceAccounts_controller_test',
   'test/controllers/main/admin/highAvailability_controller_test',
   'test/controllers/main/admin/highAvailability/progress_controller_test',
   'test/controllers/main/admin/highAvailability/progress_popup_controller_test',
+  'test/controllers/main/admin/highAvailability/nameNode/rollback_controller_test',
+  'test/controllers/main/admin/highAvailability/nameNode/step1_controller_test',
   'test/controllers/main/admin/highAvailability/nameNode/step2_controller_test',
   'test/controllers/main/admin/highAvailability/nameNode/step3_controller_test',
   'test/controllers/main/admin/highAvailability/nameNode/step4_controller_test',
+  'test/controllers/main/admin/highAvailability/nameNode/step5_controller_test',
+  'test/controllers/main/admin/highAvailability/nameNode/step6_controller_test',
+  'test/controllers/main/admin/highAvailability/nameNode/step7_controller_test',
+  'test/controllers/main/admin/highAvailability/nameNode/step8_controller_test',
+  'test/controllers/main/admin/highAvailability/nameNode/step9_controller_test',
+  'test/controllers/main/admin/highAvailability/nameNode/wizard_controller_test',
+  'test/controllers/main/admin/highAvailability/nameNode/rollbackHA/step2_controller_test',
+  'test/controllers/main/admin/highAvailability/nameNode/rollbackHA/rollback_wizard_controller_test',
   'test/controllers/main/admin/highAvailability/resourceManager/step3_controller_test',
+  'test/controllers/main/admin/highAvailability/resourceManager/step4_controller_test',
+  'test/controllers/main/admin/highAvailability/resourceManager/wizard_controller_test',
   'test/controllers/main/admin/highAvailability/hawq/addStandby/step3_controller_test',
+  'test/controllers/main/admin/highAvailability/hawq/addStandby/step4_controller_test',
+  'test/controllers/main/admin/highAvailability/hawq/addStandby/wizard_controller_test',
   'test/controllers/main/admin/highAvailability/hawq/removeStandby/step2_controller_test',
+  'test/controllers/main/admin/highAvailability/hawq/removeStandby/step3_controller_test',
+  'test/controllers/main/admin/highAvailability/hawq/removeStandby/wizard_controller_test',
   'test/controllers/main/admin/highAvailability/hawq/activateStandby/step2_controller_test',
+  'test/controllers/main/admin/highAvailability/hawq/activateStandby/step3_controller_test',
+  'test/controllers/main/admin/highAvailability/hawq/activateStandby/wizard_controller_test',
+  'test/controllers/main/admin/highAvailability/journalNode/progress_controller_test',
+  'test/controllers/main/admin/highAvailability/journalNode/step1_controller_test',
+  'test/controllers/main/admin/highAvailability/journalNode/step2_controller_test',
+  'test/controllers/main/admin/highAvailability/journalNode/step3_controller_test',
+  'test/controllers/main/admin/highAvailability/journalNode/step4_controller_test',
+  'test/controllers/main/admin/highAvailability/journalNode/step5_controller_test',
+  'test/controllers/main/admin/highAvailability/journalNode/step6_controller_test',
+  'test/controllers/main/admin/highAvailability/journalNode/step7_controller_test',
+  'test/controllers/main/admin/highAvailability/journalNode/wizard_controller_test',
+  'test/controllers/main/admin/highAvailability/rangerAdmin/step1_controller_test',
   'test/controllers/main/admin/highAvailability/rangerAdmin/step3_controller_test',
+  'test/controllers/main/admin/highAvailability/rangerAdmin/step4_controller_test',
+  'test/controllers/main/admin/highAvailability/rangerAdmin/wizard_controller_test',
   'test/controllers/main/dashboard/config_history_controller_test',
   'test/controllers/main/charts/heatmap_test',
   'test/controllers/main/charts/heatmap_metrics/heatmap_metric_test',
@@ -111,6 +138,7 @@ var files = [
   'test/controllers/main/service/item_test',
   'test/controllers/main/service/info/config_test',
   'test/controllers/main/service/info/summary_test',
+  'test/controllers/main/service/info/metric_test',
   'test/controllers/main/service_test',
   'test/controllers/main/admin_test',
   'test/controllers/main/views_controller_test',
@@ -143,32 +171,50 @@ var files = [
   'test/mappers/hosts_mapper_test',
   'test/mappers/service_mapper_test',
   'test/mappers/service_metrics_mapper_test',
-  'test/mappers/status_mapper_test',
+  'test/mappers/components_state_mapper_test',
   'test/mappers/users_mapper_test',
   'test/mappers/stack_mapper_test',
   'test/mappers/stack_service_mapper_test',
-  'test/mappers/stack_upgrade_history_mapper_test',
   'test/mappers/repository_version_mapper_test',
+  'test/mappers/stack_upgrade_history_mapper_test',
   'test/mappers/configs/config_groups_mapper_test',
   'test/mappers/configs/service_config_version_mapper_test',
   'test/mappers/configs/themes_mapper_test',
+  'test/mappers/socket/topology_mapper_test',
+  'test/mappers/socket/alert_summary_mapper_test',
+  'test/mappers/socket/host_component_status_mapper_test',
+  'test/mappers/socket/service_state_mapper_test',
+  'test/mappers/socket/host_state_mapper_test',
+  'test/mappers/socket/alert_definitions_mapper_adapter_test',
+  'test/mappers/socket/alert_groups_mapper_adapter_test',
+  'test/mappers/socket/upgrade_state_mapper_test',
   'test/mixins/common/configs/enhanced_configs_test',
   'test/mixins/common/configs/config_recommendations_test',
   'test/mixins/common/configs/config_recommendation_parser_test',
+  'test/mixins/common/configs/config_with_override_recommendation_parser_test',
+  'test/mixins/common/configs/configs_comparator_test',
+  'test/mixins/common/configs/configs_loader_test',
   'test/mixins/common/configs/configs_saver_test',
   'test/mixins/common/configs/toggle_isrequired_test',
+  'test/mixins/common/hosts/host_component_recommendation_mixin_test',
+  'test/mixins/common/hosts/host_component_validation_mixin_test',
   'test/mixins/common/widgets/export_metrics_mixin_test',
   'test/mixins/common/widgets/time_range_mixin_test',
   'test/mixins/common/widgets/widget_section_test',
+  'test/mixins/common/loading_overlay_support_test',
   'test/mixins/common/kdc_credentials_controller_mixin_test',
   'test/mixins/common/localStorage_test',
   'test/mixins/common/reload_popup_test',
   'test/mixins/common/serverValidator_test',
   'test/mixins/common/table_server_view_mixin_test',
   'test/mixins/common/widget_mixin_test',
+  'test/mixins/common/persist_test',
   'test/mixins/main/host/details/host_components/decommissionable_test',
   'test/mixins/main/host/details/host_components/install_component_test',
+  'test/mixins/main/service/groups_mapping_test',
+  'test/mixins/main/service/themes_mapping_test',
   'test/mixins/main/service/configs/widget_popover_support_test',
+  'test/mixins/main/service/configs/hive_interactive_check_test',
   'test/mixins/main/service/configs/config_overridable_test',
   'test/mixins/main/service/configs/component_actions_by_configs_test',
   'test/mixins/routers/redirections_test',
@@ -197,7 +243,6 @@ var files = [
   'test/utils/form_field_test',
   'test/utils/file_utils_test',
   'test/utils/handlebars_helpers_test',
-  'test/utils/heatmap_test',
   'test/utils/host_progress_popup_test',
   'test/utils/hosts_test',
   'test/utils/http_client_test',
@@ -205,6 +250,7 @@ var files = [
   'test/utils/number_utils_test',
   'test/utils/polling_test',
   'test/utils/validator_test',
+  'test/utils/stomp_client_test',
   'test/utils/config_test',
   'test/utils/string_utils_test',
   'test/utils/helper_test',
@@ -213,9 +259,12 @@ var files = [
   'test/utils/updater_test',
   'test/utils/configs/database_test',
   'test/utils/configs/config_initializer_test',
+  'test/utils/configs/add_component_config_initializer_test',
   'test/utils/configs/modification_handlers/modification_handler_test',
   'test/utils/configs/modification_handlers/misc_test',
   'test/utils/load_timer_test',
+  'test/utils/configs/theme/theme_test',
+  'test/views/common/breadcrumbs_view_test',
   'test/views/common/chart/linear_time_test',
   'test/views/common/configs/widgets/combo_config_widget_view_test',
   'test/views/common/configs/widgets/config_widget_view_test',
@@ -226,6 +275,7 @@ var files = [
   'test/views/common/ajax_default_error_popup_body_test',
   'test/views/common/filter_combo_cleanable_test',
   'test/views/common/filter_view_test',
+  'test/views/common/pagination_view_test',
   'test/views/common/table_view_test',
   'test/views/common/quick_link_view_test',
   'test/views/common/rolling_restart_view_test',
@@ -236,21 +286,28 @@ var files = [
   'test/views/common/widget/graph_widget_view_test',
   'test/views/common/widget/number_widget_view_test',
   'test/views/common/widget/gauge_widget_view_test',
+  'test/views/common/widget/template_widget_view_test',
+  'test/views/common/widget/heatmap_widget_view_test',
   'test/views/common/modal_popups/cluster_check_popup_test',
+  'test/views/common/modal_popups/edit_dashboard_widget_popup_test',
   'test/views/common/modal_popups/hosts_table_list_popup_test',
   'test/views/common/modal_popups/dependent_configs_list_popup_test',
   'test/views/main/admin_test',
   'test/views/main/dashboard_test',
   'test/views/main/menu_test',
   'test/views/main/host_test',
+  'test/views/main/views_view_test',
   'test/views/main/alert_definitions_view_test',
   'test/views/main/alerts/manage_alert_groups_view_test',
   'test/views/main/alerts/manage_alert_notifications_view_test',
   'test/views/main/alerts/definition_details_view_test',
   'test/views/main/alerts/definition_configs_view_test',
+  'test/views/main/alerts/alert_search_box_test',
   'test/views/main/alerts/add_alert_definition/step1_view_test',
   'test/views/main/alerts/add_alert_definition/step3_view_test',
   'test/views/main/alerts/manage_alert_groups/select_definitions_popup_body_view_test',
+  'test/views/main/alerts/alert_definition/alert_definition_state_test',
+  'test/views/main/alerts/alert_definition/alert_definition_summary_test',
   'test/views/main/admin/stack_upgrade/upgrade_version_box_view_test',
   'test/views/main/admin/stack_upgrade/upgrade_version_column_view_test',
   'test/views/main/admin/stack_upgrade/upgrade_group_view_test',
@@ -262,9 +319,21 @@ var files = [
   'test/views/main/admin/stack_upgrade/services_view_test',
   'test/views/main/admin/stack_upgrade/menu_view_test',
   'test/views/main/admin/stack_upgrade/failed_hosts_modal_view_test',
+  'test/views/main/admin/service_auto_start_test',
+  'test/controllers/main/admin/federation/step1_controller_test',
+  'test/controllers/main/admin/federation/step3_controller_test',
+  'test/controllers/main/admin/federation/step4_controller_test',
+  'test/controllers/main/admin/federation/wizard_controller_test',
+  'test/views/main/dashboard/cluster_metrics/cpu_test',
   'test/views/main/dashboard/config_history_view_test',
+  'test/views/main/dashboard/config_history_search_box_test',
   'test/views/main/dashboard/widget_test',
   'test/views/main/dashboard/widgets_test',
+  'test/views/main/dashboard/widgets/flume_agent_live_test',
+  'test/views/main/dashboard/widgets/hbase_master_heap_test',
+  'test/views/main/dashboard/widgets/hbase_links_test',
+  'test/views/main/dashboard/widgets/hdfs_capacity_test',
+  'test/views/main/dashboard/widgets/hdfs_links_test',
   'test/views/main/dashboard/widgets/text_widget_test',
   'test/views/main/dashboard/widgets/text_widget_single_threshold_test',
   'test/views/main/dashboard/widgets/uptime_text_widget_test',
@@ -275,13 +344,15 @@ var files = [
   'test/views/main/dashboard/widgets/hbase_average_load_test',
   'test/views/main/dashboard/widgets/hbase_regions_in_transition_test',
   'test/views/main/dashboard/widgets/namenode_rpc_test',
-  'test/views/main/dashboard/widgets/hbase_master_uptime_test',
-  'test/views/main/dashboard/widgets/namenode_uptime_test',
-  'test/views/main/dashboard/widgets/resource_manager_uptime_test',
   'test/views/main/dashboard/widgets/links_widget_test',
   'test/views/main/dashboard/widgets/pie_chart_widget_test',
   'test/views/main/dashboard/widgets/namenode_cpu_test',
+  'test/views/main/dashboard/widgets/namenode_heap_test',
+  'test/views/main/dashboard/widgets/supervisor_live_test',
+  'test/views/main/dashboard/widgets/resource_manager_heap_test',
   'test/views/main/dashboard/widgets/cluster_metrics_widget_test',
+  'test/views/main/dashboard/widgets/yarn_containers_test',
+  'test/views/main/dashboard/widgets/yarn_memory_test',
   'test/views/main/host/details_test',
   'test/views/main/host/summary_test',
   'test/views/main/host/menu_test',
@@ -290,6 +361,9 @@ var files = [
   'test/views/main/host/combo_search_box_test',
   'test/views/main/host/config_service_test',
   'test/views/main/host/add_view_test',
+  'test/views/main/host/logs_view_test',
+  'test/views/main/host/hosts_table_menu_view_test',
+  'test/views/main/host/log_metrics_test',
   'test/views/main/host/config_service_menu_test',
   'test/views/main/host/details/host_component_view_test',
   'test/views/main/host/details/host_component_views/decommissionable_test',
@@ -298,22 +372,57 @@ var files = [
   'test/views/main/host/details/host_component_views/regionserver_view_test',
   'test/views/main/host/details/host_component_views/tasktracker_view_test',
   'test/views/main/host/metrics/disk_test',
+  'test/views/main/host/metrics/cpu_test',
+  'test/views/main/host/metrics/load_test',
+  'test/views/main/host/metrics/memory_test',
+  'test/views/main/host/metrics/network_test',
+  'test/views/main/host/metrics/processes_test',
   'test/views/main/charts/heatmap_test',
   'test/views/main/charts/heatmap/heatmap_host_test',
   'test/views/main/service/item_test',
+  'test/views/main/service/manage_config_groups_view_test',
+  'test/views/main/service/reassign_view_test',
+  'test/views/main/service/reconfigure_test',
+  'test/views/main/service/service_test',
   'test/views/main/service/info/config_test',
   'test/views/main/service/info/summary_test',
+  'test/views/main/service/info/metrics_view_test',
   'test/views/main/service/info/menu_test',
   'test/views/main/service/info/component_list_view_test',
   'test/views/main/service/info/metrics/ambari_metrics/regionserver_base_test',
   'test/views/main/service/info/metrics/flume/flume_agent_metrics_section_test',
+  'test/views/main/service/info/metrics/flume/channel_fill_pct_test',
+  'test/views/main/service/info/metrics/flume/channel_size_test',
+  'test/views/main/service/info/metrics/flume/channel_size_mma_test',
+  'test/views/main/service/info/metrics/flume/channel_sum_test',
+  'test/views/main/service/info/metrics/flume/cpu_user_test',
+  'test/views/main/service/info/metrics/flume/flume_incoming_mma_test',
+  'test/views/main/service/info/metrics/flume/flume_incoming_sum_test',
+  'test/views/main/service/info/metrics/flume/flume_metric_graph_test',
+  'test/views/main/service/info/metrics/flume/flume_metric_graphs_test',
+  'test/views/main/service/info/metrics/flume/flume_outgoing_mma_test',
+  'test/views/main/service/info/metrics/flume/flume_outgoing_sum_test',
+  'test/views/main/service/info/metrics/flume/gc_test',
+  'test/views/main/service/info/metrics/flume/jvm_heap_test',
+  'test/views/main/service/info/metrics/flume/jvm_threads_runnable_test',
+  'test/views/main/service/info/metrics/flume/sink_connection_failed_test',
+  'test/views/main/service/info/metrics/flume/sink_drain_success_test',
+  'test/views/main/service/info/metrics/flume/source_accepted_test',
+  'test/views/main/service/info/summary/hdfs/common_widgets_test',
+  'test/views/main/service/info/summary/hdfs/slaves_test',
+  'test/views/main/service/info/summary/hdfs/widgets_test',
+  'test/views/main/service/reassign/step1_view_test',
+  'test/views/main/service/reassign/step2_view_test',
+  'test/views/main/service/reassign/step3_view_test',
+  'test/views/main/service/reassign/step4_view_test',
+  'test/views/main/service/reassign/step5_view_test',
   'test/views/main/service/services/hdfs_test',
   'test/views/main/service/services/hbase_test',
   'test/views/main/service/services/ranger_test',
   'test/views/main/service/services/storm_test',
   'test/views/main/service/services/yarn_test',
   'test/views/main/service/services/hive_test',
-  'test/views/main/service/services/oozie_test',
+  'test/views/main/service/services/onefs_test',
   'test/views/main/service/services/mapreduce2_test',
   'test/views/main/service/services/zookeeper_test',
   'test/views/main/service/services/flume_test',
@@ -331,8 +440,20 @@ var files = [
   'test/views/main/admin/highAvailability/resourceManager/wizard_view_test',
   'test/views/main/admin/highAvailability/nameNode/wizard_view_test',
   'test/views/main/admin/highAvailability/progress_view_test',
+  'test/views/main/admin/highAvailability/nameNode/rollbackHA/step1_view_test',
+  'test/views/main/admin/highAvailability/nameNode/rollbackHA/step2_view_test',
+  'test/views/main/admin/highAvailability/nameNode/rollbackHA/rollback_wizard_view_test',
+  'test/views/main/admin/highAvailability/journalNode/step2_view_test',
+  'test/views/main/admin/highAvailability/journalNode/step3_view_test',
+  'test/views/main/admin/highAvailability/journalNode/step5_view_test',
+  'test/views/main/admin/highAvailability/journalNode/progress_view_test',
+  'test/views/main/admin/kerberos/progress_view_test',
+  'test/views/main/admin/kerberos/disable_view_test',
+  'test/views/main/admin/kerberos/step1_view_test',
+  'test/views/main/admin/kerberos/step3_view_test',
   'test/views/common/host_progress_popup_body_view_test',
-  'test/views/common/configs/config_history_flow_test',
+  'test/views/common/configs/config_versions_control_view_test',
+  'test/views/common/configs/config_versions_dropdown_view_test',
   'test/views/common/configs/overriddenProperty_view_test',
   'test/views/common/configs/service_config_view_test',
   'test/views/common/configs/service_config_container_view_test',
@@ -343,6 +464,7 @@ var files = [
   'test/views/common/form/spinner_input_view_test',
   'test/views/common/form/manage_kdc_credentials_form_test',
   'test/views/common/log_file_search_view_test',
+  'test/views/common/search_box_view_test',
   'test/views/wizard/step3/hostLogPopupBody_view_test',
   'test/views/wizard/step3/hostWarningPopupBody_view_test',
   'test/views/wizard/step3/hostWarningPopupFooter_view_test',
@@ -358,6 +480,9 @@ var files = [
   'test/views/wizard/step9_view_test',
   'test/views/wizard/step9/hostLogPopupBody_view_test',
   'test/views/wizard/step7/assign_master_view_test',
+  'test/views/wizard/step7/accounts_tab_view_test',
+  'test/views/wizard/step7/directories_tab_view_test',
+  'test/views/wizard/step7/credentials_tab_view_test',
   'test/views/wizard/step10_view_test',
   'test/views/application_test',
   'test/views/installer_test',
@@ -369,6 +494,7 @@ var files = [
   'test/models/alerts/alert_definition_test',
   'test/models/alerts/alert_group_test',
   'test/models/alerts/alert_instance_test',
+  'test/models/alerts/alert_notification_test',
   'test/models/authentication_test',
   'test/models/client_component_test',
   'test/models/cluster_states_test',
@@ -393,16 +519,19 @@ var files = [
   'test/models/host_stack_version_test',
   'test/models/upgrade_entity_test',
   'test/models/finished_upgrade_entity_test',
-  'test/models/configs/sub_section_test',
-  'test/models/configs/section_test',
   'test/models/configs/service_config_version_test',
   'test/models/configs/config_group_test',
   'test/models/configs/stack_config_property_test',
   'test/models/configs/objects/service_config_test',
   'test/models/configs/objects/service_config_category_test',
   'test/models/configs/objects/service_config_property_test',
+  'test/models/configs/theme/section_test',
+  'test/models/configs/theme/sub_section_test',
+  'test/models/configs/theme/sub_section_tab_test',
   'test/models/configs/theme/tab_test',
   'test/models/stack_version/repository_version_test',
+  'test/models/stack_version/service_simple_test',
+  'test/models/stack_version/version_test',
   'test/routes/views_test',
   //contains test with fake timers that affect Date
   'test/utils/lazy_loading_test',
