@@ -41,6 +41,9 @@ App.BulkOperationsController = Em.Controller.extend({
       else if (operationData.action === 'ADD') {
         this.bulkOperationForHostComponentsAdd(operationData, hosts);
       }
+      else if (operationData.action === 'DELETE') {
+        this.bulkOperationForHostComponentsDelete(operationData, hosts);
+      }
       else {
         if (operationData.action.indexOf('DECOMMISSION') == -1) {
           this.bulkOperationForHostComponents(operationData, hosts);
@@ -62,7 +65,10 @@ App.BulkOperationsController = Em.Controller.extend({
           this.bulkOperationForHostsReinstall(operationData, hosts);
         }
         else if (operationData.action === 'DELETE'){
-          this.bulkOperationForHostsDeleteDryRun(operationData, hosts);
+          this._bulkOperationForHostsDelete(hosts);
+        }
+        else if (operationData.action === 'CONFIGURE') {
+          this.bulkOperationForHostsRefreshConfig(operationData, hosts);
         }
         else {
           if (operationData.action === 'PASSIVE_STATE') {
@@ -160,8 +166,8 @@ App.BulkOperationsController = Em.Controller.extend({
         if (nn_hosts.length == 1) {
           return App.router.get('mainHostDetailsController').checkNnLastCheckpointTime(request, nn_hosts[0]);
         }
-        if (nn_hosts.length == 2) {
-          // HA enabled
+        if (nn_hosts.length > 1) {
+          // HA or federation enabled
           return App.router.get('mainServiceItemController').checkNnLastCheckpointTime(request);
         }
       }
@@ -221,8 +227,8 @@ App.BulkOperationsController = Em.Controller.extend({
       }, hostName);
     }
     else {
-      if (nn_count == 2 && isHDFSStarted) {
-        // HA enabled
+      if (nn_count > 1 && isHDFSStarted) {
+        // HA or federation enabled
         App.router.get('mainServiceItemController').checkNnLastCheckpointTime(function () {
           batchUtils.restartHostComponents(hostComponents, Em.I18n.t('rollingrestart.context.allOnSelectedHosts'), "HOST");
         });
@@ -259,118 +265,118 @@ App.BulkOperationsController = Em.Controller.extend({
   },
 
   /**
-   * Calling dry_run for bulk delete selected hosts
-   * @param {Object} operationData - data about bulk operation (action, hostComponents etc)
-   * @param {Ember.Enumerable} hosts - list of affected hosts
-   */
-  bulkOperationForHostsDeleteDryRun: function (operationData, hosts) {
-    var self = this;
-    App.get('router.mainAdminKerberosController').getKDCSessionState(function () {
-      return App.ajax.send({
-        name: 'common.hosts.delete',
-        sender: self,
-        data: {
-          urlParams: "/?dry_run=true",
-          query: 'Hosts/host_name.in(' + hosts.mapProperty('hostName').join(',') + ')',
-          hosts: hosts.mapProperty('hostName')
-        },
-        success: 'bulkOperationForHostsDeleteDryRunCallback',
-        error: 'bulkOperationForHostsDeleteDryRunCallback',
-        showLoadingPopup: true
-      });
-    });
-  },
-
-  /**
-   * Show popup after dry_run for bulk delete hosts
-   * @method bulkOperationForHostsDeleteDryRunCallback
-   */
-  bulkOperationForHostsDeleteDryRunCallback: function (arg0, arg1, arg2, arg3, arg4) {
-    var self = this;
-    var deletableHosts = [];
-    var undeletableHosts = [];
-    if (arg1 == "error") {
-      var request = arg0;
-      var params = arg4;
-      var response = JSON.parse(request.responseText);
-      var host = Ember.Object.create({
+  * Check which hosts can be deleted and warn the user about it in advance
+  * @param {Ember.Enumerable} hosts - list of affected hosts
+  */
+  _bulkOperationForHostsDelete: function (hosts) {
+    var self = this,
+        hostNamesToDelete = [],
+        hostsNotToDelete = [];
+    var createNonDeletableComponents = function (hostName, message) {
+      return Em.Object.create({
         error: {
-          key: params.hosts[0],
-          code: response.status,
-          message: response.message
+          key: hostName,
+          message: message
         },
         isCollapsed: true,
         isBodyVisible: Em.computed.ifThenElse('isCollapsed', 'display: none;', 'display: block;')
       });
-      undeletableHosts.push(host);
-    } else {
-      var data = arg0;
-      var params = arg2;
-      if (data) {
-        data.deleteResult.forEach(function (host) {
-          if (host.deleted) {
-            deletableHosts.push(host);
-          } else {
-            var _host = Ember.Object.create({
-              error: host.error,
-              isCollapsed: true,
-              isBodyVisible: Em.computed.ifThenElse('isCollapsed', 'display: none;', 'display: block;')
-            });
-            undeletableHosts.push(_host);
-          }
-        });
+    };
+    hosts.forEach(function (host) {
+      var hostComponents = App.HostComponent.find().filterProperty('hostName', host.hostName);
+      var hostInfo = App.router.get('mainHostDetailsController').getHostComponentsInfo(hostComponents);
+      console.dir(hostInfo);
+      if (hostInfo.nonDeletableComponents.length > 0) {
+        hostsNotToDelete.push(createNonDeletableComponents(host.hostName, Em.I18n.t('hosts.bulkOperation.deleteHosts.nonDeletableComponents').format(hostInfo.nonDeletableComponents.join(", "))));
+      } else if (hostInfo.nonAddableMasterComponents.length > 0) {
+        hostsNotToDelete.push(createNonDeletableComponents(host.hostName, Em.I18n.t('hosts.bulkOperation.deleteHosts.nonAddableMasterComponents').format(hostInfo.nonAddableMasterComponents.join(", "))));
+      } else if (hostInfo.lastMasterComponents.length > 0) {
+        hostsNotToDelete.push(createNonDeletableComponents(host.hostName, Em.I18n.t('hosts.bulkOperation.deleteHosts.lastMasterComponents').format(hostInfo.lastMasterComponents.join(", "))));
+      } else if (hostInfo.runningComponents.length > 0) {
+        hostsNotToDelete.push(createNonDeletableComponents(host.hostName, Em.I18n.t('hosts.bulkOperation.deleteHosts.runningComponents').format(hostInfo.runningComponents.join(", "))));
       } else {
-        var host = {
-          deleted: {
-            key: params.hosts[0]
-          }
-        };
-        deletableHosts.push(host);
+        hostNamesToDelete.push(host.hostName);
       }
-    }
+    });
 
-    if (undeletableHosts.length) {
-      return App.ModalPopup.show({
-        header: Em.I18n.t('hosts.bulkOperation.deleteHosts.dryRun.header'),
+    return App.ModalPopup.show({
+      header: hostNamesToDelete.length ? Em.I18n.t('hosts.bulkOperation.deleteHosts.confirm.header') : Em.I18n.t('rolling.nothingToDo.header'),
+      primary: hostNamesToDelete.length ? Em.I18n.t('common.next') : null,
+      primaryClass: 'btn-default',
+      onPrimary: function () {
+        this._super();
+        self.bulkOperationForHostsDelete(hostNamesToDelete);
+      },
+      bodyClass: Em.View.extend({
+        templateName: require('templates/main/host/bulk_add_delete_confirm_popup'),
+        modifyMessage: Em.I18n.t('hosts.bulkOperation.deleteHosts.confirm.delete'),
+        skipMessage: hostNamesToDelete.length ? Em.I18n.t('hosts.bulkOperation.deleteHosts.cannot.delete1') : Em.I18n.t('hosts.bulkOperation.deleteHosts.cannot.delete2'),
+        skippedHosts: hostsNotToDelete.length ? hostsNotToDelete : null,
+        hostsToModify: hostNamesToDelete.length ? hostNamesToDelete.join("\n") : null,
+        onToggleHost: function (host) {
+          host.contexts[0].toggleProperty('isCollapsed');
+        }
+      })
+    });
+  },
 
-        primary: deletableHosts.length ? Em.I18n.t('hosts.bulkOperation.deleteHosts.dryRun.primary').format(deletableHosts.length) : null,
+  /**
+   * Bulk refresh configs for selected hosts
+   * @param {Object} operationData - data about bulk operation (action, hostComponents etc)
+   * @param {Ember.Enumerable} hosts - list of affected/selected hosts
+   */
+  bulkOperationForHostsRefreshConfig: function (operationData, hosts) {
+    return batchUtils.getComponentsFromServer({
+      passiveState: 'OFF',
+      hosts: hosts.mapProperty('hostName'),
+      displayParams: ['host_components/HostRoles/component_name']
+    }, this._getComponentsFromServerForRefreshConfigsCallback);
+  },
 
-        onPrimary: function () {
-          this._super();
-          self.bulkOperationForHostsDelete(deletableHosts);
-        },
-        bodyClass: Em.View.extend({
-          templateName: require('templates/main/host/delete_hosts_dry_run_popup'),
-          message: Em.I18n.t('hosts.bulkOperation.deleteHosts.dryRun.message').format(undeletableHosts.length),
-          undeletableHosts: undeletableHosts,
-          onToggleHost: function (host) {
-            host.contexts[0].toggleProperty('isCollapsed');
-          }
-        })
-      });
-    } else if (deletableHosts.length) {
-      this.bulkOperationForHostsDelete(deletableHosts);
-    }
+  /**
+   *
+   * @param {object} data
+   * @private
+   * @method _getComponentsFromServerForRefreshConfigsCallback
+   */
+  _getComponentsFromServerForRefreshConfigsCallback: function (data) {
+    var hostComponents = [];
+    var clients = App.components.get('clients');
+    data.items.forEach(function (host) {
+      host.host_components.forEach(function (hostComponent) {
+        if (clients.contains((hostComponent.HostRoles.component_name))) {
+          hostComponents.push(O.create({
+            componentName: hostComponent.HostRoles.component_name,
+            hostName: host.Hosts.host_name
+          }));
+        }
+      })
+    });
+    batchUtils.restartHostComponents(hostComponents, Em.I18n.t('rollingrestart.context.configs.allOnSelectedHosts'), "HOST");
   },
 
   /**
    * Bulk delete selected hosts
-   * @param {Ember.Enumerable} hosts - list of affected hosts
+   * @param {String} hosts - list of affected host names
    */
   bulkOperationForHostsDelete: function (hosts) {
-    var self = this;
+    var confirmKey = 'delete',
+        self = this;
     App.get('router.mainAdminKerberosController').getKDCSessionState(function () {
       return App.ModalPopup.show({
         header: Em.I18n.t('hosts.bulkOperation.deleteHosts.confirmation.header'),
-
+        confirmInput: '',
+        disablePrimary: Em.computed.notEqual('confirmInput', confirmKey),
+        primary: Em.I18n.t('common.confirm'),
+        primaryClass: 'btn-warning',
         onPrimary: function () {
           this._super();
           return App.ajax.send({
             name: 'common.hosts.delete',
             sender: self,
             data: {
-              query: 'Hosts/host_name.in(' + hosts.mapProperty('deleted.key').join(',') + ')',
-              hosts: hosts.mapProperty('deleted.key')
+              query: 'Hosts/host_name.in(' + hosts.join(',') + ')',
+              hosts: hosts
             },
             success: 'bulkOperationForHostsDeleteCallback',
             error: 'bulkOperationForHostsDeleteCallback',
@@ -379,7 +385,8 @@ App.BulkOperationsController = Em.Controller.extend({
         },
         bodyClass: Em.View.extend({
           templateName: require('templates/main/host/delete_hosts_popup'),
-          hosts: hosts
+          hostNames: hosts,
+          typeMessage: Em.I18n.t('services.service.confirmDelete.popup.body.type').format(confirmKey),
         })
       });
     });
@@ -411,9 +418,7 @@ App.BulkOperationsController = Em.Controller.extend({
       var params = arg2;
       if (data) {
         data.deleteResult.forEach(function (host) {
-          if (host.deleted) {
-            deletedHosts.push(host);
-          } else {
+          if (!host.deleted) {
             var _host = Ember.Object.create({
               error: host.error,
               isCollapsed: true,
@@ -422,14 +427,8 @@ App.BulkOperationsController = Em.Controller.extend({
             undeletableHosts.push(_host);
           }
         });
-      } else {
-        var host = {
-          deleted: {
-            key: params.hosts[0]
-          }
-        };
-        deletedHosts.push(host);
       }
+      deletedHosts = params.hosts;
     }
 
     return App.ModalPopup.show({
@@ -447,13 +446,20 @@ App.BulkOperationsController = Em.Controller.extend({
         }
       }),
 
-      onPrimary: function () {
+      completeDelete() {
+        if (arg1 !== 'error') {
+          App.db.unselectHosts(arg2.hosts);
+        }
         location.reload();
+      },
+
+      onPrimary: function () {
+        this.completeDelete();
         this._super();
       },
 
       onClose: function () {
-        location.reload();
+        this.completeDelete();
         this._super();
       }
     });
@@ -532,70 +538,45 @@ App.BulkOperationsController = Em.Controller.extend({
   _getComponentsFromServerForHostComponentsAddCallback: function (operationData, data, hosts) {
     var self = this;
 
-    hosts = hosts.mapProperty('hostName');
-
     var allHostsWithComponent = data.items.mapProperty('Hosts.host_name');
-    var hostsWithComponent = hosts.filter(function (host) {
-      return allHostsWithComponent.contains(host);
+    var hostsWithComponent = [];
+    hosts.forEach(function (host) {
+      const isNotHeartBeating = host.state === 'HEARTBEAT_LOST';
+      if(allHostsWithComponent.contains(host.hostName) || isNotHeartBeating) {
+        hostsWithComponent.push(Em.Object.create({
+          error: {
+            key: host.hostName,
+            message: isNotHeartBeating ? Em.I18n.t('hosts.bulkOperation.confirmation.add.component.noHeartBeat.skip') : Em.I18n.t('hosts.bulkOperation.confirmation.add.component.skip').format(operationData.componentNameFormatted)
+          },
+          isCollapsed: true,
+          isBodyVisible: Em.computed.ifThenElse('isCollapsed', 'display: none;', 'display: block;')
+        }));
+      }
     });
     var hostsWithOutComponent = hosts.filter(function(host) {
-      return !hostsWithComponent.contains(host);
+      return !hostsWithComponent.findProperty('error.key', host.hostName);
     });
 
-    var minShown = 3;
+    hostsWithOutComponent = hostsWithOutComponent.mapProperty('hostName');
 
-    if (hostsWithOutComponent.length) {
-      return App.ModalPopup.show({
-        header: Em.I18n.t('hosts.bulkOperation.confirmation.header'),
-        hostNames: hostsWithOutComponent.join("\n"),
-        visibleHosts: self._showHostNames(hostsWithOutComponent, "\n", minShown),
-        hostNamesSkippedVisible: self._showHostNames(hostsWithComponent, "\n", minShown),
-        expanded: false,
-
-        hostNamesSkipped: function() {
-          return hostsWithComponent.length ? hostsWithComponent.join("\n") : false;
-        }.property(),
-
-        didInsertElement: function() {
-          this._super();
-          this.set('expanded', hostsWithOutComponent.length <= minShown);
-        },
-
-        onPrimary: function() {
-          self.bulkAddHostComponents(operationData, hostsWithOutComponent);
-          this._super();
-        },
-        bodyClass: Em.View.extend({
-          templateName: require('templates/main/host/bulk_operation_confirm_popup'),
-          message: Em.I18n.t('hosts.bulkOperation.confirmation.add.component').format(operationData.message, operationData.componentNameFormatted, hostsWithOutComponent.length),
-          warningInfo: Em.I18n.t('hosts.bulkOperation.confirmation.add.component.skip').format(operationData.componentNameFormatted),
-          textareaVisible: false,
-          textTrigger: function() {
-            this.toggleProperty('textareaVisible');
-          },
-
-          showAll: function() {
-            this.set('parentView.visibleHosts', this.get('parentView.hostNames'));
-            this.set('parentView.hostNamesSkippedVisible', this.get('parentView.hostNamesSkipped'));
-            this.set('parentView.expanded', true);
-          },
-          putHostNamesToTextarea: function() {
-            var hostNames = this.get('parentView.hostNames');
-            if (this.get('textareaVisible')) {
-              var wrapper = $(".task-detail-log-maintext");
-              $('.task-detail-log-clipboard').html(hostNames).width(wrapper.width()).height(250);
-              Em.run.next(function() {
-                $('.task-detail-log-clipboard').select();
-              });
-            }
-          }.observes('textareaVisible')
-        })
-      });
-    }
     return App.ModalPopup.show({
-      header: Em.I18n.t('rolling.nothingToDo.header'),
-      body: Em.I18n.t('hosts.bulkOperation.confirmation.add.component.nothingToDo.body').format(operationData.componentNameFormatted),
-      secondary: false
+      header: hostsWithOutComponent.length ? Em.I18n.t('hosts.bulkOperation.confirmation.header') : Em.I18n.t('rolling.nothingToDo.header'),
+      primary: hostsWithOutComponent.length ? Em.I18n.t('hosts.host.addComponent.popup.confirm') : null,
+
+      onPrimary: function() {
+        self.bulkAddHostComponents(operationData, hostsWithOutComponent);
+        this._super();
+      },
+      bodyClass: Em.View.extend({
+        templateName: require('templates/main/host/bulk_add_delete_confirm_popup'),
+        modifyMessage: Em.I18n.t('hosts.bulkOperation.confirmation.add.component').format(operationData.componentNameFormatted),
+        skipMessage: hostsWithOutComponent.length ? Em.I18n.t('hosts.bulkOperation.confirmation.cannot.add1') : Em.I18n.t('hosts.bulkOperation.confirmation.cannot.add2').format(operationData.componentNameFormatted),
+        hostsToModify: hostsWithOutComponent.length ? hostsWithOutComponent.join("\n") : null,
+        skippedHosts: hostsWithComponent.length ? hostsWithComponent : null,
+        onToggleHost: function (host) {
+          host.contexts[0].toggleProperty('isCollapsed');
+        }
+      })
     });
   },
   /**
@@ -647,6 +628,177 @@ App.BulkOperationsController = Em.Controller.extend({
     });
   },
 
+  /**
+   * Confirm bulk delete for selected hostComponent
+   * @param {Object} operationData - data about bulk operation (action, hostComponent etc)
+   * @param {Array} hosts - list of affected hosts
+   */
+  bulkOperationForHostComponentsDelete: function (operationData, hosts) {
+    var self = this;
+    return batchUtils.getComponentsFromServer({
+      components: [operationData.componentName],
+      hosts: hosts.mapProperty('hostName'),
+      displayParams: ['host_components/HostRoles/state']
+    }, function (data) {
+      return self._getComponentsFromServerForHostComponentsDeleteCallback(operationData, data, hosts);
+    });
+  },
+
+  _getComponentsFromServerForHostComponentsDeleteCallback: function (operationData, data, requestedHosts) {
+    var self = this;
+    var minToInstall = App.StackServiceComponent.find(operationData.componentName).get('minToInstall');
+    var installedCount = App.HostComponent.getCount(operationData.componentName, 'totalCount');
+    var installedHosts = data.items.mapProperty('Hosts.host_name');
+    var hostsToDelete = data.items.filter(function (host) {
+      var state = host.host_components[0].HostRoles.state;
+      return [App.HostComponentStatus.stopped, App.HostComponentStatus.unknown, App.HostComponentStatus.install_failed, App.HostComponentStatus.upgrade_failed, App.HostComponentStatus.init].contains(state);
+    }).mapProperty('Hosts.host_name');
+
+    if (installedCount - hostsToDelete.length < minToInstall) {
+      return App.ModalPopup.show({
+        header: Em.I18n.t('rolling.nothingToDo.header'),
+        body: Em.I18n.t('hosts.bulkOperation.confirmation.delete.component.minimum.body').format(minToInstall, operationData.componentNameFormatted),
+        secondary: false
+      });
+    }
+
+    var hostsNotToDelete = [];
+
+    requestedHosts.mapProperty('hostName').forEach(function (host) {
+      if (!hostsToDelete.contains(host)) {
+        var hostToSkip = Em.Object.create({
+          error : {
+            key: host,
+            message: null,
+          },
+          isCollapsed : true,
+          isBodyVisible: Em.computed.ifThenElse('isCollapsed', 'display: none;', 'display: block;')
+        });
+        if(installedHosts.contains(host)) {
+          hostToSkip.error.message = Em.I18n.t('hosts.bulkOperation.confirmation.delete.component.notStopped').format(operationData.componentNameFormatted);
+        } else {
+          hostToSkip.error.message = Em.I18n.t('hosts.bulkOperation.confirmation.delete.component.notInstalled').format(operationData.componentNameFormatted);
+        }
+        hostsNotToDelete.push(hostToSkip);
+      }
+    });
+
+    return App.ModalPopup.show({
+      header: hostsToDelete.length ? Em.I18n.t('hosts.bulkOperation.confirmation.header') : Em.I18n.t('rolling.nothingToDo.header'),
+      primary: hostsToDelete.length ? Em.I18n.t('hosts.host.deleteComponent.popup.confirm') : null,
+      primaryClass: 'btn-warning',
+
+      onPrimary: function() {
+        self.bulkDeleteHostComponents(operationData, hostsToDelete);
+        this._super();
+      },
+      bodyClass: Em.View.extend({
+        templateName: require('templates/main/host/bulk_add_delete_confirm_popup'),
+        modifyMessage: Em.I18n.t('hosts.bulkOperation.confirmation.delete.component').format(operationData.componentNameFormatted),
+        skipMessage: hostsToDelete.length ? Em.I18n.t('hosts.bulkOperation.confirmation.delete.component.cannot1') :  Em.I18n.t('hosts.bulkOperation.confirmation.delete.component.cannot2').format(operationData.componentNameFormatted),
+        hostsToModify: hostsToDelete.length ? hostsToDelete.join("\n") : null,
+        skippedHosts: hostsNotToDelete.length ? hostsNotToDelete : null,
+        onToggleHost: function (host) {
+          host.contexts[0].toggleProperty('isCollapsed');
+        }
+      })
+    });
+  },
+
+  /**
+   * Bulk delete for selected hostComponent
+   * @param {Object} operationData - data about bulk operation (action, hostComponent etc)
+   * @param {Array} hostNames - list of affected hosts' names
+   */
+  bulkDeleteHostComponents: function (operationData, hostNames) {
+    var self= this;
+    App.get('router.mainAdminKerberosController').getKDCSessionState(function () {
+      App.ajax.send({
+        name: 'host.host_component.delete_components',
+        sender: self,
+        data: {
+          hostNames,
+          componentName: operationData.componentName,
+          data: JSON.stringify({
+            RequestInfo: {
+              query: 'HostRoles/host_name.in(' + hostNames.join(',') + ')&HostRoles/component_name.in(' + operationData.componentName + ')'
+            }
+          })
+        },
+        success: 'bulkOperationForHostComponentsDeleteCallback'
+      });
+    });
+  },
+
+  /**
+   * Show popup after bulk delete host_components
+   * @method bulkOperationForHostComponentsDeleteCallback
+   */
+  bulkOperationForHostComponentsDeleteCallback: function (arg0, arg1, arg2, arg3, arg4) {
+    var deletedHosts = [];
+    var undeletableHosts = [];
+    var componentName = arg2.componentName;
+    if (arg1 == "error") {
+      var request = arg0;
+      let params = arg4;
+      var response = JSON.parse(request.responseText);
+      var host = Ember.Object.create({
+        error: {
+          key: params.hosts[0],
+          code: response.status,
+          message: response.message
+        },
+        isCollapsed: true,
+        isBodyVisible: Em.computed.ifThenElse('isCollapsed', 'display: none;', 'display: block;')
+      });
+      undeletableHosts.push(host);
+    } else {
+      var data = arg0;
+      let params = arg2;
+      if (data) {
+        data.deleteResult.forEach(function (host) {
+          if (!host.deleted) {
+            var _host = Ember.Object.create({
+              error: host.error,
+              isCollapsed: true,
+              isBodyVisible: Em.computed.ifThenElse('isCollapsed', 'display: none;', 'display: block;')
+            });
+            undeletableHosts.push(_host);
+          }
+        });
+      }
+      deletedHosts = (params.hostNames);
+    }
+
+    return App.ModalPopup.show({
+      header: Em.I18n.t('hosts.bulkOperation.delete.component.result.header'),
+
+      secondary: null,
+
+      bodyClass: Em.View.extend({
+        templateName: require('templates/main/host/delete_hosts_result_popup'),
+        message: Em.I18n.t('hosts.bulkOperation.delete.component.dryRun.message').format(componentName),
+        componentName: componentName,
+        undeletableHosts: undeletableHosts,
+        deletedHosts: deletedHosts,
+        deleteComponents: true,
+        onToggleHost: function (host) {
+          host.contexts[0].toggleProperty('isCollapsed');
+        }
+      }),
+
+      onPrimary: function () {
+        location.reload();
+        this._super();
+      },
+
+      onClose: function () {
+        location.reload();
+        this._super();
+      }
+    });
+  },
+
   /**
    * Bulk operation for selected hostComponents
    * @param {Object} operationData - data about bulk operation (action, hostComponents etc)
@@ -959,6 +1111,7 @@ App.BulkOperationsController = Em.Controller.extend({
         id: host.id,
         clusterId: host.cluster_id,
         passiveState: host.passive_state,
+        state: host.state,
         hostName: host.host_name,
         hostComponents: host.host_components
       }
@@ -969,27 +1122,40 @@ App.BulkOperationsController = Em.Controller.extend({
     var self = this;
     var operationData = param.operationData;
     var hosts = this._convertHostsObjects(App.hostsMapper.map(json, true));
+    var repoVersion = null;
     // no hosts - no actions
     if (!hosts.length) {
       return;
     }
 
-    if ('SET_RACK_INFO' === operationData.action) {
+    if (['SET_RACK_INFO', 'ADD', 'DELETE'].contains(operationData.action)) {
       return self.bulkOperation(operationData, hosts);
     }
 
-    var hostNames = hosts.mapProperty('hostName');
-    var hostNamesSkipped = [];
-    if ('DECOMMISSION' === operationData.action) {
-      hostNamesSkipped = this._getSkippedForDecommissionHosts(json, hosts, operationData);
-    }
-    if ('PASSIVE_STATE' === operationData.action) {
-      hostNamesSkipped = this._getSkippedForPassiveStateHosts(hosts);
+     var hostNames = hosts.mapProperty('hostName');
+     var hostNamesSkipped = [];
+     if ('DECOMMISSION' === operationData.action) {
+       hostNamesSkipped = this._getSkippedForDecommissionHosts(json, hosts, operationData);
+     }
+     if ('PASSIVE_STATE' === operationData.action) {
+       repoVersion = App.StackVersion.find().findProperty('isCurrent');
+       if (!repoVersion && App.StackVersion.find().toArray().length === 1) {
+        repoVersion = App.StackVersion.find().findProperty('isOutOfSync');
+       }
+       if (!repoVersion) {
+        console.error("CLUSTER STACK VERSIONS ERROR: multiple clusters in OUT_OF_SYNC state OR none in CURRENT or OUT_OF_SYNC state");
+        return;
+       }
+       hostNamesSkipped = this._getSkippedForPassiveStateHosts(hosts, repoVersion);
+     }
+
+    var message = "";
+    if (operationData.componentNameFormatted) {
+      message = Em.I18n.t('hosts.bulkOperation.confirmation.hostComponents').format(operationData.message, operationData.componentNameFormatted, hostNames.length);
+    } else {
+      message = Em.I18n.t('hosts.bulkOperation.confirmation.hosts').format(operationData.message, hostNames.length);
     }
 
-    var message = operationData.componentNameFormatted ?
-      Em.I18n.t('hosts.bulkOperation.confirmation.hostComponents').format(operationData.message, operationData.componentNameFormatted, hostNames.length) :
-      Em.I18n.t('hosts.bulkOperation.confirmation.hosts').format(operationData.message, hostNames.length);
 
     return App.ModalPopup.show({
       header: Em.I18n.t('hosts.bulkOperation.confirmation.header'),
@@ -1022,7 +1188,7 @@ App.BulkOperationsController = Em.Controller.extend({
               return Em.I18n.t('hosts.bulkOperation.warningInfo.body');
             case "PASSIVE_STATE":
               return operationData.state === 'OFF' ? Em.I18n.t('hosts.passiveMode.popup.version.mismatch.multiple')
-                .format(App.StackVersion.find().findProperty('isCurrent').get('repositoryVersion.repositoryVersion')) : "";
+                .format(repoVersion.get('repositoryVersion.repositoryVersion')) : "";
             default:
               return ""
           }
@@ -1089,10 +1255,10 @@ App.BulkOperationsController = Em.Controller.extend({
    * @private
    * @method _getSkippedForPassiveStateHosts
    */
-  _getSkippedForPassiveStateHosts: function (hosts) {
+  _getSkippedForPassiveStateHosts: function (hosts, repoVersion) {
     var hostNames = hosts.mapProperty('hostName');
     var hostNamesSkipped = [];
-    var outOfSyncHosts = App.StackVersion.find().findProperty('isCurrent').get('outOfSyncHosts');
+    var outOfSyncHosts = repoVersion.get('outOfSyncHosts') || [];
     for (var i = 0; i < outOfSyncHosts.length; i++) {
       if (hostNames.contains(outOfSyncHosts[i])) {
         hostNamesSkipped.push(outOfSyncHosts[i]);
@@ -1101,4 +1267,4 @@ App.BulkOperationsController = Em.Controller.extend({
     return hostNamesSkipped;
   }
 
-});
\ No newline at end of file
+});
