@@ -42,7 +42,7 @@ var App = require('app');
  * @property {?object[]} slaveComponentHosts
  */
 
-App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.EnhancedConfigsMixin, App.ToggleIsRequiredMixin, App.GroupsMappingMixin, {
+App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.EnhancedConfigsMixin, App.ToggleIsRequiredMixin, App.GroupsMappingMixin, App.AddSecurityConfigs, App.KDCCredentialsControllerMixin, {
 
   name: 'wizardStep7Controller',
 
@@ -65,10 +65,26 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
   submitButtonClicked: false,
 
   isRecommendedLoaded: false,
+
+  /**
+   * Indicates if all stepConfig objects are created
+   */
+  stepConfigsCreated: false,
+
+  /**
+   * Define state of next button on credentials tab
+   */
+  credentialsTabNextEnabled: false,
+
+  /**
+   * Define state of next button on databases tab
+   */
+  databasesTabNextEnabled: false,
+
   /**
    * used in services_config.js view to mark a config with security icon
    */
-  secureConfigs: require('data/HDP2/secure_mapping'),
+  secureConfigs: require('data/configs/wizards/secure_mapping'),
 
   /**
    * If configChangeObserver Modal is shown
@@ -78,11 +94,19 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
 
   overrideToAdd: null,
 
+  isInstaller: true, //todo: refactor using of this property
+
   /**
    * Is installer controller used
    * @type {bool}
    */
-  isInstaller: true,
+  isInstallWizard: Em.computed.equal('content.controllerName', 'installerController'),
+
+  /**
+   * Is add service controller used
+   * @type {bool}
+   */
+  isAddServiceWizard: Em.computed.equal('content.controllerName', 'addServiceController'),
 
   /**
    * List of config groups
@@ -116,6 +140,29 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
    */
   isAppliedConfigLoaded: true,
 
+  /**
+   * Is there validation issues
+   * @type {bool}
+   */
+  hasErrors: false,
+
+  /**
+   * Total number of recommendation and validation issues
+   * @type {number}
+   */
+  issuesCounter: 0,
+
+  /**
+   * Number of ui-side validation issues
+   * @type {number}
+   */
+  validationsCounter: 0,
+
+  /**
+   * Tab objects to represent each config category tab
+   */
+  tabs: [],
+
   isConfigsLoaded: Em.computed.and('wizardController.stackConfigsLoaded', 'isAppliedConfigLoaded'),
 
   transitionInProgress: Em.computed.alias('App.router.btnClickInProgress'),
@@ -125,7 +172,7 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
    * @type {boolean}
    */
   supportsPreInstallChecks: function () {
-    return App.get('supports.preInstallChecks') && 'installerController' === this.get('content.controllerName');
+    return App.get('supports.preInstallChecks') && this.get('isInstallWizard');
   }.property('App.supports.preInstallChecks', 'wizardController.name'),
 
   /**
@@ -134,7 +181,7 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
    */
   errorsCount: function() {
     return this.get('selectedService.configsWithErrors').filter(function(c) {
-      return Em.isNone(c.get('widget'));
+      return Em.isNone(c.get('isInDefaultTheme'));
     }).length;
   }.property('selectedService.configsWithErrors.length'),
 
@@ -146,8 +193,10 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
     if (!this.get('stepConfigs.length')) return true;
     if (this.get('submitButtonClicked')) return true;
     if (App.get('router.btnClickInProgress')) return true;
-    return !this.get('stepConfigs').filterProperty('showConfig', true).everyProperty('errorCount', 0) || this.get("miscModalVisible");
-  }.property('stepConfigs.@each.errorCount', 'miscModalVisible', 'submitButtonClicked', 'App.router.btnClickInProgress'),
+    return !this.get('stepConfigs').filterProperty('showConfig', true).everyProperty('errorCount', 0)
+      || this.get("miscModalVisible")
+      || !!this.get('configErrorList.criticalIssues.length');
+  }.property('stepConfigs.@each.errorCount', 'miscModalVisible', 'submitButtonClicked', 'App.router.btnClickInProgress', 'configErrorList.criticalIssues.length'),
 
   /**
    * List of selected to install service names
@@ -173,7 +222,7 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
    */
   installedServiceNames: function () {
     var serviceNames = this.get('content.services').filterProperty('isInstalled').mapProperty('serviceName');
-    if (this.get('content.controllerName') !== 'installerController') {
+    if (!this.get('isInstallWizard')) {
       serviceNames = serviceNames.filter(function (_serviceName) {
         return !App.get('services.noConfigTypes').contains(_serviceName);
       });
@@ -188,6 +237,10 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
     });
   }.property('installedServiceNames.length'),
 
+  requiredChanges: function () {
+    return this.get('recommendations').filterProperty('isEditable', false);
+  }.property('recommendatios.@each.isEditable'),
+
   /**
    * List of master components
    * @type {Ember.Enumerable}
@@ -305,13 +358,21 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
       submitButtonClicked: false,
       isSubmitDisabled: true,
       isRecommendedLoaded: false,
+      stepConfigsCreated: false,
       initialRecommendations: []
     });
+    App.ServiceConfigGroup.find().filterProperty('isDefault', false).forEach(function (record) {
+      App.configGroupsMapper.deleteRecord(record);
+    });
     this.get('stepConfigs').clear();
     this.set('filter', '');
     this.get('filterColumns').setEach('selected', false);
   },
 
+  clearLastSelectedService: function () {
+    this.get('tabs').filterProperty('selectedServiceName').setEach('selectedServiceName', null);
+  },
+
   /**
    * Generate "finger-print" for current <code>stepConfigs[0]</code>
    * Used to determine, if user has some unsaved changes (comparing with <code>hash</code>)
@@ -375,7 +436,7 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
         for (var prop in config.properties) {
           var fileName = App.config.getOriginalFileName(config.type);
           var serviceConfig = serviceConfigs.filterProperty('name', prop).findProperty('filename', fileName);
-          if (serviceConfig) {
+          if (serviceConfig && serviceConfig.get('isOriginalSCP')) {
             var value = App.config.formatPropertyValue(serviceConfig, config.properties[prop]);
             var isFinal = !!(config.properties_attributes && config.properties_attributes.final && config.properties_attributes.final[prop]);
 
@@ -429,7 +490,9 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
    */
   _updateIsEditableFlagForConfig: function (serviceConfigProperty, defaultGroupSelected) {
     if (App.isAuthorized('AMBARI.ADD_DELETE_CLUSTERS')) {
-      if (App.get('isKerberosEnabled') && serviceConfigProperty.get('isConfigIdentity')) {
+      if (App.get('isKerberosEnabled') &&
+          serviceConfigProperty.get('isConfigIdentity') &&
+          !App.StackService.find().filterProperty('isSelected').mapProperty('serviceName').contains(Em.get(serviceConfigProperty, 'serviceName'))) {
         serviceConfigProperty.set('isEditable', false);
       } else if (defaultGroupSelected && !Em.get(serviceConfigProperty, 'group')) {
         if (serviceConfigProperty.get('serviceName') === 'MISC') {
@@ -488,7 +551,7 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
         self.applyServicesConfigs(configs);
       });
     } else {
-      this.applyServicesConfigs(configs);
+      this.applyServicesConfigs(configs, true);
     }
   },
 
@@ -515,13 +578,14 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
     return configs
   },
 
-  applyServicesConfigs: function (configs) {
+  applyServicesConfigs: function (configs, isRestoring) {
+    var self = this;
     console.time('applyServicesConfigs execution time: ');
     if (!this.get('installedServiceNames').contains('HAWQ') && this.get('allSelectedServiceNames').contains('HAWQ')) {
       this.updateHawqConfigs(configs);
     }
     if (App.get('isKerberosEnabled') && this.get('wizardController.name') === 'addServiceController') {
-      this.addKerberosDescriptorConfigs(configs, this.get('wizardController.kerberosDescriptorConfigs') || []);
+      this.addKerberosDescriptorConfigs(configs, this.get('wizardController.kerberosDescriptorConfigs') || [], isRestoring);
     }
     var stepConfigs = this.createStepConfigs();
     var serviceConfigs = this.renderConfigs(stepConfigs, configs);
@@ -533,12 +597,24 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
         serviceConfigs = this._reconfigureServicesOnNnHa(serviceConfigs);
       }
     }
+
+    var rangerService = App.StackService.find().findProperty('serviceName', 'RANGER');
+    const isRangerServicePresent = rangerService && (rangerService.get('isInstalled') || rangerService.get('isSelected'));
+    var infraSolrService = App.StackService.find().findProperty('serviceName', 'AMBARI_INFRA_SOLR');
+    const isInfraSolrPresent = infraSolrService && (infraSolrService.get('isInstalled') || infraSolrService.get('isSelected'));
+    if(isRangerServicePresent && (this.get('wizardController.name') === 'installerController' || this.get('wizardController.name') === 'addServiceController')) {
+      this.setRangerPluginsEnabled(serviceConfigs);
+      if (isInfraSolrPresent) {
+        this.setSolrCloudOn(serviceConfigs);
+      }
+    }
+
     this.set('stepConfigs', serviceConfigs);
+    this.set('stepConfigsCreated', true);
+    this.updateConfigAttributesFromThemes();
     this.checkHostOverrideInstaller();
     this.selectProperService();
-    var isInstallerWizard = (this.get("content.controllerName") === 'installerController');
-    var self = this;
-    var rangerService = App.StackService.find().findProperty('serviceName', 'RANGER');
+    var isInstallerWizard = this.get('isInstallWizard');
     var isRangerServiceAbsent =  rangerService && !rangerService.get('isInstalled') && !rangerService.get('isSelected');
     if (isRangerServiceAbsent) {
       var isExternalRangerSetup;
@@ -572,6 +648,35 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
 
   },
 
+  /**
+  * Sets the value of ranger-<service_name>-plugin-enabled to "Yes" if ranger authorization /
+  * is supported for that service.
+  * @param stepConfigs Object[]
+  */
+  setRangerPluginsEnabled: function(stepConfigs) {
+    var rangerServiceConfigs = stepConfigs.findProperty('serviceName', 'RANGER').get('configs');
+    var services = this.get('selectedServiceNames').filter(service => service != 'RANGER');
+
+    services.forEach(function(serviceName) {
+      var pluginEnabledPropertyName = 'ranger-' + serviceName.toLowerCase() + '-plugin-enabled';
+      var pluginEnabledProperty = rangerServiceConfigs.findProperty('name', pluginEnabledPropertyName);
+      //Kafka and Storm plugins need to be enabled only if cluster is kerberized
+      if (pluginEnabledProperty && (serviceName === 'STORM' || serviceName === 'KAFKA')) {
+        if (App.get('isKerberosEnabled')) {
+          Em.set(pluginEnabledProperty, 'value', 'Yes');
+        }
+      } else if (pluginEnabledProperty) {
+        Em.set(pluginEnabledProperty, 'value', 'Yes');
+      }
+    });
+  },
+
+  setSolrCloudOn: function(stepConfigs) {
+    var rangerServiceConfigs = stepConfigs.findProperty('serviceName', 'RANGER').get('configs');
+    var solrCloudEnabledProperty = rangerServiceConfigs.findProperty('name', 'is_solrCloud_enabled');
+    Em.set(solrCloudEnabledProperty, 'value', 'true');
+  },
+
   /**
    *
    * Makes installed service's configs resulting into component actions (add/delete) non editable on Add Service Wizard
@@ -639,21 +744,33 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
    * @param {App.ServiceConfigProperty[]} descriptor - parsed kerberos descriptor
    * @method addKerberosDescriptorConfigs
    */
-  addKerberosDescriptorConfigs: function (configs, descriptor) {
+  addKerberosDescriptorConfigs: function (configs, descriptor, isRestoring) {
+    var servicesToBeInstalled = this.get('content.services').filterProperty('isSelected').mapProperty('serviceName');
     descriptor.forEach(function (item) {
-      var property = configs.findProperty('name', item.get('name'));
+      var service = item.get('serviceName');
+      if (!servicesToBeInstalled.contains(service)) return false;
+      var name = item.get('name');
+      var filename = Em.get(item, 'filename');
+      var property = configs.filterProperty('serviceName', service).findProperty('name', name);
+      var propertyObj = {
+        isSecureConfig: true,
+        value: Em.get(isRestoring && property ? property : item, 'value'),
+        defaultValue: Em.get(item, 'value'),
+        displayName: name,
+        isOverridable: false,
+        isConfigIdentity: Em.get(item, 'isConfigIdentity'),
+        isUserProperty: !!Em.get(item, 'isUserProperty'),
+        category: (Em.get(item, 'isUserProperty') ? 'Custom ' : 'Advanced ') + filename
+      };
       if (property) {
-        Em.setProperties(property, {
-          isSecureConfig: true,
-          displayName: Em.get(item, 'name'),
-          isUserProperty: false,
-          isOverridable: false,
-          isConfigIdentity: Em.get(item, 'isConfigIdentity'),
+        Em.setProperties(property, $.extend(propertyObj, {
+          savedValue: Em.get(item, 'value'),
           description: Em.get(item, 'isConfigIdentity')
-            ? App.config.kerberosIdentitiesDescription(Em.get(property, 'description'))
-            : Em.get(property, 'description'),
-          category: 'Advanced ' + Em.get(item, 'filename')
-        });
+              ? App.config.kerberosIdentitiesDescription(Em.get(property, 'description'))
+              : Em.get(property, 'description')
+        }));
+      } else {
+        configs.push(App.ServiceConfigProperty.create(App.config.getDefaultConfig(name, filename, propertyObj)));
       }
     });
   },
@@ -1024,12 +1141,18 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
   },
 
   /**
+   * Select previously selected service if not within the tab for the first time
    * Select first addable service for <code>addServiceWizard</code>
    * Select first service at all in other cases
    * @method selectProperService
    */
   selectProperService: function () {
-    if (this.get('wizardController.name') === 'addServiceController') {
+    var activeTab = this.get('tabs').findProperty('isActive', true);
+    var tabSelectedServiceName = activeTab ? activeTab.get('selectedServiceName') : null;
+    var lastSelectedService = tabSelectedServiceName ? this.get('stepConfigs').findProperty('serviceName', tabSelectedServiceName) : null
+    if(tabSelectedServiceName && lastSelectedService) {
+      this.set('selectedService', lastSelectedService);
+    } else if (this.get('wizardController.name') === 'addServiceController') {
       this.set('selectedService', this.get('stepConfigs').filterProperty('selected', true).get('firstObject'));
     } else {
       this.set('selectedService', this.get('stepConfigs').filterProperty('showConfig', true).objectAt(0));
@@ -1041,8 +1164,8 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
    * @return {$.ajax|null}
    * @method getConfigTags
    */
-  getConfigTags: function () {
-    this.set('isAppliedConfigLoaded', false);
+  getConfigTags: function (resetFlag) {
+    if (resetFlag) this.set('isAppliedConfigLoaded', false);
     return App.ajax.send({
       name: 'config.tags',
       sender: this,
@@ -1050,6 +1173,27 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
     });
   },
 
+  getServicesConfigurations: function() {
+    var dfd = $.Deferred();
+    var configs, servicesConfigurations;
+    configs = this.get('wizardController').getConfigsAndFilenames(this, true).serviceConfigProperties;
+    servicesConfigurations = configs.reduce(function(configTags, property) {
+      var fileName = App.config.getConfigTagFromFileName(property.filename),
+          configType;
+      if (!configTags.someProperty('type', fileName)) {
+        configTags.push({
+          type: fileName,
+          properties: {}
+        });
+      }
+      configType = configTags.findProperty('type', fileName);
+      configType.properties[property.name] = property.value;
+      return configTags;
+    }, []);
+    dfd.resolve(servicesConfigurations);
+    return dfd.promise();
+  },
+
   /**
    * Success callback for config tags request
    * Updates <code>serviceConfigTags</code> with tags received from server
@@ -1210,7 +1354,7 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
           var modelGroup = App.ServiceConfigGroup.find(item.id);
           modelGroup.set('properties', []);
           item.properties.forEach(function (propertyData) {
-            var overriddenSCP, parentSCP = service.configs.filterProperty('filename', propertyData.filename).findProperty('name', propertyData.name);
+            var overriddenSCP, parentSCP = service.configs.filterProperty('filename', propertyData.filename).filterProperty('isOriginalSCP').findProperty('name', propertyData.name);
             if (parentSCP) {
               App.config.createOverride(parentSCP, propertyData, modelGroup)
             } else {
@@ -1285,7 +1429,9 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
   _setEditableValue: function (config) {
     var selectedGroup = this.get('selectedConfigGroup');
     if (!selectedGroup) return config;
-    if (App.get('isKerberosEnabled') && config.get('isConfigIdentity')) {
+    if (App.get('isKerberosEnabled') &&
+        config.get('isConfigIdentity') &&
+        !App.StackService.find().filterProperty('isSelected').mapProperty('serviceName').contains(Em.get(config, 'serviceName'))) {
       config.set('isEditable', false);
     } else {
       var isEditable = config.get('isEditable'),
@@ -1488,11 +1634,11 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
               this.hide();
               parent.hide();
               // go back to step 5: assign masters and disable default navigation warning
-              if ('installerController' === self.get('content.controllerName')) {
+              if (self.get('isInstallWizard')) {
                 App.router.get('installerController').gotoStep(5, true);
               }
               else {
-                if ('addServiceController' === self.get('content.controllerName')) {
+                if (self.get('isAddServiceWizard')) {
                   App.router.get('addServiceController').gotoStep(2, true);
                 }
               }
@@ -1567,6 +1713,8 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
       },
       onSecondary: function () {
         this.hide();
+        App.set('router.btnClickInProgress', false);
+        App.set('router.backBtnClickInProgress', false);
       }
     });
   },
@@ -1587,7 +1735,8 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
       },
       onSecondary: function () {
         this._super();
-        self.setButtonClickFinish();
+        self.set('submitButtonClicked', false);
+        App.set('router.nextBtnClickInProgress', false);
         deferred.reject();
       }
     });
@@ -1610,7 +1759,8 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
             }
           },
           onSecondary: function() {
-            self.setButtonClickFinish();
+            App.set('router.nextBtnClickInProgress', false);
+            self.set('submitButtonClicked', false);
             this.hide();
           },
           onClose: function() {
@@ -1644,14 +1794,6 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
       return false;
     }
     App.set('router.nextBtnClickInProgress', true);
-    if (this.get('wizardController.name') === 'addServiceController' && this.get('hasChangedDependencies')) {
-      return this.showChangedDependentConfigs({}, this.proceedWithChecks.bind(this), this.setButtonClickFinish.bind(this));
-    } else {
-      return this.proceedWithChecks();
-    }
-  },
-
-  proceedWithChecks: function () {
     if (this.get('supportsPreInstallChecks')) {
       var preInstallChecksController = App.router.get('preInstallChecksController');
       if (preInstallChecksController.get('preInstallChecksWhereRun')) {
@@ -1662,26 +1804,28 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
     return this.postSubmit();
   },
 
-  setButtonClickFinish: function () {
-    this.set('submitButtonClicked', false);
-    App.set('router.nextBtnClickInProgress', false);
-  },
-
   postSubmit: function () {
-    var self = this;
     this.set('submitButtonClicked', true);
-    this.serverSideValidation().done(function() {
-      self.serverSideValidationCallback();
-    })
-      .fail(function (value) {
+    if (this.get('isInstallWizard')) {
+      this.serverSideValidationCallback();
+    } else {
+      this.serverSideValidation().done(() => {
+        this.serverSideValidationCallback();
+      }).fail(value => {
         if ("invalid_configs" === value) {
-          self.setButtonClickFinish();
+          if (this.get('isAddServiceWizard')) {
+            this.get('configErrorList.issues').clear();
+            this.get('configErrorList.criticalIssues').clear();
+          }
+          this.set('submitButtonClicked', false);
+          App.set('router.nextBtnClickInProgress', false);
         } else {
           // Failed due to validation mechanism failure.
           // Should proceed with other checks
-          self.serverSideValidationCallback();
+          this.serverSideValidationCallback();
         }
       });
+    }
   },
 
   /**
@@ -1726,5 +1870,307 @@ App.WizardStep7Controller = Em.Controller.extend(App.ServerValidatorMixin, App.E
 
   hasStepConfigIssues: function() {
     return !this.get('stepConfigs').filterProperty('showConfig', true).everyProperty('hasConfigIssues', false);
-  }.property('stepConfigs.@each.hasConfigIssues')
+  }.property('stepConfigs.@each.hasConfigIssues'),
+
+  checkDescriptor: function() {
+    if (App.get('isKerberosEnabled')) {
+      return App.ajax.send({
+        sender: self,
+        name: 'admin.kerberize.cluster_descriptor_artifact'
+      });
+    }
+    return $.Deferred().resolve().promise();
+  },
+
+  /**
+   * Store status of kerberos descriptor located in cluster artifacts.
+   * This status needed for Add Service Wizard to select appropriate method to create
+   * or update descriptor.
+   *
+   * @param  {Boolean} isExists <code>true</code> if cluster descriptor present
+   */
+  storeClusterDescriptorStatus: function(isExists) {
+    this.get('wizardController').setDBProperty('isClusterDescriptorExists', isExists);
+  },
+
+   /**
+   * Get all configs, that should be stored in kerberos_descriptor
+   * @returns {Array}
+   */
+  getDescriptorConfigs: function () {
+     return this.get('stepConfigs').reduce(function (allConfigs, service) {
+      return allConfigs.concat(service.get('configs').filterProperty('isSecureConfig'));
+    }, []);
+  },
+
+  selectService: function (event) {
+    this.get('stepConfigs').forEach((service) => {
+      service.set('isActive', service.get('serviceName') === event.context.serviceName);
+    });
+    this.set('selectedService', event.context);
+    var activeTabs = this.get('tabs').findProperty('isActive', true);
+    if (activeTabs) {
+      activeTabs.set('selectedServiceName', event.context.serviceName);
+    }
+  },
+
+  /**
+   * Set initial state for <code>tabs</code>
+   */
+  initTabs: function () {
+    var storedConfigs = this.get('content.serviceConfigProperties');
+    var tabs = [
+      Em.Object.create({
+        name: 'credentials',
+        displayName: 'Credentials',
+        icon: 'glyphicon-lock',
+        isActive: false,
+        isDisabled: false,
+        isSkipped: false,
+        validateOnSwitch: false,
+        tabView: App.CredentialsTabOnStep7View
+      }),
+      Em.Object.create({
+        name: 'databases',
+        displayName: 'Databases',
+        icon: 'glyphicon-align-justify',
+        isActive: false,
+        isDisabled: false,
+        isSkipped: false,
+        validateOnSwitch: false,
+        tabView: App.DatabasesTabOnStep7View
+      }),
+      Em.Object.create({
+        name: 'directories',
+        displayName: 'Directories',
+        icon: 'glyphicon-folder-open',
+        isActive: false,
+        isDisabled: false,
+        isSkipped: false,
+        validateOnSwitch: false,
+        selectedServiceName: null,
+        tabView: App.DirectoriesTabOnStep7View
+      }),
+      Em.Object.create({
+        name: 'accounts',
+        displayName: 'Accounts',
+        icon: 'glyphicon-user',
+        isActive: false,
+        isDisabled: false,
+        isSkipped: false,
+        validateOnSwitch: false,
+        tabView: App.AccountsTabOnStep7View
+      }),
+      Em.Object.create({
+        name: 'all-configurations',
+        displayName: 'All Configurations',
+        icon: 'glyphicon-wrench',
+        isActive: false,
+        isDisabled: false,
+        isSkipped: false,
+        validateOnSwitch: true,
+        selectedServiceName: null,
+        tabView: App.ServicesConfigView
+      })
+    ];
+
+    this.set('tabs', tabs);
+
+    this.setSkippedTabs();
+
+    if (storedConfigs && storedConfigs.length) {
+      tabs.findProperty('name', 'all-configurations').set('isActive', true);
+    } else {
+      tabs.findProperty('isDisabled', false).set('isActive', true);
+      this.disableTabs();
+    }
+
+  },
+
+  setSkippedTabs: function () {
+    var servicesWithCredentials = App.Tab.find().filterProperty('themeName', 'credentials').mapProperty('serviceName');
+    var servicesWithDatabase = App.Tab.find().filterProperty('themeName', 'database').mapProperty('serviceName');
+    var selectedServices = this.get('content.selectedServiceNames');
+    var tabs = this.get('tabs');
+    var disableCredentials = true;
+    var disableDatabases = true;
+
+    for (var i = 0; i < selectedServices.length; i++) {
+      var serviceName = selectedServices[i];
+      disableCredentials = disableCredentials && servicesWithCredentials.indexOf(serviceName) === -1;
+      disableDatabases = disableDatabases && servicesWithDatabase.indexOf(serviceName) === -1;
+      if (!disableCredentials && !disableDatabases) break;
+    }
+
+    tabs.findProperty('name', 'credentials').setProperties({
+      isDisabled: disableCredentials,
+      isSkipped: disableCredentials
+    });
+    tabs.findProperty('name', 'databases').setProperties({
+      isDisabled: disableDatabases,
+      isSkipped: disableDatabases
+    });
+  },
+
+  /**
+   * Get index of current (active) tab
+   */
+  currentTabIndex: function () {
+    return this.get('tabs').findIndex(function (tab) {
+      return tab.get('isActive');
+    });
+  }.property('tabs.@each.isActive'),
+
+  /**
+   * Get name of current (active) tab
+   */
+  currentTabName: function () {
+    var activeTab = this.get('tabs').findProperty('isActive');
+    return activeTab ? activeTab.get('name') : '';
+  }.property('tabs.@each.isActive'),
+
+  /**
+   * Make selected tab active, show tab's content
+   * @param event
+   * @returns {boolean}
+   */
+  selectTab: function (event) {
+    var tab = event.context;
+    if (!tab.get('isDisabled')) {
+      $('a[href=#' + tab.name + ']').tab('show');
+      this.get('tabs').setEach('isActive', false);
+      tab.set('isActive', true);
+    }
+    return false;
+  },
+
+  /**
+   * Get disabled state for next button
+   */
+  isNextDisabled: function () {
+    var tabName = this.get('currentTabName');
+    switch (tabName) {
+      case 'credentials':
+        return !this.get('credentialsTabNextEnabled');
+      case 'databases':
+        return !this.get('databasesTabNextEnabled');
+      case 'all-configurations':
+        return this.get('isSubmitDisabled');
+      default:
+        return false;
+    }
+  }.property('tabs.@each.isActive', 'isSubmitDisabled', 'credentialsTabNextEnabled', 'databasesTabNextEnabled'),
+
+  /**
+   * Set isDisabled state for tabs
+   */
+  disableTabs: function () {
+    this.get('tabs').rejectProperty('isSkipped').setEach('isDisabled', !this.get('tabs').findProperty('name', 'credentials').get('isDisabled') && !this.get('credentialsTabNextEnabled'));
+  }.observes('credentialsTabNextEnabled'),
+
+  /**
+   * Select specified service and put property name in filter input
+   * @param event - jQuery event
+   */
+  showConfigProperty: function (event) {
+    var serviceName = event.context.serviceName;
+    var propertyName = event.context.propertyName || event.context.name;
+    var stepConfig = this.get('stepConfigs').findProperty('serviceName', serviceName)
+      || this.get('stepConfigs').findProperty('displayName', serviceName);
+    this.set('selectedService', stepConfig);
+    this.get('filterColumns').setEach('selected', false);
+    Em.run.next(this, function () {
+      this.set('filter', propertyName);
+    });
+
+    this.get('stepConfigs').setEach('isActive', false);
+    stepConfig.set('isActive', true);
+  },
+
+  /**
+   * Show bell animation
+   */
+  ringBell: function () {
+    $('#issues-bell').addClass('animated');
+    $('#issues-counter').addClass('animated');
+    setTimeout(function () {
+      $('#issues-bell').removeClass('animated');
+    }, 2000);
+    setTimeout(function () {
+      $('#issues-counter').removeClass('animated');
+    }, 300);
+  },
+
+  /**
+   * Set <code>issuesCounter</code> and run bell animation if needed
+   */
+  setIssues: function () {
+    var recommendations = this.get('changedProperties.length');
+    var validations = this.get('stepConfigs').mapProperty('configsWithErrors.length').reduce(Em.sum, 0);
+    var configErrorList = this.get('configErrorList');
+    this.set('hasErrors', Boolean(validations + configErrorList.get('criticalIssues.length')));
+    this.set('issuesCounter', recommendations + validations + configErrorList.get('issues.length') + configErrorList.get('criticalIssues.length'));
+    if (validations !== this.get('validationsCounter')) {
+      this.ringBell();
+    }
+    this.set('validationsCounter', validations);
+  }.observes('changedProperties.length', 'stepConfigs.@each.configsWithErrors.length', 'configErrorList.issues.length', 'configErrorList.criticalIssues.length'),
+
+  /**
+   * Next button action handler
+   */
+  next: function (index) {
+    var tabs = this.get('tabs');
+    var currentTabIndex = typeof(index) === 'number' ? index : this.get('currentTabIndex');
+    if (tabs.length - 1 > currentTabIndex) {
+      tabs[currentTabIndex].set('isActive', false);
+      if (tabs[currentTabIndex + 1].get('isDisabled')) {
+        this.next(++currentTabIndex);
+      } else {
+        tabs[currentTabIndex + 1].set('isActive', true);
+      }
+    } else {
+      this.submit();
+    }
+  },
+
+  /**
+   * Back button action handler
+   */
+  back: function (index) {
+    var tabs = this.get('tabs');
+    var currentTabIndex = typeof(index) === 'number' ? index : this.get('currentTabIndex');
+    if (currentTabIndex > 0) {
+      tabs[currentTabIndex].set('isActive', false);
+      if (tabs[currentTabIndex - 1].get('isDisabled')) {
+        this.back(--currentTabIndex);
+      } else {
+        tabs[currentTabIndex - 1].set('isActive', true);
+      }
+    } else {
+      App.router.send('back');
+    }
+  },
+
+  updateConfigAttributesFromThemes: function () {
+    this.get('allSelectedServiceNames').forEach(serviceName => this.updateAttributesFromTheme(serviceName));
+  },
+
+  validateOnTabSwitch: function () {
+    const activeTab = this.get('tabs')[this.get('currentTabIndex')];
+    if (activeTab && activeTab.get('validateOnSwitch')) {
+      if (this.get('requestTimer')) {
+        clearTimeout(this.get('requestTimer'));
+      }
+      if (this.get('validationRequest')) {
+        this.get('validationRequest').abort();
+      }
+      if (this.get('recommendationsInProgress')) {
+        this.valueObserver();
+      } else {
+        this.runServerSideValidation().done(() => this.set('validationRequest', null));
+      }
+    }
+  }.observes('currentTabIndex')
+
 });
