@@ -18,7 +18,7 @@
 
 var App = require('app');
 var stringUtils = require('utils/string_utils');
-var validator = require('utils/validator');
+var fileUtils = require('utils/file_utils');
 
 App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wizardDeployProgressControllerMixin, App.ConfigOverridable, App.ConfigsSaverMixin, {
 
@@ -226,7 +226,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    */
   formatProperties: function () {
     this.get('content.serviceConfigProperties').forEach(function (_configProperty) {
-      _configProperty.value = (typeof _configProperty.value === "boolean")
+      _configProperty.value = typeof _configProperty.value === "boolean"
         ? _configProperty.value.toString() : App.config.trimProperty(_configProperty, false);
     });
   },
@@ -251,7 +251,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
     var hosts = [];
     for (var hostName in allHosts) {
       if (allHosts.hasOwnProperty(hostName)) {
-        if (allHosts[hostName].bootStatus == 'REGISTERED') {
+        if (allHosts[hostName].bootStatus === 'REGISTERED') {
           allHosts[hostName].hostName = allHosts[hostName].name;
           hosts.pushObject(allHosts[hostName]);
         }
@@ -283,7 +283,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
     var totalHostsCount = 0;
     var hosts = this.get('content.hosts');
     for (var hostName in hosts) {
-      newHostsCount += ~~(!hosts[hostName].isInstalled);
+      newHostsCount += ~~!hosts[hostName].isInstalled;
       totalHostsCount++;
     }
 
@@ -292,7 +292,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
     this.get('clusterInfo').pushObject(Em.Object.create(totalHostsObj));
 
     //repo
-    if (['addHostController', 'addServiceController'].contains(this.get('content.controllerName'))) {
+    if (this.get('isAddService') || this.get('isAddHost')) {
       // For some stacks there is no info regarding stack versions to upgrade, e.g. HDP-2.1
       if (App.StackVersion.find().get('content.length')) {
         this.loadRepoInfo();
@@ -301,7 +301,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
       }
     } else {
       // from install wizard
-      var selectedStack = App.Stack.find().findProperty('isSelected');
+      var selectedStack = App.Stack.find().findProperty('isSelected', true);
       var allRepos = [];
       if (selectedStack && selectedStack.get('operatingSystems')) {
         selectedStack.get('operatingSystems').forEach(function (os) {
@@ -331,9 +331,17 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    */
   loadRepoInfo: function () {
     var stackName = App.get('currentStackName');
-    var currentStackVersionNumber = App.get('currentStackVersionNumber');
-    var currentStackVersion = App.StackVersion.find().filterProperty('stack', stackName).findProperty('version', currentStackVersionNumber);
-    var currentRepoVersion = currentStackVersion.get('repositoryVersion.repositoryVersion');
+
+    var currentRepoVersion;
+    App.RepositoryVersion.find().forEach(function (repoVersion) {
+      if (repoVersion.get('stackVersionType') === stackName && repoVersion.get('isCurrent') && repoVersion.get('isStandard')) {
+        currentRepoVersion = repoVersion.get('repositoryVersion');
+      }
+    });
+
+    if (!currentRepoVersion) {
+      console.error('Error while getting current stack repository version');
+    }
 
     return App.ajax.send({
       name: 'cluster.load_repo_version',
@@ -417,10 +425,9 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
   },
 
   /**
-   * @param {object} request
    * @method loadRepoInfoErrorCallback
    */
-  loadRepoInfoErrorCallback: function (request) {
+  loadRepoInfoErrorCallback: function () {
     var allRepos = [];
     allRepos.set('display_name', Em.I18n.t("installer.step8.repoInfo.displayName"));
     this.get('clusterInfo').set('repoInfo', allRepos);
@@ -443,7 +450,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
         // no HA component
         if (component.get('isHAComponentOnly')) return;
         // skip if component is not allowed on single node cluster
-        if (Object.keys(this.get('content.hosts')).length == 1 && component.get('isNotAllowedOnSingleNodeCluster')) return;
+        if (Object.keys(this.get('content.hosts')).length === 1 && component.get('isNotAllowedOnSingleNodeCluster')) return;
         var displayName;
         if (component.get('isClient')) {
           displayName = Em.I18n.t('common.clients')
@@ -498,7 +505,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
         var componentName = component.get('isClient') ? Em.I18n.t('common.client').toUpperCase() : component.get('componentName');
         var hostsLength = this.get('content.slaveComponentHosts')
           .findProperty('componentName', componentName).hosts.length;
-        componentValue = hostsLength + Em.I18n.t('installer.step8.host' + ((hostsLength > 1) ? 's' : ''));
+        componentValue = hostsLength + Em.I18n.t('installer.step8.host' + (hostsLength > 1 ? 's' : ''));
       }
     }
     return componentValue;
@@ -540,7 +547,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    */
   loadHbaseMasterValue: function (hbaseMaster) {
     var hbaseHostName = this.get('content.masterComponentHosts').filterProperty('component', hbaseMaster.component_name);
-    if (hbaseHostName.length == 1) {
+    if (hbaseHostName.length === 1) {
       hbaseMaster.set('component_value', hbaseHostName[0].hostName);
     } else {
       hbaseMaster.set('component_value', hbaseHostName[0].hostName + " " + Em.I18n.t('installer.step8.other').format(hbaseHostName.length - 1));
@@ -592,7 +599,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
     var selectedServiceNames = this.get('selectedServices').mapProperty('serviceName');
     var installedServiceNames = this.get('installedServices').mapProperty('serviceName');
 
-    if (this.get('content.controllerName') === 'addServiceController' && selectedServiceNames.contains('OOZIE')) {
+    if (this.get('isAddService') && selectedServiceNames.contains('OOZIE')) {
       var affectedServices = ['HDFS', 'YARN'].filter(function(serviceName) {
         return installedServiceNames.contains(serviceName);
       });
@@ -632,12 +639,12 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
   checkKDCSession: function() {
     var self = this;
     var wizardController = App.router.get(this.get('content.controllerName'));
-    if (this.get('content.controllerName') != 'installerController') {
+    if (!this.get('isInstaller')) {
       App.get('router.mainAdminKerberosController').getKDCSessionState(this.submitProceed.bind(this), function () {
         self.set('isSubmitDisabled', false);
         self.set('isBackBtnDisabled', false);
         wizardController.setStepsEnable();
-        if (self.get('content.controllerName') === 'addServiceController') {
+        if (self.get('isAddService')) {
           wizardController.setSkipSlavesStep(wizardController.getDBProperty('selectedServiceNames'), 3);
         }
       });
@@ -654,7 +661,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
     var self = this;
     this.set('clusterDeleteRequestsCompleted', 0);
     this.get('clusterDeleteErrorViews').clear();
-    if (this.get('content.controllerName') == 'addHostController') {
+    if (this.get('isAddHost')) {
       App.router.get('addHostController').setLowerStepsDisable(4);
     }
 
@@ -692,7 +699,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
     // TODO: modify for multi-cluster support
     this.getExistingClusterNames().complete(function () {
       var clusterNames = self.get('clusterNames');
-      if (self.get('content.controllerName') == 'installerController' && (!App.get('testMode')) && clusterNames.length) {
+      if (self.get('isInstaller') && !App.get('testMode') && clusterNames.length) {
         self.deleteClusters(clusterNames);
       } else {
         self.getExistingVersions();
@@ -748,7 +755,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
         sender: this,
         data: {
           name: clusterName,
-          isLast: index == clusterNames.length - 1
+          isLast: index === clusterNames.length - 1
         },
         success: 'deleteClusterSuccessCallback',
         error: 'deleteClusterErrorCallback'
@@ -837,7 +844,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    * @method getExistingVersionsSuccessCallback
    */
   getExistingVersionsSuccessCallback: function (data) {
-    if (this.get('content.controllerName') == 'installerController' && (!App.get('testMode')) && data.items.length) {
+    if (this.get('isInstaller') && !App.get('testMode') && data.items.length) {
       this.set('existingRepositoryVersions', data.items.length);
       this.deleteExistingVersions(data.items);
     } else {
@@ -881,7 +888,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    * @method updateKerberosDescriptor
    */
   updateKerberosDescriptor: function(instant) {
-    var kerberosDescriptor = App.db.get('KerberosWizard', 'kerberosDescriptorConfigs');
+    var kerberosDescriptor = this.get('wizardController').getDBProperty('kerberosDescriptorConfigs');
     var descriptorExists = this.get('wizardController').getDBProperty('isClusterDescriptorExists') === true;
 
     var ajaxOpts = {
@@ -889,7 +896,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
       data: {
         artifactName: 'kerberos_descriptor',
         data: {
-          artifact_data: kerberosDescriptor
+          artifact_data: this.removeIdentityReferences(kerberosDescriptor)
         }
       }
     };
@@ -906,7 +913,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    * @method startDeploy
    */
   startDeploy: function () {
-    if (this.get('content.controllerName') !== 'installerController') {
+    if (!this.get('isInstaller')) {
       this._startDeploy();
     } else {
       var installerController = App.router.get('installerController');
@@ -937,8 +944,8 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
   _startDeploy: function () {
     this.createCluster();
     this.createSelectedServices();
-    if (this.get('content.controllerName') !== 'addHostController') {
-      if (this.get('content.controllerName') === 'addServiceController') {
+    if (!this.get('isAddHost')) {
+      if (this.get('isAddService')) {
         // for manually enabled Kerberos descriptor was updated on transition to this step
         if (App.get('isKerberosEnabled') && !this.get('isManualKerberos')) {
           this.updateKerberosDescriptor();
@@ -956,7 +963,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
     this.createConfigurationGroups();
     this.createMasterHostComponents();
     this.createSlaveAndClientsHostComponents();
-    if (this.get('content.controllerName') === 'addServiceController') {
+    if (this.get('isAddService')) {
       this.createAdditionalClientComponents();
     }
     this.createAdditionalHostComponents();
@@ -978,13 +985,12 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    * @method createCluster
    */
   createCluster: function () {
-    if (this.get('content.controllerName') !== 'installerController') return;
-    var stackVersion = (this.get('content.installOptions.localRepo')) ? App.currentStackVersion.replace(/(-\d+(\.\d)*)/ig, "Local$&") : App.currentStackVersion;
-    var selectedStack = App.Stack.find().findProperty('isSelected', true);
+    if (!this.get('isInstaller')) return;
+    var stackVersion = this.get('content.installOptions.localRepo') ? App.currentStackVersion.replace(/(-\d+(\.\d)*)/ig, "Local$&") : App.currentStackVersion;
     this.addRequestToAjaxQueue({
       name: 'wizard.step8.create_cluster',
       data: {
-        data: JSON.stringify({ "Clusters": {"version": stackVersion, "repository_version": selectedStack.get('repositoryVersion')}})
+        data: JSON.stringify({ "Clusters": {"version": stackVersion}})
       },
       success: 'createClusterSuccess'
     });
@@ -1021,9 +1027,9 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
     if (this.get('isInstaller')) {
       selectedStack = App.Stack.find().findProperty('isSelected', true);
     }
-    return this.get('selectedServices').map(function(service) {return selectedStack ?
+    return this.get('selectedServices').map(service => selectedStack ?
       {"ServiceInfo": { "service_name": service.get('serviceName'), "desired_repository_version_id": selectedStack.get('versionInfoId') }} :
-      {"ServiceInfo": { "service_name": service.get('serviceName') }}});
+      {"ServiceInfo": { "service_name": service.get('serviceName') }});
   },
 
   /**
@@ -1033,7 +1039,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    * @method createComponents
    */
   createComponents: function () {
-    var serviceComponents = App.StackServiceComponent.find();
+    var serviceComponents = App.StackServiceComponent.find().filterProperty('isInstallable');
     this.get('selectedServices').forEach(function (_service) {
       var serviceName = _service.get('serviceName');
       var componentsData = serviceComponents.filterProperty('serviceName', serviceName).map(function (_component) {
@@ -1045,7 +1051,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
       this.addRequestToCreateComponent(componentsData, serviceName);
     }, this);
 
-    if (this.get('content.controllerName') === 'addHostController') {
+    if (this.get('isAddHost')) {
       var allServiceComponents = [];
       var services = App.Service.find().mapProperty('serviceName');
       services.forEach(function(_service){
@@ -1162,33 +1168,36 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
       return this.get('selectedServices').mapProperty('serviceName').contains(_component.serviceId)
     }, this);
     selectedMasterComponents.mapProperty('component').uniq().forEach(function (component) {
+      var hostNames = [];
       if (masterOnAllHosts.length > 0) {
         var compOnAllHosts = false;
         for (var i=0; i < masterOnAllHosts.length; i++) {
-          if (component == masterOnAllHosts[i]) {
+          if (component === masterOnAllHosts[i]) {
             compOnAllHosts = true;
             break;
           }
         }
         if (!compOnAllHosts) {
-          var hostNames = selectedMasterComponents.filterProperty('component', component).filterProperty('isInstalled', false).mapProperty('hostName');
+          hostNames = selectedMasterComponents.filterProperty('component', component).filterProperty('isInstalled', false).mapProperty('hostName');
           this.registerHostsToComponent(hostNames, component);
         }
       } else {
-        var hostNames = selectedMasterComponents.filterProperty('component', component).filterProperty('isInstalled', false).mapProperty('hostName');
+        hostNames = selectedMasterComponents.filterProperty('component', component).filterProperty('isInstalled', false).mapProperty('hostName');
         this.registerHostsToComponent(hostNames, component);
       }
     }, this);
   },
 
   getClientsMap: function (flag) {
-    var clientNames = App.StackServiceComponent.find().filterProperty('isClient').mapProperty('componentName'),
+    var clients = App.StackServiceComponent.find().filterProperty('isClient'),
       clientsMap = {},
       dependedComponents = flag ? App.StackServiceComponent.find().filterProperty(flag) : App.StackServiceComponent.find();
-    clientNames.forEach(function (clientName) {
+    clients.forEach(function (client) {
+      var clientName = client.get('componentName');
       clientsMap[clientName] = Em.A([]);
       dependedComponents.forEach(function (component) {
-        if (component.get('dependencies').mapProperty('componentName').contains(clientName)) clientsMap[clientName].push(component.get('componentName'));
+        if (component.dependsOn(client))
+          clientsMap[clientName].push(component.get('componentName'));
       });
       if (!clientsMap[clientName].length) delete clientsMap[clientName];
     });
@@ -1233,11 +1242,13 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
         clientsToSlaveMap = this.getClientsMap('isSlave');
 
     slaveHosts.forEach(function (_slave) {
+      var hostNames = [];
+      var compOnAllHosts;
       if (_slave.componentName !== 'CLIENT') {
         if (slaveOnAllHosts.length > 0) {
-          var compOnAllHosts = false;
+          compOnAllHosts = false;
           for (var i=0; i < slaveOnAllHosts.length; i++) {
-            if (_slave.componentName == slaveOnAllHosts[i]) {
+            if (_slave.componentName === slaveOnAllHosts[i]) {
               // component with ALL cardinality should not
               // registerHostsToComponent in createSlaveAndClientsHostComponents
               compOnAllHosts = true;
@@ -1245,20 +1256,20 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
             }
           }
           if (!compOnAllHosts) {
-            var hostNames = _slave.hosts.filterProperty('isInstalled', false).mapProperty('hostName');
+            hostNames = _slave.hosts.filterProperty('isInstalled', false).mapProperty('hostName');
             this.registerHostsToComponent(hostNames, _slave.componentName);
           }
         } else {
-          var hostNames = _slave.hosts.filterProperty('isInstalled', false).mapProperty('hostName');
+          hostNames = _slave.hosts.filterProperty('isInstalled', false).mapProperty('hostName');
           this.registerHostsToComponent(hostNames, _slave.componentName);
         }
       }
       else {
         clients.forEach(function (_client) {
-          var hostNames = _slave.hosts.mapProperty('hostName');
+          hostNames = _slave.hosts.mapProperty('hostName');
           // The below logic to install clients to existing/New master hosts should not be applied to Add Host wizard.
           // This is with the presumption that Add Host controller does not add any new Master component to the cluster
-          if (this.get('content.controllerName') !== 'addHostController') {
+          if (!this.get('isAddHost')) {
             if (clientsToMasterMap[_client.component_name]) {
               clientsToMasterMap[_client.component_name].forEach(function (componentName) {
                 masterHosts.filterProperty('component', componentName).forEach(function (_masterHost) {
@@ -1275,9 +1286,9 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
             });
           }
           if (clientOnAllHosts.length > 0) {
-            var compOnAllHosts = false;
+            compOnAllHosts = false;
             for (var i=0; i < clientOnAllHosts.length; i++) {
-              if (_client.component_name == clientOnAllHosts[i]) {
+              if (_client.component_name === clientOnAllHosts[i]) {
                 // component with ALL cardinality should not
                 // registerHostsToComponent in createSlaveAndClientsHostComponents
                 compOnAllHosts = true;
@@ -1407,7 +1418,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
     var hiveService = this.get('content.services').filterProperty('isSelected', true).filterProperty('isInstalled', false).findProperty('serviceName', 'HIVE');
     if (hiveService) {
       var hiveDb = this.get('content.serviceConfigProperties').findProperty('name', 'hive_database');
-      if (hiveDb.value == "New MySQL Database") {
+      if (hiveDb.value === "New MySQL Database") {
         this.registerHostsToComponent(masterHosts.filterProperty('component', 'HIVE_SERVER').mapProperty('hostName'), 'MYSQL_SERVER');
       } else if (hiveDb.value === "New PostgreSQL Database") {
         this.registerHostsToComponent(masterHosts.filterProperty('component', 'HIVE_SERVER').mapProperty('hostName'), 'POSTGRESQL_SERVER');
@@ -1460,11 +1471,9 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    * @method createConfigurations
    */
   createConfigurations: function () {
-    var tag = this.getServiceConfigVersion();
-
     if (this.get('isInstaller')) {
       /** add cluster-env **/
-      this.get('serviceConfigTags').pushObject(this.createDesiredConfig('cluster-env', tag, this.get('configs').filterProperty('filename', 'cluster-env.xml')));
+      this.get('serviceConfigTags').pushObject(this.createDesiredConfig('cluster-env', this.get('configs').filterProperty('filename', 'cluster-env.xml')));
     }
 
     this.get('selectedServices').forEach(function (service) {
@@ -1472,22 +1481,13 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
         if (!this.get('serviceConfigTags').someProperty('type', type)) {
           var configs = this.get('configs').filterProperty('filename', App.config.getOriginalFileName(type));
           var serviceConfigNote = this.getServiceConfigNote(type, service.get('displayName'));
-          this.get('serviceConfigTags').pushObject(this.createDesiredConfig(type, tag, configs, serviceConfigNote));
+          this.get('serviceConfigTags').pushObject(this.createDesiredConfig(type, configs, serviceConfigNote));
         }
       }, this);
     }, this);
     this.createNotification();
   },
 
-  /**
-   * Get config version tag
-   *
-   * @returns {string}
-   */
-  getServiceConfigVersion: function() {
-    return 'version' + (this.get('isAddService') ? (new Date).getTime() : '1');
-  },
-
   /**
    * Get config version message
    *
@@ -1496,7 +1496,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    * @returns {*}
    */
   getServiceConfigNote: function(type, serviceDisplayName) {
-    return (this.get('isAddService') && (type === 'core-site')) ?
+    return this.get('isAddService') && type === 'core-site' ?
       Em.I18n.t('dashboard.configHistory.table.notes.addService') : Em.I18n.t('dashboard.configHistory.table.notes.default').format(serviceDisplayName);
   },
 
@@ -1661,11 +1661,11 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
    * @method createNotification
    */
   createNotification: function () {
-    if (this.get('content.controllerName') !== 'installerController') return;
+    if (!this.get('isInstaller')) return;
     var miscConfigs = this.get('configs').filterProperty('serviceName', 'MISC'),
       createNotification = miscConfigs.findProperty('name', 'create_notification').value;
     if (createNotification !== 'yes') return;
-      var predefinedNotificationConfigNames = require('data/HDP2/alert_notification').mapProperty('name'),
+      var predefinedNotificationConfigNames = require('data/configs/alert_notification').mapProperty('name'),
       configsForNotification = this.get('configs').filterProperty('filename', 'alert_notification');
     var properties = {},
       names = [
@@ -1717,7 +1717,7 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
   showLoadingIndicator: function () {
     return App.ModalPopup.show({
 
-      header: '',
+      header: Em.I18n.t('installer.step8.deployPopup.header'),
 
       showFooter: false,
 
@@ -1743,14 +1743,14 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
         message: '',
 
         /**
-         * Set progress bar width and popup message when ajax-queue requests are proccessed
+         * Set progress bar width and popup message when ajax-queue requests are processed
          * @method ajaxQueueChangeObs
          */
         ajaxQueueChangeObs: function () {
           var length = this.get('controller.ajaxQueueLength');
           var left = this.get('controller.ajaxRequestsQueue.queue.length');
-          this.set('barWidth', 'width: ' + ((length - left) / length * 100) + '%;');
-          this.set('message', Em.I18n.t('installer.step8.deployPopup.message').format((length - left), length));
+          this.set('barWidth', 'width: ' + (length - left) / length * 100 + '%;');
+          this.set('message', Em.I18n.t('installer.step8.deployPopup.message').format(length - left, length));
         }.observes('controller.ajaxQueueLength', 'controller.ajaxRequestsQueue.queue.length'),
 
         /**
@@ -1761,12 +1761,285 @@ App.WizardStep8Controller = Em.Controller.extend(App.AddSecurityConfigs, App.wiz
           if (this.get('controller.servicesInstalled')) {
             this.get('parentView').hide();
           }
-        }.observes('controller.servicesInstalled')
+        }.observes('controller.servicesInstalled'),
+
+        ajaxQueueErrorAppears: function () {
+          if (this.get('controller.hasErrorOccurred')) {
+            this.get('parentView').onClose();
+          }
+        }.observes('controller.hasErrorOccurred')
+
       })
 
     });
   },
 
+  getComponentsForHost: function(host) {
+    if(!host.hostComponents) {
+      App.router.get('installerController').get('allHosts');
+    }
+    var componentNameDetail = [];
+    host.hostComponents.mapProperty('componentName').forEach(function (componentName) {
+      if(componentName === 'CLIENT') {
+        this.get('content.clients').mapProperty('component_name').forEach(function (clientComponent) {
+          componentNameDetail.push({ name : clientComponent });
+        }, this);
+        return;
+      }
+      componentNameDetail.push({ name : componentName });
+    }, this);
+    return componentNameDetail;
+  },
+
+  getPropertyAttributesForConfigType : function(configs) {
+    //Currently only looks for final properties, if any
+    var finalProperties = configs.filterProperty('isFinal', 'true');
+    var propertyAttributes = {};
+    finalProperties.forEach(function (finalProperty) {
+      propertyAttributes[finalProperty['name']] = "true";
+    });
+    var finalPropertyMap = {};
+    if (!App.isEmptyObject(finalProperties)) {
+      finalPropertyMap = {
+        "isFinal": propertyAttributes
+      };
+    }
+    return finalPropertyMap;
+  },
+
+  getConfigurationDetailsForConfigType: function(configs) {
+    var configDetails = {};
+    var self = this;
+    configs.forEach(function (propertyObj) {
+      configDetails[propertyObj['name']] = propertyObj['value'];
+    }, this);
+    var configurationsDetails = {
+      "properties_attributes": self.getPropertyAttributesForConfigType(configs),
+      "properties": configDetails
+    };
+    return configurationsDetails;
+  },
+
+  hostInExistingHostGroup: function (newHost, host_groups) {
+    var hostGroupMatched = false;
+      host_groups.some(function (existingHostGroup) {
+        if(!hostGroupMatched) {
+        var fqdnInHostGroup =  existingHostGroup.hosts[0].fqdn;
+        var componentsInExistingHostGroup = this.getRegisteredHosts().filterProperty('hostName', fqdnInHostGroup)[0].hostComponents;
+        if(componentsInExistingHostGroup.length !== newHost.hostComponents.length) {
+          return;
+        } else {
+          var componentMismatch = false;
+          componentsInExistingHostGroup.forEach(function (componentInExistingHostGroup, index) {
+          if(!componentMismatch) {
+            if(!newHost.hostComponents.mapProperty('componentName').includes(componentInExistingHostGroup.componentName)) {
+              componentMismatch = true;
+            }
+          }
+          });
+          if(!componentMismatch) {
+            hostGroupMatched = true;
+            existingHostGroup["cardinality"] = parseInt(existingHostGroup["cardinality"]) + 1;
+            existingHostGroup.hosts.push({"fqdn" : newHost.hostName});
+            return true;
+          }
+        }
+        }
+      }, this);
+    return hostGroupMatched;
+  },
+
+   hostInChildHostGroup: function (presentHostGroup, configGroupName, hostInConfigGroup) {
+    return  presentHostGroup['childHostGroups'].some(function (childHostGroup) {
+      //Check if childHostGroup name is same as this configgroupname, if yes, update childHostGroup else, compare with other childhostgroups
+      if(childHostGroup.configGroupName === configGroupName) {
+        childHostGroup.hosts.push( { "fqdn" : hostInConfigGroup } );
+        childHostGroup['cardinality'] = childHostGroup['cardinality'] + 1;
+        return true;
+      }
+      });
+  },
+
+  /**
+   * Confirmation popup before generate blueprint
+   */
+  generateBlueprintConfirmation: function () {
+    var self = this;
+    return App.showConfirmationPopup(function () {
+      self.generateBlueprint();
+      }, Em.I18n.t('installer.step8.generateBlueprint.popup.msg').format(App.clusterStatus.clusterName)
+    );
+  },
+
+  generateBlueprint: function () {
+    console.log("Prepare blueprint for download...");
+    var self = this;
+    //service configurations
+    var totalConf = [];
+    //Add cluster-env
+    var clusterEnv = this.get('configs').filterProperty('filename', 'cluster-env.xml');
+    var configurations = {};
+    configurations["cluster-env"] = self.getConfigurationDetailsForConfigType(clusterEnv);
+    totalConf.push(configurations);
+    //Add configurations for selected services
+    this.get('selectedServices').forEach(function (service) {
+      Object.keys(service.get('configTypes')).forEach(function (type) {
+        if (!this.get('serviceConfigTags').someProperty('type', type)) {
+          var configs = this.get('configs').filterProperty('filename', App.config.getOriginalFileName(type));
+          var configurations = {};
+          configurations[type] = self.getConfigurationDetailsForConfigType(configs);
+          totalConf.push(configurations);
+        }
+      }, this);
+    }, this);
+
+    var host_groups = [];
+    var cluster_template_host_groups = [];
+    var counter = 0;
+
+    this.getRegisteredHosts().filterProperty('isInstalled', false).map(function (host) {
+      if(self.hostInExistingHostGroup(host, host_groups)) {
+        return;
+      }
+      //Create new host_group if host is not mapped to existing host_groups
+      var hostGroupId = "host_group_" + counter;
+      var hostListForGroup = [];
+      hostListForGroup.push({ "fqdn": host.hostName });
+      var hostGroupDetail = {
+        "name": hostGroupId,
+        "components": self.getComponentsForHost(host),
+        "hosts": hostListForGroup,
+        "cardinality" : 1
+      };
+      hostGroupDetail.toJSON = function () {
+        var hostGroupDetailResult = _.omit(this, [ "hosts", "childHostGroups" ]);
+        hostGroupDetailResult["cardinality"] = this["cardinality"].toString();
+        return hostGroupDetailResult;
+      };
+      host_groups.push(hostGroupDetail);
+
+      var clusterTemplateHostGroupDetail = {
+        "name": hostGroupId,
+        "hosts": hostListForGroup
+      };
+
+      cluster_template_host_groups.push(clusterTemplateHostGroupDetail);
+      counter++;
+    }, this);
+
+    this.get('content.configGroups').filterProperty("is_default", false).forEach(function (configGroup) {
+      if (configGroup.properties.length == 0) {
+        return;
+      }
+      configGroup.hosts.forEach(function (hostInConfigGroup) {
+        return host_groups.some(function (presentHostGroup) {
+          return presentHostGroup.hosts.some(function (hostInPresentHostGroup, index) {
+            if (hostInConfigGroup !== hostInPresentHostGroup.fqdn) {
+              return;
+            }
+            //Check if childHostGroup already created
+            if (presentHostGroup['childHostGroups']) {
+             if (self.hostInChildHostGroup(presentHostGroup, configGroup.name, hostInConfigGroup)) {
+               // Update to remove parentHostGroup as all the hosts are added to childHostGroup/s
+               presentHostGroup.hosts.splice(index, 1);
+               presentHostGroup["cardinality"] = presentHostGroup['cardinality'] - 1;
+               return true;
+             }
+            }
+            //create configuration object
+            var hgConfigurations;
+            if(presentHostGroup.hosts.length === 1 && presentHostGroup["configurations"]) {
+              hgConfigurations = presentHostGroup["configurations"][0];
+            } else if (presentHostGroup["configurations"]) { //Deep copy
+                hgConfigurations = jQuery.extend(true, {}, presentHostGroup["configurations"][0]);
+            } else {
+                hgConfigurations = {};
+            }
+            configGroup.properties.forEach(function (hgProperties) {
+              var type = App.config.getConfigTagFromFileName(hgProperties.filename);
+              if (!hgConfigurations[type]) {
+                hgConfigurations[type] = { properties: {} };
+              }
+              hgConfigurations[type]['properties'][hgProperties.name] = hgProperties.value;
+            });
+            var totalHgConf = [];
+            totalHgConf.push(hgConfigurations);
+            //If only host in presentHostGroup then merge configuration and return
+            if (presentHostGroup.hosts.length === 1) {
+              //If host_group already has configuration, assigned from previously processed config_group
+              if(!presentHostGroup["configurations"]) {
+                presentHostGroup["configurations"] = totalHgConf;
+              }
+              return true;
+            }
+
+            //Create new host_group from this host
+            var hostGroupId = "host_group_" + counter;
+            counter++;
+            var hostListForGroup = [];
+            hostListForGroup.push({ "fqdn": hostInPresentHostGroup.fqdn });
+            var hostGroupDetail = {
+              "name": hostGroupId,
+              "components": presentHostGroup.components,
+              "cardinality": 1,
+              "hosts": hostListForGroup,
+              "configurations": totalHgConf,
+              "configGroupName": configGroup.name
+            };
+            hostGroupDetail.toJSON = function () {
+              var hostGroupDetailResult = _.omit(this, [ "hosts", "configGroupName", "childHostGroups" ]);
+              hostGroupDetailResult["cardinality"] = this["cardinality"].toString();
+              return hostGroupDetailResult;
+            };
+            host_groups.push(hostGroupDetail);
+            //Update for clustertemplate file
+            var clusterTemplateHostGroupDetail = {
+              "name": hostGroupId,
+              "hosts": hostListForGroup
+            };
+            cluster_template_host_groups.push(clusterTemplateHostGroupDetail);
+            //Add newly created host_group as child to existing host_group
+            if (!presentHostGroup['childHostGroups']) {
+              presentHostGroup['childHostGroups'] = [];
+            }
+            presentHostGroup['childHostGroups'].push(hostGroupDetail);
+            presentHostGroup.hosts.splice(index, 1);
+            presentHostGroup["cardinality"] = presentHostGroup['cardinality'] - 1;
+            //return true to indicate that host has been matched
+            return true;
+          }, this);
+        }, this);
+      }, this);
+    }, this);
+
+    const selectedStack = App.Stack.find().findProperty('isSelected', true);
+    const blueprint = {
+        'configurations': totalConf,
+        'host_groups': host_groups.filter(function (item) { return item.cardinality > 0; }),
+        'Blueprints': {'blueprint_name' : App.clusterStatus.clusterName, 'stack_name':selectedStack.get('stackName'), 'stack_version':selectedStack.get('stackVersion')}
+    };
+    const cluster_template = {
+      "blueprint": App.clusterStatus.clusterName,
+      "config_recommendation_strategy" : "NEVER_APPLY",
+      "provision_action" : "INSTALL_AND_START",
+      "configurations": [],
+      "host_groups": cluster_template_host_groups.filter(function (item) { return item.hosts.length > 0; }),
+      "Clusters": {'cluster_name': App.clusterStatus.clusterName}
+    };
+    fileUtils.downloadFilesInZip([
+      {
+        data: JSON.stringify(blueprint),
+        type: 'json',
+        name: 'blueprint.json'
+      },
+      {
+        data: JSON.stringify(cluster_template),
+        type: 'json',
+        name: 'clustertemplate.json'
+      }
+    ]);
+  },
+
   downloadCSV: function() {
     App.router.get('kerberosWizardStep5Controller').getCSVData(false);
   }
