@@ -22,9 +22,6 @@ App.HBaseService = App.Service.extend({
   regionServersStarted: DS.attr('number'),
   regionServersInstalled: DS.attr('number'),
   regionServersTotal: DS.attr('number'),
-  restServersStarted: DS.attr('number'),
-  restServersInstalled: DS.attr('number'),
-  restServersTotal: DS.attr('number'),
   phoenixServersStarted: DS.attr('number'),
   phoenixServersInstalled: DS.attr('number'),
   phoenixServersTotal: DS.attr('number'),
