@@ -322,6 +322,29 @@ Array.prototype.toWickMap = function () {
   return ret;
 };
 
+if (!Array.prototype.findIndex) {
+  Array.prototype.findIndex = function (predicate) {
+    if (this == null) {
+      throw new TypeError('"this" is null or not defined');
+    }
+    var o = Object(this),
+      len = o.length >>> 0;
+    if (typeof predicate !== 'function') {
+      throw new TypeError('predicate must be a function');
+    }
+    var thisArg = arguments[1],
+      k = 0;
+    while (k < len) {
+      var kValue = o[k];
+      if (predicate.call(thisArg, kValue, k, o)) {
+        return k;
+      }
+      k++;
+    }
+    return -1;
+  };
+}
+
 /** @namespace Em **/
 Em.CoreObject.reopen({
   t:function (key, attrs) {
@@ -360,6 +383,67 @@ Em.Handlebars.registerHelper('highlight', function (property, words, fn) {
   return new Em.Handlebars.SafeString(property);
 });
 
+/**
+ * Usage:
+ *
+ * <div {{QAAttr "someText"}}></div>
+ * <div {{QAAttr "{someProperty}"}}></div>
+ * <div {{QAAttr "someText-and-{someProperty}"}}></div>
+ * <div {{QAAttr "{someProperty:some-text}"}}></div>
+ * <div {{QAAttr "someText-and-{someProperty:some-text}"}}></div>
+ * <div {{QAAttr "{someProperty:some-text:another-text}"}}></div>
+ * <div {{QAAttr "someText-and-{someProperty:some-text:another-text}"}}></div>
+ * <div {{QAAttr "{someProperty::another-text}"}}></div>
+ * <div {{QAAttr "someText-and-{someProperty::another-text}"}}></div>
+ *
+ */
+Em.Handlebars.registerHelper('QAAttr', function (text, options) {
+  const textToReplace = text.match(/\{(.*?)\}/g);
+  let attributes;
+  if (textToReplace) {
+    const id = ++Em.$.uuid,
+      expressions = textToReplace.map((str) => {
+        const parsed = Em.View._parsePropertyPath(str.slice(1, str.length - 1)),
+          normalized = Ember.Handlebars.normalizePath(this, parsed.path, options.data),
+          {classNames, className, falsyClassName} = parsed,
+          {root, path} = normalized;
+        return {src: str, classNames, className, falsyClassName, root, path};
+      }),
+      observer = () => {
+        let dataQA = text;
+        for (let i = expressions.length; i--;) {
+          const el = Em.tryInvoke(options.data.view, '$', [`[${attributes}]`]);
+          let e = expressions[i];
+          if (!el || el.length === 0) {
+            Em.removeObserver(e.root, e.path, invoker);
+            break;
+          }
+          let value,
+            sourceValue = Em.Handlebars.getPath(e.root, e.path, options.data);
+          if (e.classNames) {
+            value = sourceValue ? e.className : e.falsyClassName;
+          } else {
+            value = sourceValue;
+          }
+          if (Em.isNone(value)) {
+            value = '';
+          }
+          dataQA = dataQA.replace(e.src, value);
+          el.attr('data-qa', dataQA);
+        }
+      },
+      invoker = () => Em.run.once(observer);
+    attributes = `data-qa-bind-id="${id}"`;
+    expressions.forEach((e) => {
+      Em.addObserver(e.root, e.path, invoker);
+    });
+    Em.run.next(observer);
+  } else {
+    attributes = `data-qa="${text}"`;
+  }
+  return new Em.Handlebars.SafeString(attributes);
+});
+
 /**
  * Usage:
  *
@@ -383,6 +467,29 @@ Em.Handlebars.registerHelper('isAuthorized', function (property, options) {
   return Ember.Handlebars.helpers.boundIf.call(permission, "isAuthorized", options);
 });
 
+/**
+ * Usage:
+ *
+ * <pre>
+ *   {{#havePermissions "SERVICE.TOGGLE_ALERTS"}}
+ *     {{! some truly code }}
+ *   {{else}}
+ *     {{! some falsy code }}
+ *   {{/havePermissions}}
+ * </pre>
+ */
+Em.Handlebars.registerHelper('havePermissions', function (property, options) {
+  var permission = Ember.Object.create({
+    havePermissions: function() {
+      return App.havePermissions(property);
+    }.property()
+  });
+
+  // wipe out contexts so boundIf uses `this` (the permission) as the context
+  options.contexts = null;
+  return Ember.Handlebars.helpers.boundIf.call(permission, "havePermissions", options);
+});
+
 /**
  * @namespace App
  */
@@ -592,6 +699,7 @@ App.format = {
         name = name.split(separator).map(function(singleName) {
           return this.normalizeName(singleName.toUpperCase());
         }, this).join(' ');
+        break;
       }
     }
     return name.capitalize();
@@ -632,11 +740,15 @@ App.format = {
    * @param {string} request_inputs
    * @return {string}
    */
-  commandDetail: function (command_detail, request_inputs) {
+  commandDetail: function (command_detail, request_inputs, ops_display_name) {
     var detailArr = command_detail.split(' ');
     var self = this;
     var result = '';
     var isIncludeExcludeFiles = false;
+    //if an optional operation display name has been specified in the service metainfo.xml
+    if (ops_display_name != null && ops_display_name.length > 0) {
+      result = result + ' ' + ops_display_name;
+    } else {
     detailArr.forEach( function(item) {
       // if the item has the pattern SERVICE/COMPONENT, drop the SERVICE part
       if (item.contains('/') && !isIncludeExcludeFiles) {
@@ -658,6 +770,7 @@ App.format = {
         result = result + ' ' + self.role(item, false);
       }
     });
+    }
 
     if (result.indexOf('Decommission:') > -1 || result.indexOf('Recommission:') > -1) {
       // for Decommission command, make sure the hostname is in lower case
@@ -763,10 +876,14 @@ App.format = {
  * @param {object} options
  */
 App.popover = function (self, options) {
+  var opts = $.extend(true, {
+    container: 'body',
+    html: true
+  }, options || {});
   if (!self) return;
-  self.popover(options);
+  self.popover(opts);
   self.on("remove", function () {
-    $(this).trigger('mouseleave').off().removeData('popover');
+    $(this).trigger('mouseleave').off().removeData('bs.popover');
   });
   self = null;
 };
@@ -780,11 +897,14 @@ App.popover = function (self, options) {
  * @param {object} options
  */
 App.tooltip = function (self, options) {
+  var opts = $.extend(true, {
+    container: 'body'
+  }, options || {});
   if (!self || !self.tooltip) return;
-  self.tooltip(options);
+  self.tooltip(opts);
   /* istanbul ignore next */
   self.on("remove", function () {
-    $(this).trigger('mouseleave').off().removeData('tooltip');
+    $(this).trigger('mouseleave').off().removeData('bs.tooltip');
   });
   self = null
 };
@@ -925,7 +1045,7 @@ App.resetDsStoreTypeMap = function(type) {
   if (typeMap) {
     var idToClientIdMap = typeMap.idToCid;
     for (var id in idToClientIdMap) {
-      if (idToClientIdMap.hasOwnProperty(id) && idToClientIdMap[id]) {
+      if (idToClientIdMap.hasOwnProperty(id) && idToClientIdMap[id] && allRecords[idToClientIdMap[id]] !== undefined) {
         delete allRecords[idToClientIdMap[id]];  // deletes the cached copy of the record from the store
       }
     }
@@ -938,6 +1058,22 @@ App.resetDsStoreTypeMap = function(type) {
   }
 };
 
+/**
+ * Clean store from already loaded data.
+ * @param {DS.Model[]} models to clear
+ **/
+App.clearModels = function (models) {
+  models.forEach(function (model) {
+    var records = App.get('store').findAll(model).filterProperty('id');
+    records.forEach(function (rec) {
+      Ember.run(this, function () {
+        rec.deleteRecord();
+        App.store.fastCommit();
+      });
+    }, this);
+  }, this);
+};
+
 App.logger = function() {
 
   var timers = {};
