@@ -20,7 +20,9 @@
 // load all views here
 
 require('views/application');
+require('views/common/breadcrumbs_view');
 require('views/common/clock_view');
+require('views/common/checkbox_view');
 require('views/common/log_search_ui_link_view');
 require('views/common/log_file_search_view');
 require('views/common/log_tail_view');
@@ -33,7 +35,9 @@ require('views/common/chart/pie');
 require('views/common/chart/linear');
 require('views/common/chart/linear_time');
 require('views/common/modal_popup');
+require('views/common/search_box_view');
 require('views/common/modal_popups/alert_popup');
+require('views/common/modal_popups/edit_dashboard_widget_popup');
 require('views/common/modal_popups/manage_kdc_credentials_popup');
 require('views/common/modal_popups/confirmation_feedback_popup');
 require('views/common/modal_popups/confirmation_popup');
@@ -48,7 +52,9 @@ require('views/common/modal_popups/log_tail_popup');
 require('views/common/modal_popups/config_validation/config_validation_failed_popup');
 require('views/common/modal_popups/config_validation/config_validation_popup');
 require('views/common/editable_list');
+require('views/common/not-scrollable-textarea');
 require('views/common/host_progress_popup_body_view');
+require('views/common/radio_button_view');
 require('views/common/rolling_restart_view');
 require('views/common/select_custom_date_view');
 require('views/common/metric');
@@ -58,6 +64,7 @@ require('views/common/form/field');
 require('views/common/form/datepicker_view');
 require('views/common/form/spinner_input_view');
 require('views/common/form/manage_credentials_form_view');
+require('views/common/form/dropdown');
 require('views/common/quick_view_link_view');
 require('views/common/configs/services_config');
 require('views/common/configs/service_config_container_view');
@@ -67,8 +74,8 @@ require('views/common/configs/service_config_tab_view');
 require('views/common/configs/config_category_container_view');
 require('views/common/configs/overriddenPropertyRow_view');
 require('views/common/configs/overriddenProperty_view');
-require('views/common/configs/compare_property_view');
-require('views/common/configs/config_history_flow');
+require('views/common/configs/config_versions_control_view');
+require('views/common/configs/config_versions_dropdown_view');
 require('views/common/configs/selectable_popup_body_view');
 require('views/common/configs/custom_category_views/notification_configs_view');
 require('views/common/configs/config_diff_view');
@@ -90,10 +97,11 @@ require('views/common/configs/widgets/toggle_config_widget_view');
 require('views/common/configs/widgets/label_config_widget_view');
 require('views/common/configs/widgets/test_db_connection_widget_view');
 require('views/common/configs/widgets/overrides/config_widget_override_view');
-require('views/common/configs/widgets/comparison/config_widget_comparison_view');
 require('views/common/configs/service_config_layout_tab_view');
+require('views/common/configs/service_config_layout_tab_compare_view');
 require('views/common/filter_combobox');
 require('views/common/filter_combo_cleanable');
+require('views/common/pagination_view');
 require('views/common/table_view');
 require('views/common/progress_bar_view');
 require('views/common/controls_view');
@@ -118,6 +126,7 @@ require('views/main/alert_definitions_view');
 require('views/main/alerts/alert_definition/alert_definition_summary');
 require('views/main/alerts/alert_definition/alert_definition_state');
 require('views/main/alerts/definition_details_view');
+require('views/main/alerts/alert_search_box');
 require('views/main/alerts/alert_definitions_actions_view');
 require('views/main/alerts/definition_configs_view');
 require('views/main/alerts/manage_alert_groups/select_definitions_popup_body_view');
@@ -127,6 +136,7 @@ require('views/main/alerts/add_alert_definition/step2_view');
 require('views/main/alerts/add_alert_definition/step3_view');
 require('views/main/alerts');
 require('views/main/alerts/manage_alert_groups_view');
+require('views/main/alerts/alert_instances_popup_view');
 require('views/main/alerts/manage_alert_notifications_view');
 require('views/main/charts');
 require('views/main/views/details');
@@ -159,8 +169,6 @@ require('views/main/host/metrics/processes');
 require('views/main/host/addHost/step4_view');
 require('views/main/admin');
 require('views/main/admin/service_auto_start');
-require('views/main/admin/service_auto_start/component_auto_start');
-require('views/main/admin/service_auto_start/service_auto_start_indicator');
 require('views/main/admin/highAvailability/nameNode/wizard_view');
 require('views/main/admin/highAvailability/progress_view');
 require('views/main/admin/highAvailability/nameNode/rollback_view');
@@ -186,7 +194,6 @@ require('views/main/admin/highAvailability/journalNode/step4_view');
 require('views/main/admin/highAvailability/journalNode/step5_view');
 require('views/main/admin/highAvailability/journalNode/step6_view');
 require('views/main/admin/highAvailability/journalNode/step7_view');
-require('views/main/admin/highAvailability/journalNode/step8_view');
 require('views/main/admin/highAvailability/resourceManager/wizard_view');
 require('views/main/admin/highAvailability/resourceManager/step1_view');
 require('views/main/admin/highAvailability/resourceManager/step2_view');
@@ -210,6 +217,11 @@ require('views/main/admin/highAvailability/rangerAdmin/step1_view');
 require('views/main/admin/highAvailability/rangerAdmin/step2_view');
 require('views/main/admin/highAvailability/rangerAdmin/step3_view');
 require('views/main/admin/highAvailability/rangerAdmin/step4_view');
+require('views/main/admin/federation/wizard_view');
+require('views/main/admin/federation/step1_view');
+require('views/main/admin/federation/step2_view');
+require('views/main/admin/federation/step3_view');
+require('views/main/admin/federation/step4_view');
 require('views/main/admin/serviceAccounts_view');
 require('views/main/admin/stack_upgrade/upgrade_wizard_view');
 require('views/main/admin/stack_upgrade/upgrade_version_box_view');
@@ -274,20 +286,22 @@ require('views/main/dashboard/widgets/resource_manager_heap');
 require('views/main/dashboard/widgets/resource_manager_uptime');
 require('views/main/dashboard/widgets/node_managers_live');
 require('views/main/dashboard/widgets/yarn_memory');
+require('views/main/dashboard/widgets/yarn_containers');
 require('views/main/dashboard/widgets/supervisor_live');
 require('views/main/dashboard/widgets/flume_agent_live');
 require('views/main/dashboard/config_history_view');
+require('views/main/dashboard/config_history_search_box');
 
 
 require('views/main/service');
 require('views/main/service/service');
 require('views/main/service/services/hdfs');
+require('views/main/service/services/onefs');
 require('views/main/service/services/yarn');
 require('views/main/service/services/mapreduce2');
 require('views/main/service/services/hbase');
 require('views/main/service/services/hive');
 require('views/main/service/services/zookeeper');
-require('views/main/service/services/oozie');
 require('views/main/service/services/flume');
 require('views/main/service/services/storm');
 require('views/main/service/services/ranger');
@@ -298,6 +312,9 @@ require('views/main/service/reconfigure');
 require('views/main/service/info/components_list_view');
 require('views/main/service/info/menu');
 require('views/main/service/info/summary');
+require('views/main/service/info/summary/hdfs/common_widgets');
+require('views/main/service/info/summary/hdfs/slaves');
+require('views/main/service/info/summary/hdfs/widgets');
 require('views/main/service/info/configs');
 require('views/main/service/info/metric_graphs_view');
 require('views/main/service/info/metrics/ambari_metrics/master_average_load');
@@ -341,6 +358,7 @@ require('views/main/charts/heatmap/heatmap_rack');
 require('views/main/charts/heatmap/heatmap_host');
 require('views/main/charts/heatmap/heatmap_host_detail');
 require('views/main/service/info/heatmap_view');
+require('views/main/service/info/metrics_view');
 
 require('views/main/service/widgets/create/wizard_view');
 require('views/main/service/widgets/create/step1_view');
@@ -364,6 +382,10 @@ require('views/wizard/step5_view');
 require('views/wizard/step6_view');
 require('views/wizard/step7_view');
 require('views/wizard/step7/assign_master_view');
+require('views/wizard/step7/credentials_tab_view');
+require('views/wizard/step7/databases_tab_view');
+require('views/wizard/step7/accounts_tab_view');
+require('views/wizard/step7/directories_tab_view');
 require('views/main/service/reassign/step7_view');
 require('views/wizard/step8_view');
 require('views/wizard/step9_view');
