@@ -38,6 +38,11 @@ App.QuickLinksView = Em.View.extend({
    */
   showQuickLinks: false,
 
+  /**
+   * @type {boolean}
+   */
+  showNoLinks: false,
+
   /**
    * @type {string}
    */
@@ -50,11 +55,6 @@ App.QuickLinksView = Em.View.extend({
    */
   quickLinks: [],
 
-  /**
-   * @type {string[]}
-   */
-  actualTags: [],
-
   /**
    * @type {object[]}
    */
@@ -74,6 +74,12 @@ App.QuickLinksView = Em.View.extend({
    */
   servicesSupportsHttps: ["HDFS", "HBASE"],
 
+  masterGroups: [],
+
+  tooltipAttribute: 'quick-links-title-tooltip',
+
+  shouldSetGroupedLinks: false,
+
   /**
    * @type {object}
    */
@@ -87,7 +93,6 @@ App.QuickLinksView = Em.View.extend({
 
   willDestroyElement: function () {
     this.get('configProperties').clear();
-    this.get('actualTags').clear();
     this.get('quickLinks').clear();
     this.get('requiredSiteNames').clear();
   },
@@ -98,67 +103,23 @@ App.QuickLinksView = Em.View.extend({
    *
    * The flags responsible for correct, up-to-date state of quick links:
    * - App.currentStackVersionNumber
-   * - App.singleNodeInstall
    * - App.router.clusterController.isHostComponentMetricsLoaded
    */
   setQuickLinks: function () {
     if (App.get('router.clusterController.isServiceMetricsLoaded')) {
-      this.loadTags();
+      this.setConfigProperties().done((configProperties) => {
+        this.get('configProperties').pushObjects(configProperties);
+        this.getQuickLinksHosts();
+      });
     }
   }.observes(
     'App.currentStackVersionNumber',
-    'App.singleNodeInstall',
     'App.router.clusterController.isServiceMetricsLoaded',
     'App.router.clusterController.isHostComponentMetricsLoaded',
     'App.router.clusterController.quickLinksUpdateCounter'
   ),
 
-  /**
-   * call for configuration tags
-   *
-   * @returns {$.ajax}
-   */
-  loadTags: function () {
-    return App.ajax.send({
-      name: 'config.tags',
-      sender: this,
-      success: 'loadTagsSuccess',
-      error: 'loadTagsError'
-    });
-  },
-
-  /**
-   * Success-callback for load-tags request
-   *
-   * @param {object} data
-   * @method loadTagsSuccess
-   */
-  loadTagsSuccess: function (data) {
-    this.get('actualTags').clear();
-    var self = this;
-    var tags = Object.keys(data.Clusters.desired_configs).map(function (prop) {
-      return Em.Object.create({
-        siteName: prop,
-        tagName: data.Clusters.desired_configs[prop].tag
-      });
-    });
-    this.get('actualTags').pushObjects(tags);
-    this.setConfigProperties().done(function (configProperties) {
-      self.get('configProperties').pushObjects(configProperties);
-      self.getQuickLinksHosts();
-    });
-  },
-
-  /**
-   * Error-callback for load-tags request
-   *
-   * @method loadTagsError
-   */
-  loadTagsError: function () {
-    this.getQuickLinksHosts();
-  },
-
-  /**
+   /**
    * Request for quick-links config
    *
    * @returns {$.ajax}
@@ -203,19 +164,29 @@ App.QuickLinksView = Em.View.extend({
       if (!Em.isEmpty(links)) {
         links.forEach(function (link) {
           if (!link.remove) {
-            var portConfig = Em.get(link, 'port');
-            var portConfigSiteProp = Em.get(portConfig, 'site');
-            if (!sites.contains(portConfigSiteProp)) {
-              sites.push(portConfigSiteProp);
-            }
+            this.addSite(link, 'host', sites);
+            this.addSite(link, 'port', sites);
           }
         }, this);
         this.set('requiredSiteNames', this.get('requiredSiteNames').pushObjects(sites).uniq());
         this.setQuickLinks();
       }
+    } else {
+      this.set('showNoLinks', true);
+
     }
   },
 
+  addSite: function(link, linkPropertyName, sites) {
+      var config = Em.get(link, linkPropertyName);
+      if (config) {
+        var siteName = Em.get(config, 'site');
+        if (!sites.contains(siteName)) {
+          sites.push(siteName);
+        }
+      }
+  },
+
   /**
    * call for public host names
    *
@@ -223,9 +194,16 @@ App.QuickLinksView = Em.View.extend({
    * @method getQuickLinksHosts
    */
   getQuickLinksHosts: function () {
-    var masterHosts = App.HostComponent.find().filterProperty('isMaster').mapProperty('hostName').uniq();
+    const links = App.QuickLinksConfig.find().mapProperty('links'),
+      components = links.reduce((componentsArray, currentLinksArray) => {
+        const componentNames = currentLinksArray.mapProperty('component_name').uniq();
+        return [...componentsArray, ...componentNames];
+      }, []),
+      hosts = App.HostComponent.find().filter(component => {
+        return components.contains(component.get('componentName'));
+      }).mapProperty('hostName').uniq();
 
-    if (masterHosts.length === 0) {
+    if (hosts.length === 0) {
       return $.Deferred().reject().promise();
     }
 
@@ -234,7 +212,7 @@ App.QuickLinksView = Em.View.extend({
       sender: this,
       data: {
         clusterName: App.get('clusterName'),
-        masterHosts: masterHosts.join(','),
+        hosts: hosts.join(','),
         urlParams: this.get('content.serviceName') === 'HBASE' ? ',host_components/metrics/hbase/master/IsActiveMaster' : ''
       },
       success: 'setQuickLinksSuccessCallback'
@@ -254,27 +232,39 @@ App.QuickLinksView = Em.View.extend({
     var hasHosts = false;
     var componentNames = hosts.mapProperty('componentName');
     componentNames.forEach(function(_componentName){
-      var masterComponent = App.MasterComponent.find().findProperty('componentName', _componentName);
-      if (masterComponent) {
-        hasHosts = hasHosts || !!masterComponent.get('totalCount');
+      var component = App.MasterComponent.find().findProperty('componentName', _componentName) ||
+        App.SlaveComponent.find().findProperty('componentName', _componentName);
+      if (component) {
+        hasHosts = hasHosts || !!component.get('totalCount');
       }
     });
     // no need to set quicklinks if
     // 1)current service does not have quick links configured
-    // 2)No host component present for the configured quicklinks
-    this.set('showQuickLinks', hasQuickLinks && hasHosts);
+    // 2)No host component present for the configured quicklinks and has no overridden hosts
+    if(hasQuickLinks && (hasHosts || this.hasOverriddenHost())) {
+      this.set('showQuickLinks', true);
+    } else {
+      this.set('showNoLinks', true);
+    }
 
     var isMultipleComponentsInLinks = componentNames.uniq().length > 1;
 
-    if (hosts.length === 0) {
+    if (hosts.length === 0 && !this.hasOverriddenHost()) {
       this.setEmptyLinks();
-    } else if (hosts.length === 1 || isMultipleComponentsInLinks) {
+    } else if (hosts.length === 1 || isMultipleComponentsInLinks || this.hasOverriddenHost()) {
       this.setSingleHostLinks(hosts, response);
+    } else if (this.get('masterGroups.length') > 1 || this.get('shouldSetGroupedLinks')) {
+      this.setMultipleGroupLinks(hosts);
     } else {
       this.setMultipleHostLinks(hosts);
     }
   },
 
+  hasOverriddenHost: function() {
+    var links = Em.get(this.getQuickLinksConfiguration(), 'links');
+    return links && links.some(function (each) { return each.host; });
+  },
+
   /**
    * Get public host name by its host name.
    *
@@ -296,11 +286,7 @@ App.QuickLinksView = Em.View.extend({
    */
   setConfigProperties: function () {
     this.get('configProperties').clear();
-    var requiredSiteNames = this.get('requiredSiteNames');
-    var tags = this.get('actualTags').filter(function (tag) {
-      return requiredSiteNames.contains(tag.siteName);
-    });
-    return App.router.get('configurationController').getConfigsByTags(tags);
+    return App.router.get('configurationController').getCurrentConfigsBySites(this.get('requiredSiteNames'));
   },
 
   /**
@@ -312,7 +298,7 @@ App.QuickLinksView = Em.View.extend({
   getQuickLinksConfiguration: function () {
     var serviceName = this.get('content.serviceName');
     var self = this;
-    var quicklinks, links = {};
+    var quicklinks = {};
     if (self.hasQuickLinksConfig(serviceName)) {
       quicklinks = App.QuickLinksConfig.find().findProperty('id', serviceName);
       Em.set(quicklinks, 'links', Em.get(quicklinks, 'links').filterProperty('visible', true));
@@ -352,7 +338,7 @@ App.QuickLinksView = Em.View.extend({
     if (serviceName === 'MAPREDUCE2' && response) {
       var portConfig = Em.get(link, 'port');
       var siteName = Em.get(portConfig, 'site');
-      var siteConfigs = this.get('configProperties').findProperty('type', siteName).properties;
+      const siteConfigs = this.get('configProperties').findProperty('type', siteName).properties;
       var hostPortConfigValue = siteConfigs[Em.get(portConfig, protocol + '_config')];
       if (!Em.isNone(hostPortConfigValue)) {
         var hostPortValue = hostPortConfigValue.match(new RegExp('([\\w\\d.-]*):(\\d+)'));
@@ -362,9 +348,12 @@ App.QuickLinksView = Em.View.extend({
         }
       }
     } else if (serviceName === 'RANGER') {
-      var siteConfigs = this.get('configProperties').findProperty('type', 'admin-properties').properties;
+      const siteConfigs = this.get('configProperties').findProperty('type', 'admin-properties').properties;
       if (siteConfigs['policymgr_external_url']) {
-        host = siteConfigs['policymgr_external_url'].split('://')[1].split(':')[0];
+        return {
+          label: link.label,
+          url: siteConfigs['policymgr_external_url']
+        }
       }
     }
 
@@ -379,11 +368,26 @@ App.QuickLinksView = Em.View.extend({
         newItem.url = template.fmt(protocol, host, linkPort);
       }
       newItem.label = link.label;
+      newItem.url = this.resolvePlaceholders(newItem.url);
       return newItem;
     }
     return null;
   },
 
+  /**
+   * Replace placeholders like ${config-type/property-name} in the given URL
+   */
+  resolvePlaceholders: function(url) {
+    return url.replace(/\$\{(\S+)\/(\S+)\}/g, function(match, configType, propertyName) {
+      var config = this.get('configProperties').findProperty('type', configType);
+      if (config) {
+        return config.properties[propertyName] ? config.properties[propertyName] : match;
+      } else {
+        return match;
+      }
+    }.bind(this));
+  },
+
   /**
    * set empty links
    *
@@ -414,16 +418,17 @@ App.QuickLinksView = Em.View.extend({
 
       var links = Em.get(quickLinksConfig, 'links');
       links.forEach(function (link) {
-        var componentName = link.component_name;
-        var hostNameForComponent = hosts.findProperty('componentName',componentName);
-        if (hostNameForComponent) {
-          var publicHostName = hostNameForComponent.publicHostName;
-          if (link.protocol) {
-            protocol = this.setProtocol(configProperties, link.protocol);
-          }
-          var newItem = this.getHostLink(link, publicHostName, protocol, configProperties, response); //quicklink generated for the hbs template
-          if (!Em.isNone(newItem)) {
-            quickLinks.push(newItem);
+        var isRelatedComponentInstalled = this.isRelatedComponentInstalled(link);
+        if (isRelatedComponentInstalled) {
+          var publicHostName = this.publicHostName(link, hosts, protocol);
+          if (publicHostName) {
+            if (link.protocol) {
+              protocol = this.setProtocol(configProperties, link.protocol);
+            }
+            var newItem = this.getHostLink(link, publicHostName, protocol, configProperties, response); //quicklink generated for the hbs template
+            if (!Em.isNone(newItem)) {
+              quickLinks.push(newItem);
+            }
           }
         }
       }, this);
@@ -436,17 +441,33 @@ App.QuickLinksView = Em.View.extend({
     }
   },
 
+  publicHostName: function(link, hosts, protocol) {
+    if (link.host) { // if quicklink overrides hostcomponent host name, get host from config
+      var configProperties = this.get('configProperties');
+      var hostProperty = Em.get(link.host, protocol + '_property');
+      var site = configProperties.findProperty('type', Em.get(link.host, 'site'));
+      return site && site.properties ? this.parseHostFromUri(site.properties[hostProperty]) : null;
+    } else {
+      var hostNameForComponent = hosts.findProperty('componentName', link.component_name);
+      return hostNameForComponent ? hostNameForComponent.publicHostName : null;
+    }
+  },
+
   /**
-   * set links that contain multiple hosts
-   *
-   * @param {hostForQuickLink[]} hosts
-   * @method setMultipleHostLinks
+   * @param {string} uri
    */
-  setMultipleHostLinks: function (hosts) {
+  parseHostFromUri: function(uri) {
+    if (uri) {
+      var match = uri.match(/:\/\/([^/:]+)/i);
+      return match != null && match.length == 2 ? match[1] : uri;
+    } else {
+      return null;
+    }
+  },
+
+  getMultipleHostLinks: function (hosts) {
     var quickLinksConfig = this.getQuickLinksConfiguration();
     if (Em.isNone(quickLinksConfig)) {
-      this.set('quickLinksArray', []);
-      this.set('isLoaded', false);
       return;
     }
 
@@ -462,15 +483,16 @@ App.QuickLinksView = Em.View.extend({
       links.forEach(function (link) {
         var linkRemoved = Em.get(link, 'removed');
         var url = Em.get(link, 'url');
-        if (url && !linkRemoved) {
+        var isRelatedComponentInstalled = this.isRelatedComponentInstalled(link);
+        if (url && !linkRemoved && isRelatedComponentInstalled) {
           var hostNameRegExp = new RegExp('([\\w\\W]*):\\d+');
           if (serviceName === 'HDFS') {
             var config;
             var configPropertiesObject = configProperties.findProperty('type', 'hdfs-site');
             if (configPropertiesObject && configPropertiesObject.properties) {
               var properties = configPropertiesObject.properties;
-              var nameServiceId = properties['dfs.nameservices'];
-              var nnProperties = ['dfs.namenode.{0}-address.{1}.nn1', 'dfs.namenode.{0}-address.{1}.nn2'].invoke('format', protocol, nameServiceId);
+              var nnKeyRegex = new RegExp('^dfs\.namenode\.' + protocol + '-address\.');
+              var nnProperties = Object.keys(properties).filter(key => nnKeyRegex.test(key));
               var nnPropertiesLength = nnProperties.length;
               for (var i = nnPropertiesLength; i--;) {
                 var propertyName = nnProperties[i];
@@ -500,8 +522,50 @@ App.QuickLinksView = Em.View.extend({
       }
       quickLinksArray.push(quickLinks);
     }, this);
-    this.set('quickLinksArray', quickLinksArray);
-    this.set('isLoaded', true);
+    return quickLinksArray;
+  },
+
+  /**
+   * set links that contain multiple hosts
+   *
+   * @param {hostForQuickLink[]} hosts
+   * @method setMultipleHostLinks
+   */
+  setMultipleHostLinks: function (hosts) {
+    const quickLinks = this.getMultipleHostLinks(hosts);
+    this.setProperties({
+      quickLinksArray: [
+        {
+          links: quickLinks || []
+        }
+      ],
+      isLoaded: !!quickLinks
+    });
+  },
+
+  /**
+   * set links that contain for multiple grouped hosts
+   *
+   * @param {hostForQuickLink[]} hosts
+   * @method setMultipleGroupLinks
+   */
+  setMultipleGroupLinks: function (hosts) {
+    let isLoaded = true;
+    const quickLinksArray = this.get('masterGroups').map(group => {
+      const groupHosts = hosts.filter(host => group.hosts.contains(host.hostName)),
+        links = this.getMultipleHostLinks(groupHosts);
+      if (!links) {
+        isLoaded = false;
+      }
+      return {
+        title: group.title,
+        links: links || []
+      };
+    });
+    this.setProperties({
+      quickLinksArray,
+      isLoaded
+    });
   },
 
   /**
@@ -536,20 +600,18 @@ App.QuickLinksView = Em.View.extend({
    * @method hostForQuickLink
    */
   processHdfsHosts: function (hosts) {
-    return hosts.map(function (host) {
-      if (host.hostName === Em.get(this, 'content.activeNameNode.hostName')) {
+    return hosts.map(host => {
+      const {hostName} = host,
+        isActiveNameNode = Em.get(this, 'content.activeNameNodes').someProperty('hostName', hostName),
+        isStandbyNameNode = Em.get(this, 'content.standbyNameNodes').someProperty('hostName', hostName);
+      if (isActiveNameNode) {
         host.status = Em.I18n.t('quick.links.label.active');
       }
-      else
-        if (host.hostName === Em.get(this, 'content.standbyNameNode.hostName')) {
-          host.status = Em.I18n.t('quick.links.label.standby');
-        }
-        else
-          if (host.hostName === Em.get(this, 'content.standbyNameNode2.hostName')) {
-            host.status = Em.I18n.t('quick.links.label.standby');
-          }
+      if (isStandbyNameNode) {
+        host.status = Em.I18n.t('quick.links.label.standby');
+      }
       return host;
-    }, this);
+    });
   },
 
   /**
@@ -613,12 +675,6 @@ App.QuickLinksView = Em.View.extend({
   getHosts: function (response, serviceName) {
     //The default error message when we cannot obtain the host information for the given service
     this.set('quickLinksErrorMessage', Em.I18n.t('quick.links.error.nohosts.label').format(serviceName));
-    if (App.get('singleNodeInstall')) {
-      return [{
-        hostName: App.get('singleNodeAlias'),
-        publicHostName: App.get('singleNodeAlias')
-      }];
-    }
     var hosts = [];
     var quickLinkConfigs = App.QuickLinksConfig.find().findProperty("id", serviceName);
     if (quickLinkConfigs) {
@@ -662,10 +718,11 @@ App.QuickLinksView = Em.View.extend({
    */
   findHosts: function (componentName, response) {
     var hosts = [];
-    var masterComponent = App.MasterComponent.find().findProperty('componentName', componentName);
-    if (masterComponent) {
-      var masterHostComponents = masterComponent.get('hostNames') || [];
-      masterHostComponents.forEach(function (_hostName) {
+    var component = App.MasterComponent.find().findProperty('componentName', componentName) ||
+      App.SlaveComponent.find().findProperty('componentName', componentName);
+    if (component) {
+      var hostComponents = component.get('hostNames') || [];
+      hostComponents.forEach(function (_hostName) {
         var host = this.getPublicHostName(response.items, _hostName);
         if (host) {
           hosts.push({
@@ -751,6 +808,9 @@ App.QuickLinksView = Em.View.extend({
     if ('HTTP_ONLY' === protocolType) {
       return 'http';
     }
+
+    protocolType = protocolType.toLowerCase();
+
     var count = 0;
     var checks = Em.get(protocolConfig, 'checks');
     if (!checks) {
@@ -765,6 +825,7 @@ App.QuickLinksView = Em.View.extend({
         count++;
       }
     }, this);
+
     return count ? this.reverseType(protocolType) : protocolType;
   },
 
@@ -778,7 +839,9 @@ App.QuickLinksView = Em.View.extend({
    * @method setPort
    */
   setPort: function (portConfigs, protocol, configProperties) {
-
+    if (!portConfigs) {
+      return '';
+    }
     var defaultPort = Em.get(portConfigs, protocol + '_default_port');
     var portProperty = Em.get(portConfigs, protocol + '_property');
     var site = configProperties.findProperty('type', Em.get(portConfigs, 'site'));
@@ -789,6 +852,12 @@ App.QuickLinksView = Em.View.extend({
     }
 
     var regexValue = Em.get(portConfigs, 'regex');
+    if (protocol === 'https') {
+      var httpsRegex = Em.get(portConfigs, 'https_regex');
+      if (httpsRegex) {
+        regexValue = httpsRegex;
+      }
+    }
     regexValue = regexValue.trim();
     if (regexValue) {
       var re = new RegExp(regexValue);
@@ -801,5 +870,22 @@ App.QuickLinksView = Em.View.extend({
     } else {
       return propertyValue;
     }
+  },
+
+  setTooltip: function () {
+    Em.run.next(() => {
+      if (this.get('showQuickLinks') && this.get('isLoaded') && this.get('quickLinksArray.length')) {
+        App.tooltip($(`[rel="${this.get('tooltipAttribute')}"]`));
+      }
+    });
+  }.observes('showQuickLinks', 'isLoaded', 'quickLinksArray.length'),
+
+  /**
+   * Check if host component related to quickLink is installed
+   * @param quickLink
+   * @returns {Boolean}
+   */
+  isRelatedComponentInstalled: function (quickLink) {
+    return App.HostComponent.find().someProperty('componentName', quickLink.component_name);
   }
 });
