@@ -20,17 +20,7 @@ var App = require('app');
 
 App.HBaseMasterUptimeView = App.UptimeTextDashboardWidgetView.extend({
 
-  title: Em.I18n.t('dashboard.widgets.HBaseMasterUptime'),
-  id: '16',
-
-  model_type: 'hbase',
-
   component: 'Hbase Master',
-  modelField: 'masterStartTime',
-
-  didInsertElement: function() {
-    this._super();
-    this.calc();
-  }
+  modelValue: Em.computed.alias('model.masterStartTime')
 
 });
\ No newline at end of file
