@@ -20,17 +20,7 @@ var App = require('app');
 
 App.ResourceManagerUptimeView = App.UptimeTextDashboardWidgetView.extend({
 
-  title: Em.I18n.t('dashboard.widgets.ResourceManagerUptime'),
-  id: '18',
-
-  model_type: 'yarn',
-
   component: 'ResourceManager',
-  modelField: 'resourceManagerStartTime',
-
-  didInsertElement: function() {
-    this._super();
-    this.calc();
-  }
+  modelValue: Em.computed.alias('model.resourceManagerStartTime')
 
 });
