@@ -20,13 +20,9 @@ var App = require('app');
 
 App.YARNMemoryPieChartView = App.PieChartDashboardWidgetView.extend({
 
-  title: Em.I18n.t('dashboard.widgets.YARNMemory'),
-  id: '20',
-
   widgetHtmlId: 'widget-yarn-memory',
-  model_type: 'yarn',
-  modelFieldUsed: 'allocatedMemory',
-  modelFieldMax: 'maxMemory',
+  modelValueUsed: Em.computed.alias('model.allocatedMemory'),
+  modelValueMax: Em.computed.alias('model.maxMemory'),
 
   didInsertElement: function() {
     this._super();
