@@ -21,6 +21,11 @@ var App = require('app');
 
 App.WizardStep4View = Em.View.extend({
 
-  templateName: require('templates/wizard/step4')
+  templateName: require('templates/wizard/step4'),
 
+  toggleCheckBox: function(event) {
+    if (event.context.get('isDisabled')) { return; }
+    var isSelected = event.context.get('isSelected');
+    event.context.set('isSelected', !isSelected);
+  }
 });
