@@ -31,9 +31,7 @@ require('utils/host_progress_popup');
 
 describe('App.BackgroundOperationsController', function () {
 
-  var controller = App.BackgroundOperationsController.create({
-    isInitLoading: Em.K
-  });
+  var controller = App.BackgroundOperationsController.create();
 
   describe('#getQueryParams', function () {
     /**
@@ -114,6 +112,10 @@ describe('App.BackgroundOperationsController', function () {
     tests.forEach(function (test) {
       it(test.m, function () {
         controller.set('levelInfo', test.levelInfo);
+        controller.set('services', [Em.Object.create({
+          id: 1,
+          previousTaskStatusMap: {}
+        })]);
         var r = controller.getQueryParams();
         expect(r.name).to.equal(test.e.name);
         expect(r.successCallback).to.equal(test.e.successCallback);
@@ -122,27 +124,6 @@ describe('App.BackgroundOperationsController', function () {
     });
   });
 
-  describe('#startPolling()', function () {
-
-    beforeEach(function () {
-      sinon.spy(controller, 'requestMostRecent');
-    });
-    afterEach(function () {
-      controller.requestMostRecent.restore();
-    });
-
-    it('isWorking = false', function () {
-      controller.set('isWorking', false);
-      expect(App.updater.run.calledOnce).to.equal(false);
-      expect(controller.requestMostRecent.calledOnce).to.equal(false);
-    });
-    it('isWorking = true', function () {
-      controller.set('isWorking', true);
-      expect(App.updater.run.calledOnce).to.equal(true);
-      expect(controller.requestMostRecent.calledOnce).to.equal(true);
-    });
-  });
-
   describe('#isUpgradeRequest', function() {
 
     it('defines if request is upgrade task (true)', function() {
@@ -168,20 +149,12 @@ describe('App.BackgroundOperationsController', function () {
 
   describe('#callBackForMostRecent()', function () {
 
-    beforeEach(function () {
-      sinon.stub(App.router.get('clusterController'), 'restoreUpgradeState', Em.K);
-    });
-
-    afterEach(function () {
-      App.router.get('clusterController').restoreUpgradeState.restore();
-    });
-
     it('No requests exists', function () {
       var data = {
         items: []
       };
       controller.callBackForMostRecent(data);
-      expect(controller.get("allOperationsCount")).to.equal(0);
+      expect(controller.get("runningOperationsCount")).to.equal(0);
       expect(controller.get("services.length")).to.equal(0);
     });
     it('One non-running request', function () {
@@ -202,7 +175,7 @@ describe('App.BackgroundOperationsController', function () {
         ]
       };
       controller.callBackForMostRecent(data);
-      expect(controller.get("allOperationsCount")).to.equal(0);
+      expect(controller.get("runningOperationsCount")).to.equal(0);
       expect(controller.get("services").mapProperty('id')).to.eql([1]);
     });
 
@@ -218,7 +191,7 @@ describe('App.BackgroundOperationsController', function () {
         ]
       };
       controller.callBackForMostRecent(data);
-      expect(controller.get("allOperationsCount")).to.equal(0);
+      expect(controller.get("runningOperationsCount")).to.equal(0);
       expect(controller.get("services").mapProperty('id')).to.eql([]);
     });
 
@@ -229,18 +202,13 @@ describe('App.BackgroundOperationsController', function () {
             Requests: {
               id: 1,
               request_context: '',
-              task_count: 1,
-              aborted_task_count: 0,
-              completed_task_count: 0,
-              failed_task_count: 0,
-              timed_out_task_count: 0,
-              queued_task_count: 0
+              request_status: 'IN_PROGRESS'
             }
           }
         ]
       };
       controller.callBackForMostRecent(data);
-      expect(controller.get("allOperationsCount")).to.equal(1);
+      expect(controller.get("runningOperationsCount")).to.equal(1);
       expect(controller.get("services").mapProperty('id')).to.eql([1]);
     });
     it('Two requests in order', function () {
@@ -261,7 +229,7 @@ describe('App.BackgroundOperationsController', function () {
         ]
       };
       controller.callBackForMostRecent(data);
-      expect(controller.get("allOperationsCount")).to.equal(0);
+      expect(controller.get("runningOperationsCount")).to.equal(0);
       expect(controller.get("services").mapProperty('id')).to.eql([2, 1]);
     });
   });
@@ -333,179 +301,7 @@ describe('App.BackgroundOperationsController', function () {
       it(test.title, function () {
         controller.set('services', test.content.services);
         controller.removeOldRequests(test.content.currentRequestIds);
-        expect(controller.get('services')).to.eql(test.result);
-      });
-    });
-  });
-
-  describe('#isRequestRunning()', function () {
-    var testCases = [
-      {
-        title: 'Counters are missing',
-        request: {
-          Requests: {}
-        },
-        result: false
-      },
-      {
-        title: 'Request has zero tasks',
-        request: {
-          Requests: {
-            task_count: 0,
-            aborted_task_count: 0,
-            completed_task_count: 0,
-            failed_task_count: 0,
-            timed_out_task_count: 0,
-            queued_task_count: 0
-          }
-        },
-        result: false
-      },
-      {
-        title: 'One task in running status',
-        request: {
-          Requests: {
-            task_count: 1,
-            aborted_task_count: 0,
-            completed_task_count: 0,
-            failed_task_count: 0,
-            timed_out_task_count: 0,
-            queued_task_count: 0
-          }
-        },
-        result: true
-      },
-      {
-        title: 'One task in queued status',
-        request: {
-          Requests: {
-            task_count: 1,
-            aborted_task_count: 0,
-            completed_task_count: 0,
-            failed_task_count: 0,
-            timed_out_task_count: 0,
-            queued_task_count: 1
-          }
-        },
-        result: true
-      },
-      {
-        title: 'One task in aborted status',
-        request: {
-          Requests: {
-            task_count: 1,
-            aborted_task_count: 1,
-            completed_task_count: 0,
-            failed_task_count: 0,
-            timed_out_task_count: 0,
-            queued_task_count: 0
-          }
-        },
-        result: false
-      },
-      {
-        title: 'One task in completed status',
-        request: {
-          Requests: {
-            task_count: 1,
-            aborted_task_count: 0,
-            completed_task_count: 1,
-            failed_task_count: 0,
-            timed_out_task_count: 0,
-            queued_task_count: 0
-          }
-        },
-        result: false
-      },
-      {
-        title: 'One task in failed status',
-        request: {
-          Requests: {
-            task_count: 1,
-            aborted_task_count: 0,
-            completed_task_count: 0,
-            failed_task_count: 1,
-            timed_out_task_count: 0,
-            queued_task_count: 0
-          }
-        },
-        result: false
-      },
-      {
-        title: 'One task in timed out status',
-        request: {
-          Requests: {
-            task_count: 1,
-            aborted_task_count: 0,
-            completed_task_count: 0,
-            failed_task_count: 0,
-            timed_out_task_count: 1,
-            queued_task_count: 0
-          }
-        },
-        result: false
-      },
-      {
-        title: 'One task in timed out status and the second one in running',
-        request: {
-          Requests: {
-            task_count: 2,
-            aborted_task_count: 0,
-            completed_task_count: 0,
-            failed_task_count: 0,
-            timed_out_task_count: 1,
-            queued_task_count: 0
-          }
-        },
-        result: true
-      },
-      {
-        title: 'One task in each status',
-        request: {
-          Requests: {
-            task_count: 5,
-            aborted_task_count: 1,
-            completed_task_count: 1,
-            failed_task_count: 1,
-            timed_out_task_count: 1,
-            queued_task_count: 1
-          }
-        },
-        result: true
-      },
-      {
-        title: 'One task in each status except queued',
-        request: {
-          Requests: {
-            task_count: 5,
-            aborted_task_count: 1,
-            completed_task_count: 1,
-            failed_task_count: 1,
-            timed_out_task_count: 1,
-            queued_task_count: 0
-          }
-        },
-        result: true
-      },
-      {
-        title: 'No tasks in running status',
-        request: {
-          Requests: {
-            task_count: 4,
-            aborted_task_count: 1,
-            completed_task_count: 1,
-            failed_task_count: 1,
-            timed_out_task_count: 1,
-            queued_task_count: 0
-          }
-        },
-        result: false
-      }
-    ];
-
-    testCases.forEach(function (test) {
-      it(test.title, function () {
-        expect(controller.isRequestRunning(test.request)).to.eql(test.result);
+        expect(JSON.stringify(controller.get('services'))).to.equal(JSON.stringify(test.result));
       });
     });
   });
@@ -676,7 +472,6 @@ describe('App.BackgroundOperationsController', function () {
       controller.callBackFilteredByRequest(data);
       expect(request.get('previousTaskStatusMap')).to.eql({"1": "COMPLETED"});
       expect(request.get('hostsMap.host1.logTasks.length')).to.equal(1);
-      expect(request.get('isRunning')).to.equal(false);
     });
 
     it('request has one completed task and one running task', function () {
@@ -713,4 +508,503 @@ describe('App.BackgroundOperationsController', function () {
       expect(request.get('isRunning')).to.equal(true);
     });
   });
+
+  describe("#isInitLoading()", function () {
+
+    it("should return false when not on HOSTS_LIST level", function() {
+      controller.set('levelInfo', Em.Object.create({
+        name: 'SERVICES_LIST'
+      }));
+      expect(controller.isInitLoading()).to.be.false;
+    });
+
+    it("should return false when no request found", function() {
+      controller.set('levelInfo', Em.Object.create({
+        name: 'HOSTS_LIST',
+        requestId: 1
+      }));
+      controller.set('services', []);
+      expect(controller.isInitLoading()).to.be.false;
+    });
+
+    it("should return false when request has hosts", function() {
+      controller.set('levelInfo', Em.Object.create({
+        name: 'HOSTS_LIST',
+        requestId: 1
+      }));
+      controller.set('services', [Em.Object.create({
+        id: 1,
+        hostsLevelLoaded: true
+      })]);
+      expect(controller.isInitLoading()).to.be.false;
+    });
+
+    it("should return true when no request has no hosts", function() {
+      controller.set('levelInfo', Em.Object.create({
+        name: 'HOSTS_LIST',
+        requestId: 1
+      }));
+      controller.set('services', [Em.Object.create({
+        id: 1,
+        hostsMap: {}
+      })]);
+      expect(controller.isInitLoading()).to.be.true;
+    });
+  });
+
+  describe("#callBackFilteredByTask()", function () {
+    var data = {
+      Tasks: {
+        request_id: 1,
+        host_name: 'host1',
+        id: 2,
+        status: 'foo',
+        stdout: 'bar',
+        stderr: 'barfoo',
+        command: 'cmd',
+        custom_command_name: 'custom-cmd',
+        structured_out: 'str-out',
+        output_log: 'out-log',
+        error_log: 'err-log'
+      }
+    };
+
+    beforeEach(function() {
+      sinon.stub(App, 'dateTime').returns(1);
+    });
+
+    afterEach(function() {
+      App.dateTime.restore();
+    });
+
+    it("should set task info", function() {
+      var task = {
+        Tasks: {
+          id: 2
+        }
+      };
+      controller.set('services', [
+        Em.Object.create({
+          id: 1,
+          hostsMap: {
+            host1: {
+              logTasks: [task]
+            }
+          }
+        })
+      ]);
+
+      controller.callBackFilteredByTask(data);
+      expect(task).to.be.eql({
+        "Tasks": {
+          "id": 2,
+          "status": "foo",
+          "stdout": "bar",
+          "stderr": "barfoo",
+          "command": "cmd",
+          "custom_command_name": "custom-cmd",
+          "structured_out": "str-out",
+          "output_log": "out-log",
+          "error_log": "err-log"
+        }
+      });
+      expect(controller.get('serviceTimestamp')).to.be.equal(1);
+    });
+  });
+
+  describe("#parseRequestContext()", function () {
+
+    beforeEach(function() {
+      sinon.stub(controller, 'getRequestContextWithPrefix').returns({
+        requestContext: 'CTX_WITH_PREFIX'
+      });
+    });
+
+    afterEach(function() {
+      controller.getRequestContextWithPrefix.restore();
+    });
+
+    it("no requestContext specified", function() {
+      expect(controller.parseRequestContext()).to.be.eql({
+        requestContext: Em.I18n.t('requestInfo.unspecified')
+      });
+    });
+
+    it("requestContext specified", function() {
+      expect(controller.parseRequestContext('CTX')).to.be.eql({
+        requestContext: 'CTX'
+      });
+    });
+
+    it("requestContext specified with prefix", function() {
+      expect(controller.parseRequestContext(App.BackgroundOperationsController.CommandContexts.PREFIX)).to.be.eql({
+        requestContext: 'CTX_WITH_PREFIX'
+      });
+    });
+  });
+
+  describe("#getRequestContextWithPrefix()", function () {
+
+    beforeEach(function() {
+      sinon.stub(App.format, 'role', function (arg) {
+        return arg;
+      })
+    });
+
+    afterEach(function() {
+      App.format.role.restore();
+    });
+
+    it("custom command", function() {
+      expect(controller.getRequestContextWithPrefix('prefix.foo.bar')).to.be.eql({
+        requestContext: undefined,
+        dependentService: 'bar',
+        contextCommand: 'foo'
+      });
+    });
+    it("STOP all services command", function() {
+      expect(controller.getRequestContextWithPrefix('prefix.STOP.ALL_SERVICES')).to.be.eql({
+        requestContext: Em.I18n.t("requestInfo.stop").format(Em.I18n.t('common.allServices')),
+        dependentService: 'ALL_SERVICES',
+        contextCommand: 'STOP'
+      });
+    });
+    it("STOP one service command", function() {
+      expect(controller.getRequestContextWithPrefix('prefix.STOP.S1')).to.be.eql({
+        requestContext: Em.I18n.t("requestInfo.stop").format('S1'),
+        dependentService: 'S1',
+        contextCommand: 'STOP'
+      });
+    });
+    it("ROLLING-RESTART service command", function() {
+      expect(controller.getRequestContextWithPrefix('prefix.ROLLING-RESTART.S1.foo.bar')).to.be.eql({
+        requestContext: Em.I18n.t("rollingrestart.rest.context").format('S1', 'foo', 'bar'),
+        dependentService: 'S1',
+        contextCommand: 'ROLLING-RESTART'
+      });
+    });
+  });
+
+  describe("#showPopup()", function () {
+
+    beforeEach(function() {
+      sinon.stub(App.router, 'get').returns({
+        dataLoading: function() {
+          return {
+            done: Em.clb
+          }
+        }
+      });
+      sinon.stub(App.HostPopup, 'initPopup').returns(Em.Object.create());
+      App.HostPopup.set('isBackgroundOperations', true);
+    });
+
+    afterEach(function() {
+      App.router.get.restore();
+      App.HostPopup.initPopup.restore();
+    });
+
+    it("App.updater.immediateRun should be called", function() {
+      controller.showPopup();
+      expect(App.updater.immediateRun.calledWith('requestMostRecent')).to.be.true;
+    });
+
+    it("popupView should be created and opened", function() {
+      controller.set('popupView', null);
+      controller.showPopup();
+      expect(controller.get('popupView')).to.be.eql(Em.Object.create({
+        isNotShowBgChecked: true
+      }));
+    });
+
+    it("popupView should be restored and opened", function() {
+      controller.set('popupView', Em.Object.create());
+      controller.showPopup();
+      expect(controller.get('popupView')).to.be.eql(Em.Object.create({
+        isNotShowBgChecked: true,
+        isOpen: true
+      }));
+    });
+  });
+
+  describe("#clear()", function () {
+
+    it("operationsCount should be 10", function() {
+      controller.clear();
+      expect(controller.get('operationsCount')).to.be.equal(10);
+    });
+  });
+
+  describe('#subscribeToUpdates', function() {
+    beforeEach(function() {
+      sinon.stub(controller, 'requestMostRecent', Em.clb);
+      sinon.stub(App.StompClient, 'subscribe');
+    });
+    afterEach(function() {
+      controller.requestMostRecent.restore();
+      App.StompClient.subscribe.restore();
+    });
+
+    it('App.StompClient.subscribe should be called', function() {
+      controller.subscribeToUpdates();
+      expect(App.StompClient.subscribe.calledWith('/events/requests')).to.be.true;
+    });
+  });
+
+  describe('#updateRequests', function() {
+    beforeEach(function() {
+      sinon.stub(controller, 'parseRequestContext').returns({
+        requestContext: 'r1'
+      });
+      sinon.stub(controller, 'generateTasksMapOfRequest').returns({
+        currentTaskStatusMap: {},
+        hostsMap: {}
+      });
+      sinon.stub(controller, 'propertyDidChange');
+    });
+    afterEach(function() {
+      controller.parseRequestContext.restore();
+      controller.generateTasksMapOfRequest.restore();
+      controller.propertyDidChange.restore();
+    });
+
+    it('should exit when request is upgrade', function() {
+      controller.updateRequests({
+        requestContext: 'upgrading'
+      });
+      expect(controller.parseRequestContext.called).to.be.false;
+    });
+
+    it('should add request to list', function() {
+      controller.set('services', []);
+      controller.updateRequests({
+        progressPercent: 0,
+        requestStatus: 'PENDING',
+        startTime: 1,
+        userName: 'admin',
+        endTime: -1,
+        requestId: 1,
+        requestContext: '',
+        Tasks: []
+      });
+      expect(controller.get('services').objectAt(0)).to.be.eql(Em.Object.create({
+        id: 1,
+        name: 'r1',
+        displayName: 'r1',
+        tasks: [],
+        progress: 0,
+        status: 'PENDING',
+        isRunning: true,
+        startTime: 1,
+        userName: 'admin',
+        endTime: -1,
+        previousTaskStatusMap: {},
+        hostsMap: {}
+      }));
+      expect(controller.propertyDidChange.calledWith('services')).to.be.true;
+    });
+
+    it('should update request status', function() {
+      controller.set('services', [Em.Object.create({
+        id: 1,
+        name: 'r1',
+        displayName: 'r1',
+        tasks: [],
+        progress: 0,
+        status: 'PENDING',
+        isRunning: true,
+        startTime: 1,
+        userName: '',
+        endTime: -1,
+        previousTaskStatusMap: {},
+        hostsMap: {}
+      })]);
+      controller.updateRequests({
+        progressPercent: 100,
+        requestStatus: 'COMPLETED',
+        startTime: 1,
+        userName: 'admin',
+        endTime: 1,
+        requestId: 1,
+        requestContext: '',
+        Tasks: []
+      });
+      expect(controller.get('services').objectAt(0)).to.be.eql(Em.Object.create({
+        id: 1,
+        name: 'r1',
+        displayName: 'r1',
+        tasks: [],
+        progress: 100,
+        status: 'COMPLETED',
+        isRunning: false,
+        startTime: 1,
+        userName: 'admin',
+        endTime: 1,
+        previousTaskStatusMap: {},
+        hostsMap: {}
+      }))
+    });
+  });
+
+  describe('#generateTasksMapOfRequest', function() {
+
+    it('should return tasks map', function() {
+      var event = {
+        Tasks: [
+          {
+            hostName: 'host1',
+            id: 1,
+            status: 'PENDING',
+            requestId: 1
+          },
+          {
+            hostName: 'host1',
+            id: 2,
+            status: 'PENDING',
+            requestId: 1
+          },
+          {
+            hostName: 'host2',
+            id: 3,
+            status: 'COMPLETED',
+            requestId: 1
+          }
+        ]
+      };
+      expect(JSON.stringify(controller.generateTasksMapOfRequest(event, null).hostsMap)).to.be.equal(JSON.stringify({
+        "host1": {
+          "name": "host1",
+          "publicName": "host1",
+          "logTasks": [
+            {
+              "Tasks": {
+                "status": "PENDING",
+                "host_name": "host1",
+                "id": 1,
+                "request_id": 1
+              }
+            },
+            {
+              "Tasks": {
+                "status": "PENDING",
+                "host_name": "host1",
+                "id": 2,
+                "request_id": 1
+              }
+            }
+          ],
+          "isModified": true
+        },
+        "host2": {
+          "name": "host2",
+          "publicName": "host2",
+          "logTasks": [{"Tasks": {"status": "COMPLETED", "host_name": "host2", "id": 3, "request_id": 1}}],
+          "isModified": true
+        }
+      }));
+      expect(controller.generateTasksMapOfRequest(event, null).currentTaskStatusMap).to.be.eql({
+        "1": "PENDING",
+        "2": "PENDING",
+        "3": "COMPLETED"
+      });
+    });
+  });
+
+  describe('#convertTaskFromEventToApi', function() {
+
+    it('should return converted task object', function() {
+      expect(controller.convertTaskFromEventToApi({
+        status: 'PENDING',
+        hostName: 'host1',
+        id: 1,
+        requestId: 1
+      })).to.be.eql({
+          Tasks: {
+            status: 'PENDING',
+            host_name: 'host1',
+            id: 1,
+            request_id: 1
+          }
+        });
+    });
+  });
+
+  describe('#handleTaskUpdates', function() {
+    beforeEach(function() {
+      sinon.stub(controller, 'updateTask');
+      sinon.stub(App.StompClient, 'subscribe', function(arg1, clb) {
+        clb({status: 'COMPLETED', id: 1});
+      });
+      sinon.stub(App.StompClient, 'unsubscribe');
+    });
+    afterEach(function() {
+      controller.updateTask.restore();
+      App.StompClient.subscribe.restore();
+      App.StompClient.unsubscribe.restore();
+    });
+
+    it('should subscribe and when task is finished unsubscribe', function() {
+      controller.set('services', [Em.Object.create({
+        id: 1,
+        previousTaskStatusMap: {
+          1: 'PENDING'
+        }
+      })]);
+      controller.set('levelInfo', Em.Object.create({
+        name: 'TASK_DETAILS',
+        requestId: 1,
+        taskId: 1
+      }));
+      expect(App.StompClient.subscribe.calledWith('/events/tasks/1')).to.be.true;
+      expect(controller.updateTask.calledOnce).to.be.true;
+      expect(App.StompClient.unsubscribe.calledWith('/events/tasks/1')).to.be.true;
+    });
+  });
+
+  describe('#updateTask', function() {
+
+    it('should update task properties', function() {
+      var event = {
+        requestId: 1,
+        id: 1,
+        hostName: 'host1',
+        status: 'COMPLETED',
+        stdout: 'stdout',
+        stderr: 'stderr',
+        structured_out: 'structured_out',
+        outLog: 'outLog',
+        errorLog: 'errorLog'
+      };
+      controller.set('services', [Em.Object.create({
+        id: 1,
+        hostsMap: {
+          host1: {
+            logTasks: [
+              {
+                Tasks: {
+                  id: 1,
+                  requestId: 1,
+                  hostName: 'host1'
+                }
+              }
+            ]
+          }
+        }
+      })]);
+      controller.updateTask(event);
+      expect(controller.get('services').objectAt(0).get('hostsMap')['host1'].logTasks[0]).to.be.eql({
+        Tasks: {
+          requestId: 1,
+          id: 1,
+          hostName: 'host1',
+          status: 'COMPLETED',
+          stdout: 'stdout',
+          stderr: 'stderr',
+          structured_out: 'structured_out',
+          output_log: 'outLog',
+          error_log: 'errorLog'
+        }
+      });
+    });
+  });
 });
