@@ -67,6 +67,24 @@ describe('App.InstallerController', function () {
     });
   });
 
+  describe('#cancelInstall', function() {
+    var mock = {
+      goToAdminView: sinon.spy()
+    };
+    beforeEach(function() {
+      sinon.stub(App.router, 'get').returns(mock);
+    });
+    afterEach(function() {
+      App.router.get.restore();
+    });
+
+    it('goToAdminView should be called', function() {
+      var popup = installerController.cancelInstall();
+      popup.onPrimary();
+      expect(mock.goToAdminView.calledOnce).to.be.true;
+    });
+  });
+
   describe('#checkRepoURL', function() {
     var stacks = Em.A([
       Em.Object.create({
@@ -132,7 +150,7 @@ describe('App.InstallerController', function () {
                   "isEmpty": false,
                   "errorTitle": "",
                   "errorContent": "",
-                  "validation": "icon-repeat",
+                  "validation": "INPROGRESS",
                   "showRepo": true
                 }
               ]
@@ -223,7 +241,7 @@ describe('App.InstallerController', function () {
                   "isEmpty": false,
                   "errorTitle": "1",
                   "errorContent": "1",
-                  "validation": "icon-ok",
+                  "validation": "OK",
                   "showRepo": true
                 }
               ]
@@ -311,7 +329,7 @@ describe('App.InstallerController', function () {
                   "repoId": 11,
                   "errorTitle": "500:error",
                   "errorContent": "",
-                  "validation": "icon-exclamation-sign"
+                  "validation": "INVALID"
                 }
               ]
             }
@@ -464,35 +482,54 @@ describe('App.InstallerController', function () {
       var checker = {
         loadStacks: function() {
           return {
-            always: function() {
-              loadStacks = true;
+            done: function(callback) {
+              callback(true);
             }
           };
         }
       };
 
       beforeEach(function () {
+        sinon.spy(checker, 'loadStacks');
         installerController.loadMap['1'][0].callback.call(checker);
       });
 
-      it('stack info is loaded', function () {
-        expect(loadStacks).to.be.true;
+      afterEach(function() {
+        checker.loadStacks.restore();
+      });
+
+      it('should call loadStacks, stack info not loaded', function () {
+        expect(checker.loadStacks.calledOnce).to.be.true;
       });
     });
 
-    describe ('Should load stacks async', function() {
-      var loadStacksVersions = false;
+    describe('Should load stacks async', function() {
       var checker = {
-        loadStacksVersions: function() {
-          loadStacksVersions = true;
-        }
+        loadStacksVersions: Em.K
       };
 
+      beforeEach(function () {
+        sinon.stub(checker, 'loadStacksVersions').returns({
+          done: Em.clb
+        });
+      });
+
+      afterEach(function() {
+        checker.loadStacksVersions.restore();
+      });
+
       it('stack versions are loaded', function () {
         installerController.loadMap['1'][1].callback.call(checker, true).then(function(data){
           expect(data).to.be.true;
         });
-        expect(loadStacksVersions).to.be.false;
+        expect(checker.loadStacksVersions.called).to.be.false;
+      });
+
+      it('should call loadStacksVersions, stack versions not loaded', function () {
+        installerController.loadMap['1'][1].callback.call(checker, false).then(function(data){
+          expect(data).to.be.true;
+        });
+        expect(checker.loadStacksVersions.calledOnce).to.be.true;
       });
     });
 
@@ -777,23 +814,6 @@ describe('App.InstallerController', function () {
     });
   });
 
-  describe('#loadServiceConfigProperties', function() {
-    beforeEach(function () {
-      sinon.stub(installerController, 'getPersistentProperty').returns($.Deferred().resolve({
-        value: 2
-      }).promise());
-    });
-    afterEach(function () {
-      installerController.getPersistentProperty.restore();
-    });
-    it ('Should load service config property', function() {
-      installerController.loadServiceConfigProperties();
-      expect(installerController.get('content.serviceConfigProperties')).to.eql({
-        "value": 2
-      });
-    });
-  });
-
   describe('#saveServices', function() {
     it ('Should return correct names', function() {
       var stepController = Em.A([
@@ -1259,4 +1279,36 @@ describe('App.InstallerController', function () {
 
   });
 
+  describe('#finish', function() {
+    beforeEach(function() {
+      sinon.stub(installerController, 'setCurrentStep');
+      sinon.stub(installerController, 'clearStorageData');
+      sinon.stub(installerController, 'clearServiceConfigProperties');
+      sinon.stub(App.themesMapper, 'resetModels');
+      installerController.finish();
+    });
+    afterEach(function() {
+      installerController.setCurrentStep.restore();
+      installerController.clearStorageData.restore();
+      installerController.clearServiceConfigProperties.restore();
+      App.themesMapper.resetModels.restore();
+    });
+
+    it('setCurrentStep should be called', function() {
+      expect(installerController.setCurrentStep.calledWith('0')).to.be.true;
+    });
+
+    it('clearStorageData should be called', function() {
+      expect(installerController.clearStorageData.calledOnce).to.be.true;
+    });
+
+    it('clearServiceConfigProperties should be called', function() {
+      expect(installerController.clearServiceConfigProperties.calledOnce).to.be.true;
+    });
+
+    it('App.themesMapper.resetModels should be called', function() {
+      expect(App.themesMapper.resetModels.calledOnce).to.be.true;
+    });
+  });
+
 });
