@@ -246,6 +246,11 @@ describe('App.WidgetWizardStep2Controller', function () {
           isGraphDataComplete: false,
           title: 'label is empty'
         },
+        {
+          dataSets: [Em.Object.create({label: '<script>alert(\'hello\')</script>'})],
+          isGraphDataComplete: false,
+          title: 'not aalowed symbols'
+        },
         {
           dataSets: [Em.Object.create({label: 'abc'})],
           isExpressionComplete: false,
@@ -717,6 +722,7 @@ describe('App.WidgetWizardStep2Controller', function () {
           serviceName: 'S1',
           componentName: 'C1',
           metricPath: 'mp',
+          tag: 'tag',
           hostComponentCriteria: 'hcc',
           isMetric: true
         },
@@ -734,7 +740,8 @@ describe('App.WidgetWizardStep2Controller', function () {
             "service_name": "S1",
             "component_name": "C1",
             "metric_path": "mp",
-            "host_component_criteria": "hcc"
+            "host_component_criteria": "hcc",
+            tag: 'tag'
           }
         ],
         value: '${m1+10}'
