@@ -425,7 +425,8 @@ describe('validator', function () {
         { value: '[a1', expected: false },
         { value: 'a{1}', expected: true },
         { value: 'a{1,2}', expected: true },
-        { value: 'a{1,2}{', expected: false }
+        { value: 'a{1,2}{', expected: false },
+        { value: 'a(1)', expected: true }
       ];
     tests.forEach(function(test) {
       it(message.format(test.value, test.expected ? 'valid' : 'not valid'), function() {
@@ -501,6 +502,27 @@ describe('validator', function () {
     });
   });
 
+  describe('#isValidRackId()', function () {
+
+    [
+      {v: '', e: false},
+      {v: 'a', e: false},
+      {v: '1', e: false},
+      {v: '/', e: false},
+      {v: '/a', e: true},
+      {v: '/1', e: true},
+      {v: '/-', e: true},
+      {v: '/' + (new Array(255)).join('a'), m: 'Value bigger than 255 symbols', e: false}
+    ].forEach(function (test) {
+
+      it(test.m || test.v, function () {
+        expect(validator.isValidRackId(test.v)).to.be.equal(test.e);
+      })
+
+    });
+
+  });
+
   describe('#isValidAlertName', function () {
 
     [
@@ -522,4 +544,28 @@ describe('validator', function () {
 
   });
 
+  describe('#isValidAlertName', function () {
+
+    [
+      {v: '', e: false},
+      {v: 'test', e: true},
+      {v: 'Test', e: true},
+      {v: 'TEST', e: true},
+      {v: 'te-st', e: true},
+      {v: '-test', e: false},
+      {v: 'test-', e: false},
+      {v: '1', e: true},
+      {v: 'test1', e: true},
+      {v: '1-test', e: true}
+    ].forEach(function (test) {
+
+      it(test.m || test.v, function () {
+        expect(validator.isValidNameServiceId(test.v)).to.be.equal(test.e);
+      })
+
+    });
+
+
+  });
+
 });
